@@ -1,36 +1,19 @@
-/***************************************************************************
+/*
     File                 : CantorWorksheet.cpp
     Project              : LabPlot
     Description          : Aspect providing a Cantor Worksheets for Multiple backends
     --------------------------------------------------------------------
-    Copyright            : (C) 2015 Garvit Khatri (garvitdelhi@gmail.com)
-    Copyright            : (C) 2016 by Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2015 Garvit Khatri <garvitdelhi@gmail.com>
+    SPDX-FileCopyrightText: 2016 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 #include "CantorWorksheet.h"
 #include "VariableParser.h"
 #include "backend/core/column/Column.h"
 #include "backend/core/column/ColumnPrivate.h"
 #include "backend/core/Project.h"
+#include "backend/lib/XmlStreamReader.h"
 #include "commonfrontend/cantorWorksheet/CantorWorksheetView.h"
 
 #include <cantor/cantorlibs_version.h>
@@ -50,7 +33,6 @@
 #include <QModelIndex>
 
 #include <KLocalizedString>
-#include <KMessageBox>
 #include <KParts/ReadWritePart>
 
 CantorWorksheet::CantorWorksheet(const QString &name, bool loading)
@@ -64,23 +46,34 @@ CantorWorksheet::CantorWorksheet(const QString &name, bool loading)
 	initializes Cantor's part and plugins
 */
 bool CantorWorksheet::init(QByteArray* content) {
-	KPluginLoader loader(QLatin1String("cantorpart"));
+	DEBUG(Q_FUNC_INFO)
+	KPluginLoader loader(QLatin1String("kf5/parts/cantorpart"));
+	KPluginLoader oldLoader(QLatin1String("cantorpart"));	// old path
 	KPluginFactory* factory = loader.factory();
 
+	if (!factory) {	// try old path
+		WARN("Failed to load Cantor plugins; file name: " << STDSTRING(loader.fileName()))
+		WARN("Error message: " << STDSTRING(loader.errorString()))
+		factory = oldLoader.factory();
+	}
+
 	if (!factory) {
 		//we can only get to this here if we open a project having Cantor content and Cantor plugins were not found.
 		//return false here, a proper error message will be created in load() and propagated further.
-		WARN("Failed to load Cantor plugin:")
-		WARN("Cantor Part file name: " << STDSTRING(loader.fileName()))
-		WARN("	" << STDSTRING(loader.errorString()))
+		WARN("Failed to load Cantor plugins; file name: " << STDSTRING(oldLoader.fileName()))
+		WARN("Error message: " << STDSTRING(oldLoader.errorString()))
+		m_error = i18n("Couldn't find the dynamic library 'cantorpart'. Please check your installation.");
 		return false;
 	} else {
 		m_part = factory->create<KParts::ReadWritePart>(this, QVariantList() << m_backendName << QLatin1String("--noprogress"));
 		if (!m_part) {
-			DEBUG("Could not create the Cantor Part.")
+			WARN("Could not create the Cantor Part for backend " << STDSTRING(m_backendName))
+			m_error = i18n("Couldn't find the plugin for %1. Please check your installation.", m_backendName);
 			return false;
 		}
 		m_worksheetAccess = m_part->findChild<Cantor::WorksheetAccessInterface*>(Cantor::WorksheetAccessInterface::Name);
+		if (!m_worksheetAccess)
+			return false;
 
 		//load worksheet content if available
 		if (content)
@@ -90,68 +83,164 @@ bool CantorWorksheet::init(QByteArray* content) {
 
 		//Cantor's session
 		m_session = m_worksheetAccess->session();
-		connect(m_session, SIGNAL(statusChanged(Cantor::Session::Status)), this, SIGNAL(statusChanged(Cantor::Session::Status)));
+		if (m_session) {
+			connect(m_session, &Cantor::Session::statusChanged, this, &CantorWorksheet::statusChanged);
 
-		//variable model
-		m_variableModel = m_session->variableDataModel();
-		connect(m_variableModel, &QAbstractItemModel::dataChanged, this, &CantorWorksheet::dataChanged);
-		connect(m_variableModel, &QAbstractItemModel::rowsInserted, this, &CantorWorksheet::rowsInserted);
-		connect(m_variableModel, &QAbstractItemModel::rowsAboutToBeRemoved, this, &CantorWorksheet::rowsAboutToBeRemoved);
-		connect(m_variableModel, &QAbstractItemModel::modelReset, this, &CantorWorksheet::modelReset);
-
-		//available plugins
-#ifdef HAVE_NEW_CANTOR_LIBS
-		auto* handler = new Cantor::PanelPluginHandler(this);
-		handler->loadPlugins();
-		m_plugins = handler->activePluginsForSession(m_session, Cantor::PanelPluginHandler::PanelStates());
-		for (auto* plugin : m_plugins)
-			plugin->connectToShell(m_part);
-#else
-		auto* handler = m_part->findChild<Cantor::PanelPluginHandler*>(QLatin1String("PanelPluginHandler"));
-		if (!handler) {
-			KMessageBox::error(nullptr, i18n("No PanelPluginHandle found for the Cantor Part."));
-			return false;
+			//variable model
+			m_variableModel = m_session->variableDataModel();
+			connect(m_variableModel, &QAbstractItemModel::dataChanged, this, &CantorWorksheet::dataChanged);
+			connect(m_variableModel, &QAbstractItemModel::rowsInserted, this, &CantorWorksheet::rowsInserted);
+			connect(m_variableModel, &QAbstractItemModel::rowsAboutToBeRemoved, this, &CantorWorksheet::rowsAboutToBeRemoved);
+			connect(m_variableModel, &QAbstractItemModel::modelReset, this, &CantorWorksheet::modelReset);
 		}
-		m_plugins = handler->plugins();
-#endif
+
+		//default settings
+		const KConfigGroup group = KSharedConfig::openConfig()->group(QLatin1String("Settings_Notebook"));
+
+		//TODO: right now we don't have the direct accces to Cantor's worksheet and to all its public methods
+		//and we need to go through the actions provided in cantor_part.
+		//-> redesign this! expose Cantor's Worksheet directly and add more settings here.
+		auto* action = m_part->action("enable_highlighting");
+		if (action) {
+			bool value = group.readEntry(QLatin1String("SyntaxHighlighting"), false);
+			action->setChecked(value);
+		}
+
+		action = m_part->action("enable_completion");
+		if (action) {
+			bool value = group.readEntry(QLatin1String("SyntaxCompletion"), false);
+			action->setChecked(value);
+		}
+
+		action = m_part->action("enable_expression_numbers");
+		if (action) {
+			bool value = group.readEntry(QLatin1String("LineNumbers"), false);
+			action->setChecked(value);
+		}
+
+		action = m_part->action("enable_typesetting");
+		if (action) {
+			bool value = group.readEntry(QLatin1String("LatexTypesetting"), false);
+			action->setChecked(value);
+		}
+
+		action = m_part->action("enable_animations");
+		if (action) {
+			bool value = group.readEntry(QLatin1String("Animations"), false);
+			action->setChecked(value);
+		}
+
+		//bool value = group.readEntry(QLatin1String("ReevaluateEntries"), false);
+		//value = group.readEntry(QLatin1String("AskConfirmation"), true);
 	}
 
 	return true;
 }
 
+const QString& CantorWorksheet::error() const {
+	return m_error;
+}
+
 //SLots
 void CantorWorksheet::dataChanged(const QModelIndex& index) {
 	const QString& name = m_variableModel->data(m_variableModel->index(index.row(), 0)).toString();
 	Column* col = child<Column>(name);
-	if (col) {
-		// Cantor::DefaultVariableModel::DataRole == 257
-		QVariant dataValue = m_variableModel->data(m_variableModel->index(index.row(), 1), 257);
-		if (dataValue.isNull())
-			dataValue = m_variableModel->data(m_variableModel->index(index.row(), 1));
-		const QString& value = dataValue.toString();
-		VariableParser parser(m_backendName, value);
-		if (parser.isParsed())
-			col->replaceValues(0, parser.values());
-	}
+	if (!col)
+		return;
 
+	QVariant dataValue = m_variableModel->data(m_variableModel->index(index.row(), 1), 257); //Cantor::DefaultVariableModel::DataRole == 257
+	if (dataValue.isNull())
+		dataValue = m_variableModel->data(m_variableModel->index(index.row(), 1));
+
+	const QString& value = dataValue.toString();
+	VariableParser parser(m_backendName, value);
+	if (parser.isParsed()) {
+		switch(parser.dataType()) {
+		case AbstractColumn::ColumnMode::Integer:
+			col->setColumnMode(AbstractColumn::ColumnMode::Integer);
+			col->replaceInteger(0, parser.integers());
+			break;
+		case AbstractColumn::ColumnMode::BigInt:
+			col->setColumnMode(AbstractColumn::ColumnMode::BigInt);
+			col->replaceBigInt(0, parser.bigInt());
+			break;
+		case AbstractColumn::ColumnMode::Double:
+			col->setColumnMode(AbstractColumn::ColumnMode::Double);
+			col->replaceValues(0, parser.doublePrecision());
+			break;
+		case AbstractColumn::ColumnMode::Month:
+		case AbstractColumn::ColumnMode::Day:
+		case AbstractColumn::ColumnMode::DateTime:
+			col->setColumnMode(AbstractColumn::ColumnMode::DateTime);
+			col->replaceDateTimes(0, parser.dateTime());
+			break;
+		case AbstractColumn::ColumnMode::Text:
+			col->setColumnMode(AbstractColumn::ColumnMode::Text);
+			col->replaceTexts(0, parser.text());
+			break;
+		}
+	}
 }
 
-void CantorWorksheet::rowsInserted(const QModelIndex& parent, int first, int last) {
-	Q_UNUSED(parent)
+void CantorWorksheet::rowsInserted(const QModelIndex& /*parent*/, int first, int last) {
 	for (int i = first; i <= last; ++i) {
 		const QString& name = m_variableModel->data(m_variableModel->index(i, 0)).toString();
 		QVariant dataValue = m_variableModel->data(m_variableModel->index(i, 1), 257);
 		if (dataValue.isNull())
 			dataValue = m_variableModel->data(m_variableModel->index(i, 1));
+
 		const QString& value = dataValue.toString();
 		VariableParser parser(m_backendName, value);
+
 		if (parser.isParsed()) {
 			Column* col = child<Column>(name);
 			if (col) {
-				col->replaceValues(0, parser.values());
+				switch(parser.dataType()) {
+					case AbstractColumn::ColumnMode::Integer:
+					col->setColumnMode(AbstractColumn::ColumnMode::Integer);
+					col->replaceInteger(0, parser.integers());
+					break;
+				case AbstractColumn::ColumnMode::BigInt:
+					col->setColumnMode(AbstractColumn::ColumnMode::BigInt);
+					col->replaceBigInt(0, parser.bigInt());
+					break;
+				case AbstractColumn::ColumnMode::Double:
+					col->setColumnMode(AbstractColumn::ColumnMode::Double);
+					col->replaceValues(0, parser.doublePrecision());
+					break;
+				case AbstractColumn::ColumnMode::Month:
+				case AbstractColumn::ColumnMode::Day:
+				case AbstractColumn::ColumnMode::DateTime:
+					col->setColumnMode(AbstractColumn::ColumnMode::DateTime);
+					col->replaceDateTimes(0, parser.dateTime());
+					break;
+				case AbstractColumn::ColumnMode::Text:
+					col->setColumnMode(AbstractColumn::ColumnMode::Text);
+					col->replaceTexts(0, parser.text());
+					break;
+				}
 			} else {
-				col = new Column(name, parser.values());
+				switch(parser.dataType()) {
+					case AbstractColumn::ColumnMode::Integer:
+					col = new Column(name, parser.integers());
+					break;
+				case AbstractColumn::ColumnMode::BigInt:
+					col = new Column(name, parser.bigInt());
+					break;
+				case AbstractColumn::ColumnMode::Double:
+					col = new Column(name, parser.doublePrecision());
+					break;
+				case AbstractColumn::ColumnMode::Month:
+				case AbstractColumn::ColumnMode::Day:
+				case AbstractColumn::ColumnMode::DateTime:
+					col = new Column(name, parser.dateTime(), parser.dataType());
+					break;
+				case AbstractColumn::ColumnMode::Text:
+					col = new Column(name, parser.text());
+					break;
+				}
 				col->setUndoAware(false);
+				col->setFixed(true);
 				addChild(col);
 
 				//TODO: Cantor currently ignores the order of variables in the worksheets
@@ -175,13 +264,11 @@ void CantorWorksheet::modified() {
 }
 
 void CantorWorksheet::modelReset() {
-	for (int i = 0; i < childCount<Column>(); ++i)
-		child<Column>(i)->remove();
+	for (auto* column : children<Column>())
+		column->remove();
 }
 
-void CantorWorksheet::rowsAboutToBeRemoved(const QModelIndex & parent, int first, int last) {
-	Q_UNUSED(parent);
-
+void CantorWorksheet::rowsAboutToBeRemoved(const QModelIndex& /*parent*/, int first, int last) {
 	for (int i = first; i <= last; ++i) {
 		const QString& name = m_variableModel->data(m_variableModel->index(first, 0)).toString();
 		Column* column = child<Column>(name);
@@ -191,6 +278,25 @@ void CantorWorksheet::rowsAboutToBeRemoved(const QModelIndex & parent, int first
 }
 
 QList<Cantor::PanelPlugin*> CantorWorksheet::getPlugins() {
+	if (!m_pluginsLoaded) {
+#ifdef HAVE_NEW_CANTOR_LIBS
+		auto* handler = new Cantor::PanelPluginHandler(this);
+		handler->loadPlugins();
+		m_plugins = handler->activePluginsForSession(m_session, Cantor::PanelPluginHandler::PanelStates());
+		for (auto* plugin : m_plugins)
+			plugin->connectToShell(m_part);
+#else
+		auto* handler = m_part->findChild<Cantor::PanelPluginHandler*>(QLatin1String("PanelPluginHandler"));
+		if (!handler) {
+			m_error = i18n("Couldn't find panel plugins. Please check your installation.");
+			return false;
+		}
+		m_plugins = handler->plugins();
+#endif
+
+		m_pluginsLoaded = true;
+	}
+
 	return m_plugins;
 }
 
@@ -201,7 +307,7 @@ KParts::ReadWritePart* CantorWorksheet::part() {
 QIcon CantorWorksheet::icon() const {
 	if (m_session)
 		return QIcon::fromTheme(m_session->backend()->icon());
-	return QIcon();
+	return {};
 }
 
 QWidget* CantorWorksheet::view() const {
@@ -212,11 +318,13 @@ QWidget* CantorWorksheet::view() const {
 		// 	connect(m_view, SIGNAL(statusInfo(QString)), this, SIGNAL(statusInfo(QString)));
 
 		//set the current path in the session to the path of the project file
-		const Project* project = const_cast<CantorWorksheet*>(this)->project();
-		const QString& fileName = project->fileName();
-		if (!fileName.isEmpty()) {
-			QFileInfo fi(fileName);
-			m_session->setWorksheetPath(fi.filePath());
+		if (m_session) {
+			const Project* project = const_cast<CantorWorksheet*>(this)->project();
+			const QString& fileName = project->fileName();
+			if (!fileName.isEmpty()) {
+				QFileInfo fi(fileName);
+				m_session->setWorksheetPath(fi.filePath());
+			}
 		}
 	}
 	return m_partView;
@@ -229,7 +337,7 @@ QWidget* CantorWorksheet::view() const {
 QMenu* CantorWorksheet::createContextMenu() {
 	QMenu* menu = AbstractPart::createContextMenu();
 	Q_ASSERT(menu);
-	emit requestProjectContextMenu(menu);
+	Q_EMIT requestProjectContextMenu(menu);
 	return menu;
 }
 
@@ -252,6 +360,14 @@ bool CantorWorksheet::printPreview() const {
 	return true;
 }
 
+void CantorWorksheet::evaluate() {
+	m_part->action("evaluate_worksheet")->trigger();
+}
+
+void CantorWorksheet::restart() {
+	m_part->action("restart_backend")->trigger();
+}
+
 //##############################################################################
 //##################  Serialization/Deserialization  ###########################
 //##############################################################################
@@ -338,6 +454,7 @@ bool CantorWorksheet::load(XmlStreamReader* reader, bool preview) {
 				delete column;
 				return false;
 			}
+			column->setFixed(true);
 			addChild(column);
 		} else { // unknown element
 			reader->raiseWarning(i18n("unknown element '%1'", reader->name().toString()));
