@@ -1,49 +1,29 @@
-/***************************************************************************
+/*
     File                 : AbstractAspect.cpp
     Project              : LabPlot
-    --------------------------------------------------------------------
-    Copyright            : (C) 2007-2009 by Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2007-2010 by Knut Franke (knut.franke@gmx.de)
-    Copyright            : (C) 2011-2016 by Alexander Semke (alexander.semke@web.de)
     Description          : Base class for all objects in a Project.
- ***************************************************************************/
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2007-2009 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2007-2010 Knut Franke <knut.franke@gmx.de>
+    SPDX-FileCopyrightText: 2011-2021 Alexander Semke <alexander.semke@web.de>
 
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "backend/core/AbstractAspect.h"
 #include "backend/core/AspectPrivate.h"
+#include "backend/core/AspectFactory.h"
 #include "backend/core/aspectcommands.h"
 #include "backend/core/Project.h"
-#include "backend/datapicker/DatapickerCurve.h"
-#include "backend/datasources/LiveDataSource.h"
-#include "backend/spreadsheet/Spreadsheet.h"
+#include "backend/lib/trace.h"
 #include "backend/lib/XmlStreamReader.h"
 #include "backend/lib/SignallingUndoCommand.h"
 #include "backend/lib/PropertyChangeCommand.h"
-#ifdef HAVE_MQTT
-#include "backend/datasources/MQTTClient.h"
-#include "backend/datasources/MQTTSubscription.h"
-#include "backend/datasources/MQTTTopic.h"
-#endif
 
+#include <QClipboard>
 #include <QMenu>
+#include <QMimeData>
+#include <KStandardAction>
 
 /**
  * \class AbstractAspect
@@ -231,7 +211,7 @@ bool AbstractAspect::setName(const QString &value, bool autoUnique) {
 
 	QString new_name;
 	if (d->m_parent) {
-			new_name = d->m_parent->uniqueNameFor(value);
+		new_name = d->m_parent->uniqueNameFor(value);
 
 		if (!autoUnique && new_name.compare(value) != 0) // value is not unique, so don't change name
 			return false; // this value is used in the dock to check if the name is valid
@@ -280,6 +260,27 @@ void AbstractAspect::setHidden(bool value) {
 	d->m_hidden = value;
 }
 
+/**
+ * \brief Set "fixed" property which defines whether the object can be renamed, deleted, etc.
+ */
+void AbstractAspect::setFixed(bool value) {
+	if (value == d->m_fixed)
+		return;
+	d->m_fixed = value;
+}
+
+bool AbstractAspect::isFixed() const {
+	return d->m_fixed;
+}
+
+void AbstractAspect::setMoved(bool value) {
+	d->m_moved = value;
+}
+
+bool AbstractAspect::isMoved() const {
+	return d->m_moved;
+}
+
 void AbstractAspect::setIsLoading(bool load) {
 	d->m_isLoading = load;
 }
@@ -292,7 +293,7 @@ bool AbstractAspect::isLoading() const {
  * \brief Return an icon to be used for decorating my views.
  */
 QIcon AbstractAspect::icon() const {
-	return QIcon();
+	return {};
 }
 
 /**
@@ -306,31 +307,77 @@ QMenu* AbstractAspect::createContextMenu() {
 
 	//TODO: activate this again when the functionality is implemented
 // 	menu->addAction( KStandardAction::cut(this) );
-// 	menu->addAction(KStandardAction::copy(this));
-// 	menu->addAction(KStandardAction::paste(this));
-// 	menu->addSeparator();
 
-	//don't allow to rename and delete
-	// - data spreadsheets of datapicker curves
-	// - columns in data spreadsheets of datapicker curves
+	if (!isFixed() && m_type != AspectType::Project && m_type != AspectType::CantorWorksheet) {
+		//copy action:
+		//don't allow to copy fixed aspects
+		auto* action = KStandardAction::copy(this);
+		connect(action, &QAction::triggered, this, &AbstractAspect::copy);
+		menu->addAction(action);
+
+		//duplicate action:
+		//don't allow to duplicate legends in the plots
+		if (m_type != AspectType::CartesianPlotLegend) {
+			auto* actionDuplicate = new QAction(QIcon::fromTheme(QLatin1String("edit-copy")), i18n("Duplicate Here"), this);
+			actionDuplicate->setShortcut(Qt::CTRL + Qt::Key_D);
+			connect(actionDuplicate, &QAction::triggered, this, &AbstractAspect::duplicate);
+			menu->addAction(actionDuplicate);
+		}
+	}
+
+	//paste action:
+	//determine the aspect type of the content available in the clipboard
+	//and enable the paste entry if the content is labplot specific
+	//and if it can be pasted into the current aspect
+	QString name;
+	auto t = clipboardAspectType(name);
+	if (t != AspectType::AbstractAspect && pasteTypes().indexOf(t) != -1) {
+		auto* action = KStandardAction::paste(this);
+		action->setText(i18n("Paste '%1'", name));
+		menu->addAction(action);
+		connect(action, &QAction::triggered, this, &AbstractAspect::paste);
+	}
+	menu->addSeparator();
+
+	//don't allow to rename and delete fixed objects and
 	// - columns in live-data source
 	// - Mqtt subscriptions
 	// - Mqtt topics
 	// - Columns in Mqtt topics
-	bool enabled = !(dynamic_cast<const Spreadsheet*>(this) && dynamic_cast<const DatapickerCurve*>(this->parentAspect()))
-		&& !(dynamic_cast<const Column*>(this) && this->parentAspect()->parentAspect() && dynamic_cast<const DatapickerCurve*>(this->parentAspect()->parentAspect()))
-		&& !(dynamic_cast<const Column*>(this) && dynamic_cast<const LiveDataSource*>(this->parentAspect()))
+	//TODO: make also these objects fixed and remove this additional handling for them here
+	bool disabled = isFixed()
+		|| (m_type == AspectType::Column && parentAspect()->type() == AspectType::LiveDataSource)
 #ifdef HAVE_MQTT
-		&& !dynamic_cast<const MQTTSubscription*>(this)
-		&& !dynamic_cast<const MQTTTopic*>(this)
-		&& !(dynamic_cast<const Column*>(this) && dynamic_cast<const MQTTTopic*>(this->parentAspect()))
+		|| (m_type == AspectType::MQTTSubscription)
+		|| (m_type == AspectType::MQTTTopic)
+		| (m_type == AspectType::Column && parentAspect()->type() == AspectType::MQTTTopic)
 #endif
 		;
 
-	if(enabled) {
-		menu->addAction(QIcon::fromTheme(QLatin1String("edit-rename")), i18n("Rename"), this, SIGNAL(renameRequested()));
-		if (type() != AspectType::Project)
-			menu->addAction(QIcon::fromTheme(QLatin1String("edit-delete")), i18n("Delete"), this, SLOT(remove()));
+	if (disabled)
+		return menu;
+
+	//rename and delete actions:
+	menu->addAction(QIcon::fromTheme(QLatin1String("edit-rename")), i18n("Rename"), this, &AbstractAspect::renameRequested);
+	if (m_type != AspectType::Project)
+		menu->addAction(QIcon::fromTheme(QLatin1String("edit-delete")), i18n("Delete"), this, &AbstractAspect::remove);
+
+	//move up and down actions:
+	//don't shown them for worksheet elements since they implement their own "Drawing order" menu
+	if (!dynamic_cast<WorksheetElement*>(this) && this != project()) {
+		const auto* parent = parentAspect();
+		int count = parent->childCount<AbstractAspect>();
+		if (count > 1) {
+			auto* moveMenu = new QMenu(i18n("Move"));
+			moveMenu->setIcon(QIcon::fromTheme("layer-bottom"));
+			if (parent->indexOfChild<AbstractAspect>(this) != 0)
+				moveMenu->addAction(QIcon::fromTheme(QLatin1String("draw-arrow-up")), i18n("Up"), this, &AbstractAspect::moveUp);
+
+			if (parent->indexOfChild<AbstractAspect>(this) != count - 1)
+				moveMenu->addAction(QIcon::fromTheme(QLatin1String("draw-arrow-down")), i18n("Down"), this, &AbstractAspect::moveDown);
+			menu->addSeparator();
+			menu->addMenu(moveMenu);
+		}
 	}
 
 	return menu;
@@ -340,7 +387,6 @@ AspectType AbstractAspect::type() const {
 	return m_type;
 }
 
-
 bool AbstractAspect::inherits(AspectType type) const {
 	return (static_cast<quint64>(m_type) & static_cast<quint64>(type)) == static_cast<quint64>(type);
 }
@@ -418,7 +464,7 @@ QString AbstractAspect::path() const {
 void AbstractAspect::addChild(AbstractAspect* child) {
 	Q_CHECK_PTR(child);
 
-	QString new_name = uniqueNameFor(child->name());
+	const QString new_name = uniqueNameFor(child->name());
 	beginMacro(i18n("%1: add %2", name(), new_name));
 	if (new_name != child->name()) {
 		info(i18n(R"(Renaming "%1" to "%2" in order to avoid name collision.)", child->name(), new_name));
@@ -426,7 +472,6 @@ void AbstractAspect::addChild(AbstractAspect* child) {
 	}
 
 	exec(new AspectChildAddCmd(d, child, d->m_children.count()));
-	child->finalizeAdd();
 	endMacro();
 }
 
@@ -434,10 +479,12 @@ void AbstractAspect::addChild(AbstractAspect* child) {
  * \brief Add the given Aspect to my list of children without any checks and without putting this step onto the undo-stack
  */
 void AbstractAspect::addChildFast(AbstractAspect* child) {
-	emit aspectAboutToBeAdded(this, nullptr, child); //TODO: before-pointer is 0 here, also in the commands classes. why?
+	Q_EMIT aspectAboutToBeAdded(this, nullptr, child); //TODO: before-pointer is 0 here, also in the commands classes. why?
 	d->insertChild(d->m_children.count(), child);
 	child->finalizeAdd();
-	emit aspectAdded(child);
+	//PERFTRACE(Q_FUNC_INFO);
+	Q_EMIT aspectAdded(child);
+	//print_callstack();
 }
 
 /**
@@ -471,9 +518,10 @@ void AbstractAspect::insertChildBeforeFast(AbstractAspect* child, AbstractAspect
 	if (index == -1)
 		index = d->m_children.count();
 
-	emit aspectAboutToBeAdded(this, nullptr, child);
+	Q_EMIT aspectAboutToBeAdded(this, nullptr, child);
 	d->insertChild(index, child);
-	emit aspectAdded(child);
+	child->finalizeAdd();
+	Q_EMIT aspectAdded(child);
 }
 
 /**
@@ -484,17 +532,9 @@ void AbstractAspect::insertChildBeforeFast(AbstractAspect* child, AbstractAspect
  * \sa reparent()
  */
 void AbstractAspect::removeChild(AbstractAspect* child) {
+	QDEBUG(Q_FUNC_INFO << ", CHILD =" << child << ", PARENT =" << child->parentAspect())
 	Q_ASSERT(child->parentAspect() == this);
 
-	//when the child being removed is a LiveDataSource or a MQTT client,
-	//stop reading from the source before removing the child from the project
-	if (child->type() == AspectType::LiveDataSource)
-		static_cast<LiveDataSource*>(child)->pauseReading();
-#ifdef HAVE_MQTT
-	else if (child->type() == AspectType::MQTTClient)
-		static_cast<MQTTClient*>(child)->pauseReading();
-#endif
-
 	beginMacro(i18n("%1: remove %2", name(), child->name()));
 	exec(new AspectChildRemoveCmd(d, child));
 	endMacro();
@@ -516,9 +556,9 @@ void AbstractAspect::removeAllChildren() {
 	}
 
 	while (current) {
-		emit aspectAboutToBeRemoved(current);
+		Q_EMIT aspectAboutToBeRemoved(current);
 		exec(new AspectChildRemoveCmd(d, current));
-		emit aspectRemoved(this, nextSibling, current);
+		Q_EMIT aspectRemoved(this, nextSibling, current);
 
 		current = nextSibling;
 		if (i != children_list.constEnd() && ++i != children_list.constEnd())
@@ -546,23 +586,23 @@ void AbstractAspect::reparent(AbstractAspect* newParent, int newIndex) {
 // 	auto* old_sibling = old_parent->child<AbstractAspect>(old_index+1, IncludeHidden);
 // 	auto* new_sibling = newParent->child<AbstractAspect>(newIndex, IncludeHidden);
 
-// 	emit newParent->aspectAboutToBeAdded(newParent, new_sibling, this);
+// 	Q_EMIT newParent->aspectAboutToBeAdded(newParent, new_sibling, this);
 	exec(new AspectChildReparentCmd(parentAspect()->d, newParent->d, this, newIndex));
-// 	emit old_parent->aspectRemoved(old_parent, old_sibling, this);
+// 	Q_EMIT old_parent->aspectRemoved(old_parent, old_sibling, this);
 }
 
 QVector<AbstractAspect*> AbstractAspect::children(AspectType type, ChildIndexFlags flags) const {
 	QVector<AbstractAspect*> result;
 	for (auto* child : children()) {
 		if (flags & ChildIndexFlag::IncludeHidden || !child->hidden()) {
-			if (child->inherits(type) || !(flags & ChildIndexFlag::Compress)) {
+			if (child->inherits(type))
 				result << child;
-				if (flags & ChildIndexFlag::Recursive) {
-					result << child->children(type, flags);
-				}
-			}
+
+			if (flags & ChildIndexFlag::Recursive)
+				result << child->children(type, flags);
 		}
 	}
+
 	return result;
 }
 
@@ -579,6 +619,30 @@ void AbstractAspect::remove() {
 		parentAspect()->removeChild(this);
 }
 
+void AbstractAspect::moveUp() {
+	auto* parent = parentAspect();
+	int index = parent->indexOfChild<AbstractAspect>(this);
+	auto* sibling = parent->child<AbstractAspect>(index - 1);
+	beginMacro(i18n("%1: move up", name()));
+	setMoved(true);
+	remove();
+	parent->insertChildBefore(this, sibling);
+	setMoved(false);
+	endMacro();
+}
+
+void AbstractAspect::moveDown() {
+	auto* parent = parentAspect();
+	int index = parent->indexOfChild<AbstractAspect>(this);
+	auto* sibling = parent->child<AbstractAspect>(index + 2);
+	beginMacro(i18n("%1: move down", name()));
+	setMoved(true);
+	remove();
+	parent->insertChildBefore(this, sibling);
+	setMoved(false);
+	endMacro();
+}
+
 /*!
  * returns the list of all parent aspects (folders and sub-folders)
  */
@@ -590,12 +654,161 @@ QVector<AbstractAspect*> AbstractAspect::dependsOn() const {
 	return aspects;
 }
 
+/*!
+ * return the list of all aspect types that can be copy&pasted into the current aspect.
+ * returns an empty list on default, needs to be re-implemented in all derived classes
+ * that want to allow other aspects to be pasted into.
+ */
+QVector<AspectType> AbstractAspect::pasteTypes() const {
+	return {};
+}
+
+void AbstractAspect::setPasted(bool pasted) {
+	d->m_pasted = pasted;
+}
+
+bool AbstractAspect::pasted() const {
+	return d->m_pasted;
+}
+
+/*!
+ * copies the aspect to the clipboard. The standard XML-serialization
+ * via AbstractAspect::load() is used.
+ */
+void AbstractAspect::copy() const {
+	QString output;
+	QXmlStreamWriter writer(&output);
+	writer.writeStartDocument();
+
+	//add LabPlot's copy&paste "identifier"
+	writer.writeDTD(QLatin1String("<!DOCTYPE LabPlotCopyPasteXML>"));
+	writer.writeStartElement("copy_content"); //root element
+
+	//write the type of the copied aspect
+	writer.writeStartElement(QLatin1String("type"));
+	writer.writeAttribute(QLatin1String("value"), QString::number(static_cast<int>(m_type)));
+	writer.writeEndElement();
+
+	//write the aspect itself
+	save(&writer);
+
+	writer.writeEndElement(); //end the root-element
+	writer.writeEndDocument();
+	QApplication::clipboard()->setText(output);
+}
+
+void AbstractAspect::duplicate() {
+	copy();
+	parentAspect()->paste(true);
+}
+
+/*!
+ * in case the clipboard containts a LabPlot's specific copy&paste content,
+ * this function deserializes the XML string and adds the created aspect as
+ * a child to the current aspect ("paste").
+ */
+void AbstractAspect::paste(bool duplicate) {
+	const QClipboard* clipboard = QApplication::clipboard();
+	const QMimeData* mimeData = clipboard->mimeData();
+	if (!mimeData->hasText())
+		return;
+
+	const QString& xml = clipboard->text();
+	if (!xml.startsWith(QLatin1String("<?xml version=\"1.0\"?><!DOCTYPE LabPlotCopyPasteXML>")))
+		return;
+
+	WAIT_CURSOR;
+	AbstractAspect* aspect = nullptr;
+	XmlStreamReader reader(xml);
+	while (!reader.atEnd()) {
+		reader.readNext();
+
+		if (!reader.isStartElement())
+			continue;
+
+		if (reader.name() == QLatin1String("type")) {
+			auto attribs = reader.attributes();
+			auto type = static_cast<AspectType>(attribs.value(QLatin1String("value")).toInt());
+			if (type != AspectType::AbstractAspect)
+				aspect = AspectFactory::createAspect(type, this);
+		} else {
+			if (aspect) {
+				aspect->setPasted(true);
+				aspect->load(&reader, false);
+				break;
+			}
+		}
+	}
+
+	if (aspect) {
+		if (!duplicate)
+			beginMacro(i18n("%1: pasted '%2'", name(), aspect->name()));
+		else {
+			beginMacro(i18n("%1: duplicated '%2'", name(), aspect->name()));
+			aspect->setName(i18n("Copy of '%1'", aspect->name()));
+		}
+
+		if (aspect->type() != AspectType::CartesianPlotLegend)
+			addChild(aspect);
+		else {
+			//spectial handling for the legend since only one single
+			//legend object is allowed per plot
+			auto* plot = static_cast<CartesianPlot*>(this);
+			auto* legend = static_cast<CartesianPlotLegend*>(aspect);
+			plot->addLegend(legend);
+		}
+
+		project()->restorePointers(aspect);
+		project()->retransformElements(aspect);
+		aspect->setPasted(false);
+		endMacro();
+	}
+	RESET_CURSOR;
+}
+
+/*!
+ * helper function determening whether the current content of the clipboard
+ * contants the labplot specific copy&paste XML content. In case a valid content
+ * is available, the aspect type of the object to be pasted is returned.
+ * AspectType::AbstractAspect is returned otherwise.
+ */
+AspectType AbstractAspect::clipboardAspectType(QString& name) {
+	AspectType type = AspectType::AbstractAspect;
+	const QClipboard* clipboard = QApplication::clipboard();
+	const QMimeData* mimeData = clipboard->mimeData();
+	if (!mimeData->hasText())
+		return type;
+
+	const QString& xml = clipboard->text();
+	if (!xml.startsWith(QLatin1String("<?xml version=\"1.0\"?><!DOCTYPE LabPlotCopyPasteXML>")))
+		return type;
+
+	XmlStreamReader reader(xml);
+	bool typeFound = false;
+	while (!reader.atEnd()) {
+		reader.readNext();
+		if (reader.isStartElement()) {
+			auto attribs = reader.attributes();
+			if (reader.name() == QLatin1String("type")) {
+				type = static_cast<AspectType>(attribs.value(QLatin1String("value")).toInt());
+				typeFound = true;
+			} else {
+				name = attribs.value(QLatin1String("name")).toString();
+				if (typeFound)
+					break;
+			}
+		}
+	}
+
+	return type;
+}
+
 bool AbstractAspect::isDraggable() const {
 	return false;
 }
 
 QVector<AspectType> AbstractAspect::dropableOn() const {
-	return QVector<AspectType>();
+	return {};
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -792,9 +1005,9 @@ void AbstractAspect::endMacro() {
  */
 void AbstractAspect::setSelected(bool s) {
 	if (s)
-		emit selected(this);
+		Q_EMIT selected(this);
 	else
-		emit deselected(this);
+		Q_EMIT deselected(this);
 }
 
 void AbstractAspect::childSelected(const AbstractAspect* aspect) {
@@ -805,12 +1018,13 @@ void AbstractAspect::childSelected(const AbstractAspect* aspect) {
 	//* XYFitCurve with the child column for calculated residuals
 	//* XYSmouthCurve with the child column for calculated rough values
 	//* CantorWorksheet with the child columns for CAS variables
-	if (aspect->parentAspect()
-		&& !aspect->parentAspect()->inherits(AspectType::Folder)
-		&& !aspect->parentAspect()->inherits(AspectType::XYFitCurve)
-		&& !aspect->parentAspect()->inherits(AspectType::XYSmoothCurve)
-		&& !aspect->parentAspect()->inherits(AspectType::CantorWorksheet))
-		emit aspect->parentAspect()->selected(aspect);
+    AbstractAspect* parent = this->parentAspect();
+	if (parent
+		&& !parent->inherits(AspectType::Folder)
+		&& !parent->inherits(AspectType::XYFitCurve)
+		&& !parent->inherits(AspectType::XYSmoothCurve)
+		&& !parent->inherits(AspectType::CantorWorksheet))
+		Q_EMIT this->selected(aspect);
 }
 
 void AbstractAspect::childDeselected(const AbstractAspect* aspect) {
@@ -821,12 +1035,13 @@ void AbstractAspect::childDeselected(const AbstractAspect* aspect) {
 	//* XYFitCurve with the child column for calculated residuals
 	//* XYSmouthCurve with the child column for calculated rough values
 	//* CantorWorksheet with the child columns for CAS variables
-	if (aspect->parentAspect()
-		&& !aspect->parentAspect()->inherits(AspectType::Folder)
-		&& !aspect->parentAspect()->inherits(AspectType::XYFitCurve)
-		&& !aspect->parentAspect()->inherits(AspectType::XYSmoothCurve)
-		&& !aspect->parentAspect()->inherits(AspectType::CantorWorksheet))
-		emit aspect->parentAspect()->deselected(aspect);
+    AbstractAspect* parent = this->parentAspect();
+	if (parent
+		&& !parent->inherits(AspectType::Folder)
+		&& !parent->inherits(AspectType::XYFitCurve)
+		&& !parent->inherits(AspectType::XYSmoothCurve)
+		&& !parent->inherits(AspectType::CantorWorksheet))
+		Q_EMIT this->deselected(aspect);
 }
 
 /**
@@ -896,7 +1111,7 @@ AbstractAspectPrivate::AbstractAspectPrivate(AbstractAspect* owner, const QStrin
 }
 
 AbstractAspectPrivate::~AbstractAspectPrivate() {
-	for (auto* child : m_children)
+	for (auto* child : qAsConst(m_children))
 		delete child;
 }
 
@@ -918,10 +1133,12 @@ int AbstractAspectPrivate::indexOfChild(const AbstractAspect* child) const {
 }
 
 int AbstractAspectPrivate::removeChild(AbstractAspect* child) {
+	QDEBUG(Q_FUNC_INFO << " CHILD = " << child << ", PARENT =" << child->parentAspect())
 	int index = indexOfChild(child);
 	Q_ASSERT(index != -1);
 	m_children.removeAll(child);
 	QObject::disconnect(child, nullptr, q, nullptr);
 	child->setParentAspect(nullptr);
+	QDEBUG(Q_FUNC_INFO << " DONE. CHILD = " << child)
 	return index;
 }
