@@ -1,32 +1,14 @@
-/***************************************************************************
+/*
     File                 : AbstractAspect.h
     Project              : LabPlot
-    --------------------------------------------------------------------
-    Copyright            : (C) 2007-2009 by Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2007-2010 by Knut Franke (knut.franke@gmx.de)
-    Copyright            : (C) 2011-2015 by Alexander Semke (alexander.semke@web.de)
     Description          : Base class for all objects in a Project.
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2007-2009 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2007-2010 Knut Franke <knut.franke@gmx.de>
+    SPDX-FileCopyrightText: 2011-2015 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 #ifndef ABSTRACT_ASPECT_H
 #define ABSTRACT_ASPECT_H
 
@@ -67,6 +49,8 @@ enum class AspectType : quint64 {
 		TextLabel = 0x0210020,
 		Image = 0x0210030,
 		ReferenceLine = 0x0210040,
+		InfoElement = 0x0210080,
+		BoxPlot = 0x0210100,
 		WorksheetElementContainer = 0x0220000,
 			AbstractPlot = 0x0221000,
 				CartesianPlot = 0x0221001,
@@ -74,7 +58,7 @@ enum class AspectType : quint64 {
 		XYCurve = 0x0240000,
 			XYEquationCurve = 0x0240001,
 		XYAnalysisCurve = 0x0280000,
-			XYConvolution = 0x0280001,
+			XYConvolutionCurve = 0x0280001,
 			XYCorrelationCurve = 0x0280002,
 			XYDataReductionCurve = 0x0280004,
 			XYDifferentiationCurve = 0x0280008,
@@ -84,6 +68,7 @@ enum class AspectType : quint64 {
 			XYInterpolationCurve = 0x0280080,
 			XYIntegrationCurve = 0x0280100,
 			XYSmoothCurve = 0x0280200,
+			XYHilbertTransformCurve = 0x0280400,
 
 	AbstractPart = 0x0400000,
 		AbstractDataSource = 0x0410000,
@@ -109,7 +94,12 @@ enum class AspectType : quint64 {
 		MQTTSubscription = 0x2000004,
 };
 
+#ifdef SDK
+#include "labplot_export.h"
+class LABPLOT_EXPORT AbstractAspect : public QObject {
+#else
 class AbstractAspect : public QObject {
+#endif
 	Q_OBJECT
 
 public:
@@ -128,6 +118,120 @@ public:
 	AbstractAspect(const QString& name, AspectType type);
 	~AbstractAspect() override;
 
+	// type name for internal use (no translation)
+	static QString typeName(AspectType type) {
+		switch(type) {
+		case AspectType::AbstractAspect:
+			return QStringLiteral("AbstractAspect");
+		case AspectType::AbstractFilter:
+			return QStringLiteral("AbstractFilter");
+		case AspectType::DatapickerCurve:
+			return QStringLiteral("DatapickerCurve");
+		case AspectType::DatapickerPoint:
+			return QStringLiteral("DatapickerPoint");
+		case AspectType::WorksheetElement:
+			return QStringLiteral("WorksheetElement");
+		case AspectType::Axis:
+			return QStringLiteral("Axis");
+		case AspectType::CartesianPlotLegend:
+			return QStringLiteral("CartesianPlotLegend");
+		case AspectType::CustomPoint:
+			return QStringLiteral("CustomPoint");
+		case AspectType::Histogram:
+			return QStringLiteral("Histogram");
+		case AspectType::PlotArea:
+			return QStringLiteral("PlotArea");
+		case AspectType::TextLabel:
+			return QStringLiteral("TextLabel");
+		case AspectType::Image:
+			return QStringLiteral("Image");
+		case AspectType::ReferenceLine:
+			return QStringLiteral("ReferenceLine");
+		case AspectType::InfoElement:
+			return QStringLiteral("InfoElement");
+		case AspectType::WorksheetElementContainer:
+			return QStringLiteral("WorksheetElementContainer");
+		case AspectType::AbstractPlot:
+			return QStringLiteral("AbstractPlot");
+		case AspectType::CartesianPlot:
+			return QStringLiteral("CartesianPlot");
+		case AspectType::WorksheetElementGroup:
+			return QStringLiteral("WorksheetElementGroup");
+		case AspectType::XYCurve:
+			return QStringLiteral("XYCurve");
+		case AspectType::XYEquationCurve:
+			return QStringLiteral("XYEquationCurve");
+		case AspectType::XYAnalysisCurve:
+			return QStringLiteral("XYAnalysisCurve");
+		case AspectType::XYConvolutionCurve:
+			return QStringLiteral("XYConvolutionCurve");
+		case AspectType::XYCorrelationCurve:
+			return QStringLiteral("XYCorrelationCurve");
+		case AspectType::XYDataReductionCurve:
+			return QStringLiteral("XYDataReductionCurve");
+		case AspectType::XYDifferentiationCurve:
+			return QStringLiteral("XYDifferentiationCurve");
+		case AspectType::XYFitCurve:
+			return QStringLiteral("XYFitCurve");
+		case AspectType::XYFourierFilterCurve:
+			return QStringLiteral("XYFourierFilterCurve");
+		case AspectType::XYFourierTransformCurve:
+			return QStringLiteral("XYFourierTransformCurve");
+		case AspectType::XYInterpolationCurve:
+			return QStringLiteral("XYInterpolationCurve");
+		case AspectType::XYIntegrationCurve:
+			return QStringLiteral("XYIntegrationCurve");
+		case AspectType::XYSmoothCurve:
+			return QStringLiteral("XYSmoothCurve");
+		case AspectType::XYHilbertTransformCurve:
+			return QStringLiteral("XYHilbertTransformCurve");
+		case AspectType::BoxPlot:
+			return QStringLiteral("BoxPlot");
+		case AspectType::AbstractPart:
+			return QStringLiteral("AbstractPart");
+		case AspectType::AbstractDataSource:
+			return QStringLiteral("AbstractDataSource");
+		case AspectType::Matrix:
+			return QStringLiteral("Matrix");
+		case AspectType::Spreadsheet:
+			return QStringLiteral("Spreadsheet");
+		case AspectType::LiveDataSource:
+			return QStringLiteral("LiveDataSource");
+		case AspectType::MQTTTopic:
+			return QStringLiteral("MQTTTopic");
+		case AspectType::CantorWorksheet:
+			return QStringLiteral("CantorWorksheet");
+		case AspectType::Datapicker:
+			return QStringLiteral("Datapicker");
+		case AspectType::DatapickerImage:
+			return QStringLiteral("DatapickerImage");
+		case AspectType::Note:
+			return QStringLiteral("Note");
+		case AspectType::Workbook:
+			return QStringLiteral("Workbook");
+		case AspectType::Worksheet:
+			return QStringLiteral("Worksheet");
+		case AspectType::AbstractColumn:
+			return QStringLiteral("AbstractColumn");
+		case AspectType::Column:
+			return QStringLiteral("Column");
+		case AspectType::SimpleFilterColumn:
+			return QStringLiteral("SimpleFilterColumn");
+		case AspectType::ColumnStringIO:
+			return QStringLiteral("ColumnStringIO");
+		case AspectType::Folder:
+			return QStringLiteral("Folder");
+		case AspectType::Project:
+			return QStringLiteral("Project");
+		case AspectType::MQTTClient:
+			return QStringLiteral("MQTTClient");
+		case AspectType::MQTTSubscription:
+			return QStringLiteral("MQTTSubscription");
+		}
+
+		return QString();
+	}
+
 	QString name() const;
 	QString comment() const;
 	void setCreationTime(const QDateTime&);
@@ -136,7 +240,11 @@ public:
 	virtual QString path() const;
 	void setHidden(bool);
 	bool hidden() const;
+	void setFixed(bool);
+	bool isFixed() const;
 	void setSelected(bool);
+	void setMoved(bool);
+	bool isMoved() const;
 	void setIsLoading(bool);
 	bool isLoading() const;
 	virtual QIcon icon() const;
@@ -162,6 +270,7 @@ public:
 	void removeAllChildren();
 	virtual QVector<AbstractAspect*> dependsOn() const;
 
+	virtual QVector<AspectType> pasteTypes() const;
 	virtual bool isDraggable() const;
 	virtual QVector<AspectType> dropableOn() const;
 	virtual void processDropEvent(const QVector<quintptr>&) {};
@@ -245,6 +354,10 @@ public:
 	//save/load
 	virtual void save(QXmlStreamWriter*) const = 0;
 	virtual bool load(XmlStreamReader*, bool preview) = 0;
+	void setPasted(bool);
+	bool pasted() const;
+
+	static AspectType clipboardAspectType(QString&);
 
 protected:
 	void info(const QString& text) { emit statusInfo(text); }
@@ -264,16 +377,23 @@ private:
 	const QVector<AbstractAspect*>& children() const;
 	void connectChild(AbstractAspect*);
 
-public slots:
+public Q_SLOTS:
 	bool setName(const QString&, bool autoUnique = true);
 	void setComment(const QString&);
 	void remove();
+	void copy() const;
+	void duplicate();
+	void paste(bool duplicate = false);
 
-protected slots:
+private Q_SLOTS:
+	void moveUp();
+	void moveDown();
+
+protected Q_SLOTS:
 	virtual void childSelected(const AbstractAspect*);
 	virtual void childDeselected(const AbstractAspect*);
 
-signals:
+Q_SIGNALS:
 	void aspectDescriptionAboutToChange(const AbstractAspect*);
 	void aspectDescriptionChanged(const AbstractAspect*);
 	void aspectAboutToBeAdded(const AbstractAspect* parent, const AbstractAspect* before, const AbstractAspect* child);
