@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : AbstractColumn.cpp
     Project              : LabPlot
     Description          : Interface definition for data with column logic
     --------------------------------------------------------------------
-    Copyright            : (C) 2007,2008 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2017-2020 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2007, 2008 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2017-2020 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "backend/core/AbstractColumn.h"
 #include "backend/core/AbstractColumnPrivate.h"
@@ -84,13 +66,16 @@ AbstractColumn::AbstractColumn(const QString &name, AspectType type)
 }
 
 AbstractColumn::~AbstractColumn() {
-	emit aboutToBeDestroyed(this);
+	Q_EMIT aboutToBeDestroyed(this);
 	delete d;
 }
 
 QStringList AbstractColumn::dateFormats() {
-	static const QStringList dates{"yyyy-MM-dd", "yyyy/MM/dd", "dd/MM/yyyy",
-		"dd/MM/yy", "dd.MM.yyyy", "dd.MM.yy", "MM/yyyy", "dd.MM.", "yyyyMMdd"};
+	static const QStringList dates{"yyyy-MM-dd", "yyyy.MM.dd", "yyyy/MM/dd", "yyyyMMdd",
+									"dd-MM-yyyy", "dd.MM.yyyy", "dd/MM/yyyy", "ddMMyyyy",
+									"dd-MM-yy", "dd.MM.yy", "dd/MM/yy", "ddMMyy",
+									"MM-yyyy", "MM.yyyy", "MM/yyyy",
+									"dd-MM", "dd.MM", "dd/MM", "ddMM"};
 
 	return dates;
 }
@@ -114,12 +99,85 @@ QStringList AbstractColumn::dateTimeFormats() {
 	return dateTimes;
 }
 
+/**
+ * \brief Convenience method for getting plot designation string
+ * translated since used in UI
+ */
+QString AbstractColumn::plotDesignationString(PlotDesignation d, bool withBrackets) {
+	QString s;
+
+	switch (d) {
+	case PlotDesignation::NoDesignation:
+		s = i18n("None");
+		break;
+	case PlotDesignation::X:
+		s = QLatin1String("X");
+		break;
+	case PlotDesignation::Y:
+		s = QLatin1String("Y");
+		break;
+	case PlotDesignation::Z:
+		s = QLatin1String("Z");
+		break;
+	case PlotDesignation::XError:
+		s = i18n("X-error");
+		break;
+	case PlotDesignation::XErrorPlus:
+		s = i18n("X-error +");
+		break;
+	case PlotDesignation::XErrorMinus:
+		s = i18n("X-error -");
+		break;
+	case PlotDesignation::YError:
+		s = i18n("Y-error");
+		break;
+	case PlotDesignation::YErrorPlus:
+		s = i18n("Y-error +");
+		break;
+	case PlotDesignation::YErrorMinus:
+		s = i18n("Y-error -");
+		break;
+	default:
+		return {};
+	}
+
+	if (withBrackets)
+		s = QLatin1String("[") + s + QLatin1Char(']');
+
+	return s;
+}
+
+/**
+ * \brief Convenience method for getting mode string
+ * translated since used in UI
+ */
+QString AbstractColumn::columnModeString(ColumnMode mode) {
+	switch (mode) {
+	case ColumnMode::Double:
+		return i18n("Double");
+	case ColumnMode::Integer:
+		return i18n("Integer");
+	case ColumnMode::BigInt:
+		return i18n("Big Integer");
+	case ColumnMode::Text:
+		return i18n("Text");
+	case ColumnMode::DateTime:
+		return i18n("Date & Time");
+	case ColumnMode::Month:
+		return i18n("Month Names");
+	case ColumnMode::Day:
+		return i18n("Day Names");
+	}
+
+	return i18n("UNDEFINED");
+}
+
 /**
  * \brief Convenience method for mode-dependent icon
  */
-QIcon AbstractColumn::iconForMode(ColumnMode mode) {
+QIcon AbstractColumn::modeIcon(ColumnMode mode) {
 	switch (mode) {
-	case ColumnMode::Numeric:
+	case ColumnMode::Double:
 	case ColumnMode::Integer:
 	case ColumnMode::BigInt:
 		break;
@@ -163,8 +221,7 @@ void AbstractColumn::setColumnMode(AbstractColumn::ColumnMode) {}
  * of 'other' is not the same as the type of 'this'.
  * Use a filter to convert a column to another type.
  */
-bool AbstractColumn::copy(const AbstractColumn *other) {
-	Q_UNUSED(other)
+bool AbstractColumn::copy(const AbstractColumn* /*other*/) {
 	return false;
 }
 
@@ -178,11 +235,7 @@ bool AbstractColumn::copy(const AbstractColumn *other) {
  * \param destination_start first row to copy in
  * \param num_rows the number of rows to copy
  */
-bool AbstractColumn::copy(const AbstractColumn *source, int source_start, int destination_start, int num_rows) {
-	Q_UNUSED(source)
-	Q_UNUSED(source_start)
-	Q_UNUSED(destination_start)
-	Q_UNUSED(num_rows)
+bool AbstractColumn::copy(const AbstractColumn* /*source*/, int /*source_start*/, int /*destination_start*/, int /*num_rows*/) {
 	return false;
 }
 
@@ -242,18 +295,17 @@ void AbstractColumn::handleRowRemoval(int first, int count) {
 /**
  * \brief Set the column plot designation
  */
-void AbstractColumn::setPlotDesignation(AbstractColumn::PlotDesignation pd) {
-	Q_UNUSED(pd)
+void AbstractColumn::setPlotDesignation(AbstractColumn::PlotDesignation) {
 }
 
 bool AbstractColumn::isNumeric() const {
 	const auto mode = columnMode();
-	return (mode == ColumnMode::Numeric || mode == ColumnMode::Integer || mode == ColumnMode::BigInt);
+	return (mode == ColumnMode::Double || mode == ColumnMode::Integer || mode == ColumnMode::BigInt);
 }
 
 bool AbstractColumn::isPlottable() const {
 	const auto mode = columnMode();
-	return (mode == ColumnMode::Numeric || mode == ColumnMode::Integer || mode == ColumnMode::BigInt || mode == ColumnMode::DateTime);
+	return (mode == ColumnMode::Double || mode == ColumnMode::Integer || mode == ColumnMode::BigInt || mode == ColumnMode::DateTime);
 }
 
 /**
@@ -266,7 +318,7 @@ void AbstractColumn::clear() {}
  */
 bool AbstractColumn::isValid(int row) const {
 	switch (columnMode()) {
-	case ColumnMode::Numeric:
+	case ColumnMode::Double:
 		return !(std::isnan(valueAt(row)) || std::isinf(valueAt(row)));
 	case ColumnMode::Integer:	// there is no invalid integer
 	case ColumnMode::BigInt:
@@ -346,9 +398,8 @@ void AbstractColumn::setMasked(int row, bool mask) {
 /**
  * \brief Return the formula associated with row 'row'
  */
-QString AbstractColumn::formula(int row) const {
-	Q_UNUSED(row);
-	return QString();
+QString AbstractColumn::formula(int /*row*/) const {
+	return {};
 }
 
 /**
@@ -365,27 +416,46 @@ QString AbstractColumn::formula(int row) const {
  * \endcode
  */
 QVector< Interval<int> > AbstractColumn::formulaIntervals() const {
-	return QVector< Interval<int> >();
+	return {};
 }
 
 /**
  * \brief Set a formula string for an interval of rows
  */
-void AbstractColumn::setFormula(const Interval<int>& i, const QString& formula) {
-	Q_UNUSED(i) Q_UNUSED(formula)
+void AbstractColumn::setFormula(const Interval<int>&, const QString& /*formula*/) {
 }
 
 /**
  * \brief Overloaded function for convenience
  */
-void AbstractColumn::setFormula(int row, const QString& formula) {
-	Q_UNUSED(row) Q_UNUSED(formula)
+void AbstractColumn::setFormula(int /*row*/, const QString& /*formula*/) {
 }
 
 /**
  * \brief Clear all formulas
  */
-void AbstractColumn::clearFormulas() {};
+void AbstractColumn::clearFormulas() {}
+
+
+//conditional formatting
+bool AbstractColumn::hasHeatmapFormat() const {
+	return (d->m_heatmapFormat != nullptr);
+}
+
+AbstractColumn::HeatmapFormat& AbstractColumn::heatmapFormat() const {
+	if (!d->m_heatmapFormat)
+		d->m_heatmapFormat = new HeatmapFormat();
+
+	return *(d->m_heatmapFormat);
+}
+
+void AbstractColumn::setHeatmapFormat(const AbstractColumn::HeatmapFormat& format) {
+	exec(new AbstractColumnSetHeatmapFormatCmd(d, format));
+}
+
+void AbstractColumn::removeFormat() {
+	exec(new AbstractColumnRemoveHeatmapFormatCmd(d));
+}
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 //@}
@@ -401,9 +471,8 @@ void AbstractColumn::clearFormulas() {};
  *
  * Use this only when columnMode() is Text
  */
-QString AbstractColumn::textAt(int row) const {
-	Q_UNUSED(row);
-	return QString();
+QString AbstractColumn::textAt(int /*row*/) const {
+	return {};
 }
 
 /**
@@ -411,8 +480,7 @@ QString AbstractColumn::textAt(int row) const {
  *
  * Use this only when columnMode() is Text
  */
-void AbstractColumn::setTextAt(int row, const QString& new_value) {
-	Q_UNUSED(row) Q_UNUSED(new_value)
+void AbstractColumn::setTextAt(int /*row*/, const QString& /*new_text*/) {
 }
 
 /**
@@ -420,17 +488,15 @@ void AbstractColumn::setTextAt(int row, const QString& new_value) {
  *
  * Use this only when columnMode() is Text
  */
-void AbstractColumn::replaceTexts(int first, const QVector<QString>& new_values) {
-	Q_UNUSED(first) Q_UNUSED(new_values)
-};
+void AbstractColumn::replaceTexts(int /*first*/, const QVector<QString>& /*new_text*/) {
+}
 
 /**
  * \brief Return the date part of row 'row'
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-QDate AbstractColumn::dateAt(int row) const {
-	Q_UNUSED(row);
+QDate AbstractColumn::dateAt(int /*row*/) const {
 	return QDate{};
 }
 
@@ -439,18 +505,16 @@ QDate AbstractColumn::dateAt(int row) const {
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-void AbstractColumn::setDateAt(int row, QDate new_value) {
-	Q_UNUSED(row) Q_UNUSED(new_value)
-};
+void AbstractColumn::setDateAt(int /*row*/, QDate) {
+}
 
 /**
  * \brief Return the time part of row 'row'
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-QTime AbstractColumn::timeAt(int row) const {
-	Q_UNUSED(row);
-	return QTime{};
+QTime AbstractColumn::timeAt(int /*row*/) const {
+	return {};
 }
 
 /**
@@ -458,8 +522,7 @@ QTime AbstractColumn::timeAt(int row) const {
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-void AbstractColumn::setTimeAt(int row, QTime new_value) {
-	Q_UNUSED(row) Q_UNUSED(new_value)
+void AbstractColumn::setTimeAt(int /*row*/, QTime) {
 }
 
 /**
@@ -467,9 +530,8 @@ void AbstractColumn::setTimeAt(int row, QTime new_value) {
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-QDateTime AbstractColumn::dateTimeAt(int row) const {
-	Q_UNUSED(row);
-	return QDateTime();
+QDateTime AbstractColumn::dateTimeAt(int /*row*/) const {
+	return {};
 }
 
 /**
@@ -477,26 +539,23 @@ QDateTime AbstractColumn::dateTimeAt(int row) const {
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-void AbstractColumn::setDateTimeAt(int row, const QDateTime& new_value) {
-	Q_UNUSED(row) Q_UNUSED(new_value)
-};
+void AbstractColumn::setDateTimeAt(int /*row*/, const QDateTime&) {
+}
 
 /**
  * \brief Replace a range of values
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-void AbstractColumn::replaceDateTimes(int first, const QVector<QDateTime>& new_values) {
-	Q_UNUSED(first) Q_UNUSED(new_values)
-};
+void AbstractColumn::replaceDateTimes(int /*first*/, const QVector<QDateTime>&) {
+}
 
 /**
  * \brief Return the double value in row 'row'
  *
  * Use this only when columnMode() is Numeric
  */
-double AbstractColumn::valueAt(int row) const {
-	Q_UNUSED(row);
+double AbstractColumn::valueAt(int /*row*/) const {
 	return NAN;
 }
 
@@ -505,17 +564,15 @@ double AbstractColumn::valueAt(int row) const {
  *
  * Use this only when columnMode() is Numeric
  */
-void AbstractColumn::setValueAt(int row, const double new_value) {
-	Q_UNUSED(row) Q_UNUSED(new_value)
-};
+void AbstractColumn::setValueAt(int /*row*/, const double) {
+}
 
 /**
  * \brief Replace a range of values
  *
  * Use this only when columnMode() is Numeric
  */
-void AbstractColumn::replaceValues(int first, const QVector<double>& new_values) {
-	Q_UNUSED(first) Q_UNUSED(new_values)
+void AbstractColumn::replaceValues(int /*first*/, const QVector<double>&) {
 }
 
 /**
@@ -523,8 +580,7 @@ void AbstractColumn::replaceValues(int first, const QVector<double>& new_values)
  *
  * Use this only when columnMode() is Integer
  */
-int AbstractColumn::integerAt(int row) const {
-	Q_UNUSED(row);
+int AbstractColumn::integerAt(int /*row*/) const {
 	return 42;
 }
 
@@ -533,17 +589,15 @@ int AbstractColumn::integerAt(int row) const {
  *
  * Use this only when columnMode() is Integer
  */
-void AbstractColumn::setIntegerAt(int row, const int new_value) {
-	Q_UNUSED(row) Q_UNUSED(new_value)
-};
+void AbstractColumn::setIntegerAt(int /*row*/, const int) {
+}
 
 /**
  * \brief Replace a range of values
  *
  * Use this only when columnMode() is Integer
  */
-void AbstractColumn::replaceInteger(int first, const QVector<int>& new_values) {
-	Q_UNUSED(first) Q_UNUSED(new_values)
+void AbstractColumn::replaceInteger(int /*first*/, const QVector<int>&) {
 }
 
 /**
@@ -551,8 +605,7 @@ void AbstractColumn::replaceInteger(int first, const QVector<int>& new_values) {
  *
  * Use this only when columnMode() is BigInt
  */
-qint64 AbstractColumn::bigIntAt(int row) const {
-	Q_UNUSED(row);
+qint64 AbstractColumn::bigIntAt(int /*row*/) const {
 	return 42;
 }
 
@@ -561,17 +614,15 @@ qint64 AbstractColumn::bigIntAt(int row) const {
  *
  * Use this only when columnMode() is BigInt
  */
-void AbstractColumn::setBigIntAt(int row, const qint64 new_value) {
-	Q_UNUSED(row) Q_UNUSED(new_value)
-};
+void AbstractColumn::setBigIntAt(int /*row*/, const qint64) {
+}
 
 /**
  * \brief Replace a range of values
  *
  * Use this only when columnMode() is BigInt
  */
-void AbstractColumn::replaceBigInt(int first, const QVector<qint64>& new_values) {
-	Q_UNUSED(first) Q_UNUSED(new_values)
+void AbstractColumn::replaceBigInt(int /*first*/, const QVector<qint64>&) {
 }
 
 /**
@@ -583,38 +634,27 @@ AbstractColumn::Properties AbstractColumn::properties() const {
 }
 
 /**********************************************************************/
-double AbstractColumn::minimum(int count) const {
-	Q_UNUSED(count);
+double AbstractColumn::minimum(int /*count*/) const {
 	return -INFINITY;
 }
 
-double AbstractColumn::minimum(int startIndex, int endIndex) const {
-	Q_UNUSED(startIndex);
-	Q_UNUSED(endIndex);
+double AbstractColumn::minimum(int /*startIndex*/, int /*endIndex*/) const {
 	return -INFINITY;
 }
 
-double AbstractColumn::maximum(int count) const {
-	Q_UNUSED(count);
+double AbstractColumn::maximum(int /*count*/) const {
 	return INFINITY;
 }
 
-double AbstractColumn::maximum(int startIndex, int endIndex) const {
-	Q_UNUSED(startIndex);
-	Q_UNUSED(endIndex);
+double AbstractColumn::maximum(int /*startIndex*/, int /*endIndex*/) const {
 	return INFINITY;
 }
 
-bool AbstractColumn::indicesMinMax(double v1, double v2, int& start, int& end)  const {
-	Q_UNUSED(v1)
-	Q_UNUSED(v2)
-	Q_UNUSED(start)
-	Q_UNUSED(end)
+bool AbstractColumn::indicesMinMax(double /*v1*/, double /*v2*/, int& /*start*/, int& /*end*/) const {
 	return false;
 }
 
-int AbstractColumn::indexForValue(double x) const {
-	Q_UNUSED(x)
+int AbstractColumn::indexForValue(double /*x*/) const {
 	return 0;
 }
 
