@@ -1,38 +1,21 @@
-/***************************************************************************
+/*
     File                 : AbstractColumn.h
     Project              : LabPlot
     Description          : Interface definition for data with column logic
     --------------------------------------------------------------------
-    Copyright            : (C) 2007,2008 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2013 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2017-2020 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2007, 2008 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2013 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2017-2020 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #ifndef ABSTRACTCOLUMN_H
 #define ABSTRACTCOLUMN_H
 
 #include "backend/core/AbstractAspect.h"
 #include <cmath>	// NAN
+#include <QColor>
 
 class AbstractColumnPrivate;
 class AbstractSimpleFilter;
@@ -53,7 +36,7 @@ public:
 	enum class PlotDesignation {NoDesignation, X, Y, Z, XError, XErrorPlus, XErrorMinus, YError, YErrorMinus, YErrorPlus};
 	enum class ColumnMode {
 		// BASIC FORMATS
-		Numeric = 0,	// double
+		Double = 0,	// double
 		Text = 1,	// QString
 		// Time = 2 and Date = 3 are skipped to avoid problems with old obsolete values
 		Month = 4,	// month of year: numeric or "Jan", etc.
@@ -92,58 +75,42 @@ public:
 		// etc.
 	};
 	enum class Properties {	// TODO: why bit pattern? Aren't they exclusive?
-		No = 0x00,
+		No = 0x00, // invalid values or masked values
 		Constant = 0x01,
 		MonotonicIncreasing = 0x02, // prev_value >= value for all values in column
-		MonotonicDecreasing = 0x04 // prev_value <= value for all values in column
-		// add new values with next bit set (0x08)
+		MonotonicDecreasing = 0x04, // prev_value <= value for all values in column
+		NonMonotonic = 0x8,
+		// add new values with next bit set (0x10)
 	};
 
 	struct ColumnStatistics {
-		ColumnStatistics() {
-			size = 0;
-			minimum = NAN;
-			maximum = NAN;
-			arithmeticMean = NAN;
-			geometricMean = NAN;
-			harmonicMean = NAN;
-			contraharmonicMean = NAN;
-			mode = NAN;
-			firstQuartile = NAN;
-			median = NAN;
-			thirdQuartile = NAN;
-			iqr = NAN;
-			trimean = NAN;
-			variance = NAN;
-			standardDeviation = NAN;
-			meanDeviation = NAN;
-			meanDeviationAroundMedian = NAN;
-			medianDeviation = NAN;
-			skewness = NAN;
-			kurtosis = NAN;
-			entropy = NAN;
-		}
-		int size;
-		double minimum;
-		double maximum;
-		double arithmeticMean;
-		double geometricMean;
-		double harmonicMean;
-		double contraharmonicMean;
-		double mode;
-		double firstQuartile;
-		double median;
-		double thirdQuartile;
-		double iqr;
-		double trimean;
-		double variance;
-		double standardDeviation;
-		double meanDeviation; // mean absolute deviation around mean
-		double meanDeviationAroundMedian; // mean absolute deviation around median
-		double medianDeviation; // median absolute deviation
-		double skewness;
-		double kurtosis;
-		double entropy;
+		int size{0};
+		double minimum{NAN};
+		double maximum{NAN};
+		double arithmeticMean{NAN};
+		double geometricMean{NAN};
+		double harmonicMean{NAN};
+		double contraharmonicMean{NAN};
+		double mode{NAN};
+		double firstQuartile{NAN};
+		double median{NAN};
+		double thirdQuartile{NAN};
+		double iqr{NAN};
+		double percentile_1{NAN};
+		double percentile_5{NAN};
+		double percentile_10{NAN};
+		double percentile_90{NAN};
+		double percentile_95{NAN};
+		double percentile_99{NAN};
+		double trimean{NAN};
+		double variance{NAN};
+		double standardDeviation{NAN};
+		double meanDeviation{NAN}; // mean absolute deviation around mean
+		double meanDeviationAroundMedian{NAN}; // mean absolute deviation around median
+		double medianDeviation{NAN}; // median absolute deviation
+		double skewness{NAN};
+		double kurtosis{NAN};
+		double entropy{NAN};
 	};
 
 	AbstractColumn(const QString& name, AspectType type);
@@ -152,7 +119,9 @@ public:
 	static QStringList dateFormats();	// supported date formats
 	static QStringList timeFormats();	// supported time formats
 	static QStringList dateTimeFormats();	// supported datetime formats
-	static QIcon iconForMode(ColumnMode mode);
+	static QString plotDesignationString(PlotDesignation, bool withBrackets = true);
+	static QString columnModeString(ColumnMode);
+	static QIcon modeIcon(ColumnMode);
 
 	virtual bool isReadOnly() const {
 		return true;
@@ -160,7 +129,6 @@ public:
 	virtual ColumnMode columnMode() const = 0;
 	virtual void setColumnMode(AbstractColumn::ColumnMode);
 	virtual PlotDesignation plotDesignation() const = 0;
-	virtual QString plotDesignationString() const = 0;
 	virtual void setPlotDesignation(AbstractColumn::PlotDesignation);
 	bool isNumeric() const;
 	bool isPlottable() const;
@@ -169,7 +137,7 @@ public:
 	virtual bool copy(const AbstractColumn *source, int source_start, int dest_start, int num_rows);
 
 	virtual int rowCount() const = 0;
-	virtual int availableRowCount() const = 0;
+	virtual int availableRowCount(int max = -1) const = 0;
 	void insertRows(int before, int count);
 	void removeRows(int first, int count);
 	virtual void clear();
@@ -217,7 +185,23 @@ public:
 	virtual void replaceBigInt(int first, const QVector<qint64>& new_values);
 	virtual Properties properties() const;
 
-signals:
+	//conditional formatting
+	enum class Formatting {Background, Foreground, Icon};
+
+	struct HeatmapFormat {
+		double min = 0.0;
+		double max = 1.0;
+		QString name;
+		Formatting type = Formatting::Background;
+		QVector<QColor> colors;
+	};
+
+	bool hasHeatmapFormat() const;
+	HeatmapFormat& heatmapFormat() const;
+	void setHeatmapFormat(const HeatmapFormat&);
+	void removeFormat();
+
+Q_SIGNALS:
 	void plotDesignationAboutToChange(const AbstractColumn* source);
 	void plotDesignationChanged(const AbstractColumn* source);
 	void modeAboutToChange(const AbstractColumn* source);
