@@ -1,32 +1,15 @@
-/***************************************************************************
+/*
     File                 : AbstractSimpleFilter.h
     Project              : AbstractColumn
-    --------------------------------------------------------------------
-    Copyright            : (C) 2007 Knut Franke (knut.franke@gmx.de)
-    Copyright            : (C) 2007 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2017-2020 Stefan Gerlach (stefan.gerlach@uni.kn)
     Description          : Simplified filter interface for filters with
-                           only one output port.
- ***************************************************************************/
+    only one output port.
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2007 Knut Franke <knut.franke@gmx.de>
+    SPDX-FileCopyrightText: 2007 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2017-2020 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef ABSTRACTSIMPLEFILTER_H
 #define ABSTRACTSIMPLEFILTER_H
 
@@ -34,6 +17,8 @@
 #include "AbstractColumn.h"
 #include "backend/lib/IntervalAttribute.h"
 
+#include <QLocale>
+
 class SimpleFilterColumn;
 
 class AbstractSimpleFilter : public AbstractFilter {
@@ -46,7 +31,6 @@ public:
 	AbstractColumn* output(int port) override;
 	const AbstractColumn * output(int port) const override;
 	virtual AbstractColumn::PlotDesignation plotDesignation() const;
-	virtual QString plotDesignationString() const;
 	virtual AbstractColumn::ColumnMode columnMode() const;
 	virtual QString textAt(int row) const;
 	virtual QDate dateAt(int row) const;
@@ -60,14 +44,14 @@ public:
 	void setNumberLocaleToDefault() { m_useDefaultLocale = true; }
 
 	virtual int rowCount() const;
-	virtual int availableRowCount() const;
+	virtual int availableRowCount(int max = -1) const;
 	virtual QList<Interval<int>> dependentRows(const Interval<int>& inputRange) const;
 
 	void save(QXmlStreamWriter*) const override;
 	bool load(XmlStreamReader*, bool preview) override;
 	virtual void writeExtraAttributes(QXmlStreamWriter*) const;
 
-signals:
+Q_SIGNALS:
 	void formatChanged();
 	void digitsChanged();
 
@@ -97,9 +81,8 @@ public:
 
 	AbstractColumn::ColumnMode columnMode() const override;
 	int rowCount() const override { return m_owner->rowCount(); }
-	int availableRowCount() const override { return m_owner->availableRowCount(); }
+	int availableRowCount(int max = -1) const override { return m_owner->availableRowCount(max); }
 	AbstractColumn::PlotDesignation plotDesignation() const override { return m_owner->plotDesignation(); }
-	QString plotDesignationString() const override { return m_owner->plotDesignationString(); }
 	QString textAt(int row) const override;
 	QDate dateAt(int row) const override;
 	QTime timeAt(int row) const override;
