@@ -1,32 +1,14 @@
-/***************************************************************************
+/*
     File       	    : AspectTreeModel.h
     Project         : LabPlot
     Description     : Represents a tree of AbstractAspect objects as a Qt item model.
     --------------------------------------------------------------------
-    Copyright            : (C) 2007-2009 by Knut Franke (knut.franke@gmx.de)
-    Copyright            : (C) 2007-2009 by Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2011-2016 Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2007-2009 Knut Franke <knut.franke@gmx.de>
+    SPDX-FileCopyrightText: 2007-2009 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2011-2016 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 #ifndef ASPECT_TREE_MODEL_H
 #define ASPECT_TREE_MODEL_H
 
@@ -45,14 +27,18 @@ public:
 	QModelIndex parent(const QModelIndex &index) const override;
 	int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 	int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+
 	QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 	QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 	bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
 	Qt::ItemFlags flags(const QModelIndex &index) const override;
-	void setSelectableAspects(const QList<AspectType>&);
+
 	QModelIndex modelIndexOfAspect(const AbstractAspect*, int column=0) const;
 	QModelIndex modelIndexOfAspect(const QString& path, int column=0) const;
 
+	void setSelectableAspects(const QList<AspectType>&);
+	const QList<AspectType>& selectableAspects() const;
+
 	void setReadOnly(bool);
 	void enablePlottableColumnsOnly(bool);
 	void enableNumericColumnsOnly(bool);
@@ -62,7 +48,7 @@ public:
 	void setFilterCaseSensitivity(Qt::CaseSensitivity);
 	void setFilterMatchCompleteWord(bool);
 
-private slots:
+private Q_SLOTS:
 	void aspectDescriptionChanged(const AbstractAspect*);
 	void aspectAboutToBeAdded(const AbstractAspect* parent, const AbstractAspect* before, const AbstractAspect* child);
 	void aspectAdded(const AbstractAspect* parent);
@@ -89,7 +75,7 @@ private:
 	bool m_matchCompleteWord{false};
 	bool containsFilterString(const AbstractAspect*) const;
 
-signals:
+Q_SIGNALS:
 	void renameRequested(const QModelIndex&);
 	void indexSelected(const QModelIndex&);
 	void indexDeselected(const QModelIndex&);
