@@ -1,48 +1,34 @@
-/***************************************************************************
+/*
     File                 : Folder.cpp
     Project              : LabPlot
     Description          : Folder in a project
     --------------------------------------------------------------------
-    Copyright            : (C) 2009-2015 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2007 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2007 Knut Franke (knut.franke@gmx.de)
+    SPDX-FileCopyrightText: 2009-2020 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2007 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2007 Knut Franke <knut.franke@gmx.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "backend/core/Folder.h"
-#include "backend/datapicker/Datapicker.h"
-#include "backend/core/Project.h"
-#include "backend/core/Workbook.h"
 #include "backend/core/column/Column.h"
+#include "backend/core/Project.h"
+#ifndef SDK
+#include "backend/datapicker/Datapicker.h"
+#include "backend/core/Workbook.h"
 #include "backend/datasources/LiveDataSource.h"
 #include "backend/matrix/Matrix.h"
 #include "backend/note/Note.h"
-#include "backend/spreadsheet/Spreadsheet.h"
 #ifdef HAVE_CANTOR_LIBS
 #include "backend/cantorWorksheet/CantorWorksheet.h"
 #endif
 #ifdef HAVE_MQTT
 #include "backend/datasources/MQTTClient.h"
 #endif
+#endif
+
+#include "backend/lib/XmlStreamReader.h"
+#include "backend/spreadsheet/Spreadsheet.h"
 #include "backend/worksheet/Worksheet.h"
 
 #include <QDropEvent>
@@ -84,6 +70,16 @@ bool Folder::isDraggable() const {
 		return true;
 }
 
+QVector<AspectType> Folder::pasteTypes() const {
+	return QVector<AspectType>{
+		AspectType::Folder,
+		AspectType::Worksheet, AspectType::Workbook,
+		AspectType::Spreadsheet, AspectType::Matrix,
+		AspectType::Datapicker, AspectType::LiveDataSource,
+		AspectType::Note, AspectType::CantorWorksheet
+	};
+}
+
 QVector<AspectType> Folder::dropableOn() const {
 	return QVector<AspectType>{AspectType::Folder, AspectType::Project};
 }
@@ -119,7 +115,8 @@ void Folder::save(QXmlStreamWriter* writer) const {
 	writeBasicAttributes(writer);
 	writeCommentElement(writer);
 
-	for (auto* child : children<AbstractAspect>(ChildIndexFlag::IncludeHidden)) {
+	const auto& children = this->children<AbstractAspect>(ChildIndexFlag::IncludeHidden);
+	for (auto* child : children) {
 		writer->writeStartElement(QLatin1String("child_aspect"));
 		child->save(writer);
 		writer->writeEndElement(); // "child_aspect"
@@ -195,7 +192,7 @@ bool Folder::readChildAspectElement(XmlStreamReader* reader, bool preview) {
 
 	QString element_name = reader->name().toString();
 	if (element_name == QLatin1String("folder")) {
-		Folder* folder = new Folder(QString());
+		auto* folder = new Folder(QString());
 
 		if (!m_pathesToLoad.isEmpty()) {
 			//a child folder to be read -> provide the list of aspects to be loaded to the child folder, too.
@@ -215,7 +212,7 @@ bool Folder::readChildAspectElement(XmlStreamReader* reader, bool preview) {
 
 			//remove the path of the current child folder
 			QStringList pathesToLoadNew;
-			for (auto path : m_pathesToLoad) {
+			for (const auto& path : qAsConst(m_pathesToLoad)) {
 				if (path.startsWith(curFolderPath))
 					pathesToLoadNew << path.right(path.length() - curFolderPath.length());
 			}
@@ -229,28 +226,34 @@ bool Folder::readChildAspectElement(XmlStreamReader* reader, bool preview) {
 		}
 		addChildFast(folder);
 	} else if (element_name == QLatin1String("workbook")) {
-		Workbook* workbook = new Workbook(QString());
+#ifndef SDK
+		auto* workbook = new Workbook(QString());
 		if (!workbook->load(reader, preview)) {
 			delete workbook;
 			return false;
 		}
 		addChildFast(workbook);
+#endif
 	} else if (element_name == QLatin1String("spreadsheet")) {
-		Spreadsheet* spreadsheet = new Spreadsheet(QString(), true);
+#ifndef SDK
+		auto* spreadsheet = new Spreadsheet(QString(), true);
 		if (!spreadsheet->load(reader, preview)) {
 			delete spreadsheet;
 			return false;
 		}
 		addChildFast(spreadsheet);
+#endif
 	} else if (element_name == QLatin1String("matrix")) {
-		Matrix* matrix = new Matrix(QString(), true);
+#ifndef SDK
+		auto* matrix = new Matrix(QString(), true);
 		if (!matrix->load(reader, preview)) {
 			delete matrix;
 			return false;
 		}
 		addChildFast(matrix);
+#endif
 	} else if (element_name == QLatin1String("worksheet")) {
-		Worksheet* worksheet = new Worksheet(QString());
+		auto* worksheet = new Worksheet(QString(), true);
 		worksheet->setIsLoading(true);
 		if (!worksheet->load(reader, preview)) {
 			delete worksheet;
@@ -260,7 +263,8 @@ bool Folder::readChildAspectElement(XmlStreamReader* reader, bool preview) {
 		worksheet->setIsLoading(false);
 	} else if (element_name == QLatin1String("cantorWorksheet")) {
 #ifdef HAVE_CANTOR_LIBS
-		CantorWorksheet* cantorWorksheet = new CantorWorksheet(QLatin1String("null"), true);
+#ifndef SDK
+		auto* cantorWorksheet = new CantorWorksheet(QLatin1String("null"), true);
 		if (!cantorWorksheet->load(reader, preview)) {
 			delete cantorWorksheet;
 
@@ -279,6 +283,7 @@ bool Folder::readChildAspectElement(XmlStreamReader* reader, bool preview) {
 			}
 		} else
 			addChildFast(cantorWorksheet);
+#endif
 #else
 	if (!preview) {
 		while (!reader->atEnd()) {
@@ -299,36 +304,44 @@ bool Folder::readChildAspectElement(XmlStreamReader* reader, bool preview) {
 	}
 #endif
 #ifdef HAVE_MQTT
+#ifndef SDK
 	} else if (element_name == QLatin1String("MQTTClient")) {
-		MQTTClient* client = new MQTTClient(QString());
+		auto* client = new MQTTClient(QString());
 		if (!client->load(reader, preview)) {
 			delete client;
 			return false;
 		}
 		addChildFast(client);
+#endif
 #endif
 	} else if (element_name == QLatin1String("liveDataSource")
 		|| element_name == QLatin1String("LiveDataSource")) { //TODO: remove "LiveDataSources" in couple of releases
+#ifndef SDK
 		auto* liveDataSource = new LiveDataSource(QString(), true);
 		if (!liveDataSource->load(reader, preview)) {
 			delete liveDataSource;
 			return false;
 		}
 		addChildFast(liveDataSource);
+#endif
 	} else if (element_name == QLatin1String("datapicker")) {
-		Datapicker* datapicker = new Datapicker(QString(), true);
+#ifndef SDK
+		auto* datapicker = new Datapicker(QString(), true);
 		if (!datapicker->load(reader, preview)) {
 			delete datapicker;
 			return false;
 		}
 		addChildFast(datapicker);
+#endif
 	} else if (element_name == QLatin1String("note")) {
+#ifndef SDK
 		Note* note = new Note(QString());
 		if (!note->load(reader, preview)) {
 			delete note;
 			return false;
 		}
 		addChildFast(note);
+#endif
 	} else {
 		reader->raiseWarning(i18n("unknown element '%1' found", element_name));
 		if (!reader->skipToEndElement())
