@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : Workbook.h
     Project              : LabPlot
     Description          : Aspect providing a container for storing data
 				   in form of spreadsheets and matrices
     --------------------------------------------------------------------
-    Copyright            : (C) 2015 Alexander Semke(alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2015 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "Workbook.h"
 #include "backend/spreadsheet/Spreadsheet.h"
@@ -55,7 +37,7 @@ QIcon Workbook::icon() const {
 QMenu* Workbook::createContextMenu() {
 	QMenu *menu = AbstractPart::createContextMenu();
 	Q_ASSERT(menu);
-	emit requestProjectContextMenu(menu);
+	Q_EMIT requestProjectContextMenu(menu);
 	return menu;
 }
 
@@ -137,14 +119,13 @@ Matrix* Workbook::currentMatrix() const {
  */
 void Workbook::childSelected(const AbstractAspect* aspect) {
 	int index = indexOfChild<AbstractAspect>(aspect);
-	emit workbookItemSelected(index);
+	Q_EMIT workbookItemSelected(index);
 }
 
 /*!
 	this slot is called when a worksheet element is deselected in the project explorer.
  */
-void Workbook::childDeselected(const AbstractAspect* aspect) {
-	Q_UNUSED(aspect);
+void Workbook::childDeselected(const AbstractAspect*) {
 }
 
 /*!
@@ -156,20 +137,30 @@ void Workbook::childDeselected(const AbstractAspect* aspect) {
 void Workbook::setChildSelectedInView(int index, bool selected) {
 	auto* aspect = child<AbstractAspect>(index);
 	if (selected) {
-		emit childAspectSelectedInView(aspect);
+		Q_EMIT childAspectSelectedInView(aspect);
 
 		//deselect the workbook in the project explorer, if a child (spreadsheet or matrix) was selected.
 		//prevents unwanted multiple selection with workbook if it was selected before.
-		emit childAspectDeselectedInView(this);
+		Q_EMIT childAspectDeselectedInView(this);
 	} else {
-		emit childAspectDeselectedInView(aspect);
+		Q_EMIT childAspectDeselectedInView(aspect);
 
 		//deselect also all children that were potentially selected before (columns of a spreadsheet)
 		for (auto* child : aspect->children<AbstractAspect>())
-			emit childAspectDeselectedInView(child);
+			Q_EMIT childAspectDeselectedInView(child);
 	}
 }
 
+QVector<AspectType> Workbook::pasteTypes() const {
+	return QVector<AspectType>{AspectType::Spreadsheet, AspectType::Matrix};
+}
+
+void Workbook::processDropEvent(const QVector<quintptr>& vec) {
+	for (auto a : vec) {
+		auto* aspect = reinterpret_cast<AbstractAspect*>(a);
+		aspect->reparent(this);
+	}
+}
 //##############################################################################
 //##################  Serialization/Deserialization  ###########################
 //##############################################################################
@@ -204,14 +195,14 @@ bool Workbook::load(XmlStreamReader* reader, bool preview) {
 			if (!readCommentElement(reader))
 				return false;
 		} else if (reader->name() == "spreadsheet") {
-			Spreadsheet* spreadsheet = new Spreadsheet("spreadsheet", true);
+			auto* spreadsheet = new Spreadsheet("spreadsheet", true);
 			if (!spreadsheet->load(reader, preview)) {
 				delete spreadsheet;
 				return false;
 			} else
 				addChild(spreadsheet);
 		} else if (reader->name() == "matrix") {
-			Matrix* matrix = new Matrix(i18n("matrix"), true);
+			auto* matrix = new Matrix(i18n("matrix"), true);
 			if (!matrix->load(reader, preview)) {
 				delete matrix;
 				return false;
