@@ -1,33 +1,15 @@
-/***************************************************************************
+/*
     File                 : aspectcommands.h
     Project              : LabPlot
-    --------------------------------------------------------------------
-    Copyright            : (C) 2007-2010 by Knut Franke (knut.franke@gmx.de)
-    Copyright            : (C) 2007-2009 Tilman Benkert(thzs@gmx.net)
-    Copyright            : (C) 2013-2017 by Alexander Semke (alexander.semke@web.de)
     Description          : Undo commands used by AbstractAspect.
-                           Only meant to be used within AbstractAspect.cpp
+    Only meant to be used within AbstractAspect.cpp
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2007-2010 Knut Franke <knut.franke@gmx.de>
+    SPDX-FileCopyrightText: 2007-2009 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2013-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 #ifndef ASPECTCOMMANDS_H
 #define ASPECTCOMMANDS_H
 
@@ -38,7 +20,7 @@
 class AspectChildRemoveCmd : public QUndoCommand {
 public:
 	AspectChildRemoveCmd(AbstractAspectPrivate* target, AbstractAspect* child)
-		: m_target(target), m_child(child), m_index(-1) {
+		: m_target(target), m_child(child), m_moved(child->isMoved()) {
 		setText(i18n("%1: remove %2", m_target->m_name, m_child->name()));
 	}
 
@@ -50,20 +32,26 @@ public:
 
 	// calling redo transfers ownership of m_child to the undo command
 	void redo() override {
+		QDEBUG(Q_FUNC_INFO << ", TARGET = " << m_target->q << " CHILD = " << m_child << ", PARENT = " << m_child->parentAspect())
 		AbstractAspect* nextSibling;
 		if (m_child == m_target->m_children.last())
 			nextSibling = nullptr;
 		else
 			nextSibling = m_target->m_children.at(m_target->indexOfChild(m_child) + 1);
 
+		//emit the "about to be removed" signal also for all children columns so the curves can react.
+		//no need to notify when the parent is just being moved (move up, moved down in the project explorer),
+		//(move = delete at the current position + insert at the new position)
+		if (!m_moved) {
+			const auto& columns = m_child->children<Column>(AbstractAspect::ChildIndexFlag::Recursive);
+			for (auto* col : columns)
+				emit col->parentAspect()->aspectAboutToBeRemoved(col);
+		}
+
 		emit m_target->q->aspectAboutToBeRemoved(m_child);
-
-		//emit the "about to be removed" signal also for all children of the aspect being currently removed
-		for (auto* child : m_child->children<AbstractAspect>(AbstractAspect::ChildIndexFlag::Recursive | AbstractAspect::ChildIndexFlag::IncludeHidden))
-			m_child->aspectAboutToBeRemoved(child);
-
 		m_index = m_target->removeChild(m_child);
 		emit m_target->q->aspectRemoved(m_target->q, nextSibling, m_child);
+		QDEBUG(Q_FUNC_INFO << ", DONE. CHILD = " << m_child)
 //		m_removed = true;
 	}
 
@@ -71,16 +59,24 @@ public:
 	void undo() override {
 		Q_ASSERT(m_index != -1); // m_child must be a child of m_target->q
 
+		if (m_moved)
+			m_child->setMoved(true);
+
 		emit m_target->q->aspectAboutToBeAdded(m_target->q, nullptr, m_child);
 		m_target->insertChild(m_index, m_child);
+		m_child->finalizeAdd();
 		emit m_target->q->aspectAdded(m_child);
+
+		if (m_moved)
+			m_child->setMoved(false);
 // 		m_removed = false;
 	}
 
 protected:
-	AbstractAspectPrivate* m_target;
-	AbstractAspect* m_child;
-	int m_index;
+	AbstractAspectPrivate* m_target{nullptr};
+	AbstractAspect* m_child{nullptr};
+	int m_index{-1};
+	bool m_moved{false};
 // 	bool m_removed{false};
 };
 
@@ -128,8 +124,8 @@ public:
 	}
 
 protected:
-	AbstractAspectPrivate * m_target;
-	AbstractAspectPrivate * m_new_parent;
+	AbstractAspectPrivate* m_target;
+	AbstractAspectPrivate* m_new_parent;
 	AbstractAspect* m_child;
 	int m_index{-1};
 	int m_new_index;
