@@ -1,55 +1,46 @@
-/***************************************************************************
+/*
     File                 : Column.h
     Project              : LabPlot
     Description          : Aspect that manages a column
     --------------------------------------------------------------------
-    Copyright            : (C) 2007-2009 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2013-2017 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2017 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2007-2009 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2013-2017 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2017 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #ifndef COLUMN_H
 #define COLUMN_H
 
-#include "backend/core/AbstractSimpleFilter.h"
-#include "backend/lib/XmlStreamReader.h"
-#include "backend/core/column/ColumnPrivate.h"
+#include "backend/core/AbstractColumn.h"
 
+class AbstractSimpleFilter;
 class CartesianPlot;
 class ColumnStringIO;
+class QAction;
 class QActionGroup;
+class XmlStreamReader;
+class ColumnPrivate;
+class ColumnSetGlobalFormulaCmd;
 
+#ifdef SDK
+#include "labplot_export.h"
+class LABPLOT_EXPORT Column : public AbstractColumn {
+#else
 class Column : public AbstractColumn {
+#endif
 	Q_OBJECT
 
 public:
-	explicit Column(const QString& name, AbstractColumn::ColumnMode = ColumnMode::Numeric);
-	// template constructor for all supported data types (AbstractColumn::ColumnMode) must be defined in header
-	template <typename T>
-	Column(const QString& name, QVector<T> data, AbstractColumn::ColumnMode mode = ColumnMode::Numeric)
-		: AbstractColumn(name, AspectType::Column), d(new ColumnPrivate(this, mode, new QVector<T>(data))) {
-		init();
-	}
+	explicit Column(const QString& name, AbstractColumn::ColumnMode = ColumnMode::Double);
+	// Templating does not work, because then ColumnPrivate.h must be included into this header,
+	// But Column.h is already included in ColumnPrivate.h
+	Column(const QString& name, const QVector<double>& data);
+	Column(const QString& name, const QVector<int> &data);
+	Column(const QString& name, const QVector<qint64>& data);
+	Column(const QString& name, const QVector<QString>& data);
+	Column(const QString& name, const QVector<QDateTime> &data, ColumnMode);
 	void init();
 	~Column() override;
 
@@ -59,6 +50,7 @@ public:
 	void updateLocale();
 
 	AbstractColumn::ColumnMode columnMode() const override;
+	QString columnModeString() const;
 	void setColumnMode(AbstractColumn::ColumnMode) override;
 	void setColumnModeFast(AbstractColumn::ColumnMode);
 
@@ -69,12 +61,13 @@ public:
 	bool copy(const AbstractColumn* source, int source_start, int dest_start, int num_rows) override;
 
 	AbstractColumn::PlotDesignation plotDesignation() const override;
-	QString plotDesignationString() const override;
+	QString plotDesignationString(bool withBrackets = true) const;
 	void setPlotDesignation(AbstractColumn::PlotDesignation) override;
 
 	bool isReadOnly() const override;
+	void resizeTo(int);
 	int rowCount() const override;
-	int availableRowCount() const override;
+	int availableRowCount(int max = -1) const override;
 	int width() const;
 	void setWidth(const int);
 	void clear() override;
@@ -84,11 +77,40 @@ public:
 	void setFormula(const QString& formula, const QStringList& variableNames,
 					const QVector<Column*>& columns, bool autoUpdate);
 	QString formula() const;
-	const QStringList& formulaVariableNames() const;
-	const QVector<Column*>& formulaVariableColumns() const;
-	const QStringList& formulaVariableColumnPaths() const;
-	void setformulVariableColumnsPath(int index, const QString& path);
-	void setformulVariableColumn(int index, Column*);
+	struct FormulaData {
+#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))	// required to use in QVector
+		FormulaData() = default;
+#endif
+		FormulaData(const QString& variableName, const QString& columnPath): m_variableName(variableName), m_columnPath(columnPath) {}
+		FormulaData(const QString& variableName, Column* column): m_column(column), m_variableName(variableName), m_columnPath(column->path()) {}
+		QString columnName() const {return (m_column ? m_column->path() : m_columnPath);}
+		bool setColumnPath(const QString& path) {
+			if (m_column && m_column->path() != path)
+				return false;
+			else if (!m_column)
+				m_columnPath = path;
+			return true;
+		}
+		void setColumn(Column* c) {
+			m_column = c;
+			if (c)
+				m_columnPath = c->path(); // do not clear path
+		}
+		// column can be changed only with setColumn
+		const Column* column() const {return m_column;}
+		const QString& variableName() const {return m_variableName;}
+	private:
+		// Should be only accessible by the columnName() function
+		Column* m_column{nullptr};
+		QString m_variableName;
+		QString m_columnPath;
+		friend ColumnSetGlobalFormulaCmd;
+	};
+
+	const QVector<FormulaData>& formulaData() const;
+	void setFormulaVariableColumn(Column*);
+	void setFormulVariableColumnsPath(int index, const QString& path);
+	void setFormulVariableColumn(int index, Column*);
 	bool formulaAutoUpdate() const;
 
 	QString formula(int) const  override;
@@ -100,28 +122,52 @@ public:
 	const AbstractColumn::ColumnStatistics& statistics() const;
 	void* data() const;
 	bool hasValues() const;
+	bool hasValueLabels() const;
+	void removeValueLabel(const QString&);
+	void clearValueLabels();
+
+	Properties properties() const override;
+	void invalidateProperties();
 
 	void setFromColumn(int, AbstractColumn*, int);
 	QString textAt(int) const override;
 	void setTextAt(int, const QString&) override;
+	void setText(const QVector<QString>&);
 	void replaceTexts(int, const QVector<QString>&) override;
+	void addValueLabel(const QString&, const QString&);
+	const QMap<QString, QString>& textValueLabels();
+
 	QDate dateAt(int) const override;
 	void setDateAt(int, QDate) override;
 	QTime timeAt(int) const override;
 	void setTimeAt(int, QTime) override;
+	void setDateTimes(const QVector<QDateTime>&);
 	QDateTime dateTimeAt(int) const override;
 	void setDateTimeAt(int, const QDateTime&) override;
 	void replaceDateTimes(int, const QVector<QDateTime>&) override;
+	void addValueLabel(const QDateTime&, const QString&);
+	const QMap<QDateTime, QString>& dateTimeValueLabels();
+
 	double valueAt(int) const override;
+	void setValues(const QVector<double>&);
 	void setValueAt(int, double) override;
 	void replaceValues(int, const QVector<double>&) override;
+	void addValueLabel(double, const QString&);
+	const QMap<double, QString>& valueLabels();
+
 	int integerAt(int) const override;
+	void setIntegers(const QVector<int>&);
 	void setIntegerAt(int, int) override;
 	void replaceInteger(int, const QVector<int>&) override;
+	void addValueLabel(int, const QString&);
+	const QMap<int, QString>& intValueLabels();
+
 	qint64 bigIntAt(int) const override;
 	void setBigIntAt(int, qint64) override;
+	void setBigInts(const QVector<qint64>&);
 	void replaceBigInt(int, const QVector<qint64>&) override;
-	Properties properties() const override;
+	void addValueLabel(qint64, const QString&);
+	const QMap<qint64, QString>& bigIntValueLabels();
 
 	double maximum(int count = 0) const override;
 	double maximum(int startIndex, int endIndex) const override;
@@ -143,7 +189,8 @@ public:
 	bool load(XmlStreamReader*, bool preview) override;
 	void finalizeLoad();
 
-public slots:
+public Q_SLOTS:
+	void pasteData();
 	void updateFormula();
 
 private:
@@ -159,15 +206,16 @@ private:
 
 	bool m_suppressDataChangedSignal{false};
 	QAction* m_copyDataAction{nullptr};
+	QAction* m_pasteDataAction{nullptr};
 	QActionGroup* m_usedInActionGroup{nullptr};
 
 	ColumnPrivate* d;
 	ColumnStringIO* m_string_io;
 
-signals:
+Q_SIGNALS:
 	void requestProjectContextMenu(QMenu*);
 
-private slots:
+private Q_SLOTS:
 	void navigateTo(QAction*);
 	void handleFormatChange();
 	void copyData();
