@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : DateTime2StringFilter.cpp
     Project              : LabPlot
-    --------------------------------------------------------------------
-    Copyright            : (C) 2007 by Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2007 by Knut Franke (knut.franke@gmx.de)
     Description          : Conversion filter QDateTime -> QString.
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2007 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2007 Knut Franke <knut.franke@gmx.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "DateTime2StringFilter.h"
 #include "backend/lib/XmlStreamReader.h"
@@ -52,10 +34,11 @@ void DateTime2StringFilter::setFormat(const QString& format) {
 }
 
 QString DateTime2StringFilter::textAt(int row) const {
-	//DEBUG("DateTime2StringFilter::textAt()");
-	if (!m_inputs.value(0)) return QString();
+	if (!m_inputs.value(0))
+		return {};
 	QDateTime inputValue = m_inputs.value(0)->dateTimeAt(row);
-	if (!inputValue.isValid()) return QString();
+	if (!inputValue.isValid())
+		return {};
 
 	//QDEBUG("	: " << inputValue << " -> " << m_format << " -> " << inputValue.toString(m_format));
 	return inputValue.toString(m_format);
@@ -81,7 +64,7 @@ void DateTime2StringFilterSetFormatCmd::redo() {
 	QString tmp = m_target->m_format;
 	m_target->m_format = m_other_format;
 	m_other_format = tmp;
-	emit m_target->formatChanged();
+	Q_EMIT m_target->formatChanged();
 }
 
 void DateTime2StringFilterSetFormatCmd::undo() {
