@@ -1,31 +1,12 @@
-/***************************************************************************
+/*
     File                 : Double2StringFilter.cpp
     Project              : AbstractColumn
-    --------------------------------------------------------------------
-    Copyright            : (C) 2007 by Knut Franke, Tilman Benkert
-    Email (use @ for *)  : knut.franke*gmx.de, thzs@gmx.net
     Description          : Locale-aware conversion filter double -> QString.
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2007 Knut Franke <knut.franke*gmx.de (use @ for *)>
+    SPDX-FileCopyrightText: 2007 Tilman Benkert <thzs@gmx.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "Double2StringFilter.h"
 #include "backend/lib/XmlStreamReader.h"
@@ -105,7 +86,7 @@ void Double2StringFilterSetFormatCmd::redo() {
 	char tmp = m_target->m_format;
 	m_target->m_format = m_other_format;
 	m_other_format = tmp;
-	emit m_target->formatChanged();
+	Q_EMIT m_target->formatChanged();
 }
 
 void Double2StringFilterSetFormatCmd::undo() {
@@ -124,7 +105,7 @@ void Double2StringFilterSetDigitsCmd::redo() {
 	int tmp = m_target->m_digits;
 	m_target->m_digits = m_other_digits;
 	m_other_digits = tmp;
-	emit m_target->digitsChanged();
+	Q_EMIT m_target->digitsChanged();
 }
 
 void Double2StringFilterSetDigitsCmd::undo() {
