@@ -1,30 +1,13 @@
-/***************************************************************************
+/*
     File                 : Datapicker.cpp
     Project              : LabPlot
     Description          : Datapicker
     --------------------------------------------------------------------
-    Copyright            : (C) 2015 by Ankit Wagadre (wagadre.ankit@gmail.com)
-    Copyright            : (C) 2015-2019 Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+    SPDX-FileCopyrightText: 2015-2022 Alexander Semke <alexander.semke@web.de>
 
- ***************************************************************************/
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "Datapicker.h"
 #include "backend/spreadsheet/Spreadsheet.h"
@@ -72,7 +55,7 @@ void Datapicker::init() {
     Returns an icon to be used in the project explorer.
 */
 QIcon Datapicker::icon() const {
-	return QIcon::fromTheme("color-picker-black");
+	return QIcon::fromTheme(QLatin1String("color-picker-black"));
 }
 
 /*!
@@ -80,7 +63,6 @@ QIcon Datapicker::icon() const {
  */
 QMenu* Datapicker::createContextMenu() {
 	QMenu* menu = AbstractPart::createContextMenu();
-	Q_ASSERT(menu);
 	m_image->createContextMenu(menu);
 	return menu;
 }
@@ -95,33 +77,27 @@ QWidget* Datapicker::view() const {
 
 
 bool Datapicker::exportView() const {
-	Spreadsheet* s = currentSpreadsheet();
-	bool ret;
+	auto* s = currentSpreadsheet();
 	if (s)
-		ret = s->exportView();
+		return s->exportView();
 	else
-		ret = m_image->exportView();
-	return ret;
+		return m_image->exportView();
 }
 
 bool Datapicker::printView() {
-	Spreadsheet* s = currentSpreadsheet();
-	bool ret;
+	auto* s = currentSpreadsheet();
 	if (s)
-		ret = s->printView();
+		return s->printView();
 	else
-		ret = m_image->printView();
-	return ret;
+		return m_image->printView();
 }
 
 bool Datapicker::printPreview() const {
-	Spreadsheet* s = currentSpreadsheet();
-	bool ret;
+	auto* s = currentSpreadsheet();
 	if (s)
-		ret = s->printPreview();
+		return s->printPreview();
 	else
-		ret = m_image->printPreview();
-	return ret;
+		return m_image->printPreview();
 }
 
 DatapickerCurve* Datapicker::activeCurve() {
@@ -157,15 +133,15 @@ void Datapicker::childSelected(const AbstractAspect* aspect) {
 	if (m_activeCurve) {
 		//if one of the curves is currently selected, select the image with the plot (the very first child)
 		index = 0;
-		emit statusInfo(i18n("%1, active curve \"%2\"", this->name(), m_activeCurve->name()));
-		emit requestUpdateActions();
+		Q_EMIT statusInfo(i18n("%1, active curve \"%2\"", this->name(), m_activeCurve->name()));
+		Q_EMIT requestUpdateActions();
 	} else if (aspect) {
 		const auto* curve = aspect->ancestor<const DatapickerCurve>();
 		index = indexOfChild<AbstractAspect>(curve);
 		++index; //+1 because of the hidden plot image being the first child and shown in the first tab in the view
 	}
 
-	emit datapickerItemSelected(index);
+	Q_EMIT datapickerItemSelected(index);
 }
 
 /*!
@@ -185,13 +161,13 @@ void Datapicker::setChildSelectedInView(int index, bool selected) {
 	//select/deselect the datapicker itself if the first tab "representing" the plot image and the curves was selected in the view
 	if (index == 0) {
 		if (selected)
-			emit childAspectSelectedInView(this);
+			Q_EMIT childAspectSelectedInView(this);
 		else {
-			emit childAspectDeselectedInView(this);
+			Q_EMIT childAspectDeselectedInView(this);
 
 			//deselect also all curves (they don't have any tab index in the view) that were potentially selected before
 			for (const auto* curve : children<const DatapickerCurve>())
-				emit childAspectDeselectedInView(curve);
+				Q_EMIT childAspectDeselectedInView(curve);
 		}
 
 		return;
@@ -203,17 +179,17 @@ void Datapicker::setChildSelectedInView(int index, bool selected) {
 	auto spreadsheets = children<const Spreadsheet>(ChildIndexFlag::Recursive);
 	const AbstractAspect* aspect = spreadsheets.at(index);
 	if (selected) {
-		emit childAspectSelectedInView(aspect);
+		Q_EMIT childAspectSelectedInView(aspect);
 
 		//deselect the datapicker in the project explorer, if a child (spreadsheet or image) was selected.
 		//prevents unwanted multiple selection with datapicker if it was selected before.
-		emit childAspectDeselectedInView(this);
+		Q_EMIT childAspectDeselectedInView(this);
 	} else {
-		emit childAspectDeselectedInView(aspect);
+		Q_EMIT childAspectDeselectedInView(aspect);
 
 		//deselect also all children that were potentially selected before (columns of a spreadsheet)
 		for (const auto* child : aspect->children<const AbstractAspect>())
-			emit childAspectDeselectedInView(child);
+			Q_EMIT childAspectDeselectedInView(child);
 	}
 }
 
@@ -223,9 +199,9 @@ void Datapicker::setChildSelectedInView(int index, bool selected) {
 */
 void Datapicker::setSelectedInView(const bool b) {
 	if (b)
-		emit childAspectSelectedInView(this);
+		Q_EMIT childAspectSelectedInView(this);
 	else
-		emit childAspectDeselectedInView(this);
+		Q_EMIT childAspectDeselectedInView(this);
 }
 
 void Datapicker::addNewPoint(QPointF pos, AbstractAspect* parentAspect) {
@@ -241,17 +217,18 @@ void Datapicker::addNewPoint(QPointF pos, AbstractAspect* parentAspect) {
 
 	auto* datapickerCurve = static_cast<DatapickerCurve*>(parentAspect);
 	if (m_image == parentAspect) {
-		DatapickerImage::ReferencePoints axisPoints = m_image->axisPoints();
+		auto axisPoints = m_image->axisPoints();
 		axisPoints.scenePos[points.count()].setX(pos.x());
 		axisPoints.scenePos[points.count()].setY(pos.y());
 		m_image->setAxisPoints(axisPoints);
+		newPoint->setIsReferencePoint(true);
 	} else if (datapickerCurve) {
 		newPoint->initErrorBar(datapickerCurve->curveErrorTypes());
 		datapickerCurve->updatePoint(newPoint);
 	}
 
 	endMacro();
-	emit requestUpdateActions();
+	Q_EMIT requestUpdateActions();
 }
 
 QVector3D Datapicker::mapSceneToLogical(QPointF point) const {
@@ -272,12 +249,12 @@ void Datapicker::handleAspectAboutToBeRemoved(const AbstractAspect* aspect) {
 
 		if (curve == m_activeCurve) {
 			m_activeCurve = nullptr;
-			emit statusInfo(QString());
+			Q_EMIT statusInfo(QString());
 		}
 	} else
 		handleChildAspectAboutToBeRemoved(aspect);
 
-	emit requestUpdateActions();
+	Q_EMIT requestUpdateActions();
 }
 
 void Datapicker::handleAspectAdded(const AbstractAspect* aspect) {
@@ -303,7 +280,7 @@ void Datapicker::handleAspectAdded(const AbstractAspect* aspect) {
 			point->graphicsItem()->setZValue(zVal++);
 	}
 
-	emit requestUpdateActions();
+	Q_EMIT requestUpdateActions();
 }
 
 void Datapicker::handleChildAspectAboutToBeRemoved(const AbstractAspect* aspect) {
