@@ -1,30 +1,13 @@
-/***************************************************************************
+/*
     File                 : DatapickerCurve.cpp
     Project              : LabPlot
     Description          : container for Curve-Point and Datasheet/Spreadsheet
-                           of datapicker
+    of datapicker
     --------------------------------------------------------------------
-    Copyright            : (C) 2015 by Ankit Wagadre (wagadre.ankit@gmail.com)
-    Copyright            : (C) 2015-2019 Alexander Semke (alexander.semke@web.de)
- ***************************************************************************/
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+    SPDX-FileCopyrightText: 2015-2022 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "DatapickerCurve.h"
 #include "backend/datapicker/DatapickerCurvePrivate.h"
@@ -34,6 +17,7 @@
 #include "backend/lib/XmlStreamReader.h"
 #include "backend/spreadsheet/Spreadsheet.h"
 #include "backend/worksheet/Worksheet.h"
+#include "backend/worksheet/plots/cartesian/Symbol.h"
 
 #include <QIcon>
 #include <QVector3D>
@@ -70,26 +54,25 @@ void DatapickerCurve::init() {
 	KConfig config;
 	KConfigGroup group;
 	group = config.group("DatapickerCurve");
+	d->pointVisibility = group.readEntry("PointVisibility", true);
+
+	//error bars
 	d->curveErrorTypes.x = (ErrorType) group.readEntry("CurveErrorType_X", static_cast<int>(ErrorType::NoError));
 	d->curveErrorTypes.y = (ErrorType) group.readEntry("CurveErrorType_Y", static_cast<int>(ErrorType::NoError));
-
-	// point properties
-	d->pointStyle = (Symbol::Style)group.readEntry("PointStyle", static_cast<int>(Symbol::Style::Cross));
-	d->pointSize = group.readEntry("Size", Worksheet::convertToSceneUnits(7, Worksheet::Unit::Point));
-	d->pointRotationAngle = group.readEntry("Rotation", 0.0);
-	d->pointOpacity = group.readEntry("Opacity", 1.0);
-	d->pointBrush.setStyle( (Qt::BrushStyle)group.readEntry("FillingStyle", (int)Qt::NoBrush) );
-	d->pointBrush.setColor( group.readEntry("FillingColor", QColor(Qt::black)) );
-	d->pointPen.setStyle( (Qt::PenStyle)group.readEntry("BorderStyle", (int)Qt::SolidLine) );
-	d->pointPen.setColor( group.readEntry("BorderColor", QColor(Qt::red)) );
-	d->pointPen.setWidthF( group.readEntry("BorderWidth", Worksheet::convertToSceneUnits(1, Worksheet::Unit::Point)) );
 	d->pointErrorBarSize = group.readEntry("ErrorBarSize", Worksheet::convertToSceneUnits(8, Worksheet::Unit::Point));
 	d->pointErrorBarBrush.setStyle( (Qt::BrushStyle)group.readEntry("ErrorBarFillingStyle", (int)Qt::NoBrush) );
 	d->pointErrorBarBrush.setColor( group.readEntry("ErrorBarFillingColor", QColor(Qt::black)) );
 	d->pointErrorBarPen.setStyle( (Qt::PenStyle)group.readEntry("ErrorBarBorderStyle", (int)Qt::SolidLine) );
 	d->pointErrorBarPen.setColor( group.readEntry("ErrorBarBorderColor", QColor(Qt::black)) );
 	d->pointErrorBarPen.setWidthF( group.readEntry("ErrorBarBorderWidth", Worksheet::convertToSceneUnits(1, Worksheet::Unit::Point)) );
-	d->pointVisibility = group.readEntry("PointVisibility", true);
+
+	//initialize the symbol
+	d->symbol = new Symbol(QString());
+	addChild(d->symbol);
+	d->symbol->setHidden(true);
+	connect(d->symbol, &Symbol::updateRequested, [=]{d->retransform();});
+	connect(d->symbol, &Symbol::updatePixmapRequested, [=]{d->retransform();});
+	d->symbol->init(group);
 }
 
 /*!
@@ -100,9 +83,9 @@ QIcon DatapickerCurve::icon() const {
 }
 
 Column* DatapickerCurve::appendColumn(const QString& name) {
-	Column* col = new Column(i18n("Column"), AbstractColumn::ColumnMode::Numeric);
+	auto* col = new Column(name);
 	col->insertRows(0, m_datasheet->rowCount());
-	col->setName(name);
+	col->setFixed(true);
 	m_datasheet->addChild(col);
 
 	return col;
@@ -111,16 +94,15 @@ Column* DatapickerCurve::appendColumn(const QString& name) {
 //##############################################################################
 //##########################  getter methods  ##################################
 //##############################################################################
+Symbol* DatapickerCurve::symbol() const {
+	Q_D(const DatapickerCurve);
+	return d->symbol;
+}
+
 BASIC_SHARED_D_READER_IMPL(DatapickerCurve, DatapickerCurve::Errors, curveErrorTypes, curveErrorTypes)
-BASIC_SHARED_D_READER_IMPL(DatapickerCurve, Symbol::Style, pointStyle, pointStyle)
-BASIC_SHARED_D_READER_IMPL(DatapickerCurve, qreal, pointOpacity, pointOpacity)
-BASIC_SHARED_D_READER_IMPL(DatapickerCurve, qreal, pointRotationAngle, pointRotationAngle)
-BASIC_SHARED_D_READER_IMPL(DatapickerCurve, qreal, pointSize, pointSize)
-CLASS_SHARED_D_READER_IMPL(DatapickerCurve, QBrush, pointBrush, pointBrush)
-CLASS_SHARED_D_READER_IMPL(DatapickerCurve, QPen, pointPen, pointPen)
 BASIC_SHARED_D_READER_IMPL(DatapickerCurve, qreal, pointErrorBarSize, pointErrorBarSize)
-CLASS_SHARED_D_READER_IMPL(DatapickerCurve, QBrush, pointErrorBarBrush, pointErrorBarBrush)
-CLASS_SHARED_D_READER_IMPL(DatapickerCurve, QPen, pointErrorBarPen, pointErrorBarPen)
+BASIC_SHARED_D_READER_IMPL(DatapickerCurve, QBrush, pointErrorBarBrush, pointErrorBarBrush)
+BASIC_SHARED_D_READER_IMPL(DatapickerCurve, QPen, pointErrorBarPen, pointErrorBarPen)
 BASIC_SHARED_D_READER_IMPL(DatapickerCurve, bool, pointVisibility, pointVisibility)
 
 BASIC_SHARED_D_READER_IMPL(DatapickerCurve, AbstractColumn*, posXColumn, posXColumn)
@@ -165,32 +147,67 @@ void DatapickerCurve::addDatasheet(DatapickerImage::GraphType type) {
 	Q_D(DatapickerCurve);
 
 	m_datasheet = new Spreadsheet(i18n("Data"));
+	m_datasheet->setFixed(true);
 	addChild(m_datasheet);
-	QString xLabel('x');
-	QString yLabel('y');
 
-	if (type == DatapickerImage::GraphType::PolarInDegree) {
+	QString xLabel;
+	QString yLabel;
+
+	switch (type) {
+	case DatapickerImage::GraphType::Cartesian: {
+		xLabel = QLatin1Char('x');
+		yLabel = QLatin1Char('y');
+		break;
+	}
+	case DatapickerImage::GraphType::PolarInDegree: {
 		xLabel = QLatin1String("r");
 		yLabel = QLatin1String("y(deg)");
-	} else if (type == DatapickerImage::GraphType::PolarInRadians) {
+		break;
+	}
+	case DatapickerImage::GraphType::PolarInRadians: {
 		xLabel = QLatin1String("r");
 		yLabel = QLatin1String("y(rad)");
-	} else if (type == DatapickerImage::GraphType::LogarithmicX) {
+		break;
+	}
+	case DatapickerImage::GraphType::LogarithmicX: {
 		xLabel = QLatin1String("log(x)");
 		yLabel = QLatin1String("y");
-	} else if (type == DatapickerImage::GraphType::LogarithmicY) {
+		break;
+	}
+	case DatapickerImage::GraphType::LogarithmicY: {
 		xLabel = QLatin1String("x");
 		yLabel = QLatin1String("log(y)");
+		break;
+	}
+	case DatapickerImage::GraphType::Ternary: {
+		xLabel = QLatin1Char('a');
+		yLabel = QLatin1Char('b');
+		break;
+	}
 	}
 
+	//the default spreadsheet can have arbitrary number of colums as per user's default template.
+	//make sure we have the columns for x and y only
+	if (m_datasheet->columnCount() < 1)
+		appendColumn(xLabel);
+	if (m_datasheet->columnCount() < 2)
+		appendColumn(yLabel);
+	if (m_datasheet->columnCount() > 2)
+		m_datasheet->setColumnCount(2);
+
+	//add the third column for Ternary
 	if (type == DatapickerImage::GraphType::Ternary)
-		d->posZColumn = appendColumn(i18n("c"));
+		d->posZColumn = appendColumn(QLatin1String("c"));
 
 	d->posXColumn = m_datasheet->column(0);
 	d->posXColumn->setName(xLabel);
+	d->posXColumn->setPlotDesignation(AbstractColumn::PlotDesignation::X);
+	d->posXColumn->setFixed(true);
 
 	d->posYColumn = m_datasheet->column(1);
 	d->posYColumn->setName(yLabel);
+	d->posXColumn->setPlotDesignation(AbstractColumn::PlotDesignation::Y);
+	d->posYColumn->setFixed(true);
 }
 
 STD_SETTER_CMD_IMPL_S(DatapickerCurve, SetCurveErrorTypes, DatapickerCurve::Errors, curveErrorTypes)
@@ -281,48 +298,6 @@ void DatapickerCurve::setMinusDeltaYColumn(AbstractColumn* column) {
 		exec(new DatapickerCurveSetMinusDeltaYColumnCmd(d, column, ki18n("%1: set -delta_Y column")));
 }
 
-STD_SETTER_CMD_IMPL_F_S(DatapickerCurve, SetPointStyle, Symbol::Style, pointStyle, retransform)
-void DatapickerCurve::setPointStyle(Symbol::Style newStyle) {
-	Q_D(DatapickerCurve);
-	if (newStyle != d->pointStyle)
-		exec(new DatapickerCurveSetPointStyleCmd(d, newStyle, ki18n("%1: set point's style")));
-}
-
-STD_SETTER_CMD_IMPL_F_S(DatapickerCurve, SetPointSize, qreal, pointSize, retransform)
-void DatapickerCurve::setPointSize(qreal value) {
-	Q_D(DatapickerCurve);
-	if (!qFuzzyCompare(1 + value, 1 + d->pointSize))
-		exec(new DatapickerCurveSetPointSizeCmd(d, value, ki18n("%1: set point's size")));
-}
-
-STD_SETTER_CMD_IMPL_F_S(DatapickerCurve, SetPointRotationAngle, qreal, pointRotationAngle, retransform)
-void DatapickerCurve::setPointRotationAngle(qreal angle) {
-	Q_D(DatapickerCurve);
-	if (!qFuzzyCompare(1 + angle, 1 + d->pointRotationAngle))
-		exec(new DatapickerCurveSetPointRotationAngleCmd(d, angle, ki18n("%1: rotate point")));
-}
-
-STD_SETTER_CMD_IMPL_F_S(DatapickerCurve, SetPointBrush, QBrush, pointBrush, retransform)
-void DatapickerCurve::setPointBrush(const QBrush& newBrush) {
-	Q_D(DatapickerCurve);
-	if (newBrush != d->pointBrush)
-		exec(new DatapickerCurveSetPointBrushCmd(d, newBrush, ki18n("%1: set point's filling")));
-}
-
-STD_SETTER_CMD_IMPL_F_S(DatapickerCurve, SetPointPen, QPen, pointPen, retransform)
-void DatapickerCurve::setPointPen(const QPen &newPen) {
-	Q_D(DatapickerCurve);
-	if (newPen != d->pointPen)
-		exec(new DatapickerCurveSetPointPenCmd(d, newPen, ki18n("%1: set outline style")));
-}
-
-STD_SETTER_CMD_IMPL_F_S(DatapickerCurve, SetPointOpacity, qreal, pointOpacity, retransform)
-void DatapickerCurve::setPointOpacity(qreal newOpacity) {
-	Q_D(DatapickerCurve);
-	if (newOpacity != d->pointOpacity)
-		exec(new DatapickerCurveSetPointOpacityCmd(d, newOpacity, ki18n("%1: set point's opacity")));
-}
-
 STD_SETTER_CMD_IMPL_F_S(DatapickerCurve, SetPointErrorBarSize, qreal, pointErrorBarSize, retransform)
 void DatapickerCurve::setPointErrorBarSize(qreal size) {
 	Q_D(DatapickerCurve);
@@ -362,10 +337,11 @@ void DatapickerCurve::setPrinting(bool on) {
 */
 void DatapickerCurve::setSelectedInView(bool b) {
 	if (b)
-		emit childAspectSelectedInView(this);
+		Q_EMIT childAspectSelectedInView(this);
 	else
-		emit childAspectDeselectedInView(this);
+		Q_EMIT childAspectDeselectedInView(this);
 }
+
 //##############################################################################
 //######  SLOTs for changes triggered via QActions in the context menu  ########
 //##############################################################################
@@ -390,6 +366,11 @@ void DatapickerCurve::updatePoint(const DatapickerPoint* point) {
 
 	auto* datapicker = static_cast<Datapicker*>(parentAspect());
 	int row = indexOfChild<DatapickerPoint>(point, ChildIndexFlag::IncludeHidden);
+
+	//resize the spreadsheet if needed (row starts with 0, add 1 when comparing with rowCount())
+	if (m_datasheet->rowCount() < row + 1)
+		m_datasheet->setRowCount(row + 1);
+
 	QVector3D data = datapicker->mapSceneToLogical(point->position());
 
 	if (d->posXColumn)
@@ -433,7 +414,9 @@ QString DatapickerCurvePrivate::name() const {
 }
 
 void DatapickerCurvePrivate::retransform() {
-	auto points = q->children<DatapickerPoint>(AbstractAspect::ChildIndexFlag::IncludeHidden);
+	if (q->isLoading())
+		return;
+	const auto& points = q->children<DatapickerPoint>(AbstractAspect::ChildIndexFlag::IncludeHidden);
 	for (auto* point : points)
 		point->retransform();
 }
@@ -460,18 +443,11 @@ void DatapickerCurve::save(QXmlStreamWriter* writer) const {
 	WRITE_COLUMN(d->minusDeltaYColumn, minusDeltaYColumn);
 	writer->writeAttribute( "curveErrorType_X", QString::number(static_cast<int>(d->curveErrorTypes.x)) );
 	writer->writeAttribute( "curveErrorType_Y", QString::number(static_cast<int>(d->curveErrorTypes.y)) );
+	writer->writeAttribute( "vibible", QString::number(d->pointVisibility) );
 	writer->writeEndElement();
 
-	//symbol properties
-	writer->writeStartElement("symbolProperties");
-	writer->writeAttribute( "pointRotationAngle", QString::number(d->pointRotationAngle) );
-	writer->writeAttribute( "pointOpacity", QString::number(d->pointOpacity) );
-	writer->writeAttribute( "pointSize", QString::number(d->pointSize) );
-	writer->writeAttribute( "pointStyle", QString::number(static_cast<int>(d->pointStyle)) );
-	writer->writeAttribute( "pointVisibility", QString::number(d->pointVisibility) );
-	WRITE_QBRUSH(d->pointBrush);
-	WRITE_QPEN(d->pointPen);
-	writer->writeEndElement();
+	//Symbols
+	d->symbol->save(writer);
 
 	//error bar properties
 	writer->writeStartElement("errorBarProperties");
@@ -511,6 +487,7 @@ bool DatapickerCurve::load(XmlStreamReader* reader, bool preview) {
 		} else if (!preview && reader->name() == "general") {
 			attribs = reader->attributes();
 
+			READ_INT_VALUE("visible", pointVisibility, bool);
 			READ_INT_VALUE("curveErrorType_X", curveErrorTypes.x, ErrorType);
 			READ_INT_VALUE("curveErrorType_Y", curveErrorTypes.y, ErrorType);
 
@@ -522,16 +499,104 @@ bool DatapickerCurve::load(XmlStreamReader* reader, bool preview) {
 			READ_COLUMN(plusDeltaYColumn);
 			READ_COLUMN(minusDeltaYColumn);
 		} else if (!preview && reader->name() == "symbolProperties") {
+			//old serialization that was used before the switch to Symbol::load().
+			//in the old serialization the symbol properties and "point visibility" where saved
+			//under "symbolProperties".
 			attribs = reader->attributes();
 
-			READ_DOUBLE_VALUE("pointRotationAngle", pointRotationAngle);
-			READ_DOUBLE_VALUE("pointOpacity", pointOpacity);
-			READ_DOUBLE_VALUE("pointSize", pointSize);
-			READ_INT_VALUE("pointStyle", pointStyle, Symbol::Style);
-			READ_INT_VALUE("pointVisibility", pointVisibility, bool);
+			str = attribs.value("pointRotationAngle").toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs("pointRotationAngle").toString());
+			else
+				d->symbol->setRotationAngle(str.toDouble());
 
-			READ_QBRUSH(d->pointBrush);
-			READ_QPEN(d->pointPen);
+			str = attribs.value("pointOpacity").toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs("pointOpacity").toString());
+			else
+				d->symbol->setOpacity(str.toDouble());
+
+			str = attribs.value("pointSize").toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs("pointSize").toString());
+			else
+				d->symbol->setSize(str.toDouble());
+
+			str = attribs.value("pointStyle").toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs("pointStyle").toString());
+			else
+				d->symbol->setStyle(static_cast<Symbol::Style>(str.toInt()));
+
+			//brush
+			QBrush brush;
+			str = attribs.value("brush_style").toString();
+			if(str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs("brush_style").toString());
+			else
+				brush.setStyle( static_cast<Qt::BrushStyle>(str.toInt()) );
+
+			QColor color;
+			str = attribs.value("brush_color_r").toString();
+			if(str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs("brush_color_r").toString());
+			else
+				color.setRed(str.toInt());
+
+			str = attribs.value("brush_color_g").toString();
+			if(str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs("brush_color_g").toString());
+			else
+				color.setGreen(str.toInt());
+
+			str = attribs.value("brush_color_b").toString();
+			if(str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs("brush_color_b").toString());
+			else
+				color.setBlue(str.toInt());
+
+			brush.setColor(color);
+			d->symbol->setBrush(brush);
+
+			//pen
+			QPen pen;
+			str = attribs.value("style").toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs("style").toString());
+			else
+				pen.setStyle( static_cast<Qt::PenStyle>(str.toInt()) );
+
+			str = attribs.value("color_r").toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs("color_r").toString());
+			else
+				color.setRed( str.toInt() );
+
+			str = attribs.value("color_g").toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs("color_g").toString());
+			else
+				color.setGreen( str.toInt() );
+
+			str = attribs.value("color_b").toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs("color_b").toString());
+			else
+				color.setBlue( str.toInt() );
+
+			pen.setColor(color);
+
+			str = attribs.value("width").toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs("width").toString());
+			else
+				pen.setWidthF( str.toDouble() );
+
+			d->symbol->setPen(pen);
+
+			READ_INT_VALUE("pointVisibility", pointVisibility, bool);
+		} else if (!preview && reader->name() == "symbols") {
+			d->symbol->load(reader, preview);
 		} else if (!preview && reader->name() == "errorBarProperties") {
 			attribs = reader->attributes();
 
@@ -549,12 +614,16 @@ bool DatapickerCurve::load(XmlStreamReader* reader, bool preview) {
 				curvePoint->initErrorBar(curveErrorTypes());
 			}
 		} else if (reader->name() == "spreadsheet") {
-			Spreadsheet* datasheet = new Spreadsheet("spreadsheet", true);
+			auto* datasheet = new Spreadsheet("spreadsheet", true);
 			if (!datasheet->load(reader, preview)) {
 				delete datasheet;
 				return false;
 			} else {
 				addChild(datasheet);
+				datasheet->setFixed(true);
+				const auto& columns = datasheet->children<Column>();
+				for (auto* col : columns)
+					col->setFixed(true);
 				m_datasheet = datasheet;
 			}
 		} else { // unknown element
