@@ -1,30 +1,13 @@
-/***************************************************************************
+/*
     File                 : DatapickerCurve.h
     Project              : LabPlot
     Description          : container for Curve-Point and Datasheet/Spreadsheet
-                           of datapicker
+    of datapicker
     --------------------------------------------------------------------
-    Copyright            : (C) 2015 by Ankit Wagadre (wagadre.ankit@gmail.com)
-    Copyright            : (C) 2015-2019 Alexander Semke (alexander.semke@web.de)
- ***************************************************************************/
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+    SPDX-FileCopyrightText: 2015-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef DATAPICKERCURVE_H
 #define DATAPICKERCURVE_H
@@ -61,13 +44,8 @@ public:
 	void updatePoints();
 	void updatePoint(const DatapickerPoint*);
 
+	Symbol* symbol() const;
 	BASIC_D_ACCESSOR_DECL(Errors, curveErrorTypes, CurveErrorTypes)
-	BASIC_D_ACCESSOR_DECL(Symbol::Style, pointStyle, PointStyle)
-	BASIC_D_ACCESSOR_DECL(qreal, pointOpacity, PointOpacity)
-	BASIC_D_ACCESSOR_DECL(qreal, pointRotationAngle, PointRotationAngle)
-	BASIC_D_ACCESSOR_DECL(qreal, pointSize, PointSize)
-	CLASS_D_ACCESSOR_DECL(QBrush, pointBrush, PointBrush)
-	CLASS_D_ACCESSOR_DECL(QPen, pointPen, PointPen)
 	BASIC_D_ACCESSOR_DECL(qreal, pointErrorBarSize, PointErrorBarSize)
 	CLASS_D_ACCESSOR_DECL(QBrush, pointErrorBarBrush, PointErrorBarBrush)
 	CLASS_D_ACCESSOR_DECL(QPen, pointErrorBarPen, PointErrorBarPen)
@@ -105,7 +83,7 @@ private:
 
 	Spreadsheet* m_datasheet{nullptr};
 
-signals:
+Q_SIGNALS:
 	void curveErrorTypesChanged(const DatapickerCurve::Errors&);
 	void posXColumnChanged(const AbstractColumn*);
 	void posYColumnChanged(const AbstractColumn*);
