@@ -1,30 +1,13 @@
-/***************************************************************************
-  File                 : DatapickerImage.h
-  Project              : LabPlot
-  Description          : Worksheet for Datapicker
-  --------------------------------------------------------------------
-  Copyright            : (C) 2015 by Ankit Wagadre (wagadre.ankit@gmail.com)
-  Copyright            : (C) 2015-2016 by Alexander Semke (alexander.semke@web.de)
+/*
+    File                 : DatapickerImage.h
+    Project              : LabPlot
+    Description          : Worksheet for Datapicker
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+    SPDX-FileCopyrightText: 2015-2021 Alexander Semke <alexander.semke@web.de>
 
-***************************************************************************/
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef DATAPICKERIMAGE_H
 #define DATAPICKERIMAGE_H
@@ -36,11 +19,8 @@
 #include <QVector3D>
 #include <QPen>
 
-class QImage;
-class QBrush;
 class DatapickerImagePrivate;
 class DatapickerImageView;
-class ImageEditor;
 class Segments;
 
 class QGraphicsScene;
@@ -120,12 +100,7 @@ public:
 	BASIC_D_ACCESSOR_DECL(int, pointSeparation, PointSeparation)
 	BASIC_D_ACCESSOR_DECL(int, minSegmentLength, minSegmentLength)
 
-	BASIC_D_ACCESSOR_DECL(Symbol::Style, pointStyle, PointStyle)
-	BASIC_D_ACCESSOR_DECL(qreal, pointOpacity, PointOpacity)
-	BASIC_D_ACCESSOR_DECL(qreal, pointRotationAngle, PointRotationAngle)
-	BASIC_D_ACCESSOR_DECL(qreal, pointSize, PointSize)
-	CLASS_D_ACCESSOR_DECL(QBrush, pointBrush, PointBrush)
-	CLASS_D_ACCESSOR_DECL(QPen, pointPen, PointPen)
+	Symbol* symbol() const;
 	BASIC_D_ACCESSOR_DECL(bool, pointVisibility, PointVisibility)
 
 	typedef DatapickerImagePrivate Private;
@@ -138,7 +113,7 @@ private:
 	friend class DatapickerImagePrivate;
 	Segments* m_segments;
 
-signals:
+Q_SIGNALS:
 	void requestProjectContextMenu(QMenu*);
 	void requestUpdate();
 	void requestUpdateActions();
