@@ -1,36 +1,20 @@
-/***************************************************************************
+/*
     File                 : DatapickerPoint.cpp
     Project              : LabPlot
     Description          : Graphic Item for coordinate points of Datapicker
     --------------------------------------------------------------------
-    Copyright            : (C) 2015 by Ankit Wagadre (wagadre.ankit@gmail.com)
-	Copyright            : (C) 2015-2019 Alexander Semke (alexander.semke@web.de)
- ***************************************************************************/
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+    SPDX-FileCopyrightText: 2015-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "DatapickerPoint.h"
-#include "backend/worksheet/Worksheet.h"
 #include "DatapickerPointPrivate.h"
 #include "backend/lib/commandtemplates.h"
 #include "backend/lib/XmlStreamReader.h"
 #include "backend/datapicker/DatapickerCurve.h"
+#include "backend/worksheet/Worksheet.h"
+#include "backend/worksheet/plots/cartesian/Symbol.h"
 
 #include <QPainter>
 #include <QGraphicsScene>
@@ -212,12 +196,12 @@ void DatapickerPoint::retransform() {
 
 /* ============================ getter methods ================= */
 //point
-CLASS_SHARED_D_READER_IMPL(DatapickerPoint, QPointF, position, position)
+BASIC_SHARED_D_READER_IMPL(DatapickerPoint, QPointF, position, position)
 //error-bar
-CLASS_SHARED_D_READER_IMPL(DatapickerPoint, QPointF, plusDeltaXPos, plusDeltaXPos)
-CLASS_SHARED_D_READER_IMPL(DatapickerPoint, QPointF, minusDeltaXPos, minusDeltaXPos)
-CLASS_SHARED_D_READER_IMPL(DatapickerPoint, QPointF, plusDeltaYPos, plusDeltaYPos)
-CLASS_SHARED_D_READER_IMPL(DatapickerPoint, QPointF, minusDeltaYPos, minusDeltaYPos)
+BASIC_SHARED_D_READER_IMPL(DatapickerPoint, QPointF, plusDeltaXPos, plusDeltaXPos)
+BASIC_SHARED_D_READER_IMPL(DatapickerPoint, QPointF, minusDeltaXPos, minusDeltaXPos)
+BASIC_SHARED_D_READER_IMPL(DatapickerPoint, QPointF, plusDeltaYPos, plusDeltaYPos)
+BASIC_SHARED_D_READER_IMPL(DatapickerPoint, QPointF, minusDeltaYPos, minusDeltaYPos)
 
 /* ============================ setter methods and undo commands ================= */
 STD_SETTER_CMD_IMPL_F_S(DatapickerPoint, SetPosition, QPointF, position, retransform)
@@ -304,6 +288,16 @@ void DatapickerPoint::setPrinting(bool on) {
 	d->m_printing = on;
 }
 
+void DatapickerPoint::setIsReferencePoint(bool value) {
+	Q_D(DatapickerPoint);
+	d->isReferencePoint = value;
+}
+
+bool DatapickerPoint::isReferencePoint() const {
+	Q_D(const DatapickerPoint);
+	return d->isReferencePoint;
+}
+
 //##############################################################################
 //####################### Private implementation ###############################
 //##############################################################################
@@ -322,13 +316,14 @@ QString DatapickerPointPrivate::name() const {
     calculates the position and the bounding box of the item/point. Called on geometry or properties changes.
  */
 void DatapickerPointPrivate::retransform() {
+	if (q->isLoading())
+		return;
 	updatePropeties();
 	setPos(position);
-	QPainterPath path = Symbol::pathFromStyle(pointStyle);
+	QPainterPath path = Symbol::stylePath(pointStyle);
 	boundingRectangle = path.boundingRect();
 	recalcShapeAndBoundingRect();
 	retransformErrorBar();
-	updatePoint();
 }
 
 /*!
@@ -357,20 +352,20 @@ void DatapickerPointPrivate::updatePropeties() {
 	auto* curve = dynamic_cast<DatapickerCurve*>(q->parentAspect());
 	auto* image = dynamic_cast<DatapickerImage*>(q->parentAspect());
 	if (image) {
-		rotationAngle = image->pointRotationAngle();
-		pointStyle = image->pointStyle();
-		brush = image->pointBrush();
-		pen = image->pointPen();
-		opacity = image->pointOpacity();
-		size = image->pointSize();
+		rotationAngle = image->symbol()->rotationAngle();
+		pointStyle = image->symbol()->style();
+		brush = image->symbol()->brush();
+		pen = image->symbol()->pen();
+		opacity = image->symbol()->opacity();
+		size = image->symbol()->size();
 		setVisible(image->pointVisibility());
 	} else if (curve) {
-		rotationAngle = curve->pointRotationAngle();
-		pointStyle = curve->pointStyle();
-		brush = curve->pointBrush();
-		pen = curve->pointPen();
-		opacity = curve->pointOpacity();
-		size = curve->pointSize();
+		rotationAngle = curve->symbol()->rotationAngle();
+		pointStyle = curve->symbol()->style();
+		brush = curve->symbol()->brush();
+		pen = curve->symbol()->pen();
+		opacity = curve->symbol()->opacity();
+		size = curve->symbol()->size();
 		errorBarBrush = curve->pointErrorBarBrush();
 		errorBarPen = curve->pointErrorBarPen();
 		errorBarSize = curve->pointErrorBarSize();
@@ -420,11 +415,8 @@ void DatapickerPointPrivate::hoverLeaveEvent(QGraphicsSceneHoverEvent*) {
 	setCursor(Qt::CrossCursor);
 }
 
-void DatapickerPointPrivate::paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget) {
-	Q_UNUSED(option)
-	Q_UNUSED(widget)
-
-	QPainterPath path = Symbol::pathFromStyle(pointStyle);
+void DatapickerPointPrivate::paint(QPainter* painter, const QStyleOptionGraphicsItem* /*option*/, QWidget*) {
+	QPainterPath path = Symbol::stylePath(pointStyle);
 	QTransform trafo;
 	trafo.scale(size, size);
 	path = trafo.map(path);
