@@ -1,28 +1,11 @@
-/***************************************************************************
+/*
     File                 : Segments.cpp
     Project              : LabPlot
     Description          : Contains methods to trace curve of image/plot
     --------------------------------------------------------------------
-    Copyright            : (C) 2015 by Ankit Wagadre (wagadre.ankit@gmail.com)
- ***************************************************************************/
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "Segments.h"
 #include "backend/datapicker/Segment.h"
@@ -75,8 +58,8 @@ void Segments::makeSegments(QImage &imageProcessed) {
 	bool* lastBool = new bool [height];
 	bool* currBool = new bool [height];
 	bool* nextBool = new bool [height];
-	Segment** lastSegment = new Segment* [(size_t)height];
-	Segment** currSegment = new Segment* [(size_t)height];
+	auto** lastSegment = new Segment* [(size_t)height];
+	auto** currSegment = new Segment* [(size_t)height];
 	loadSegment(lastSegment, height);
 
 	//initialize one column of boolean flags using the pixels of the specified column
