@@ -1,39 +1,23 @@
-/***************************************************************************
-File		: LiveDataSource.cpp
-Project		: LabPlot
-Description	: Represents live data source
---------------------------------------------------------------------
-Copyright	: (C) 2009-2019 Alexander Semke (alexander.semke@web.de)
-Copyright	: (C) 2017 Fabian Kristof (fkristofszabolcs@gmail.com)
-Copyright	: (C) 2018 Stefan Gerlach (stefan.gerlach@uni.kn)
+/*
+    File		: LiveDataSource.cpp
+    Project		: LabPlot
+    Description	: Represents live data source
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2009-2022 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2017 Fabian Kristof <fkristofszabolcs@gmail.com>
+    SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-***************************************************************************/
-
-/***************************************************************************
-*                                                                         *
-*  This program is free software; you can redistribute it and/or modify   *
-*  it under the terms of the GNU General Public License as published by   *
-*  the Free Software Foundation; either version 2 of the License, or      *
-*  (at your option) any later version.                                    *
-*                                                                         *
-*  This program is distributed in the hope that it will be useful,        *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
-*  GNU General Public License for more details.                           *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the Free Software           *
-*   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
-*   Boston, MA  02110-1301  USA                                           *
-*                                                                         *
-***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "backend/datasources/LiveDataSource.h"
 #include "backend/datasources/filters/AsciiFilter.h"
 #include "backend/datasources/filters/FITSFilter.h"
 #include "backend/datasources/filters/BinaryFilter.h"
 #include "backend/datasources/filters/ROOTFilter.h"
+#include "backend/datasources/filters/SpiceFilter.h"
 #include "backend/core/Project.h"
+#include "backend/lib/XmlStreamReader.h"
 #include "commonfrontend/spreadsheet/SpreadsheetView.h"
 #include "kdefrontend/spreadsheet/PlotDataDialog.h"
 
@@ -45,7 +29,6 @@ Copyright	: (C) 2018 Stefan Gerlach (stefan.gerlach@uni.kn)
 #include <QIcon>
 #include <QMenu>
 #include <QMessageBox>
-#include <QProcess>
 #include <QTimer>
 #include <QTcpSocket>
 #include <QUdpSocket>
@@ -64,7 +47,11 @@ Copyright	: (C) 2018 Stefan Gerlach (stefan.gerlach@uni.kn)
 LiveDataSource::LiveDataSource(const QString& name, bool loading) : Spreadsheet(name, loading, AspectType::LiveDataSource),
 	m_updateTimer(new QTimer(this)), m_watchTimer(new QTimer(this)) {
 
-	initActions();
+	m_watchTimer->setSingleShot(true);
+	m_watchTimer->setInterval(100);
+
+	//stop reading from the source before removing the child from the project
+	connect(this, &AbstractAspect::aspectAboutToBeRemoved,  [this](const AbstractAspect* aspect) { if (aspect == this) pauseReading(); } );
 
 	connect(m_updateTimer, &QTimer::timeout, this, &LiveDataSource::read);
 	connect(m_watchTimer, &QTimer::timeout, this, &LiveDataSource::readOnUpdate);
@@ -83,13 +70,6 @@ LiveDataSource::~LiveDataSource() {
 #endif
 }
 
-void LiveDataSource::initActions() {
-	m_plotDataAction = new QAction(QIcon::fromTheme("office-chart-line"), i18n("Plot data"), this);
-	connect(m_plotDataAction, &QAction::triggered, this, &LiveDataSource::plotData);
-	m_watchTimer->setSingleShot(true);
-	m_watchTimer->setInterval(100);
-}
-
 QWidget* LiveDataSource::view() const {
 	if (!m_partView) {
 		m_view = new SpreadsheetView(const_cast<LiveDataSource*>(this), true);
@@ -414,9 +394,16 @@ QIcon LiveDataSource::icon() const {
 	case AbstractFileFilter::FileType::JSON:
 		icon = QIcon::fromTheme("application-json");
 		break;
+	case AbstractFileFilter::FileType::MATIO:
+		icon = QIcon::fromTheme("matlab");
+		break;
+	case AbstractFileFilter::FileType::READSTAT:
+		icon = QIcon::fromTheme("view-statistics");
+		break;
 	case AbstractFileFilter::FileType::ROOT:
-	case AbstractFileFilter::FileType::NgspiceRawAscii:
-	case AbstractFileFilter::FileType::NgspiceRawBinary:
+		icon = QIcon::fromTheme("application-x-root");
+		break;
+	case AbstractFileFilter::FileType::Spice:
 		break;
 	}
 
@@ -433,6 +420,11 @@ QMenu* LiveDataSource::createContextMenu() {
 	if (menu->actions().size() > 1)
 		firstAction = menu->actions().at(1);
 
+	if (!m_plotDataAction) {
+		m_plotDataAction = new QAction(QIcon::fromTheme("office-chart-line"), i18n("Plot data"), this);
+		connect(m_plotDataAction, &QAction::triggered, this, &LiveDataSource::plotData);
+	}
+
 	menu->insertAction(firstAction, m_plotDataAction);
 	menu->insertSeparator(firstAction);
 
@@ -492,7 +484,11 @@ void LiveDataSource::read() {
 			m_tcpSocket->connectToHost(m_host, m_port, QIODevice::ReadOnly);
 
 			connect(m_tcpSocket, &QTcpSocket::readyRead, this, &LiveDataSource::readyRead);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+			connect(m_tcpSocket, static_cast<void (QTcpSocket::*) (QAbstractSocket::SocketError)>(&QTcpSocket::errorOccurred), this, &LiveDataSource::tcpSocketError);
+#else
 			connect(m_tcpSocket, static_cast<void (QTcpSocket::*) (QAbstractSocket::SocketError)>(&QTcpSocket::error), this, &LiveDataSource::tcpSocketError);
+#endif
 
 			break;
 		case SourceType::NetworkUdpSocket:
@@ -504,7 +500,11 @@ void LiveDataSource::read() {
 			// only connect to readyRead when update is on new data
 			if (m_updateType == UpdateType::NewData)
 				connect(m_udpSocket, &QUdpSocket::readyRead, this, &LiveDataSource::readyRead);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+			connect(m_udpSocket, static_cast<void (QUdpSocket::*) (QAbstractSocket::SocketError)>(&QUdpSocket::errorOccurred), this, &LiveDataSource::tcpSocketError);
+#else
 			connect(m_udpSocket, static_cast<void (QUdpSocket::*) (QAbstractSocket::SocketError)>(&QUdpSocket::error), this, &LiveDataSource::tcpSocketError);
+#endif
 
 			break;
 		case SourceType::LocalSocket:
@@ -513,7 +513,11 @@ void LiveDataSource::read() {
 			m_localSocket->connectToServer(m_localSocketName, QLocalSocket::ReadOnly);
 
 			connect(m_localSocket, &QLocalSocket::readyRead, this, &LiveDataSource::readyRead);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+			connect(m_localSocket, static_cast<void (QLocalSocket::*) (QLocalSocket::LocalSocketError)>(&QLocalSocket::errorOccurred), this, &LiveDataSource::localSocketError);
+#else
 			connect(m_localSocket, static_cast<void (QLocalSocket::*) (QLocalSocket::LocalSocketError)>(&QLocalSocket::error), this, &LiveDataSource::localSocketError);
+#endif
 
 			break;
 		case SourceType::SerialPort:
@@ -557,8 +561,7 @@ void LiveDataSource::read() {
 			// bytes = qSharedPointerCast<BinaryFilter>(m_filter)->readFromLiveDevice(*m_file, this, m_bytesRead);
 // 			m_bytesRead += bytes;
 		case AbstractFileFilter::FileType::ROOT:
-		case AbstractFileFilter::FileType::NgspiceRawAscii:
-		case AbstractFileFilter::FileType::NgspiceRawBinary:
+		case AbstractFileFilter::FileType::Spice:
 			//only re-reading of the whole file is supported
 			m_filter->readDataFromFile(m_fileName, this);
 			break;
@@ -568,6 +571,8 @@ void LiveDataSource::read() {
 		case AbstractFileFilter::FileType::NETCDF:
 		case AbstractFileFilter::FileType::FITS:
 		case AbstractFileFilter::FileType::JSON:
+		case AbstractFileFilter::FileType::READSTAT:
+		case AbstractFileFilter::FileType::MATIO:
 			break;
 		}
 		break;
@@ -631,8 +636,7 @@ void LiveDataSource::readyRead() {
 		read();
 }
 
-void LiveDataSource::localSocketError(QLocalSocket::LocalSocketError socketError) {
-	Q_UNUSED(socketError);
+void LiveDataSource::localSocketError(QLocalSocket::LocalSocketError /*socketError*/) {
 	/*disconnect(m_localSocket, SIGNAL(error(QLocalSocket::LocalSocketError)), this, SLOT(localSocketError(QLocalSocket::LocalSocketError)));
 	disconnect(m_localSocket, SIGNAL(readyRead()), this, SLOT(readyRead()));*/
 
@@ -655,8 +659,7 @@ void LiveDataSource::localSocketError(QLocalSocket::LocalSocketError socketError
 	}*/
 }
 
-void LiveDataSource::tcpSocketError(QAbstractSocket::SocketError socketError) {
-	Q_UNUSED(socketError);
+void LiveDataSource::tcpSocketError(QAbstractSocket::SocketError /*socketError*/) {
 	/*switch (socketError) {
 	case QAbstractSocket::ConnectionRefusedError:
 		QMessageBox::critical(0, i18n("TCP Socket Error"),
@@ -780,7 +783,11 @@ void LiveDataSource::save(QXmlStreamWriter* writer) const {
 	writer->writeEndElement(); //general
 
 	//filter
-	m_filter->save(writer);
+	if (m_filter) {
+		// If older project do not have loaded the filter correctly
+		// The filter might not be available. So check before saving
+		m_filter->save(writer);
+	}
 
 	//columns
 	if (!m_fileLinked) {
@@ -920,6 +927,10 @@ bool LiveDataSource::load(XmlStreamReader* reader, bool preview) {
 			setFilter(new ROOTFilter);
 			if (!m_filter->load(reader))
 				return false;
+		} else if (reader->name() == SpiceFilter::xmlElementName) {
+			setFilter(new SpiceFilter);
+			if (!m_filter->load(reader))
+				return false;
 		} else if (reader->name() == "column") {
 			Column* column = new Column(QString(), AbstractColumn::ColumnMode::Text);
 			if (!column->load(reader, preview)) {
@@ -927,6 +938,7 @@ bool LiveDataSource::load(XmlStreamReader* reader, bool preview) {
 				setColumnCount(0);
 				return false;
 			}
+			column->setFixed(true);
 			addChild(column);
 		} else {// unknown element
 			reader->raiseWarning(i18n("unknown element '%1'", reader->name().toString()));
