@@ -1,37 +1,18 @@
-/***************************************************************************
+/*
     File                 : LiveDataSource.h
     Project              : LabPlot
     Description          : File data source
     --------------------------------------------------------------------
-    Copyright            : (C) 2017 Fabian Kristof (fkristofszabolcs@gmail.com)
-    Copyright            : (C) 2017-2018 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2018 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2017 Fabian Kristof <fkristofszabolcs@gmail.com>
+    SPDX-FileCopyrightText: 2017-2018 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 #ifndef LIVEDATASOURCE_H
 #define LIVEDATASOURCE_H
 
 #include "backend/spreadsheet/Spreadsheet.h"
-#include "backend/matrix/Matrix.h"
 
 #include <QLocalSocket>
 #include <QTimer>
@@ -105,7 +86,7 @@ public:
 
 	bool isPaused() const;
 
-	void setSerialPort(const QString& name);
+	void setSerialPort(const QString&);
 	QString serialPortName() const;
 
 	QString host() const;
@@ -151,8 +132,6 @@ public:
 	void finalizeLoad();
 
 private:
-	void initActions();
-
 	QString m_fileName;
 	QString m_dirName;
 	QString m_serialPortName;
@@ -195,11 +174,11 @@ private:
 	QIODevice* m_device{nullptr};
 	QAction* m_plotDataAction{nullptr};
 
-public slots:
+public Q_SLOTS:
 	void read();
 	void readOnUpdate();
 
-private slots:
+private Q_SLOTS:
 	void plotData();
 	void readyRead();
 
