@@ -1,35 +1,18 @@
-/***************************************************************************
-File		: MQTTClient.cpp
-Project		: LabPlot
-Description	: Represents a MQTT Client
---------------------------------------------------------------------
-Copyright	: (C) 2018 Kovacs Ferencz (kferike98@gmail.com)
+/*
+    File		: MQTTClient.cpp
+    Project		: LabPlot
+    Description	: Represents a MQTT Client
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2018 Kovacs Ferencz <kferike98@gmail.com>
 
-***************************************************************************/
-
-/***************************************************************************
-*                                                                         *
-*  This program is free software; you can redistribute it and/or modify   *
-*  it under the terms of the GNU General Public License as published by   *
-*  the Free Software Foundation; either version 2 of the License, or      *
-*  (at your option) any later version.                                    *
-*                                                                         *
-*  This program is distributed in the hope that it will be useful,        *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
-*  GNU General Public License for more details.                           *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the Free Software           *
-*   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
-*   Boston, MA  02110-1301  USA                                           *
-*                                                                         *
-***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "backend/datasources/MQTTClient.h"
 #include "backend/datasources/MQTTSubscription.h"
 #include "backend/datasources/MQTTTopic.h"
-#include "backend/datasources/filters/AsciiFilter.h"
 #include "kdefrontend/datasources/MQTTErrorWidget.h"
+#include "backend/datasources/filters/AsciiFilter.h"
+#include "backend/lib/XmlStreamReader.h"
 
 #include <QTimer>
 
@@ -45,6 +28,9 @@ MQTTClient::MQTTClient(const QString& name) : Folder(name, AspectType::MQTTClien
 	m_client(new QMqttClient(this)),
 	m_willTimer(new QTimer(this)) {
 
+	//stop reading from the source before removing the child from the project
+	connect(this, &AbstractAspect::aspectAboutToBeRemoved, this, &MQTTClient::pauseReading);
+
 	connect(m_updateTimer, &QTimer::timeout, this, &MQTTClient::read);
 	connect(m_client, &QMqttClient::connected, this, &MQTTClient::onMQTTConnect);
 	connect(m_willTimer, &QTimer::timeout, this, &MQTTClient::updateWillMessage);
@@ -52,10 +38,9 @@ MQTTClient::MQTTClient(const QString& name) : Folder(name, AspectType::MQTTClien
 }
 
 MQTTClient::~MQTTClient() {
-	emit clientAboutToBeDeleted(m_client->hostname(), m_client->port());
+	Q_EMIT clientAboutToBeDeleted(m_client->hostname(), m_client->port());
 	//stop reading before deleting the objects
 	pauseReading();
-	qDebug() << "Delete MQTTClient: " << m_client->hostname() << m_client->port();
 
 	delete m_filter;
 	delete m_updateTimer;
@@ -421,7 +406,7 @@ void MQTTClient::addMQTTSubscription(const QString& topicName, quint8 QoS) {
 
 			connect(temp, &QMqttSubscription::messageReceived, this, &MQTTClient::MQTTSubscriptionMessageReceived);
 
-			emit MQTTTopicsChanged();
+			Q_EMIT MQTTTopicsChanged();
 		}
 	}
 }
@@ -465,7 +450,7 @@ void MQTTClient::removeMQTTSubscription(const QString& subscriptionName) {
 				break;
 			}
 		}
-		emit MQTTTopicsChanged();
+		Q_EMIT MQTTTopicsChanged();
 	}
 }
 
@@ -536,7 +521,7 @@ void MQTTClient::addBeforeRemoveSubscription(const QString& topicName, quint8 Qo
  * \param parent, the name of the MQTTSubscription
  */
 void MQTTClient::reparentTopic(const QString& topicName, const QString& parentTopicName) {
-	//We can only reparent if the parent containd the topic
+	//We can only reparent if the parent contained the topic
 	if (m_subscriptions.contains(parentTopicName) && m_topicNames.contains(topicName)) {
 // 		qDebug() << "Reparent " << topicName << " to " << parentTopicName;
 		//search for the parent MQTTSubscription
@@ -578,8 +563,13 @@ bool MQTTClient::checkTopicContains(const QString& superior, const QString& infe
 		return true;
 	else {
 		if (superior.contains(QLatin1String("/"))) {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+			QStringList superiorList = superior.split('/', Qt::SkipEmptyParts);
+			QStringList inferiorList = inferior.split('/', Qt::SkipEmptyParts);
+#else
 			QStringList superiorList = superior.split('/', QString::SkipEmptyParts);
 			QStringList inferiorList = inferior.split('/', QString::SkipEmptyParts);
+#endif
 
 			//a longer topic can't contain a shorter one
 			if (superiorList.size() > inferiorList.size())
@@ -617,8 +607,13 @@ bool MQTTClient::checkTopicContains(const QString& superior, const QString& infe
  * \return The name of the common topic, if it exists, otherwise an empty string
  */
 QString MQTTClient::checkCommonLevel(const QString& first, const QString& second) {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+	QStringList firstList = first.split('/', Qt::SkipEmptyParts);
+	QStringList secondtList = second.split('/', Qt::SkipEmptyParts);
+#else
 	QStringList firstList = first.split('/', QString::SkipEmptyParts);
 	QStringList secondtList = second.split('/', QString::SkipEmptyParts);
+#endif
 	QString commonTopic;
 
 	if (!firstList.isEmpty()) {
@@ -819,7 +814,7 @@ void MQTTClient::updateWillMessage() {
 				//TODO: check this logic again - why last column only?
 				const auto* col = willTopic->child<Column>(willTopic->childCount<Column>() - 1);
 				auto mode = col->columnMode();
-				if (mode == AbstractColumn::ColumnMode::Integer || mode == AbstractColumn::ColumnMode::Numeric)
+				if (mode == AbstractColumn::ColumnMode::Integer || mode == AbstractColumn::ColumnMode::Double)
 					m_client->setWillMessage(this->statistics(willTopic).toUtf8());
 				else
 					m_client->setWillMessage(QByteArray()); //empty message
@@ -1012,7 +1007,7 @@ void MQTTClient::read() {
 	if ((m_client->state() == QMqttClient::ClientState::Connected) && m_MQTTFirstConnectEstablished) {
 // 		qDebug()<<"Read";
 		//Signal for every MQTTTopic that they can read
-		emit readFromTopics();
+		Q_EMIT readFromTopics();
 	}
 }
 
@@ -1049,7 +1044,7 @@ void MQTTClient::onMQTTConnect() {
 			}
 			m_MQTTFirstConnectEstablished = true;
 			//Signal that the initial subscriptions were made
-			emit MQTTSubscribed();
+			Q_EMIT MQTTSubscribed();
 		}
 		//if there was already a connection made(happens after updating will message)
 		else {
@@ -1093,7 +1088,7 @@ void MQTTClient::MQTTSubscriptionMessageReceived(const QMqttMessage& msg) {
 		if (msg.topic().name() == m_MQTTWill.willTopic) {
 			m_MQTTWill.willLastMessage = QString(msg.payload());
 
-			emit MQTTTopicsChanged();
+			Q_EMIT MQTTTopicsChanged();
 		}
 	}
 }
