@@ -1,33 +1,16 @@
-/***************************************************************************
-File		: MQTTSubscription.cpp
-Project		: LabPlot
-Description	: Represents a subscription made in MQTTClient
---------------------------------------------------------------------
-Copyright	: (C) 2018 Kovacs Ferencz (kferike98@gmail.com)
+/*
+    File		: MQTTSubscription.cpp
+    Project		: LabPlot
+    Description	: Represents a subscription made in MQTTClient
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2018 Kovacs Ferencz <kferike98@gmail.com>
 
-***************************************************************************/
-
-/***************************************************************************
-*                                                                         *
-*  This program is free software; you can redistribute it and/or modify   *
-*  it under the terms of the GNU General Public License as published by   *
-*  the Free Software Foundation; either version 2 of the License, or      *
-*  (at your option) any later version.                                    *
-*                                                                         *
-*  This program is distributed in the hope that it will be useful,        *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
-*  GNU General Public License for more details.                           *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the Free Software           *
-*   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
-*   Boston, MA  02110-1301  USA                                           *
-*                                                                         *
-***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "backend/datasources/MQTTSubscription.h"
 #include "backend/datasources/MQTTTopic.h"
 #include "backend/datasources/MQTTClient.h"
+#include "backend/lib/XmlStreamReader.h"
 
 #include <KLocalizedString>
 #include <QIcon>
@@ -187,7 +170,7 @@ bool MQTTSubscription::load(XmlStreamReader* reader, bool preview) {
 		}
 	}
 
-	emit loaded(this->subscriptionName());
+	Q_EMIT loaded(this->subscriptionName());
 	return !reader->hasError();
 }
 
