@@ -1,34 +1,16 @@
-/***************************************************************************
-File                 : AbstractFileFilter.h
-Project              : LabPlot
-Description          : file I/O-filter related interface
---------------------------------------------------------------------
-Copyright            : (C) 2009-2017 Alexander Semke (alexander.semke@web.de)
-Copyright            : (C) 2017 Stefan Gerlach (stefan.gerlach@uni.kn)
-***************************************************************************/
+/*
+    File                 : AbstractFileFilter.h
+    Project              : LabPlot
+    Description          : file I/O-filter related interface
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2009-2017 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2017 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "backend/datasources/filters/AbstractFileFilter.h"
-#include "backend/datasources/filters/NgspiceRawAsciiFilter.h"
-#include "backend/datasources/filters/NgspiceRawBinaryFilter.h"
+#include "backend/datasources/filters/SpiceFilter.h"
 #include "backend/lib/macros.h"
 
 #include <QDateTime>
@@ -45,7 +27,7 @@ bool AbstractFileFilter::isNan(const QString& s) {
 	return false;
 }
 
-AbstractColumn::ColumnMode AbstractFileFilter::columnMode(const QString& valueString, const QString& dateTimeFormat, QLocale::Language lang) {
+AbstractColumn::ColumnMode AbstractFileFilter::columnMode(const QString& valueString, QString& dateTimeFormat, QLocale::Language lang) {
 	return columnMode(valueString, dateTimeFormat, QLocale(lang));
 }
 
@@ -53,52 +35,53 @@ AbstractColumn::ColumnMode AbstractFileFilter::columnMode(const QString& valueSt
  * return the column mode for the given value string and settings \c dateTimeFormat and \c locale.
  * in case \c dateTimeFormat is empty, all possible datetime formats are tried out to determine the valid datetime object.
  */
-AbstractColumn::ColumnMode AbstractFileFilter::columnMode(const QString& valueString, const QString& dateTimeFormat, const QLocale& locale) {
+AbstractColumn::ColumnMode AbstractFileFilter::columnMode(const QString& valueString, QString& dateTimeFormat, const QLocale& locale) {
 	//TODO: use BigInt as default integer?
+	auto mode = AbstractColumn::ColumnMode::Integer;
 	if (valueString.size() == 0)	// empty string treated as integer (meaning the non-empty strings will determine the data type)
-		return AbstractColumn::ColumnMode::Integer;
+		return mode;
 
 	if (isNan(valueString))
-		return AbstractColumn::ColumnMode::Numeric;
+		return AbstractColumn::ColumnMode::Double;
 
 	// check if integer first
 	bool ok;
 	int intValue = locale.toInt(valueString, &ok);
 	DEBUG(Q_FUNC_INFO << ", " << STDSTRING(valueString) << " : toInt " << intValue << " ?: " << ok);
 	Q_UNUSED(intValue)
-	if (ok || isNan(valueString))
-		return AbstractColumn::ColumnMode::Integer;
-
-	//check big integer
-	qint64 bigIntValue = locale.toLongLong(valueString, &ok);
-	DEBUG(Q_FUNC_INFO << ", " << STDSTRING(valueString) << " : toBigInt " << bigIntValue << " ?: " << ok);
-	Q_UNUSED(bigIntValue)
-	if (ok || isNan(valueString))
-		return AbstractColumn::ColumnMode::BigInt;
-
-	//try to convert to a double
-	auto mode = AbstractColumn::ColumnMode::Numeric;
-	double value = locale.toDouble(valueString, &ok);
-	DEBUG(Q_FUNC_INFO << ", " << STDSTRING(valueString) << " : toDouble " << value << " ?: " << ok);
-	Q_UNUSED(value)
-
-	//if not a number, check datetime. if that fails: string
 	if (!ok) {
+		//if not a int, check datetime. if that fails: check double and big int, else it's a string
 		QDateTime valueDateTime;
 		if (dateTimeFormat.isEmpty()) {
 			for (const auto& format : AbstractColumn::dateTimeFormats()) {
 				valueDateTime = QDateTime::fromString(valueString, format);
-				if (valueDateTime.isValid())
+				if (valueDateTime.isValid()) {
+					DEBUG(Q_FUNC_INFO << ", " << STDSTRING(valueString) << " : valid DateTime format - " << STDSTRING(format));
+					dateTimeFormat = format;
 					break;
+				}
 			}
 		} else
 			valueDateTime = QDateTime::fromString(valueString, dateTimeFormat);
 
-		if (valueDateTime.isValid())
+		if (valueDateTime.isValid()) {
 			mode = AbstractColumn::ColumnMode::DateTime;
-		else {
+		} else {
 			DEBUG(Q_FUNC_INFO << ", DATETIME invalid! String: " << STDSTRING(valueString) << " DateTime format: " << STDSTRING(dateTimeFormat))
-			mode = AbstractColumn::ColumnMode::Text;
+
+			//check if big integer
+			qint64 bigIntValue = locale.toLongLong(valueString, &ok);
+			DEBUG(Q_FUNC_INFO << ", " << STDSTRING(valueString) << " : toBigInt " << bigIntValue << " ?: " << ok);
+			Q_UNUSED(bigIntValue)
+			if (ok)
+				return AbstractColumn::ColumnMode::BigInt;
+
+			//check if double
+			double value = locale.toDouble(valueString, &ok);
+			DEBUG(Q_FUNC_INFO << ", " << STDSTRING(valueString) << " : toDouble " << value << " ?: " << ok);
+			Q_UNUSED(value)
+
+			mode = ok ? AbstractColumn::ColumnMode::Double : AbstractColumn::ColumnMode::Text;
 		}
 	}
 
@@ -130,14 +113,17 @@ AbstractFileFilter::FileType AbstractFileFilter::fileType(const QString& fileNam
 	QString fileInfo;
 #ifndef HAVE_WINDOWS
 	//check, if we can guess the file type by content
-	QProcess proc;
-	proc.start("file", QStringList() << "-b" << "-z" << fileName);
-	if (!proc.waitForFinished(1000)) {
-		proc.kill();
-		DEBUG("ERROR: reading file type of file" << STDSTRING(fileName));
-		return FileType::Binary;
+	const QString fileFullPath = QStandardPaths::findExecutable(QLatin1String("file"));
+	if (!fileFullPath.isEmpty()) {
+		QProcess proc;
+		proc.start(fileFullPath, QStringList() << "-b" << "-z" << fileName);
+		if (!proc.waitForFinished(1000)) {
+			proc.kill();
+			DEBUG("ERROR: reading file type of file" << STDSTRING(fileName));
+			return FileType::Binary;
+		}
+		fileInfo = proc.readLine();
 	}
-	fileInfo = proc.readLine();
 #endif
 
 	FileType fileType;
@@ -151,21 +137,28 @@ AbstractFileFilter::FileType AbstractFileFilter::fileType(const QString& fileNam
 		|| fileName.endsWith(QLatin1String("har"), Qt::CaseInsensitive) ) {
 		//*.json files can be recognized as ASCII. so, do the check for the json-extension as first.
 		fileType = FileType::JSON;
+	} else if (SpiceFilter::isSpiceFile(fileName)) {
+		fileType = FileType::Spice;
 	} else if (fileInfo.contains(QLatin1String("ASCII"))
 		|| fileName.endsWith(QLatin1String("txt"), Qt::CaseInsensitive)
 		|| fileName.endsWith(QLatin1String("csv"), Qt::CaseInsensitive)
 		|| fileName.endsWith(QLatin1String("dat"), Qt::CaseInsensitive)
 		|| fileInfo.contains(QLatin1String("compressed data"))/* for gzipped ascii data */ ) {
-		if (NgspiceRawAsciiFilter::isNgspiceAsciiFile(fileName))
-			fileType = FileType::NgspiceRawAscii;
+		if (fileName.endsWith(QLatin1String(".sas7bdat"), Qt::CaseInsensitive))
+			fileType = FileType::READSTAT;
 		else //probably ascii data
 			fileType = FileType::Ascii;
 	}
-#ifdef HAVE_HDF5
+#ifdef HAVE_MATIO	// before HDF5 to prefer this filter for MAT 7.4 files
+	else if (fileInfo.contains(QLatin1String("Matlab")) || fileName.endsWith(QLatin1String("mat"), Qt::CaseInsensitive))
+		fileType = FileType::MATIO;
+#endif
+#ifdef HAVE_HDF5	// before NETCDF to treat NetCDF 4 files with .nc ending as HDF5 when fileInfo detects it
 	else if (fileInfo.contains(QLatin1String("Hierarchical Data Format"))
 		|| fileName.endsWith(QLatin1String("h5"), Qt::CaseInsensitive)
 		|| fileName.endsWith(QLatin1String("hdf"), Qt::CaseInsensitive)
-		|| fileName.endsWith(QLatin1String("hdf5"), Qt::CaseInsensitive) )
+		|| fileName.endsWith(QLatin1String("hdf5"), Qt::CaseInsensitive)
+		|| fileName.endsWith(QLatin1String("nc4"), Qt::CaseInsensitive) )
 		fileType = FileType::HDF5;
 #endif
 #ifdef HAVE_NETCDF
@@ -186,11 +179,21 @@ AbstractFileFilter::FileType AbstractFileFilter::fileType(const QString& fileNam
 	else if (fileInfo.contains(QLatin1String("ROOT")) //can be "ROOT Data Format" or "ROOT file Version ??? (Compression: 1)"
 		||  fileName.endsWith(QLatin1String("root"), Qt::CaseInsensitive)) // TODO find out file description
 		fileType = FileType::ROOT;
+#endif
+#ifdef HAVE_READSTAT	// sas7bdat -> ASCII
+	else if (fileInfo.startsWith(QLatin1String("SAS")) || fileInfo.startsWith(QLatin1String("SPSS"))
+		|| fileName.endsWith(QLatin1String(".dta"), Qt::CaseInsensitive)
+		|| fileName.endsWith(QLatin1String(".sav"), Qt::CaseInsensitive)
+		|| fileName.endsWith(QLatin1String(".zsav"), Qt::CaseInsensitive)
+		|| fileName.endsWith(QLatin1String(".por"), Qt::CaseInsensitive)
+		|| fileName.endsWith(QLatin1String(".sas7bcat"), Qt::CaseInsensitive)
+		|| fileName.endsWith(QLatin1String(".xpt"), Qt::CaseInsensitive)
+		|| fileName.endsWith(QLatin1String(".xpt5"), Qt::CaseInsensitive)
+		|| fileName.endsWith(QLatin1String(".xpt8"), Qt::CaseInsensitive))
+		fileType = FileType::READSTAT;
 #endif
 	else if (fileInfo.contains("image") || fileInfo.contains("bitmap") || !imageFormat.isEmpty())
 		fileType = FileType::Image;
-	else if (NgspiceRawBinaryFilter::isNgspiceBinaryFile(fileName))
-		fileType = FileType::NgspiceRawBinary;
 	else
 		fileType = FileType::Binary;
 
@@ -201,15 +204,15 @@ AbstractFileFilter::FileType AbstractFileFilter::fileType(const QString& fileNam
   returns the list of all supported data file formats
 */
 QStringList AbstractFileFilter::fileTypes() {
-	return (QStringList() << i18n("ASCII data")
-		<< i18n("Binary data")
+	return (QStringList() << i18n("ASCII Data")
+		<< i18n("Binary Data")
 		<< i18n("Image")
 		<< i18n("Hierarchical Data Format 5 (HDF5)")
 		<< i18n("Network Common Data Format (NetCDF)")
 		<< i18n("Flexible Image Transport System Data Format (FITS)")
-		<< i18n("JSON data")
+		<< i18n("JSON Data")
 		<< i18n("ROOT (CERN) Histograms")
-		<< "Ngspice RAW ASCII"
-		<< "Ngspice RAW Binary"
+		<< i18n("Spice")
+		<< i18n("SAS, Stata or SPSS")
 	);
 }
