@@ -1,30 +1,12 @@
-/***************************************************************************
-File                 : AsciiFilter.h
-Project              : LabPlot
-Description          : ASCII I/O-filter
---------------------------------------------------------------------
-Copyright            : (C) 2009-2019 Alexander Semke (alexander.semke@web.de)
-Copyright            : (C) 2017 Stefan Gerlach (stefan.gerlach@uni.kn)
-***************************************************************************/
-
-/***************************************************************************
-*                                                                         *
-*  This program is free software; you can redistribute it and/or modify   *
-*  it under the terms of the GNU General Public License as published by   *
-*  the Free Software Foundation; either version 2 of the License, or      *
-*  (at your option) any later version.                                    *
-*                                                                         *
-*  This program is distributed in the hope that it will be useful,        *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
-*  GNU General Public License for more details.                           *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the Free Software           *
-*   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
-*   Boston, MA  02110-1301  USA                                           *
-*                                                                         *
-***************************************************************************/
+/*
+    File                 : AsciiFilter.h
+    Project              : LabPlot
+    Description          : ASCII I/O-filter
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2009-2022 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2017-2022 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef ASCIIFILTER_H
 #define ASCIIFILTER_H
 
@@ -53,8 +35,8 @@ public:
 
 	static QString fileInfoString(const QString&);
 	static int columnNumber(const QString& fileName, const QString& separator = QString());
-	static size_t lineNumber(const QString& fileName);
-	size_t lineNumber(QIODevice&) const;	// calculate number of lines if device supports it
+	static size_t lineNumber(const QString& fileName, size_t maxLines = std::numeric_limits<std::size_t>::max());
+	size_t lineNumber(QIODevice&, size_t maxLines = std::numeric_limits<std::size_t>::max()) const; // calculate number of lines if device supports it
 
 	// read data from any device
 	void readDataFromDevice(QIODevice& device, AbstractDataSource*,
@@ -91,6 +73,7 @@ public:
 	void setAutoModeEnabled(const bool);
 	bool isAutoModeEnabled() const;
 	void setHeaderEnabled(const bool);
+	void setHeaderLine(int);
 	bool isHeaderEnabled() const;
 	void setSkipEmptyParts(const bool);
 	bool skipEmptyParts() const;
