@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : AsciiFilterPrivate.h
     Project              : LabPlot
     Description          : Private implementation class for AsciiFilter.
     --------------------------------------------------------------------
-    Copyright            : (C) 2009-2020 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2017 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2009-2020 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2017-2022 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #ifndef ASCIIFILTERPRIVATE_H
 #define ASCIIFILTERPRIVATE_H
@@ -62,10 +44,11 @@ public:
 	void write(const QString& fileName, AbstractDataSource*);
 
 	//helpers
-	int prepareDeviceToRead(QIODevice&);
+	int prepareDeviceToRead(QIODevice&, size_t maxLines = std::numeric_limits<std::size_t>::max());
 	void initDataContainers(Spreadsheet*);
 	QString previewValue(const QString&, AbstractColumn::ColumnMode);
-	void setValue(int col, int row, const QString& value);
+	void setValue(int col, int row, QStringView value);
+	QString getLine(QIODevice&);
 	QStringList getLineString(QIODevice&);
 
 #ifdef HAVE_MQTT
@@ -85,14 +68,15 @@ public:
 	QLocale::Language numberFormat{QLocale::C};
 	QLocale locale{QLocale::C};
 	bool autoModeEnabled{true};
-	bool headerEnabled{true};
+	bool headerEnabled{true};	// read header from file
+	int headerLine{0};	// 0: no header line
 	bool skipEmptyParts{false};
 	bool simplifyWhitespacesEnabled{false};
 	double nanValue{NAN};
 	bool removeQuotesEnabled{false};
 	bool createIndexEnabled{false};
 	bool createTimestampEnabled{false};
-	QStringList vectorNames;
+	QStringList columnNames;
 	QVector<AbstractColumn::ColumnMode> columnModes;
 	int startRow{1};
 	int endRow{-1};
