@@ -1,30 +1,12 @@
-/***************************************************************************
-File                 : FITSFilter.cpp
-Project              : LabPlot
-Description          : FITS I/O-filter
---------------------------------------------------------------------
-Copyright            : (C) 2016 by Fabian Kristof (fkristofszabolcs@gmail.com)
-Copyright            : (C) 2017 Alexander Semke (alexander.semke@web.de)
-***************************************************************************/
-
-/***************************************************************************
-*                                                                         *
-*  This program is free software; you can redistribute it and/or modify   *
-*  it under the terms of the GNU General Public License as published by   *
-*  the Free Software Foundation; either version 2 of the License, or      *
-*  (at your option) any later version.                                    *
-*                                                                         *
-*  This program is distributed in the hope that it will be useful,        *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
-*  GNU General Public License for more details.                           *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the Free Software           *
-*   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
-*   Boston, MA  02110-1301  USA                                           *
-*                                                                         *
-***************************************************************************/
+/*
+    File                 : FITSFilter.cpp
+    Project              : LabPlot
+    Description          : FITS I/O-filter
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2016 Fabian Kristof <fkristofszabolcs@gmail.com>
+    SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "FITSFilter.h"
 #include "FITSFilterPrivate.h"
@@ -94,12 +76,10 @@ QList<FITSFilter::Keyword> FITSFilter::chduKeywords(const QString &fileName) {
 	return d->chduKeywords(fileName);
 }
 
-void FITSFilter::loadFilterSettings(const QString& fileName) {
-	Q_UNUSED(fileName)
+void FITSFilter::loadFilterSettings(const QString& /*fileName*/) {
 }
 
-void FITSFilter::saveFilterSettings(const QString& fileName) const {
-	Q_UNUSED(fileName)
+void FITSFilter::saveFilterSettings(const QString& /*fileName*/) const {
 }
 
 /*!
@@ -373,7 +353,8 @@ QVector<QStringList> FITSFilterPrivate::readCHDU(const QString& fileName, Abstra
 				else
 					static_cast<QVector<double>*>(dataContainer[jj++])->operator[](ii) = data[i* naxes[0] + j];
 			}
-			dataStrings << line;
+            if (noDataSource)
+                dataStrings << line;
 			j = jstart;
 			ii++;
 		}
@@ -435,7 +416,7 @@ QVector<QStringList> FITSFilterPrivate::readCHDU(const QString& fileName, Abstra
 
 		if (endRow != -1)
 			lines = endRow;
-		QVector<QStringList*> stringDataPointers;
+        QVector<QVector<QString>*> stringDataPointers;
 		std::vector<void*> numericDataPointers;
 		QList<bool> columnNumericTypes;
 
@@ -515,14 +496,14 @@ QVector<QStringList> FITSFilterPrivate::readCHDU(const QString& fileName, Abstra
 				DEBUG("Reading columns ...");
 				for (int n = 0; n < actualCols - startCol; ++n) {
 					if (columnNumericTypes.at(n)) {
-						spreadsheet->column(columnOffset+ n)->setColumnMode(AbstractColumn::ColumnMode::Numeric);
+						spreadsheet->column(columnOffset+ n)->setColumnMode(AbstractColumn::ColumnMode::Double);
 						auto* datap = static_cast<QVector<double>* >(spreadsheet->column(columnOffset+n)->data());
 						numericDataPointers.push_back(datap);
 						if (importMode == AbstractFileFilter::ImportMode::Replace)
 							datap->clear();
 					} else {
 						spreadsheet->column(columnOffset+ n)->setColumnMode(AbstractColumn::ColumnMode::Text);
-						auto* list = static_cast<QStringList*>(spreadsheet->column(columnOffset+n)->data());
+                        auto* list = static_cast<QVector<QString>*>(spreadsheet->column(columnOffset+n)->data());
 						stringDataPointers.push_back(list);
 						if (importMode == AbstractFileFilter::ImportMode::Replace)
 							list->clear();
@@ -598,7 +579,8 @@ QVector<QStringList> FITSFilterPrivate::readCHDU(const QString& fileName, Abstra
 						line << tmpColstr;
 				}
 			}
-			dataStrings << line;
+            if (noDataSource)
+                dataStrings << line;
 		}
 
 		if (!noDataSource)
@@ -829,7 +811,7 @@ void FITSFilterPrivate::writeCHDU(const QString &fileName, AbstractDataSource *d
 					tunit[i][0] = '\0';
 				}
 				switch (column->columnMode()) {
-				case AbstractColumn::ColumnMode::Numeric: {
+				case AbstractColumn::ColumnMode::Double: {
 						int maxSize = -1;
 						for (int row = 0; row < nrows; ++row) {
 							if (QString::number(column->valueAt(row)).size() > maxSize)
@@ -911,7 +893,7 @@ void FITSFilterPrivate::writeCHDU(const QString &fileName, AbstractDataSource *d
 				const Column* c =  spreadsheet->column(col-1);
 				auto columnMode = c->columnMode();
 
-				if (columnMode == AbstractColumn::ColumnMode::Numeric) {
+				if (columnMode == AbstractColumn::ColumnMode::Double) {
 					for (int row = 0; row < nrows; ++row)
 						columnNumeric[row] = c->valueAt(row);
 
@@ -970,11 +952,11 @@ QMultiMap<QString, QString> FITSFilterPrivate::extensionNames(const QString& fil
 	int status = 0;
 	fitsfile* fitsFile = nullptr;
 	if (fits_open_file(&fitsFile, fileName.toLatin1(), READONLY, &status ))
-		return QMultiMap<QString, QString>();
+		return {};
 	int hduCount;
 
 	if (fits_get_num_hdus(fitsFile, &hduCount, &status))
-		return QMultiMap<QString, QString>();
+		return {};
 	int imageCount = 0;
 	int asciiTableCount = 0;
 	int binaryTableCount = 0;
@@ -1058,7 +1040,7 @@ void FITSFilterPrivate::printError(int status) const {
 #ifdef HAVE_FITS
 	if (status) {
 		char errorText[FLEN_ERRMSG];
-		fits_get_errstatus(status, errorText );
+		fits_get_errstatus(status, errorText);
 		qDebug() << QLatin1String(errorText);
 	}
 #else
@@ -1344,12 +1326,12 @@ QList<FITSFilter::Keyword> FITSFilterPrivate::chduKeywords(const QString& fileNa
 
 	if (fits_open_file(&m_fitsFile, fileName.toLatin1(), READONLY, &status )) {
 		printError(status);
-		return QList<FITSFilter::Keyword> ();
+		return {};
 	}
 	int numberOfKeys;
 	if (fits_get_hdrspace(m_fitsFile, &numberOfKeys, nullptr, &status)) {
 		printError(status);
-		return QList<FITSFilter::Keyword> ();
+		return {};
 	}
 
 	QList<FITSFilter::Keyword> keywords;
@@ -1590,15 +1572,13 @@ FITSFilterPrivate::~FITSFilterPrivate() = default;
   Saves as XML.
 */
 
-void FITSFilter::save(QXmlStreamWriter * writer) const {
-	Q_UNUSED(writer)
+void FITSFilter::save(QXmlStreamWriter*) const {
 }
 
 /*!
   Loads from XML.
 */
 
-bool FITSFilter::load(XmlStreamReader * loader) {
-	Q_UNUSED(loader)
+bool FITSFilter::load(XmlStreamReader*) {
 	return false;
 }
