@@ -1,33 +1,17 @@
-/***************************************************************************
-File                 : ImageFilter.cpp
-Project              : LabPlot
-Description          : Image I/O-filter
---------------------------------------------------------------------
-Copyright            : (C) 2015 by Stefan Gerlach (stefan.gerlach@uni.kn)
-***************************************************************************/
-
-/***************************************************************************
-*                                                                         *
-*  This program is free software; you can redistribute it and/or modify   *
-*  it under the terms of the GNU General Public License as published by   *
-*  the Free Software Foundation; either version 2 of the License, or      *
-*  (at your option) any later version.                                    *
-*                                                                         *
-*  This program is distributed in the hope that it will be useful,        *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
-*  GNU General Public License for more details.                           *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the Free Software           *
-*   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
-*   Boston, MA  02110-1301  USA                                           *
-*                                                                         *
-***************************************************************************/
+/*
+    File                 : ImageFilter.cpp
+    Project              : LabPlot
+    Description          : Image I/O-filter
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2015 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "backend/datasources/filters/ImageFilter.h"
 #include "backend/datasources/filters/ImageFilterPrivate.h"
 #include "backend/spreadsheet/Spreadsheet.h"
 #include "backend/core/column/Column.h"
+#include "backend/lib/macros.h"
+#include "backend/lib/XmlStreamReader.h"
 
 #include <QImage>
 #include <KLocalizedString>
@@ -72,15 +56,13 @@ void ImageFilter::write(const QString & fileName, AbstractDataSource* dataSource
 /*!
   loads the predefined filter settings for \c filterName
 */
-void ImageFilter::loadFilterSettings(const QString& filterName) {
-	Q_UNUSED(filterName);
+void ImageFilter::loadFilterSettings(const QString& /*filterName*/) {
 }
 
 /*!
   saves the current settings as a new filter with the name \c filterName
 */
-void ImageFilter::saveFilterSettings(const QString& filterName) const {
-	Q_UNUSED(filterName);
+void ImageFilter::saveFilterSettings(const QString& /*filterName*/) const {
 }
 
 ///////////////////////////////////////////////////////////////////////
@@ -124,13 +106,11 @@ int ImageFilter::endColumn() const {
 	return d->endColumn;
 }
 
-QString ImageFilter::fileInfoString(const QString& fileName) {
+QString ImageFilter::fileInfoString(const QString& /*fileName*/) {
 	DEBUG("ImageFilter::fileInfoString()");
 	QString info;
 
 	//TODO
-	Q_UNUSED(fileName);
-
 	return info;
 }
 
@@ -207,7 +187,7 @@ void ImageFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataS
 					double value = qGray(image.pixel(j+startColumn-1, i+startRow-1));
 					static_cast<QVector<double>*>(dataContainer[j])->operator[](i) = value;
 				}
-				emit q->completed(100*i/actualRows);
+				Q_EMIT q->completed(100*i/actualRows);
 			}
 			break;
 		}
@@ -221,7 +201,7 @@ void ImageFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataS
 					static_cast<QVector<int>*>(dataContainer[2])->operator[](currentRow) = qGray(color);
 					currentRow++;
 				}
-				emit q->completed(100*i/actualRows);
+				Q_EMIT q->completed(100*i/actualRows);
 			}
 			break;
 		}
@@ -237,7 +217,7 @@ void ImageFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataS
 					static_cast<QVector<int>*>(dataContainer[4])->operator[](currentRow) = qBlue(color);
 					currentRow++;
 				}
-				emit q->completed(100*i/actualRows);
+				Q_EMIT q->completed(100*i/actualRows);
 			}
 			break;
 		}
@@ -264,9 +244,7 @@ void ImageFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataS
 /*!
     writes the content of \c dataSource to the file \c fileName.
 */
-void ImageFilterPrivate::write(const QString & fileName, AbstractDataSource* dataSource) {
-	Q_UNUSED(fileName);
-	Q_UNUSED(dataSource);
+void ImageFilterPrivate::write(const QString& /*fileName*/, AbstractDataSource* /*dataSource*/) {
 	//TODO
 }
 
@@ -285,8 +263,7 @@ void ImageFilter::save(QXmlStreamWriter* writer) const {
 /*!
   Loads from XML.
 */
-bool ImageFilter::load(XmlStreamReader* reader) {
-	Q_UNUSED(reader);
+bool ImageFilter::load(XmlStreamReader*) {
 // 	KLocalizedString attributeWarning = ki18n("Attribute '%1' missing or empty, default value is used");
 // 	QXmlStreamAttributes attribs = reader->attributes();
 
