@@ -1,39 +1,21 @@
-/***************************************************************************
+/*
     File                 : JsonFilter.cpp
     Project              : LabPlot
     Description          : JSON I/O-filter.
     --------------------------------------------------------------------
-    --------------------------------------------------------------------
-    Copyright            : (C) 2018 Andrey Cygankov (craftplace.ms@gmail.com)
-    Copyright            : (C) 2018-2020 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2018-2020 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2018 Andrey Cygankov <craftplace.ms@gmail.com>
+    SPDX-FileCopyrightText: 2018-2020 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2018-2020 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "backend/datasources/filters/JsonFilter.h"
 #include "backend/datasources/filters/JsonFilterPrivate.h"
 #include "backend/datasources/AbstractDataSource.h"
 #include "backend/core/column/Column.h"
 #include "backend/spreadsheet/Spreadsheet.h"
+#include "backend/lib/XmlStreamReader.h"
 #include "backend/lib/trace.h"
 
 #include <QJsonDocument>
@@ -92,15 +74,13 @@ void JsonFilter::write(const QString& fileName, AbstractDataSource* dataSource)
 /*!
 loads the predefined filter settings for \c filterName
 */
-void JsonFilter::loadFilterSettings(const QString& filterName) {
-	Q_UNUSED(filterName);
+void JsonFilter::loadFilterSettings(const QString& /*filterName*/) {
 }
 
 /*!
 saves the current settings as a new filter with the name \c filterName
 */
-void JsonFilter::saveFilterSettings(const QString& filterName) const {
-	Q_UNUSED(filterName);
+void JsonFilter::saveFilterSettings(const QString& /*filterName*/) const {
 }
 
 /*!
@@ -333,7 +313,7 @@ int JsonFilterPrivate::parseColumnModes(const QJsonValue& row, const QString& ro
 
 		switch (columnValue.type()) {
 			case QJsonValue::Double:
-				columnModes << AbstractColumn::ColumnMode::Numeric;
+				columnModes << AbstractColumn::ColumnMode::Double;
 				break;
 			case QJsonValue::String:
 				columnModes << AbstractFileFilter::columnMode(columnValue.toString(), dateTimeFormat, numberFormat);
@@ -352,7 +332,7 @@ int JsonFilterPrivate::parseColumnModes(const QJsonValue& row, const QString& ro
 
 void JsonFilterPrivate::setEmptyValue(int column, int row) {
 	switch (columnModes[column]) {
-		case AbstractColumn::ColumnMode::Numeric:
+		case AbstractColumn::ColumnMode::Double:
 			static_cast<QVector<double>*>(m_dataContainer[column])->operator[](row) = nanValue;
 			break;
 		case AbstractColumn::ColumnMode::Integer:
@@ -376,7 +356,7 @@ void JsonFilterPrivate::setEmptyValue(int column, int row) {
 void JsonFilterPrivate::setValueFromString(int column, int row, const QString& valueString) {
 	QLocale locale(numberFormat);
 	switch (columnModes[column]) {
-		case AbstractColumn::ColumnMode::Numeric: {
+		case AbstractColumn::ColumnMode::Double: {
 			bool isNumber;
 			const double value = locale.toDouble(valueString, &isNumber);
 			static_cast<QVector<double>*>(m_dataContainer[column])->operator[](row) = isNumber ? value : nanValue;
@@ -561,8 +541,6 @@ void JsonFilterPrivate::readDataFromDevice(QIODevice& device, AbstractDataSource
 import the content of document \c m_preparedDoc to the data source \c dataSource. Uses the settings defined in the data source.
 */
 void JsonFilterPrivate::importData(AbstractDataSource* dataSource, AbstractFileFilter::ImportMode importMode, int lines) {
-	Q_UNUSED(lines)
-
 	m_columnOffset = dataSource->prepareImport(m_dataContainer, importMode, m_actualRows, m_actualCols, vectorNames, columnModes);
 	int rowOffset = startRow - 1;
 	int colOffset = (int)createIndexEnabled + (int)importObjectNames;
@@ -570,7 +548,7 @@ void JsonFilterPrivate::importData(AbstractDataSource* dataSource, AbstractFileF
 	DEBUG("reading " << m_actualCols << " columns");
 
 	int progressIndex = 0;
-	const float progressInterval = 0.01*lines; //update on every 1% only
+	const float progressInterval = 0.01 * lines; //update on every 1% only
 
 	const auto& array = m_preparedDoc.array();
 	const auto& arrayIterator = array.begin();
@@ -615,7 +593,7 @@ void JsonFilterPrivate::importData(AbstractDataSource* dataSource, AbstractFileF
 
 			switch (value.type()) {
 			case QJsonValue::Double:
-				if (columnModes[colOffset + n] == AbstractColumn::ColumnMode::Numeric)
+				if (columnModes[colOffset + n] == AbstractColumn::ColumnMode::Double)
 					static_cast<QVector<double>*>(m_dataContainer[colOffset + n])->operator[](i) = value.toDouble();
 				else
 					setEmptyValue(colOffset + n, i + startRow - 1);
@@ -637,14 +615,15 @@ void JsonFilterPrivate::importData(AbstractDataSource* dataSource, AbstractFileF
 		//only in 1% steps
 		progressIndex++;
 		if (m_actualRows > 1000 && progressIndex > progressInterval) {
-			emit q->completed(100 * i/m_actualRows);
+			double value = 100. * i/lines;
+			Q_EMIT q->completed(static_cast<int>(value));
 			progressIndex = 0;
 			QApplication::processEvents(QEventLoop::AllEvents, 0);
 		}
 	}
 
 	//set the plot designation to 'X' for index and name columns, if available
-	Spreadsheet* spreadsheet = dynamic_cast<Spreadsheet*>(dataSource);
+	auto* spreadsheet = dynamic_cast<Spreadsheet*>(dataSource);
 	if (spreadsheet) {
 		if (createIndexEnabled)
 			spreadsheet->column(m_columnOffset )->setPlotDesignation(AbstractColumn::PlotDesignation::X);
@@ -674,14 +653,14 @@ QVector<QStringList> JsonFilterPrivate::preview(QIODevice& device, int lines) {
 		const int deviceError = prepareDeviceToRead(device);
 		if (deviceError != 0) {
 			DEBUG("Device error = " << deviceError);
-			return QVector<QStringList>();
+			return {};
 		}
 	}
 
 	if (prepareDocumentToRead())
 		return preview(lines);
-	else
-		return QVector<QStringList>();
+
+	return {};
 }
 
 /*!
@@ -758,10 +737,7 @@ QVector<QStringList> JsonFilterPrivate::preview(int lines) {
 /*!
 writes the content of \c dataSource to the file \c fileName.
 */
-void JsonFilterPrivate::write(const QString& fileName, AbstractDataSource* dataSource) {
-	Q_UNUSED(fileName);
-	Q_UNUSED(dataSource);
-
+void JsonFilterPrivate::write(const QString& /*fileName*/, AbstractDataSource* /*dataSource*/) {
 	//TODO: saving data to json file not supported yet
 }
 
