@@ -1,34 +1,18 @@
-/***************************************************************************
-File                 : NetCDFFilter.cpp
-Project              : LabPlot
-Description          : NetCDF I/O-filter
---------------------------------------------------------------------
-Copyright            : (C) 2015-2019 by Stefan Gerlach (stefan.gerlach@uni.kn)
-Copyright            : (C) 2017 Alexander Semke (alexander.semke@web.de)
-***************************************************************************/
-
-/***************************************************************************
-*                                                                         *
-*  This program is free software; you can redistribute it and/or modify   *
-*  it under the terms of the GNU General Public License as published by   *
-*  the Free Software Foundation; either version 2 of the License, or      *
-*  (at your option) any later version.                                    *
-*                                                                         *
-*  This program is distributed in the hope that it will be useful,        *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
-*  GNU General Public License for more details.                           *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the Free Software           *
-*   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
-*   Boston, MA  02110-1301  USA                                           *
-*                                                                         *
-***************************************************************************/
-#include "backend/datasources/filters/NetCDFFilter.h"
-#include "backend/datasources/filters/NetCDFFilterPrivate.h"
+/*
+    File                 : NetCDFFilter.cpp
+    Project              : LabPlot
+    Description          : NetCDF I/O-filter
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2015-2019 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
+#include "NetCDFFilter.h"
+#include "NetCDFFilterPrivate.h"
 #include "backend/spreadsheet/Spreadsheet.h"
 #include "backend/core/column/Column.h"
+#include "backend/lib/macros.h"
+#include "backend/lib/XmlStreamReader.h"
 
 #include <KLocalizedString>
 #include <QProcess>
@@ -115,7 +99,7 @@ Copyright            : (C) 2017 Alexander Semke (alexander.semke@web.de)
 					line << QString::number(data[i][j]); \
 			} \
 			dataStrings << line; \
-			emit q->completed(100*i/actualRows); \
+			Q_EMIT q->completed(100*i/actualRows); \
 		} \
 	} \
 	free(data[0]); \
@@ -174,15 +158,13 @@ void NetCDFFilter::write(const QString & fileName, AbstractDataSource* dataSourc
 /*!
   loads the predefined filter settings for \c filterName
 */
-void NetCDFFilter::loadFilterSettings(const QString& filterName) {
-	Q_UNUSED(filterName);
+void NetCDFFilter::loadFilterSettings(const QString& /*filterName*/) {
 }
 
 /*!
   saves the current settings as a new filter with the name \c filterName
 */
-void NetCDFFilter::saveFilterSettings(const QString& filterName) const {
-	Q_UNUSED(filterName);
+void NetCDFFilter::saveFilterSettings(const QString& /*filterName*/) const {
 }
 
 ///////////////////////////////////////////////////////////////////////
@@ -228,9 +210,7 @@ int NetCDFFilter::endColumn() const {
 }
 
 QString NetCDFFilter::fileInfoString(const QString& fileName) {
-	DEBUG("NetCDFFilter::fileInfoString()");
-
-	DEBUG("fileName = " << qPrintable(fileName))
+	DEBUG(Q_FUNC_INFO << ", fileName = " << qPrintable(fileName))
 
 	QString info;
 #ifdef HAVE_NETCDF
@@ -268,6 +248,8 @@ QString NetCDFFilter::fileInfoString(const QString& fileName) {
 
 	status = ncclose(ncid);
 	NetCDFFilterPrivate::handleError(status, "nc_close");
+#else
+	Q_UNUSED(fileName)
 #endif
 
 	return info;
@@ -282,15 +264,19 @@ QString NetCDFFilter::fileCDLString(const QString& fileName) {
 
 	QString CDLString;
 #ifdef Q_OS_LINUX
-	auto* proc = new QProcess();
+	const QString ncdumpFullPath = QStandardPaths::findExecutable(QLatin1String("ncdump"));
+	if (ncdumpFullPath.isEmpty())
+		return i18n("ncdump not found.");
+
+	QProcess proc;
 	QStringList args;
 	args << "-cs" << fileName;
-	proc->start( "ncdump", args);
+	proc.start(ncdumpFullPath, args);
 
-	if (proc->waitForReadyRead(1000) == false)
+	if (proc.waitForReadyRead(1000) == false)
 		CDLString += i18n("Reading from file %1 failed.", fileName);
 	else {
-		CDLString += proc->readAll();
+		CDLString += proc.readAll();
 		CDLString.replace('\n', "<br>\n");
 		CDLString.replace("\t","&nbsp;&nbsp;&nbsp;&nbsp;");
 		//DEBUG("	CDL string: " << STDSTRING(CDLString));
@@ -314,11 +300,11 @@ NetCDFFilterPrivate::NetCDFFilterPrivate(NetCDFFilter* owner) : q(owner) {
 
 #ifdef HAVE_NETCDF
 void NetCDFFilterPrivate::handleError(int err, const QString& function) {
+	Q_UNUSED(function);
 	if (err != NC_NOERR) {
 		DEBUG("NETCDF ERROR:" << STDSTRING(function) << "() - " << nc_strerror(err));
 		return;
 	}
-	Q_UNUSED(function);
 }
 
 QString NetCDFFilterPrivate::translateDataType(nc_type type) {
@@ -646,8 +632,10 @@ QString NetCDFFilterPrivate::readAttribute(const QString& fileName, const QStrin
 QVector<QStringList> NetCDFFilterPrivate::readCurrentVar(const QString& fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode mode, int lines) {
 	QVector<QStringList> dataStrings;
 
-	if (currentVarName.isEmpty())
+	if (currentVarName.isEmpty()) {
+		DEBUG(Q_FUNC_INFO << ", WARNING: current var name is empty!")
 		return dataStrings << (QStringList() << i18n("No variable selected"));
+	}
 	DEBUG(" current variable = " << STDSTRING(currentVarName));
 
 #ifdef HAVE_NETCDF
@@ -698,7 +686,7 @@ QVector<QStringList> NetCDFFilterPrivate::readCurrentVar(const QString& fileName
 		case NC_UINT64:	// converted to double (int is too small)
 		case NC_DOUBLE:
 		case NC_FLOAT:
-			columnModes[0] = AbstractColumn::ColumnMode::Numeric;
+			columnModes[0] = AbstractColumn::ColumnMode::Double;
 			break;
 		case NC_CHAR:
 			columnModes[0] = AbstractColumn::ColumnMode::Text;
@@ -773,7 +761,7 @@ QVector<QStringList> NetCDFFilterPrivate::readCurrentVar(const QString& fileName
 		case NC_UINT64:	// converted to double (int is too small)
 		case NC_DOUBLE:
 		case NC_FLOAT:
-			columnModes[0] = AbstractColumn::ColumnMode::Numeric;
+			columnModes[0] = AbstractColumn::ColumnMode::Double;
 			break;
 		case NC_CHAR:
 			columnModes[0] = AbstractColumn::ColumnMode::Text;
@@ -867,7 +855,7 @@ QVector<QStringList> NetCDFFilterPrivate::readCurrentVar(const QString& fileName
 		case NC_DOUBLE:
 		case NC_FLOAT:
 			for (int i = 0; i < actualCols; i++)
-				columnModes[i] = AbstractColumn::ColumnMode::Numeric;
+				columnModes[i] = AbstractColumn::ColumnMode::Double;
 			break;
 		case NC_CHAR:
 			for (int i = 0; i < actualCols; i++)
@@ -903,7 +891,7 @@ QVector<QStringList> NetCDFFilterPrivate::readCurrentVar(const QString& fileName
 							line << QString(data[i][j]);
 					}
 					dataStrings << line;
-					emit q->completed(100*i/actualRows);
+					Q_EMIT q->completed(100*i/actualRows);
 				}
 			}
 			free(data[0]);
@@ -935,6 +923,7 @@ QVector<QStringList> NetCDFFilterPrivate::readCurrentVar(const QString& fileName
 	m_status = ncclose(ncid);
 	handleError(m_status, "nc_close");
 
+	// TODO: why 1 row?
 	if (dataSource)
 		dataSource->finalizeImport(columnOffset, 1, actualCols, QString(), mode);
 #else
@@ -952,10 +941,11 @@ QVector<QStringList> NetCDFFilterPrivate::readCurrentVar(const QString& fileName
     Uses the settings defined in the data source.
 */
 QVector<QStringList> NetCDFFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode mode) {
+	DEBUG(Q_FUNC_INFO)
 	QVector<QStringList> dataStrings;
 
 	if (currentVarName.isEmpty()) {
-		DEBUG(" No variable selected");
+		DEBUG(Q_FUNC_INFO << ", no variable selected");
 		return dataStrings;
 	}
 
@@ -965,10 +955,8 @@ QVector<QStringList> NetCDFFilterPrivate::readDataFromFile(const QString& fileNa
 /*!
     writes the content of \c dataSource to the file \c fileName.
 */
-void NetCDFFilterPrivate::write(const QString & fileName, AbstractDataSource* dataSource) {
-	Q_UNUSED(fileName);
-	Q_UNUSED(dataSource);
-	//TODO: write NetCDF files not implemented yet
+void NetCDFFilterPrivate::write(const QString& /*fileName*/, AbstractDataSource* /*dataSource*/) {
+	//TODO: writing NetCDF files not implemented yet
 }
 
 //##############################################################################
@@ -986,8 +974,7 @@ void NetCDFFilter::save(QXmlStreamWriter* writer) const {
 /*!
   Loads from XML.
 */
-bool NetCDFFilter::load(XmlStreamReader* reader) {
-	Q_UNUSED(reader);
+bool NetCDFFilter::load(XmlStreamReader*) {
 // 	KLocalizedString attributeWarning = ki18n("Attribute '%1' missing or empty, default value is used");
 // 	QXmlStreamAttributes attribs = reader->attributes();
 	return true;
