@@ -1,27 +1,9 @@
 /*
- * The MIT License (MIT)
- *
- * Copyright (c) 2011 SCHUTZ Sacha
- * Copyright (C) 2020 Alexander Semke (alexander.semke@web.de)
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in all
- * copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
- */
+    SPDX-FileCopyrightText: 2011 SCHUTZ Sacha
+    SPDX-FileCopyrightText: 2020 Alexander Semke <alexander.semke@web.de>
+
+    SPDX-License-Identifier: MIT
+*/
 
 #include "QJsonModel.h"
 #include "backend/lib/trace.h"
@@ -251,7 +233,7 @@ bool QJsonModel::loadJson(const QJsonDocument& jdoc) {
 
 QVariant QJsonModel::data(const QModelIndex& index, int role) const {
 	if (!index.isValid())
-		return QVariant();
+		return {};
 
 	auto* item = static_cast<QJsonTreeItem*>(index.internalPointer());
 
@@ -259,9 +241,9 @@ QVariant QJsonModel::data(const QModelIndex& index, int role) const {
 		if (index.column() == 0)
 			return item->key();
 		else if (index.column() == 1) {
-			//in case the value is very long, cut it so the preview tree tree view doesnt' explode
+			//in case the value is very long, cut it so the preview tree tree view doesn't explode
 			if (item->value().length() > 200)
-				return item->value().left(200) + QLatin1String(" ...");
+				return QString( item->value().left(200) + QLatin1String(" ...") );
 			else
 				return item->value();
 		} else {
@@ -282,7 +264,7 @@ QVariant QJsonModel::data(const QModelIndex& index, int role) const {
 		}
 	}
 
-	return QVariant();
+	return {};
 }
 
 bool QJsonModel::setData(const QModelIndex& index, const QVariant& value, int role) {
@@ -290,7 +272,7 @@ bool QJsonModel::setData(const QModelIndex& index, const QVariant& value, int ro
 		if (index.column() == 1) {
 			auto* item = static_cast<QJsonTreeItem*>(index.internalPointer());
 			item->setValue(value.toString());
-			emit dataChanged(index, index, {Qt::EditRole});
+			Q_EMIT dataChanged(index, index, {Qt::EditRole});
 			return true;
 		}
 	}
@@ -302,7 +284,7 @@ QVariant QJsonModel::headerData(int section, Qt::Orientation orientation, int ro
 	if (role == Qt::DisplayRole && orientation == Qt::Horizontal)
 		return mHeaders.value(section);
 
-	return QVariant();
+	return {};
 }
 
 QModelIndex QJsonModel::index(int row, int column, const QModelIndex& parent) const {
@@ -320,7 +302,7 @@ QModelIndex QJsonModel::index(int row, int column, const QModelIndex& parent) co
 	if (childItem)
 		return createIndex(row, column, childItem);
 
-	return QModelIndex{};
+	return {};
 }
 
 QModelIndex QJsonModel::parent(const QModelIndex& index) const {
@@ -349,8 +331,7 @@ int QJsonModel::rowCount(const QModelIndex& parent) const {
 	return parentItem->childCount();
 }
 
-int QJsonModel::columnCount(const QModelIndex& parent) const {
-	Q_UNUSED(parent)
+int QJsonModel::columnCount(const QModelIndex& /*parent*/) const {
 	return 3;
 }
 
@@ -401,7 +382,7 @@ QJsonValue QJsonModel::genJson(QJsonTreeItem* item) const {
 
 QJsonDocument QJsonModel::genJsonByIndex(const QModelIndex& index) const {
 	if (!index.isValid())
-		return QJsonDocument();
+		return {};
 
 	auto* item = static_cast<QJsonTreeItem*>(index.internalPointer());
 	return QJsonDocument::fromVariant(genJson(item).toVariant());
