@@ -1,35 +1,19 @@
-/***************************************************************************
-File                 : ROOTFilter.cpp
-Project              : LabPlot
-Description          : ROOT(CERN) I/O-filter
---------------------------------------------------------------------
-Copyright            : (C) 2018 by Christoph Roick (chrisito@gmx.de)
-Copyright            : (C) 2018 by Stefan Gerlach (stefan.gerlach@uni.kn)
-***************************************************************************/
-
-/***************************************************************************
-*                                                                         *
-*  This program is free software; you can redistribute it and/or modify   *
-*  it under the terms of the GNU General Public License as published by   *
-*  the Free Software Foundation; either version 2 of the License, or      *
-*  (at your option) any later version.                                    *
-*                                                                         *
-*  This program is distributed in the hope that it will be useful,        *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
-*  GNU General Public License for more details.                           *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the Free Software           *
-*   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
-*   Boston, MA  02110-1301  USA                                           *
-*                                                                         *
-***************************************************************************/
+/*
+    File                 : ROOTFilter.cpp
+    Project              : LabPlot
+    Description          : ROOT(CERN) I/O-filter
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2018 Christoph Roick <chrisito@gmx.de>
+    SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "backend/datasources/filters/ROOTFilter.h"
 #include "backend/datasources/filters/ROOTFilterPrivate.h"
 #include "backend/spreadsheet/Spreadsheet.h"
 #include "backend/core/column/Column.h"
+#include "backend/lib/macros.h"
+#include "backend/lib/XmlStreamReader.h"
 
 #include <KLocalizedString>
 
@@ -63,12 +47,10 @@ void ROOTFilter::write(const QString& fileName, AbstractDataSource* dataSource)
 	d->write(fileName, dataSource);
 }
 
-void ROOTFilter::loadFilterSettings(const QString& filterName) {
-	Q_UNUSED(filterName);
+void ROOTFilter::loadFilterSettings(const QString& /*filterName*/) {
 }
 
-void ROOTFilter::saveFilterSettings(const QString& filterName) const {
-	Q_UNUSED(filterName);
+void ROOTFilter::saveFilterSettings(const QString& /*filterName*/) const {
 }
 
 void ROOTFilter::setCurrentObject(const QString& object) {
@@ -225,7 +207,7 @@ ROOTFilterPrivate::FileType ROOTFilterPrivate::currentObjectPosition(const QStri
 
 void ROOTFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataSource* dataSource,
 		AbstractFileFilter::ImportMode importMode) {
-	DEBUG("ROOTFilterPrivate::readDataFromFile()");
+	DEBUG(Q_FUNC_INFO);
 
 	long int pos = 0;
 	auto type = currentObjectPosition(fileName, pos);
@@ -247,13 +229,13 @@ void ROOTFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataSo
 
 		std::vector<void*> dataContainer;
 		const int columnOffset = dataSource->prepareImport(dataContainer, importMode, last - first + 1, columns.size(),
-			headers, QVector<AbstractColumn::ColumnMode>(columns.size(), AbstractColumn::ColumnMode::Numeric));
+			headers, QVector<AbstractColumn::ColumnMode>(columns.size(), AbstractColumn::ColumnMode::Double));
 
 		// read data
 		DEBUG("	reading " << first - last + 1 << " lines");
 
 		int c = 0;
-		Spreadsheet* spreadsheet = dynamic_cast<Spreadsheet*>(dataSource);
+		auto* spreadsheet = dynamic_cast<Spreadsheet*>(dataSource);
 
 		for (const auto& l : columns) {
 			QVector<double>& container = *static_cast<QVector<double>*>(dataContainer[c]);
@@ -305,7 +287,7 @@ void ROOTFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataSo
 
 		std::vector<void*> dataContainer;
 		const int columnOffset = dataSource->prepareImport(dataContainer, importMode, last - first + 1, columns.size(),
-			headers, QVector<AbstractColumn::ColumnMode>(columns.size(), AbstractColumn::ColumnMode::Numeric));
+			headers, QVector<AbstractColumn::ColumnMode>(columns.size(), AbstractColumn::ColumnMode::Double));
 
 		int c = 0;
 		for (const auto& l : columns) {
@@ -331,9 +313,7 @@ void ROOTFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataSo
 	}
 }
 
-void ROOTFilterPrivate::write(const QString& fileName, AbstractDataSource* dataSource) {
-	Q_UNUSED(fileName);
-	Q_UNUSED(dataSource);
+void ROOTFilterPrivate::write(const QString& /*fileName*/, AbstractDataSource* /*dataSource*/) {
 }
 
 ROOTFilter::Directory ROOTFilterPrivate::listContent(const std::map<long int, ROOTData::Directory>& dataContent, std::string (ROOTData::*nameFunc)(long int))
@@ -414,7 +394,7 @@ QVector<QStringList> ROOTFilterPrivate::previewCurrentObject(const QString& file
 	long int pos = 0;
 	auto type = currentObjectPosition(fileName, pos);
 	if (pos == 0)
-		return QVector<QStringList>(1, QStringList());
+		return {1, QStringList()};
 
 	if (type == FileType::Hist) {
 		auto bins = readHistogram(pos);
@@ -482,7 +462,7 @@ QVector<QStringList> ROOTFilterPrivate::previewCurrentObject(const QString& file
 
 		return preview;
 	} else
-		return QVector<QStringList>(1, QStringList());
+		return {1, QStringList()};
 }
 
 int ROOTFilterPrivate::rowsInCurrentObject(const QString& fileName) {
@@ -604,12 +584,12 @@ std::string String(char*& buffer) {
 	// root/io/io/src/TBufferFile.cxx -> ReadTString
 	size_t s = *(buffer++);
 	if (s == 0)
-		return std::string();
+		return {};
 	else {
 		if (s == 0xFF)
 			s = read<int>(buffer);
 		buffer += s;
-		return std::string(buffer - s, buffer);
+		return {buffer - s, buffer};
 	}
 }
 
@@ -870,16 +850,14 @@ void ROOTData::readNBins(ROOTData::KeyBuffer& kbuffer) {
 	}
 }
 
-std::string ROOTData::histogramName(long int pos)
-{
+std::string ROOTData::histogramName(long int pos) {
 	auto it = histkeys.find(pos);
 	if (it != histkeys.end())
 		return it->second.name + ';' + std::to_string(it->second.cycle);
-	return std::string();
+	return {};
 }
 
-int ROOTData::histogramBins(long int pos)
-{
+int ROOTData::histogramBins(long int pos) {
 	auto it = histkeys.find(pos);
 	if (it != histkeys.end())
 		return it->second.nrows;
@@ -889,7 +867,7 @@ int ROOTData::histogramBins(long int pos)
 std::vector<ROOTData::BinPars> ROOTData::readHistogram(long int pos) {
 	auto it = histkeys.find(pos);
 	if (it == histkeys.end())
-		return std::vector<ROOTData::BinPars>();
+		return {};
 
 	std::string buffer = data(it->second);
 	if (!buffer.empty()) {
@@ -906,7 +884,7 @@ std::vector<ROOTData::BinPars> ROOTData::readHistogram(long int pos) {
 
 		std::vector<BinPars> r(read<int>(buf)); // fNcells
 		if (r.size() < 3)
-			return std::vector<BinPars>();
+			return {};
 
 		r.front().lowedge = -std::numeric_limits<double>::infinity();
 
@@ -951,7 +929,7 @@ std::vector<ROOTData::BinPars> ROOTData::readHistogram(long int pos) {
 
 		return r;
 	} else
-		return std::vector<BinPars>();
+		return {};
 }
 
 void ROOTData::readNEntries(ROOTData::KeyBuffer& kbuffer) {
@@ -967,16 +945,14 @@ void ROOTData::readNEntries(ROOTData::KeyBuffer& kbuffer) {
 	}
 }
 
-std::string ROOTData::treeName(long int pos)
-{
+std::string ROOTData::treeName(long int pos) {
 	auto it = treekeys.find(pos);
 	if (it != treekeys.end())
 		return it->second.name;
-	return std::string();
+	return {};
 }
 
-int ROOTData::treeEntries(long int pos)
-{
+int ROOTData::treeEntries(long int pos) {
 	auto it = treekeys.find(pos);
 	if (it != treekeys.end())
 		return it->second.nrows;
@@ -1298,7 +1274,7 @@ std::string ROOTData::data(const ROOTData::KeyBuffer& buffer, std::ifstream& is)
 #endif
 	}
 
-	return std::string();
+	return {};
 }
 
 void ROOTData::readStreamerInfo(const ROOTData::KeyBuffer& buffer) {
@@ -1495,7 +1471,5 @@ QString ROOTFilter::fileInfoString(const QString& fileName) {
 	info += i18n("Size of TStreamerInfo record: %1 bytes", QString::number(infoBytes));
 	info += QLatin1String("<br>");
 
-	Q_UNUSED(fileName);
-
 	return info;
 }
