@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File             : ExpressionParser.cpp
     Project          : LabPlot
-    --------------------------------------------------------------------
-    Copyright        : (C) 2014 Alexander Semke (alexander.semke@web.de)
-    Copyright        : (C) 2014-2020 Stefan Gerlach (stefan.gerlach@uni.kn)
     Description      : C++ wrapper for the bison generated parser.
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2014 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2014-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include <QRegularExpression>
 
@@ -51,7 +33,7 @@ ExpressionParser::ExpressionParser() {
 	initConstants();
 }
 
-// initialize function list	(sync with functions.h!)
+// initialize function list	(sync with functions.h and FunctionsWidget.cpp!)
 void ExpressionParser::initFunctions() {
 	for (int i = 0; _functions[i].name != nullptr; i++)
 		m_functions << _functions[i].name;
@@ -87,13 +69,17 @@ void ExpressionParser::initFunctions() {
 	m_functionsGroups << i18n("Lambert W Functions");
 	m_functionsGroups << i18n("Legendre Functions and Spherical Harmonics");
 	m_functionsGroups << i18n("Logarithm and Related Functions");
-//	m_functionsGroups << i18n("Mathieu Functions");
+#if (GSL_MAJOR_VERSION >= 2)
+	m_functionsGroups << i18n("Mathieu Functions");
+#endif
 	m_functionsGroups << i18n("Power Function");
 	m_functionsGroups << i18n("Psi (Digamma) Function");
 	m_functionsGroups << i18n("Synchrotron Functions");
 	m_functionsGroups << i18n("Transport Functions");
 	m_functionsGroups << i18n("Trigonometric Functions");
 	m_functionsGroups << i18n("Zeta Functions");
+	// GSL random numbers
+	m_functionsGroups << i18n("Random number generator");
 	// GSL random distribution functions
 	m_functionsGroups << i18n("Gaussian Distribution");
 	m_functionsGroups << i18n("Exponential Distribution");
@@ -163,6 +149,8 @@ void ExpressionParser::initFunctions() {
 #endif
 		m_functionsGroupIndex << index;
 
+	index++;	// separator
+
 	// Airy Functions and Derivatives
 	m_functionsNames << i18n("Airy function of the first kind");
 	m_functionsNames << i18n("Airy function of the second kind");
@@ -398,12 +386,19 @@ void ExpressionParser::initFunctions() {
 	m_functionsNames << i18n("Hermite polynomials physicists version");
 	m_functionsNames << i18n("Hermite polynomials probabilists version");
 	m_functionsNames << i18n("Hermite functions");
+#if (GSL_MAJOR_VERSION > 2) || (GSL_MAJOR_VERSION == 2) && (GSL_MINOR_VERSION >= 6)
+	m_functionsNames << i18n("Hermite functions (fast version)");
+#endif
 	m_functionsNames << i18n("Derivatives of Hermite polynomials physicists version");
 	m_functionsNames << i18n("Derivatives of Hermite polynomials probabilists version");
 	m_functionsNames << i18n("Derivatives of Hermite functions");
 
 	index++;
+#if (GSL_MAJOR_VERSION == 2) && (GSL_MINOR_VERSION < 6)
 	for (int i = 0; i < 6; i++)
+#else
+	for (int i = 0; i < 7; i++)
+#endif
 		m_functionsGroupIndex << index;
 #endif
 
@@ -427,9 +422,10 @@ void ExpressionParser::initFunctions() {
 	m_functionsNames << i18n("generalized Laguerre polynomials L_1");
 	m_functionsNames << i18n("generalized Laguerre polynomials L_2");
 	m_functionsNames << i18n("generalized Laguerre polynomials L_3");
+	m_functionsNames << i18n("generalized Laguerre polynomials L_n");
 
 	index++;
-	for (int i = 0; i < 3; i++)
+	for (int i = 0; i < 4; i++)
 		m_functionsGroupIndex << index;
 
 	// Lambert W Functions
@@ -475,6 +471,20 @@ void ExpressionParser::initFunctions() {
 	for (int i = 0; i < 4; i++)
 		m_functionsGroupIndex << index;
 
+	//Mathieu Functions
+#if (GSL_MAJOR_VERSION >= 2)
+	m_functionsNames << i18n("Characteristic values a_n(q) of the Mathieu functions ce_n(q,x)");
+	m_functionsNames << i18n("Characteristic values b_n(q) of the Mathieu functions se_n(q,x)");
+	m_functionsNames << i18n("Angular Mathieu functions ce_n(q,x)");
+	m_functionsNames << i18n("Angular Mathieu functions se_n(q,x)");
+	m_functionsNames << i18n("Radial j-th kind Mathieu functions Mc_n^{(j)}(q,x)");
+	m_functionsNames << i18n("Radial j-th kind Mathieu functions Ms_n^{(j)}(q,x)");
+
+	index++;
+	for (int i = 0; i < 6; i++)
+		m_functionsGroupIndex << index;
+#endif
+
 	// Power Function
 	m_functionsNames << i18n("x^n for integer n with an error estimate");
 	index++;
@@ -561,6 +571,33 @@ void ExpressionParser::initFunctions() {
 	for (int i = 0; i < 7; i++)
 		m_functionsGroupIndex << index;
 
+	index++;	// separator
+
+	// GSL Random Number Generators: see https://www.gnu.org/software/gsl/doc/html/randist.html
+	m_functionsNames << i18n("Gaussian random numbers");
+	m_functionsNames << i18n("Exponential random numbers");
+	m_functionsNames << i18n("Laplacian random numbers");
+	m_functionsNames << i18n("Cauchy/Lorentz random numbers");
+	m_functionsNames << i18n("Rayleigh random numbers");
+	m_functionsNames << i18n("Landau random numbers");
+	m_functionsNames << i18n("Levy alpha-stable random numbers");
+	m_functionsNames << i18n("Gamma random numbers");
+	m_functionsNames << i18n("Flat random numbers");
+	m_functionsNames << i18n("Lognormal random numbers");
+
+	m_functionsNames << i18n("Chi-squared random numbers");
+	m_functionsNames << i18n("t-distributed random numbers");
+	m_functionsNames << i18n("Logistic random numbers");
+	m_functionsNames << i18n("Poisson random numbers");
+	m_functionsNames << i18n("Bernoulli random numbers");
+	m_functionsNames << i18n("Binomial random numbers");
+
+	index++;
+	for (int i = 0; i < 16; i++)
+		m_functionsGroupIndex << index;
+
+	index++;	// separator
+
 	// GSL Random Number Distributions: see https://www.gnu.org/software/gsl/doc/html/randist.html
 	// Gaussian Distribution
 	m_functionsNames << i18n("Probability density for a Gaussian distribution");
@@ -1282,62 +1319,62 @@ int ExpressionParser::functionArgumentCount(const QString& functionName) {
 QString ExpressionParser::functionArgumentString(const QString& functionName, const XYEquationCurve::EquationType type) {
 	switch (functionArgumentCount(functionName)) {
 	case 0:
-		return QString("()");
+		return {"()"};
 	case 1:
 		switch(type) {
 		case XYEquationCurve::EquationType::Cartesian:
-			return QString("(x)");
+			return {"(x)"};
 		case XYEquationCurve::EquationType::Polar:
-			return QString("(phi)");
+			return {"(phi)"};
 		case XYEquationCurve::EquationType::Parametric:
-			return QString("(t)");
+			return {"(t)"};
 		case XYEquationCurve::EquationType::Implicit:
 		case XYEquationCurve::EquationType::Neutral:
-			return QString("(x)");
+			return {"(x)"};
 		}
 		break;
 	case 2:
 		switch(type) {
 		case XYEquationCurve::EquationType::Cartesian:
-			return QString("(x, y)");
+			return {"(x, y)"};
 		case XYEquationCurve::EquationType::Polar:
-			return QString("(phi, theta)");
+			return {"(phi, theta)"};
 		case XYEquationCurve::EquationType::Parametric:
-			return QString("(u, v)");
+			return {"(u, v)"};
 		case XYEquationCurve::EquationType::Implicit:
 		case XYEquationCurve::EquationType::Neutral:
-			return QString("(x, y)");
+			return {"(x, y)"};
 		}
 		break;
 	case 3:
 		switch(type) {
 		case XYEquationCurve::EquationType::Cartesian:
-			return QString("(x, y, z)");
+			return {"(x, y, z)"};
 		case XYEquationCurve::EquationType::Polar:
-			return QString("(alpha, beta, gamma)");
+			return {"(alpha, beta, gamma)"};
 		case XYEquationCurve::EquationType::Parametric:
-			return QString("(u, v, w)");
+			return {"(u, v, w)"};
 		case XYEquationCurve::EquationType::Implicit:
 		case XYEquationCurve::EquationType::Neutral:
-			return QString("(x, y, z)");
+			return {"(x, y, z)"};
 		}
 		break;
 	case 4:
 		switch(type) {
 		case XYEquationCurve::EquationType::Cartesian:
-			return QString("(a, b, c, d)");
+			return {"(a, b, c, d)"};
 		case XYEquationCurve::EquationType::Polar:
-			return QString("(alpha, beta, gamma, delta)");
+			return {"(alpha, beta, gamma, delta)"};
 		case XYEquationCurve::EquationType::Parametric:
-			return QString("(a, b, c, d)");
+			return {"(a, b, c, d)"};
 		case XYEquationCurve::EquationType::Implicit:
 		case XYEquationCurve::EquationType::Neutral:
-			return QString("(a, b, c, d)");
+			return {"(a, b, c, d)"};
 		}
 		break;
 	}
 
-	return QString("(...)");
+	return {"(...)"};
 }
 
 const QStringList& ExpressionParser::constants() {
@@ -1372,8 +1409,18 @@ bool ExpressionParser::isValid(const QString& expr, const QStringList& vars) {
 		assign_symbol(qPrintable(var), 0);
 
 	SET_NUMBER_LOCALE
+	DEBUG(Q_FUNC_INFO << ", number locale: " << STDSTRING(numberLocale.name()))
 	parse(qPrintable(expr), qPrintable(numberLocale.name()));
 
+	// if parsing with number locale fails, try default locale
+	if (parse_errors() > 0) {
+		DEBUG(Q_FUNC_INFO << ", WARNING: failed parsing expr \"" << STDSTRING(expr)
+			<< "\" with locale " << numberLocale.name().toStdString() << ", errors = "  << parse_errors())
+		parse(qPrintable(expr), "en_US");
+		if (parse_errors() > 0)
+			DEBUG(Q_FUNC_INFO << ", ERROR: parsing FAILED, errors = " << parse_errors())
+	}
+
 	/* remove temporarily defined symbols */
 	for (const auto& var: vars)
 		remove_symbol(qPrintable(var));
@@ -1417,24 +1464,30 @@ QStringList ExpressionParser::getParameter(const QString& expr, const QStringLis
 bool ExpressionParser::evaluateCartesian(const QString& expr, const QString& min, const QString& max,
 		int count, QVector<double>* xVector, QVector<double>* yVector,
 		const QStringList& paramNames, const QVector<double>& paramValues) {
-	DEBUG(Q_FUNC_INFO << ", v1")
+	DEBUG(Q_FUNC_INFO << ", v1: range = " << STDSTRING(min) << " .. " << STDSTRING(max))
 	gsl_set_error_handler_off();
 
 	const Range<double> range{min, max};
 	const double step = range.stepSize(count);
+	DEBUG(Q_FUNC_INFO << ", range = " << range.toStdString() << ", step = " << step)
 
 	for (int i = 0; i < paramNames.size(); ++i)
 		assign_symbol(qPrintable(paramNames.at(i)), paramValues.at(i));
 
 	SET_NUMBER_LOCALE
 	for (int i = 0; i < count; i++) {
-		const double x{ range.min() + step * i };
+		const double x{ range.start() + step * i };
 		assign_symbol("x", x);
 
-		const double y{ parse(qPrintable(expr), qPrintable(numberLocale.name())) };
+		double y = parse(qPrintable(expr), qPrintable(numberLocale.name()));
+		if (parse_errors() > 0)	// try default locale if failing
+			y = parse(qPrintable(expr), "en_US");
 		if (parse_errors() > 0)
 			return false;
 
+		if (std::isnan(y))
+			WARN(Q_FUNC_INFO << ", WARNING: expression " << STDSTRING(expr) << " evaluated @ " << x << " is NAN")
+
 		(*xVector)[i] = x;
 		(*yVector)[i] = y;
 	}
@@ -1452,13 +1505,20 @@ bool ExpressionParser::evaluateCartesian(const QString& expr, const QString& min
 
 	SET_NUMBER_LOCALE
 	for (int i = 0; i < count; i++) {
-		const double x{ range.min() + step * i };
+		const double x{ range.start() + step * i };
 		assign_symbol("x", x);
 
-		const double y{ parse(qPrintable(expr), qPrintable(numberLocale.name())) };
+		double y = parse(qPrintable(expr), qPrintable(numberLocale.name()));
+		if (parse_errors() > 0)	{ // try default locale if failing
+			y = parse(qPrintable(expr), "en_US");
+			//DEBUG(Q_FUNC_INFO << ", WARNING: PARSER failed, trying default locale: y = " << y)
+		}
 		if (parse_errors() > 0)
 			return false;
 
+		if (std::isnan(y))
+			WARN(Q_FUNC_INFO << ", WARNING: expression " << STDSTRING(expr) << " evaluated @ " << x << " is NAN")
+
 		(*xVector)[i] = x;
 		(*yVector)[i] = y;
 	}
@@ -1473,12 +1533,16 @@ bool ExpressionParser::evaluateCartesian(const QString& expr, QVector<double>* x
 	SET_NUMBER_LOCALE
 	for (int i = 0; i < xVector->count(); i++) {
 		assign_symbol("x", xVector->at(i));
-		const double y = parse(qPrintable(expr), qPrintable(numberLocale.name()));
-
+		double y = parse(qPrintable(expr), qPrintable(numberLocale.name()));
+		if (parse_errors() > 0)	// try default locale if failing
+			y = parse(qPrintable(expr), "en_US");
 		if (parse_errors() > 0)
 			return false;
 
-		(*yVector)[i] = y;
+		if (std::isnan(y))
+			WARN(Q_FUNC_INFO << ", WARNING: expression " << STDSTRING(expr) << " evaluated @ " << xVector->at(i) << " is NAN")
+ 
+ 		(*yVector)[i] = y;
 	}
 
 	return true;
@@ -1496,10 +1560,15 @@ bool ExpressionParser::evaluateCartesian(const QString& expr, QVector<double>* x
 	for (int i = 0; i < xVector->count(); i++) {
 		assign_symbol("x", xVector->at(i));
 
-		const double y = parse(qPrintable(expr), qPrintable(numberLocale.name()));
+		double y = parse(qPrintable(expr), qPrintable(numberLocale.name()));
+		if (parse_errors() > 0)	// try default locale if failing
+			y = parse(qPrintable(expr), "en_US");
 		if (parse_errors() > 0)
 			return false;
 
+		if (std::isnan(y))
+			WARN(Q_FUNC_INFO << ", WARNING: expression " << STDSTRING(expr) << " evaluated @ " << xVector->at(i) << " is NAN")
+
 		(*yVector)[i] = y;
 	}
 
@@ -1517,7 +1586,7 @@ bool ExpressionParser::evaluateCartesian(const QString& expr, const QStringList&
 	gsl_set_error_handler_off();
 
 	//determine the minimal size of involved vectors
-	double minSize = INFINITY;
+	int minSize{std::numeric_limits<int>::max()};
 	for (auto* xVector : xVectors) {
 		if (xVector->size() < minSize)
 			minSize = xVector->size();
@@ -1531,16 +1600,21 @@ bool ExpressionParser::evaluateCartesian(const QString& expr, const QStringList&
 		for (int n = 0; n < vars.size(); ++n)
 			assign_symbol(qPrintable(vars.at(n)), xVectors.at(n)->at(i));
 
-		const double y = parse(qPrintable(expr), qPrintable(numberLocale.name()));
+		double y = parse(qPrintable(expr), qPrintable(numberLocale.name()));
+		if (parse_errors() > 0)	// try default locale if failing
+			y = parse(qPrintable(expr), "en_US");
 		if (parse_errors() > 0)
 			return false;
 
+		if (std::isnan(y))
+			WARN(Q_FUNC_INFO << ", WARNING: expression " << STDSTRING(expr) << " evaluated to NAN")
+
 		(*yVector)[i] = y;
 	}
 
-	//if the y-vector is longer than the x-vector(s), set all exceeding elements to NAN
+	//if the y-vector is longer than the x-vector(s), set all exceeding elements to NaN
 	for (int i = minSize; i < yVector->size(); ++i)
-		(*yVector)[i] = NAN;
+		(*yVector)[i] = std::numeric_limits<double>::quiet_NaN();
 
 	return true;
 }
@@ -1554,13 +1628,18 @@ bool ExpressionParser::evaluatePolar(const QString& expr, const QString& min, co
 
 	SET_NUMBER_LOCALE
 	for (int i = 0; i < count; i++) {
-		const double phi = range.min() + step * i;
+		const double phi = range.start() + step * i;
 		assign_symbol("phi", phi);
 
-		const double r = parse(qPrintable(expr), qPrintable(numberLocale.name()));
+		double r = parse(qPrintable(expr), qPrintable(numberLocale.name()));
+		if (parse_errors() > 0)	// try default locale if failing
+			r = parse(qPrintable(expr), "en_US");
 		if (parse_errors() > 0)
 			return false;
 
+		if (std::isnan(r))
+			WARN(Q_FUNC_INFO << ", WARNING: expression " << STDSTRING(expr) << " evaluated @ " << phi << " is NAN")
+
 		(*xVector)[i] = r*cos(phi);
 		(*yVector)[i] = r*sin(phi);
 	}
@@ -1577,16 +1656,25 @@ bool ExpressionParser::evaluateParametric(const QString& xexpr, const QString& y
 
 	SET_NUMBER_LOCALE
 	for (int i = 0; i < count; i++) {
-		assign_symbol("t", range.min() + step * i);
+		assign_symbol("t", range.start() + step * i);
 
-		const double x = parse(qPrintable(xexpr), qPrintable(numberLocale.name()));
+		double x = parse(qPrintable(xexpr), qPrintable(numberLocale.name()));
+		if (parse_errors() > 0)	// try default locale if failing
+			x = parse(qPrintable(xexpr), "en_US");
 		if (parse_errors() > 0)
 			return false;
 
-		const double y = parse(qPrintable(yexpr), qPrintable(numberLocale.name()));
+		double y = parse(qPrintable(yexpr), qPrintable(numberLocale.name()));
+		if (parse_errors() > 0)	// try default locale if failing
+			y = parse(qPrintable(yexpr), "en_US");
 		if (parse_errors() > 0)
 			return false;
 
+		if (std::isnan(x))
+			WARN(Q_FUNC_INFO << ", WARNING: X expression " << STDSTRING(xexpr) << " evaluated @ " << range.start() + step * i << " is NAN")
+		if (std::isnan(y))
+			WARN(Q_FUNC_INFO << ", WARNING: Y expression " << STDSTRING(yexpr) << " evaluated @ " << range.start() + step * i << " is NAN")
+
 		(*xVector)[i] = x;
 		(*yVector)[i] = y;
 	}
