@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : functions.h
     Project              : LabPlot
     Description          : definition of functions
     --------------------------------------------------------------------
-    Copyright            : (C) 2014 by Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2014-2018 by Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2014 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2014-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #ifndef FUNCTIONS_H
 #define FUNCTIONS_H
@@ -234,11 +216,14 @@ struct funs _functions[] = {
 	{"Cn", (func_t)nsl_sf_gegenpoly_n, 3},
 #if (GSL_MAJOR_VERSION > 2) || (GSL_MAJOR_VERSION == 2) && (GSL_MINOR_VERSION >= 4)
 	/* Hermite polynomials and functions */
+	{"Hn", (func_t)nsl_sf_hermite, 2},
 	{"Hen", (func_t)nsl_sf_hermite_prob, 2},
-	{"Hn", (func_t)nsl_sf_hermite_phys, 2},
 	{"Hfn", (func_t)nsl_sf_hermite_func, 2},
-	{"Hend", (func_t)nsl_sf_hermite_prob_der, 3},
-	{"Hnd", (func_t)nsl_sf_hermite_phys_der, 3},
+#if (GSL_MAJOR_VERSION > 2) || (GSL_MAJOR_VERSION == 2) && (GSL_MINOR_VERSION >= 6)
+	{"Hfnf", (func_t)nsl_sf_hermite_func_fast, 2},
+#endif
+	{"Hnd", (func_t)nsl_sf_hermite_deriv, 3},
+	{"Hend", (func_t)nsl_sf_hermite_prob_deriv, 3},
 	{"Hfnd", (func_t)nsl_sf_hermite_func_der, 3},
 #endif
 	/* Hypergeometric Functions */
@@ -256,6 +241,7 @@ struct funs _functions[] = {
 	{"L1", (func_t)gsl_sf_laguerre_1, 2},
 	{"L2", (func_t)gsl_sf_laguerre_2, 2},
 	{"L3", (func_t)gsl_sf_laguerre_3, 2},
+	{"Ln", (func_t)nsl_sf_laguerre_n, 3},
 	/* Lambert W Functions */
 	{"W0", (func_t)gsl_sf_lambert_W0, 1},
 	{"Wm1", (func_t)gsl_sf_lambert_Wm1, 1},
@@ -283,6 +269,15 @@ struct funs _functions[] = {
 	{"logabs", (func_t)gsl_sf_log_abs, 1},
 	{"logp", (func_t)gsl_sf_log_1plusx, 1},
 	{"logpm", (func_t)gsl_sf_log_1plusx_mx, 1},
+	/* Mathieu Functions */
+#if (GSL_MAJOR_VERSION >= 2)
+	{"an", (func_t)nsl_sf_mathieu_a, 2},
+	{"bn", (func_t)nsl_sf_mathieu_b, 2},
+	{"ce", (func_t)nsl_sf_mathieu_ce, 3},
+	{"se", (func_t)nsl_sf_mathieu_se, 3},
+	{"Mc", (func_t)nsl_sf_mathieu_Mc, 4},
+	{"Ms", (func_t)nsl_sf_mathieu_Ms, 4},
+#endif
 	/* Power Function */
 	{"gsl_powint", (func_t)nsl_sf_powint, 2},
 	/* Psi (Digamma) Function */
@@ -342,6 +337,24 @@ struct funs _functions[] = {
 	{"etaint", (func_t)nsl_sf_etaint, 1},
 	{"eta", (func_t)gsl_sf_eta, 1},
 
+	/* GSL Random Number Generators: see https://www.gnu.org/software/gsl/doc/html/randist.html */
+	{"randgaussian", (func_t)nsl_sf_ran_gaussian, 1},
+	{"randexponential", (func_t)nsl_sf_ran_exponential, 1},
+	{"randlaplace", (func_t)nsl_sf_ran_laplace, 1},
+	{"randcauchy", (func_t)nsl_sf_ran_cauchy, 1},
+	{"randrayleigh", (func_t)nsl_sf_ran_rayleigh, 1},
+	{"randlandau", (func_t)nsl_sf_ran_landau, 0},
+	{"randlevy", (func_t)nsl_sf_ran_levy, 2},
+	{"randgamma", (func_t)nsl_sf_ran_gamma, 2},
+	{"randflat", (func_t)nsl_sf_ran_flat, 2},
+	{"randlognormal", (func_t)nsl_sf_ran_lognormal, 2},
+	{"randchisq", (func_t)nsl_sf_ran_chisq, 1},
+	{"randtdist", (func_t)nsl_sf_ran_tdist, 1},
+	{"randlogistic", (func_t)nsl_sf_ran_logistic, 1},
+	{"randpoisson", (func_t)nsl_sf_ran_poisson, 1},
+	{"randbernoulli", (func_t)nsl_sf_ran_bernoulli, 1},
+	{"randbinomial", (func_t)nsl_sf_ran_binomial, 2},
+
 	/* GSL Random Number Distributions: see https://www.gnu.org/software/gsl/doc/html/randist.html */
 	/* Gaussian Distribution */
 	{"gaussian", (func_t)gsl_ran_gaussian_pdf, 2},
