@@ -1,32 +1,12 @@
-/***************************************************************************
+/*
     File                 : SignallingUndoCommand.cpp
     Project              : SciDAVis / LabPlot
-    --------------------------------------------------------------------
-    Copyright            : (C) 2010 Knut Franke
-    Email (use @ for *)  : Knut.Franke*gmx.net
     Description          : An undo command calling a method/signal/slot on a
-                           QObject on redo/undo.
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    QObject on redo/undo.
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2010 Knut Franke <knut.franke*gmx.de (use @ for *)>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "SignallingUndoCommand.h"
 #include <QMetaObject>
