@@ -1,32 +1,14 @@
-/***************************************************************************
+/*
     File                 : macros.h
     Project              : LabPlot
     Description          : Various preprocessor macros
     --------------------------------------------------------------------
-    Copyright            : (C) 2008 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2013-2015 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2016-2020 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2008 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2013-2015 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2016-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #ifndef MACROS_H
 #define MACROS_H
@@ -40,14 +22,14 @@
 
 // C++ style warning (works on Windows)
 #include <iostream>
-#define WARN(x) std::cout << x << std::endl;
+#include <iomanip>
+#define WARN(x) std::cout << std::dec << std::boolalpha << std::setprecision (15) << x << std::endl;
 
 #ifndef NDEBUG
 #include <QDebug>
 #define QDEBUG(x) qDebug() << x;
 // C++ style debugging (works on Windows)
-#include <iomanip>
-#define DEBUG(x) std::cout << x << std::endl;
+#define DEBUG(x) std::cout << std::dec << std::boolalpha << std::setprecision (15) << x << std::endl;
 #else
 #define QDEBUG(x) {}
 #define DEBUG(x) {}
@@ -63,21 +45,60 @@ constexpr std::add_const_t<T>& qAsConst(T& t) noexcept {
 #define WAIT_CURSOR QApplication::setOverrideCursor(QCursor(Qt::WaitCursor))
 #define RESET_CURSOR QApplication::restoreOverrideCursor()
 
-#define UTF8_QSTRING(str) QString::fromUtf8(str)
+#ifdef HAVE_WINDOWS
 #define STDSTRING(qstr) qstr.toUtf8().constData()
+#else
+#define STDSTRING(qstr) qstr.toStdString()
+#endif
+#define UTF8_QSTRING(str) QString::fromUtf8(str)
 
-#define ENUM_TO_STRING(class, enum, value) \
-    (class::staticMetaObject.enumerator(class::staticMetaObject.indexOfEnumerator(#enum)).valueToKey(static_cast<int>(value)))
+#define CHECK(expr) if ( !(expr) ) { DEBUG(Q_FUNC_INFO << ", FAILING " #expr);  return false; }
+// check if var is in [min, max)
+#define INRANGE(var, min, max) (var >= min && var < max)
+
+// access enums in Q_OBJECT/Q_GADGET classes
+#define ENUM_TO_STRING(class, enum, index) \
+    (class::staticMetaObject.enumerator(class::staticMetaObject.indexOfEnumerator(#enum)).valueToKey(static_cast<int>(index)))
 #define ENUM_COUNT(class, enum) \
 	(class::staticMetaObject.enumerator(class::staticMetaObject.indexOfEnumerator(#enum)).keyCount())
 
 // define number locale from setting (using system locale when QLocale::AnyLanguage)
 #define SET_NUMBER_LOCALE \
 QLocale::Language numberLocaleLanguage = static_cast<QLocale::Language>(KSharedConfig::openConfig()->group("Settings_General").readEntry( QLatin1String("DecimalSeparatorLocale"), static_cast<int>(QLocale::Language::AnyLanguage) )); \
+QLocale::NumberOptions numberOptions = static_cast<QLocale::NumberOptions>(KSharedConfig::openConfig()->group("Settings_General").readEntry( QLatin1String("NumberOptions"), static_cast<int>(QLocale::DefaultNumberOptions) )); \
 QLocale numberLocale(numberLocaleLanguage == QLocale::AnyLanguage ? QLocale() : numberLocaleLanguage); \
-if (numberLocale.language() == QLocale::Language::C) \
-	numberLocale.setNumberOptions(QLocale::DefaultNumberOptions);
+numberLocale.setNumberOptions(numberOptions);
+//if (numberLocale.language() == QLocale::Language::C)
+//	numberLocale.setNumberOptions(QLocale::DefaultNumberOptions);
 
+// "red" warning color in formula inputs, etc.
+#define SET_WARNING_STYLE(elem) \
+{ \
+QPalette p; \
+if (qGray(p.color(QPalette::Base).rgb()) > 160)	/* light */ \
+	elem->setStyleSheet( QLatin1String("background: rgb(255, 200, 200);") ); \
+else	/* dark */ \
+	elem->setStyleSheet( QLatin1String("background: rgb(128, 0, 0);") ); \
+}
+
+#define SET_WARNING_PALETTE \
+{ \
+QPalette p = palette(); \
+if (qGray(p.color(QPalette::Base).rgb()) > 160)	/* light */ \
+	p.setColor(QPalette::Text, QColor(255, 200, 200)); \
+else	/* dark */ \
+	p.setColor(QPalette::Text, QColor(128, 0, 0)); \
+setPalette(p); \
+}
+
+#define SET_WARNING_BACKGROUND(elem) \
+{ \
+QPalette p = palette(); \
+if (qGray(p.color(QPalette::Base).rgb()) > 160)	/* light */ \
+	elem->setBackground(QColor(255, 200, 200)); \
+else	/* dark */ \
+	elem->setBackground(QColor(128, 0, 0)); \
+}
 //////////////////////// LineEdit Access ///////////////////////////////
 #define SET_INT_FROM_LE(var, le) { \
 	bool ok; \
@@ -95,8 +116,25 @@ if (numberLocale.language() == QLocale::Language::C) \
 		var = tmp; \
 }
 
+// including enable recalculate
+#define SET_DOUBLE_FROM_LE_REC(var, le) { \
+	QString str = (le)->text().trimmed(); \
+	if (!str.isEmpty()) { \
+		bool ok; \
+		SET_NUMBER_LOCALE \
+		const double tmp = numberLocale.toDouble(str, &ok); \
+		if (ok) { \
+			var = tmp; \
+			enableRecalculate(); \
+		} \
+	} \
+}
+
 //////////////////////// Accessor ///////////////////////////////
 
+// type: BASIC (by value), CLASS (by reference)
+// D: private var, SHARED: Q_D
+// DECL and IMPL
 #define BASIC_ACCESSOR(type, var, method, Method) \
 	type method() const { return var; }; \
 	void set ## Method(const type value) { var = value; }
@@ -107,23 +145,21 @@ if (numberLocale.language() == QLocale::Language::C) \
 #define BASIC_D_ACCESSOR_DECL(type, method, Method) \
 	type method() const; \
 	void set ## Method(const type value);
+#define CLASS_D_ACCESSOR_DECL(type, method, Method) \
+	type method() const; \
+	void set ## Method(const type & value);
 
-#define BASIC_D_ACCESSOR_IMPL(classname, type, method, Method, var) \
-	void classname::set ## Method(const type value) \
-	{ \
-		d->var = value; \
-	} \
-	type classname::method() const \
-	{ \
-		return d->var; \
-	}
+#define BASIC_D_INDEX_ACCESSOR_DECL(type, method, Method) \
+	type method(int index) const; \
+	void set ## Method(int index, type value);
 
+// replaces CLASS_D_READER_IMPL
 #define BASIC_D_READER_IMPL(classname, type, method, var) \
 	type classname::method() const \
 	{ \
 		return d->var; \
 	}
-
+// replaces CLASS_SHARED_D_READER_IMPL
 #define BASIC_SHARED_D_READER_IMPL(classname, type, method, var) \
 	type classname::method() const \
 	{ \
@@ -131,32 +167,36 @@ if (numberLocale.language() == QLocale::Language::C) \
 		return d->var; \
 	}
 
-#define CLASS_D_ACCESSOR_DECL(type, method, Method) \
-	type method() const; \
-	void set ## Method(const type & value);
+#define BASIC_D_ACCESSOR_IMPL(classname, type, method, Method, var) \
+	void classname::set ## Method(const type value) \
+	{ \
+		d->var = value; \
+	} \
+	BASIC_D_READER_IMPL(classname, type, method, var)
 
 #define CLASS_D_ACCESSOR_IMPL(classname, type, method, Method, var) \
 	void classname::set ## Method(const type & value) \
 	{ \
 		d->var = value; \
 	} \
-	type classname::method() const \
-	{ \
-		return d->var; \
-	}
+	BASIC_D_READER_IMPL(classname, type, method, var)
 
-#define CLASS_D_READER_IMPL(classname, type, method, var) \
-	type classname::method() const \
+#define BASIC_SHARED_D_ACCESSOR_IMPL(classname, type, method, Method, var) \
+	void classname::set ## Method(const type value) \
 	{ \
-		return d->var; \
-	}
+		Q_D(classname); \
+		d->var = value; \
+	} \
+	BASIC_SHARED_D_READER_IMPL(classname, type, method, var)
 
-#define CLASS_SHARED_D_READER_IMPL(classname, type, method, var) \
-	type classname::method() const \
+#define CLASS_SHARED_D_ACCESSOR_IMPL(classname, type, method, Method, var) \
+	void classname::set ## Method(const type & value) \
 	{ \
-		Q_D(const classname); \
-		return d->var; \
-	}
+		Q_D(classname); \
+		d->var = value; \
+	} \
+	BASIC_SHARED_D_READER_IMPL(classname, type, method, var)
+
 
 #define POINTER_D_ACCESSOR_DECL(type, method, Method) \
 	type *method() const; \
@@ -220,6 +260,14 @@ class class_name ## cmd_name ## Cmd: public StandardSetterCmd<class_name::Privat
 		virtual void finalize() override { m_target->finalize_method(); emit m_target->q->field_name##Changed(m_target->*m_field); } \
 };
 
+#define STD_SETTER_CMD_IMPL_F_S_Arguments(class_name, cmd_name, value_type, field_name, finalize_method) \
+class class_name ## cmd_name ## Cmd: public StandardSetterCmd<class_name::Private, value_type> { \
+	public: \
+		class_name ## cmd_name ## Cmd(class_name::Private *target, value_type newValue, const KLocalizedString &description) \
+			: StandardSetterCmd<class_name::Private, value_type>(target, &class_name::Private::field_name, newValue, description) {} \
+		virtual void finalize() override { m_target->finalize_method; emit m_target->q->field_name##Changed(m_target->*m_field); } \
+};
+
 // setter class with finalize() and signal emitting for changing several properties in one single step (embedded in beginMacro/endMacro)
 #define STD_SETTER_CMD_IMPL_M_F_S(class_name, cmd_name, value_type, field_name, finalize_method) \
 class class_name ## cmd_name ## Cmd: public StandardMacroSetterCmd<class_name::Private, value_type> { \
@@ -279,256 +327,276 @@ class class_name ## cmd_name ## Cmd: public StandardSwapMethodSetterCmd<class_na
 		virtual void finalize() { m_target->finalize_method(); } \
 };
 
-
 //////////////////////// XML - serialization/deserialization /////
+//TODO: do we really need all these tabs?
+//TODO: why "do {...} while(0)"?
 
 //QColor
-#define WRITE_QCOLOR(color) 												\
-do { 																		\
-writer->writeAttribute( "color_r", QString::number(color.red()) );			\
-writer->writeAttribute( "color_g", QString::number(color.green()) ); 		\
-writer->writeAttribute( "color_b", QString::number(color.blue()) ); 		\
-} while (0)
+#define WRITE_QCOLOR(color) \
+{ \
+writer->writeAttribute( "color_r", QString::number(color.red()) ); \
+writer->writeAttribute( "color_g", QString::number(color.green()) ); \
+writer->writeAttribute( "color_b", QString::number(color.blue()) ); \
+}
 
-#define READ_QCOLOR(color) 													\
-do {																		\
-str = attribs.value("color_r").toString();									\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("color_r").toString());				\
-else																		\
-	color.setRed( str.toInt() );											\
-																			\
-str = attribs.value("color_g").toString();									\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("color_g").toString());				\
-else																		\
-	color.setGreen( str.toInt() );											\
-																			\
-str = attribs.value("color_b").toString();									\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("color_b").toString());				\
-else																		\
-	color.setBlue( str.toInt() );											\
-} while(0)
+#define WRITE_QCOLOR2(color, label) \
+{ \
+writer->writeAttribute( label"_r", QString::number(color.red()) ); \
+writer->writeAttribute( label"_g", QString::number(color.green()) ); \
+writer->writeAttribute( label"_b", QString::number(color.blue()) ); \
+}
 
+#define READ_QCOLOR(color) \
+{ \
+str = attribs.value("color_r").toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("color_r").toString()); \
+else \
+	color.setRed( str.toInt() ); \
+\
+str = attribs.value("color_g").toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("color_g").toString()); \
+else \
+	color.setGreen( str.toInt() ); \
+\
+str = attribs.value("color_b").toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("color_b").toString()); \
+else \
+	color.setBlue( str.toInt() ); \
+}
+
+#define READ_QCOLOR2(color, label) \
+{ \
+str = attribs.value(label"_r").toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs(label"_r").toString()); \
+else \
+	color.setRed( str.toInt() ); \
+\
+str = attribs.value(label"_g").toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs(label"_g").toString()); \
+else \
+	color.setGreen( str.toInt() ); \
+\
+str = attribs.value(label"_b").toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs(label"_b").toString()); \
+else \
+	color.setBlue( str.toInt() ); \
+}
 //QPen
-#define WRITE_QPEN(pen) 													\
-do { 																		\
-writer->writeAttribute( "style", QString::number(pen.style()) ); 			\
-writer->writeAttribute( "color_r", QString::number(pen.color().red()) ); 	\
-writer->writeAttribute( "color_g", QString::number(pen.color().green()) ); 	\
-writer->writeAttribute( "color_b", QString::number(pen.color().blue()) ); 	\
-writer->writeAttribute( "width", QString::number(pen.widthF()) ); 			\
-} while (0)
+#define WRITE_QPEN(pen) \
+{ \
+writer->writeAttribute( "style", QString::number(pen.style()) ); \
+writer->writeAttribute( "color_r", QString::number(pen.color().red()) ); \
+writer->writeAttribute( "color_g", QString::number(pen.color().green()) ); \
+writer->writeAttribute( "color_b", QString::number(pen.color().blue()) ); \
+writer->writeAttribute( "width", QString::number(pen.widthF()) ); \
+}
 
-#define READ_QPEN(pen) 														\
-do {																		\
-str = attribs.value("style").toString(); 									\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("style").toString());					\
-else																		\
-	pen.setStyle( (Qt::PenStyle)str.toInt() );								\
-																			\
-QColor color;																\
-str = attribs.value("color_r").toString();									\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("color_r").toString());				\
-else																		\
-	color.setRed( str.toInt() );											\
-																			\
-str = attribs.value("color_g").toString();									\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("color_g").toString());				\
-else																		\
-	color.setGreen( str.toInt() );											\
-																			\
-str = attribs.value("color_b").toString();									\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("color_b").toString());				\
-else																		\
-	color.setBlue( str.toInt() );											\
-																			\
-pen.setColor(color);														\
-																			\
-str = attribs.value("width").toString();									\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("width").toString());					\
-else																		\
-	pen.setWidthF( str.toDouble() );										\
-} while(0)
+#define READ_QPEN(pen) \
+{ \
+str = attribs.value("style").toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("style").toString()); \
+else \
+	pen.setStyle( static_cast<Qt::PenStyle>(str.toInt()) );	\
+\
+QColor color; \
+str = attribs.value("color_r").toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("color_r").toString()); \
+else \
+	color.setRed( str.toInt() ); \
+\
+str = attribs.value("color_g").toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("color_g").toString()); \
+else \
+	color.setGreen( str.toInt() ); \
+\
+str = attribs.value("color_b").toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("color_b").toString()); \
+else \
+	color.setBlue( str.toInt() ); \
+\
+pen.setColor(color); \
+\
+str = attribs.value("width").toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("width").toString()); \
+else \
+	pen.setWidthF( str.toDouble() ); \
+}
 
 //QFont
-#define WRITE_QFONT(font) 													\
-do {																		\
-writer->writeAttribute( "fontFamily", font.family() );						\
-writer->writeAttribute( "fontSize", QString::number(font.pixelSize()) );	\
-writer->writeAttribute( "fontPointSize", QString::number(font.pointSize()));\
-writer->writeAttribute( "fontWeight", QString::number(font.weight()) );		\
-writer->writeAttribute( "fontItalic", QString::number(font.italic()) );		\
-} while(0)
+#define WRITE_QFONT(font) \
+{ \
+writer->writeAttribute( "fontFamily", font.family() ); \
+writer->writeAttribute( "fontSize", QString::number(font.pixelSize()) ); \
+writer->writeAttribute( "fontPointSize", QString::number(font.pointSize())); \
+writer->writeAttribute( "fontWeight", QString::number(font.weight()) );	\
+writer->writeAttribute( "fontItalic", QString::number(font.italic()) );	\
+}
 
-#define READ_QFONT(font) 													\
-do {																		\
-str = attribs.value("fontFamily").toString();								\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("fontFamily").toString());				\
-else																		\
-	font.setFamily( str );													\
-																			\
-str = attribs.value("fontSize").toString();									\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("fontSize").toString());				\
-else {																		\
-	int size = str.toInt();													\
-	if (size != -1)															\
-		font.setPixelSize(size);											\
-}																			\
-																			\
-str = attribs.value("fontPointSize").toString();							\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("fontPointSize").toString());			\
-else {																		\
-	int size = str.toInt();													\
-	if (size != -1)															\
-		font.setPointSize(size);											\
-}																			\
-																			\
-str = attribs.value("fontWeight").toString();								\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("fontWeight").toString());				\
-else																		\
-	font.setWeight( str.toInt() );											\
-																			\
-str = attribs.value("fontItalic").toString();								\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("fontItalic").toString());				\
-else																		\
-	font.setItalic( str.toInt() );											\
-} while(0)
+#define READ_QFONT(font) \
+{ \
+str = attribs.value("fontFamily").toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("fontFamily").toString()); \
+else \
+	font.setFamily( str ); \
+\
+str = attribs.value("fontSize").toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("fontSize").toString()); \
+else { \
+	int size = str.toInt();	\
+	if (size != -1) \
+		font.setPixelSize(size); \
+} \
+\
+str = attribs.value("fontPointSize").toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("fontPointSize").toString()); \
+else { \
+	int size = str.toInt();	\
+	if (size != -1) \
+		font.setPointSize(size); \
+} \
+\
+str = attribs.value("fontWeight").toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("fontWeight").toString()); \
+else \
+	font.setWeight( str.toInt() ); \
+\
+str = attribs.value("fontItalic").toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("fontItalic").toString()); \
+else \
+	font.setItalic( str.toInt() ); \
+}
 
 //QBrush
-#define WRITE_QBRUSH(brush) 													\
-do {																			\
-writer->writeAttribute("brush_style", QString::number(brush.style()) );			\
-writer->writeAttribute("brush_color_r", QString::number(brush.color().red()));	\
-writer->writeAttribute("brush_color_g", QString::number(brush.color().green()));\
-writer->writeAttribute("brush_color_b", QString::number(brush.color().blue()));	\
-} while(0)
-
-#define READ_QBRUSH(brush) 													\
-do {																		\
-str = attribs.value("brush_style").toString();								\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("brush_style").toString());			\
-else																		\
-	brush.setStyle( (Qt::BrushStyle)str.toInt() );							\
-																			\
-QColor color;																\
-str = attribs.value("brush_color_r").toString();							\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("brush_color_r").toString());			\
-else																		\
-	color.setRed( str.toInt() );											\
-																			\
-str = attribs.value("brush_color_g").toString();							\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("brush_color_g").toString());			\
-else																		\
-	color.setGreen( str.toInt() );											\
-																			\
-str = attribs.value("brush_color_b").toString();							\
-if(str.isEmpty())															\
-	reader->raiseWarning(attributeWarning.subs("brush_color_b").toString());			\
-else																		\
-	color.setBlue( str.toInt() );											\
-																			\
-brush.setColor(color);														\
-} while(0)
-
+#define WRITE_QBRUSH(brush) \
+{ \
+writer->writeAttribute("brush_style", QString::number(brush.style()) ); \
+writer->writeAttribute("brush_color_r", QString::number(brush.color().red())); \
+writer->writeAttribute("brush_color_g", QString::number(brush.color().green())); \
+writer->writeAttribute("brush_color_b", QString::number(brush.color().blue())); \
+}
 
+#define READ_QBRUSH(brush) \
+{ \
+str = attribs.value("brush_style").toString(); \
+if(str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("brush_style").toString()); \
+else \
+	brush.setStyle( static_cast<Qt::BrushStyle>(str.toInt()) ); \
+\
+QColor color; \
+str = attribs.value("brush_color_r").toString(); \
+if(str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("brush_color_r").toString()); \
+else \
+	color.setRed( str.toInt() ); \
+\
+str = attribs.value("brush_color_g").toString(); \
+if(str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("brush_color_g").toString()); \
+else \
+	color.setGreen( str.toInt() ); \
+\
+str = attribs.value("brush_color_b").toString(); \
+if(str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.subs("brush_color_b").toString()); \
+else \
+	color.setBlue( str.toInt() ); \
+\
+brush.setColor(color); \
+}
 
 //Column
-#define WRITE_COLUMN(column, columnName) 											\
-do {																				\
-if (column){																		\
-	writer->writeAttribute( #columnName, column->path() );							\
-} else {																			\
-	writer->writeAttribute( #columnName, QString() );										\
-}																					\
-} while(0)
+#define WRITE_COLUMN(column, columnName) \
+if (column) { \
+	writer->writeAttribute( #columnName, column->path() ); \
+} else { \
+	writer->writeAttribute( #columnName, QString() ); \
+}
 
 //column names can be empty in case no columns were used before save
 //the actual pointers to the x- and y-columns are restored in Project::load()
-#define READ_COLUMN(columnName)														\
-do {																				\
-	str = attribs.value(#columnName).toString();									\
-	d->columnName ##Path = str;														\
-} while(0)
+#define READ_COLUMN(columnName)	\
+{ \
+	str = attribs.value(#columnName).toString(); \
+	d->columnName ##Path = str; \
+}
 
-#define READ_INT_VALUE(name, var, type) \
+#define READ_INT_VALUE_DIRECT(name, var, type) \
+{ \
 str = attribs.value(name).toString(); \
 if (str.isEmpty()) \
 	reader->raiseWarning(attributeWarning.subs(name).toString()); \
 else \
-	d->var = (type)str.toInt();
+	var = static_cast<type>(str.toInt()); \
+}
+
+#define READ_INT_VALUE(name, var, type) READ_INT_VALUE_DIRECT(name, d->var, type)
 
 #define READ_DOUBLE_VALUE(name, var) \
+{ \
 str = attribs.value(name).toString(); \
 if (str.isEmpty()) \
 	reader->raiseWarning(attributeWarning.subs(name).toString()); \
 else \
-	d->var = str.toDouble();
+	d->var = str.toDouble(); \
+}
 
 #define READ_STRING_VALUE(name, var) \
-str = attribs.value(name).toString(); \
-if (str.isEmpty()) \
-	reader->raiseWarning(attributeWarning.subs(name).toString()); \
-else \
-	d->var = str;
+{ \
+d->var = attribs.value(name).toString(); \
+}
 
 //used in Project::load()
-#define RESTORE_COLUMN_POINTER(obj, col, Col) 										\
-do {																				\
-if (!obj->col ##Path().isEmpty()) {													\
-	for (Column* column : columns) {												\
-		if (!column) continue;														\
-		if (column->path() == obj->col ##Path()) {									\
- 			obj->set## Col(column);													\
-			break;				 													\
-		}																			\
-	}																				\
-}																					\
-} while(0)
+#define RESTORE_COLUMN_POINTER(obj, col, Col) \
+if (!obj->col ##Path().isEmpty()) { \
+	for (Column* column : columns) { \
+		if (!column) continue; \
+		if (column->path() == obj->col ##Path()) { \
+			obj->set## Col(column);	\
+			break; \
+		} \
+	} \
+}
 
+#define WRITE_PATH(obj, name) \
+if (obj) { \
+	writer->writeAttribute( #name, obj->path() ); \
+} else { \
+	writer->writeAttribute( #name, QString() ); \
+}
 
+#define READ_PATH(name)	\
+{ \
+	str = attribs.value(#name).toString(); \
+	d->name ##Path = str; \
+}
 
-#define WRITE_PATH(obj, name) 														\
-do {																				\
-if (obj){																			\
-	writer->writeAttribute( #name, obj->path() );									\
-} else {																			\
-	writer->writeAttribute( #name, QString() );											\
-}																					\
-} while(0)
-
-#define READ_PATH(name)																\
-do {																				\
-	str = attribs.value(#name).toString();											\
-	d->name ##Path = str;															\
-} while(0)
-
-#define RESTORE_POINTER(obj, name, Name, Type, list) 								\
-do {																				\
-if (!obj->name ##Path().isEmpty()) {												\
-	for (AbstractAspect* aspect : list) {											\
-		if (aspect->path() == obj->name ##Path()) {									\
-			auto a = dynamic_cast<Type*>(aspect);									\
-			if (!a) continue;														\
- 			obj->set## Name(a);														\
-			break;				 													\
-		}																			\
-	}																				\
-}																					\
-} while(0)
+#define RESTORE_POINTER(obj, name, Name, Type, list) \
+if (!obj->name ##Path().isEmpty()) { \
+	for (AbstractAspect* aspect : list) { \
+		if (aspect->path() == obj->name ##Path()) { \
+			auto a = dynamic_cast<Type*>(aspect); \
+			if (!a) continue; \
+			obj->set## Name(a); \
+			break; \
+		} \
+	} \
+}
 
 #endif // MACROS_H
