@@ -1,33 +1,14 @@
-
-/***************************************************************************
+/*
     File                 : Matrix.cpp
     Project              : Matrix
     Description          : Spreadsheet with a MxN matrix data model
     --------------------------------------------------------------------
-    Copyright            : (C) 2008-2009 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2015-2017 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2017-2020 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2008-2009 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2015-2017 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2017-2020 Stefan Gerlach <stefan.gerlach@uni.kn>
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "Matrix.h"
 #include "MatrixPrivate.h"
@@ -113,7 +94,7 @@ QIcon Matrix::icon() const {
 */
 QMenu* Matrix::createContextMenu() {
 	QMenu* menu = AbstractPart::createContextMenu();
-	emit requestProjectContextMenu(menu);
+	Q_EMIT requestProjectContextMenu(menu);
 	return menu;
 }
 
@@ -160,7 +141,7 @@ bool Matrix::exportView() const {
 			m_view->exportToFile(path, separator, format);
 		}
 		RESET_CURSOR;
-    	}
+	}
 	delete dlg;
 
 	return ret;
@@ -202,7 +183,7 @@ BASIC_D_READER_IMPL(Matrix, double, yEnd, yEnd)
 BASIC_D_READER_IMPL(Matrix, char, numericFormat, numericFormat)
 BASIC_D_READER_IMPL(Matrix, int, precision, precision)
 BASIC_D_READER_IMPL(Matrix, Matrix::HeaderFormat, headerFormat, headerFormat)
-CLASS_D_READER_IMPL(Matrix, QString, formula, formula)
+BASIC_D_READER_IMPL(Matrix, QString, formula, formula)
 
 void Matrix::setSuppressDataChangedSignal(bool b) {
 	if (m_model)
@@ -283,7 +264,7 @@ void Matrix::setHeaderFormat(Matrix::HeaderFormat format) {
 	if (m_view)
 		m_view->resizeHeaders();
 
-	emit headerFormatChanged(format);
+	Q_EMIT headerFormatChanged(format);
 }
 
 //columns
@@ -302,7 +283,7 @@ void Matrix::removeColumns(int first, int count) {
 	if (count < 1 || first < 0 || first+count > columnCount()) return;
 	WAIT_CURSOR;
 	switch (d->mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		exec(new MatrixRemoveColumnsCmd<double>(d, first, count));
 		break;
 	case AbstractColumn::ColumnMode::Text:
@@ -326,7 +307,7 @@ void Matrix::removeColumns(int first, int count) {
 void Matrix::clearColumn(int c) {
 	WAIT_CURSOR;
 	switch (d->mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		exec(new MatrixClearColumnCmd<double>(d, c));
 		break;
 	case AbstractColumn::ColumnMode::Text:
@@ -363,7 +344,7 @@ void Matrix::removeRows(int first, int count) {
 	if (count < 1 || first < 0 || first+count > rowCount()) return;
 	WAIT_CURSOR;
 	switch (d->mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		exec(new MatrixRemoveRowsCmd<double>(d, first, count));
 		break;
 	case AbstractColumn::ColumnMode::Text:
@@ -386,7 +367,7 @@ void Matrix::removeRows(int first, int count) {
 
 void Matrix::clearRow(int r) {
 	switch (d->mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		for (int c = 0; c < columnCount(); ++c)
 			exec(new MatrixSetCellValueCmd<double>(d, r, c, 0.0));
 		break;
@@ -456,7 +437,7 @@ template void Matrix::setCell<QDateTime>(int row, int col, QDateTime value);
 
 void Matrix::clearCell(int row, int col) {
 	switch (d->mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		exec(new MatrixSetCellValueCmd<double>(d, row, col, 0.0));
 		break;
 	case AbstractColumn::ColumnMode::Text:
@@ -515,7 +496,7 @@ void Matrix::copy(Matrix* other) {
 
 	d->suppressDataChange = true;
 	switch (d->mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		for (int i = 0; i < columns; i++)
 			setColumnCells(i, 0, rows-1, other->columnCells<double>(i, 0, rows-1));
 		break;
@@ -544,7 +525,7 @@ void Matrix::copy(Matrix* other) {
 	setPrecision(other->precision());
 	d->formula = other->formula();
 	d->suppressDataChange = false;
-	emit dataChanged(0, 0, rows-1, columns-1);
+	Q_EMIT dataChanged(0, 0, rows-1, columns-1);
 	if (m_view)
 		m_view->adjustHeaders();
 
@@ -648,7 +629,7 @@ void Matrix::setData(void* data) {
 	bool isEmpty = false;
 
 	switch (d->mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		if (static_cast<QVector<QVector<double>>*>(data)->isEmpty())
 			isEmpty = true;
 		break;
@@ -676,6 +657,12 @@ void Matrix::setData(void* data) {
 		exec(new MatrixReplaceValuesCmd(d, data));
 }
 
+QVector<AspectType> Matrix::dropableOn() const {
+	auto vec = AbstractPart::dropableOn();
+	vec << AspectType::Workbook;
+	return vec;
+}
+
 //##############################################################################
 //#########################  Public slots  #####################################
 //##############################################################################
@@ -684,7 +671,7 @@ void Matrix::clear() {
 	WAIT_CURSOR;
 	beginMacro(i18n("%1: clear", name()));
 	switch (d->mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		exec(new MatrixClearCmd<double>(d));
 		break;
 	case AbstractColumn::ColumnMode::Text:
@@ -709,7 +696,7 @@ void Matrix::clear() {
 void Matrix::transpose() {
 	WAIT_CURSOR;
 	switch (d->mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		exec(new MatrixTransposeCmd<double>(d));
 		break;
 	case AbstractColumn::ColumnMode::Text:
@@ -733,7 +720,7 @@ void Matrix::transpose() {
 void Matrix::mirrorHorizontally() {
 	WAIT_CURSOR;
 	switch (d->mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		exec(new MatrixMirrorHorizontallyCmd<double>(d));
 		break;
 	case AbstractColumn::ColumnMode::Text:
@@ -757,7 +744,7 @@ void Matrix::mirrorHorizontally() {
 void Matrix::mirrorVertically() {
 	WAIT_CURSOR;
 	switch (d->mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		exec(new MatrixMirrorVerticallyCmd<double>(d));
 		break;
 	case AbstractColumn::ColumnMode::Text:
@@ -786,7 +773,7 @@ MatrixPrivate::MatrixPrivate(Matrix* owner, const AbstractColumn::ColumnMode m)
 		: q(owner), data(nullptr), mode(m), rowCount(0), columnCount(0), suppressDataChange(false) {
 
 	switch (mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		data = new QVector<QVector<double>>();
 		break;
 	case AbstractColumn::ColumnMode::Text:
@@ -809,7 +796,7 @@ MatrixPrivate::MatrixPrivate(Matrix* owner, const AbstractColumn::ColumnMode m)
 MatrixPrivate::~MatrixPrivate() {
 	if (data) {
 		switch (mode) {
-		case AbstractColumn::ColumnMode::Numeric:
+		case AbstractColumn::ColumnMode::Double:
 			delete static_cast<QVector<QVector<double>>*>(data);
 			break;
 		case AbstractColumn::ColumnMode::Text:
@@ -841,9 +828,9 @@ void MatrixPrivate::insertColumns(int before, int count) {
 	Q_ASSERT(before >= 0);
 	Q_ASSERT(before <= columnCount);
 
-	emit q->columnsAboutToBeInserted(before, count);
+	Q_EMIT q->columnsAboutToBeInserted(before, count);
 	switch (mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		for (int i = 0; i < count; i++) {
 			static_cast<QVector<QVector<double>>*>(data)->insert(before+i, QVector<double>(rowCount));
 			columnWidths.insert(before+i, 0);
@@ -878,19 +865,19 @@ void MatrixPrivate::insertColumns(int before, int count) {
 	}
 
 	columnCount += count;
-	emit q->columnsInserted(before, count);
+	Q_EMIT q->columnsInserted(before, count);
 }
 
 /*!
 	Remove \c count columns starting with column index \c first
 */
 void MatrixPrivate::removeColumns(int first, int count) {
-	emit q->columnsAboutToBeRemoved(first, count);
+	Q_EMIT q->columnsAboutToBeRemoved(first, count);
 	Q_ASSERT(first >= 0);
 	Q_ASSERT(first + count <= columnCount);
 
 	switch (mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		(static_cast<QVector<QVector<double>>*>(data))->remove(first, count);
 		break;
 	case AbstractColumn::ColumnMode::Text:
@@ -912,19 +899,19 @@ void MatrixPrivate::removeColumns(int first, int count) {
 	for (int i = 0; i < count; i++)
 		columnWidths.remove(first);
 	columnCount -= count;
-	emit q->columnsRemoved(first, count);
+	Q_EMIT q->columnsRemoved(first, count);
 }
 
 /*!
 	Insert \c count rows before row with the index \c before
 */
 void MatrixPrivate::insertRows(int before, int count) {
-	emit q->rowsAboutToBeInserted(before, count);
+	Q_EMIT q->rowsAboutToBeInserted(before, count);
 	Q_ASSERT(before >= 0);
 	Q_ASSERT(before <= rowCount);
 
 	switch (mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		for (int col = 0; col < columnCount; col++)
 			for (int i = 0; i < count; i++)
 				(static_cast<QVector<QVector<double>>*>(data))->operator[](col).insert(before+i, 0.0);
@@ -956,19 +943,19 @@ void MatrixPrivate::insertRows(int before, int count) {
 		rowHeights.insert(before+i, 0);
 
 	rowCount += count;
-	emit q->rowsInserted(before, count);
+	Q_EMIT q->rowsInserted(before, count);
 }
 
 /*!
 	Remove \c count columns starting from the column with index \c first
 */
 void MatrixPrivate::removeRows(int first, int count) {
-	emit q->rowsAboutToBeRemoved(first, count);
+	Q_EMIT q->rowsAboutToBeRemoved(first, count);
 	Q_ASSERT(first >= 0);
 	Q_ASSERT(first+count <= rowCount);
 
 	switch (mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		for (int col = 0; col < columnCount; col++)
 			(static_cast<QVector<QVector<double>>*>(data))->operator[](col).remove(first, count);
 		break;
@@ -996,13 +983,13 @@ void MatrixPrivate::removeRows(int first, int count) {
 		rowHeights.remove(first);
 
 	rowCount -= count;
-	emit q->rowsRemoved(first, count);
+	Q_EMIT q->rowsRemoved(first, count);
 }
 
 //! Fill column with zeroes
 void MatrixPrivate::clearColumn(int col) {
 	switch (mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		static_cast<QVector<QVector<double>>*>(data)->operator[](col).fill(0.0);
 		break;
 	case AbstractColumn::ColumnMode::Text:
@@ -1022,7 +1009,7 @@ void MatrixPrivate::clearColumn(int col) {
 	}
 
 	if (!suppressDataChange)
-		emit q->dataChanged(0, col, rowCount-1, col);
+		Q_EMIT q->dataChanged(0, col, rowCount-1, col);
 }
 
 //##############################################################################
@@ -1072,9 +1059,9 @@ void Matrix::save(QXmlStreamWriter* writer) const {
 	writer->writeEndElement();
 
 	//columns
-	DEBUG("	mode = " << static_cast<int>(d->mode));
+	DEBUG("	mode = " << static_cast<int>(d->mode))
 	switch (d->mode) {
-	case AbstractColumn::ColumnMode::Numeric:
+	case AbstractColumn::ColumnMode::Double:
 		size = d->rowCount*sizeof(double);
 		for (int i = 0; i < d->columnCount; ++i) {
 			data = reinterpret_cast<const char*>(static_cast<QVector<QVector<double>>*>(d->data)->at(i).constData());
@@ -1128,7 +1115,7 @@ void Matrix::save(QXmlStreamWriter* writer) const {
 }
 
 bool Matrix::load(XmlStreamReader* reader, bool preview) {
-	DEBUG("Matrix::load()");
+	DEBUG("Matrix::load()")
 	if (!readBasicAttributes(reader))
 		return false;
 
@@ -1238,7 +1225,7 @@ bool Matrix::load(XmlStreamReader* reader, bool preview) {
 			QByteArray bytes = QByteArray::fromBase64(content.toLatin1());
 
 			switch (d->mode) {
-			case AbstractColumn::ColumnMode::Numeric: {
+			case AbstractColumn::ColumnMode::Double: {
 				int count = bytes.size()/sizeof(double);
 				QVector<double> column;
 				column.resize(count);
@@ -1298,10 +1285,12 @@ bool Matrix::load(XmlStreamReader* reader, bool preview) {
 //########################  Data Import  #######################################
 //##############################################################################
 int Matrix::prepareImport(std::vector<void*>& dataContainer, AbstractFileFilter::ImportMode mode,
-	int actualRows, int actualCols, QStringList colNameList, QVector<AbstractColumn::ColumnMode> columnMode) {
-	QDEBUG("prepareImport() rows =" << actualRows << " cols =" << actualCols);
+	int actualRows, int actualCols, QStringList /*colNameList*/, QVector<AbstractColumn::ColumnMode> columnMode) {
+	auto newColumnMode = columnMode.at(0);	// only first column mode used
+	DEBUG(Q_FUNC_INFO << ", rows = " << actualRows << " cols = " << actualCols
+	      << ", mode = " << ENUM_TO_STRING(AbstractFileFilter, ImportMode, mode)
+	      << ", column mode = " << ENUM_TO_STRING(AbstractColumn, ColumnMode, newColumnMode))
 	//QDEBUG("	column modes = " << columnMode);
-	Q_UNUSED(colNameList);
 	int columnOffset = 0;
 	setUndoAware(false);
 
@@ -1311,23 +1300,39 @@ int Matrix::prepareImport(std::vector<void*>& dataContainer, AbstractFileFilter:
 	if (mode == AbstractFileFilter::ImportMode::Replace) {
 		clear();
 		setDimensions(actualRows, actualCols);
-	} else {
+	} else {	// Append
+		// handle mismatch of modes
+		DEBUG(Q_FUNC_INFO << ", TODO: matrix mode = " <<  ENUM_TO_STRING(AbstractColumn, ColumnMode, d->mode) << ", columnMode = " << ENUM_TO_STRING(AbstractColumn, ColumnMode, columnMode.at(0)))
+		// TODO: no way to convert types yet!
+		if (d->mode != newColumnMode) {
+			DEBUG(Q_FUNC_INFO << ", WARNING mismatch of types in append mode!")
+		}
+		// catch some cases
+		if ( (d->mode == AbstractColumn::ColumnMode::Integer || d->mode == AbstractColumn::ColumnMode::BigInt)
+			&& newColumnMode == AbstractColumn::ColumnMode::Double)
+			d->mode = newColumnMode;
+
+		columnOffset = columnCount();
+		actualCols += columnOffset;
+		DEBUG(Q_FUNC_INFO << ", col count = " << columnCount() << ", actualCols = " << actualCols)
 		if (rowCount() < actualRows)
 			setDimensions(actualRows, actualCols);
 		else
 			setDimensions(rowCount(), actualCols);
 	}
 
+
+	DEBUG(Q_FUNC_INFO << ", actual rows/cols = " << actualRows << "/" << actualCols)
 	// data() returns a void* which is a pointer to a matrix of any data type (see ColumnPrivate.cpp)
 	dataContainer.resize(actualCols);
-	switch (columnMode[0]) {	// only columnMode[0] is used
-	case AbstractColumn::ColumnMode::Numeric:
+	switch (newColumnMode) {	// prepare all columns
+	case AbstractColumn::ColumnMode::Double:
 		for (int n = 0; n < actualCols; n++) {
 			QVector<double>* vector = &(static_cast<QVector<QVector<double>>*>(data())->operator[](n));
 			vector->resize(actualRows);
 			dataContainer[n] = static_cast<void*>(vector);
 		}
-		d->mode = AbstractColumn::ColumnMode::Numeric;
+		d->mode = AbstractColumn::ColumnMode::Double;
 		break;
 	case AbstractColumn::ColumnMode::Integer:
 		for (int n = 0; n < actualCols; n++) {
@@ -1368,16 +1373,10 @@ int Matrix::prepareImport(std::vector<void*>& dataContainer, AbstractFileFilter:
 	return columnOffset;
 }
 
-void Matrix::finalizeImport(int columnOffset, int startColumn, int endColumn, const QString& dateTimeFormat, AbstractFileFilter::ImportMode importMode)  {
-	DEBUG("Matrix::finalizeImport()");
-	Q_UNUSED(columnOffset);
-	Q_UNUSED(startColumn);
-	Q_UNUSED(endColumn);
-	Q_UNUSED(dateTimeFormat);
-	Q_UNUSED(importMode);
+void Matrix::finalizeImport(size_t /*columnOffset*/, size_t /*startColumn*/, size_t /*endColumn*/, const QString& /*dateTimeFormat*/, AbstractFileFilter::ImportMode)  {
+	DEBUG(Q_FUNC_INFO)
 
 	setSuppressDataChangedSignal(false);
 	setChanged();
 	setUndoAware(true);
-	DEBUG("Matrix::finalizeImport() DONE");
 }
