@@ -1,36 +1,19 @@
-/***************************************************************************
+/*
     File                 : Notes.cpp
     Project              : LabPlot
     Description          : Notes Widget for taking notes
     --------------------------------------------------------------------
-    Copyright            : (C) 2009-2015 Garvit Khatri (garvitdelhi@gmail.com)
-    Copyright            : (C) 2016 Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2009-2015 Garvit Khatri <garvitdelhi@gmail.com>
+    SPDX-FileCopyrightText: 2016 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "Note.h"
 #include "commonfrontend/note/NoteView.h"
 #include "backend/lib/XmlStreamReader.h"
 #include "backend/lib/macros.h"
+#include "backend/core/Project.h"
 
 #include <QPalette>
 #include <QPrinter>
@@ -78,6 +61,7 @@ bool Note::exportView() const {
 
 void Note::setNote(const QString& note) {
 	m_note = note;
+	project()->setChanged(true);
 }
 
 const QString& Note::note() const {
@@ -86,7 +70,7 @@ const QString& Note::note() const {
 
 void Note::setBackgroundColor(const QColor& color) {
 	m_backgroundColor = color;
-	emit backgroundColorChanged(color);
+	Q_EMIT backgroundColorChanged(color);
 }
 
 const QColor& Note::backgroundColor() const {
@@ -95,7 +79,7 @@ const QColor& Note::backgroundColor() const {
 
 void Note::setTextColor(const QColor& color) {
 	m_textColor = color;
-	emit textColorChanged(color);
+	Q_EMIT textColorChanged(color);
 }
 
 const QColor& Note::textColor() const{
@@ -104,7 +88,7 @@ const QColor& Note::textColor() const{
 
 void Note::setTextFont(const QFont& font) {
 	m_textFont = font;
-	emit textFontChanged(font);
+	Q_EMIT textFontChanged(font);
 }
 
 const QFont& Note::textFont() const {
