@@ -1,30 +1,12 @@
-/***************************************************************************
+/*
     File                 : nsl_dft.c
     Project              : LabPlot
     Description          : NSL discrete Fourier transform functions
     --------------------------------------------------------------------
-    Copyright            : (C) 2016 by Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2016 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "nsl_dft.h"
 #include "nsl_common.h"
@@ -61,7 +43,7 @@ int nsl_dft_transform(double data[], size_t stride, size_t n, int two_sided, nsl
 	/* stride ignored */
 	(void)stride;
 
-	fftw_plan plan = fftw_plan_dft_r2c_1d(n, data, (fftw_complex *) result, FFTW_ESTIMATE);
+	fftw_plan plan = fftw_plan_dft_r2c_1d((int)n, data, (fftw_complex *) result, FFTW_ESTIMATE);
 	fftw_execute(plan);
 	fftw_destroy_plan(plan);
 
@@ -119,7 +101,7 @@ int nsl_dft_transform(double data[], size_t stride, size_t n, int two_sided, nsl
 		break;
 	case nsl_dft_result_phase:
 		for (i = 0; i < N; i++)
-			data[i] = -atan2(result[2*i+1],result[2*i]);
+			data[i] = -atan2(result[2*i+1], result[2*i]);
 		break;
 	case nsl_dft_result_dB:
 		for (i = 0; i < N; i++) {
@@ -156,6 +138,12 @@ int nsl_dft_transform(double data[], size_t stride, size_t n, int two_sided, nsl
 		}
 		break;
 	case nsl_dft_result_raw:
+#ifdef HAVE_FFTW3
+		// write gsl_halfcomplex data
+		data[0] = result[0];
+		for (i = 1; i < N; i++)
+			data[i] = result[i+1];
+#endif
 		break;
 	}
 
