@@ -1,30 +1,12 @@
-/***************************************************************************
+/*
     File                 : nsl_sf_basic.c
     Project              : LabPlot
     Description          : NSL special basic functions
     --------------------------------------------------------------------
-    Copyright            : (C) 2018-2020 by Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2018-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "nsl_sf_basic.h"
 #include <stdlib.h>
@@ -66,6 +48,90 @@ double nsl_sf_theta(double x) {
 		return 0;
 }
 
+double nsl_sf_exp10(double x) {
+#ifdef __linux__
+	return exp10(x);
+#else
+	return pow(10., x);
+#endif
+}
+
+
+/* non-uniform random number generation
+ * using a generator chosen by the environment variable GSL_RNG_TYPE
+ */
+#define SETUP_GSL_RNG \
+        gsl_rng_env_setup(); \
+        const gsl_rng_type* T = gsl_rng_default; \
+        gsl_rng* r = gsl_rng_alloc(T); \
+        gsl_rng_set(r, rand());	/*seed*/
+
+double nsl_sf_ran_gaussian(double sigma) {
+	SETUP_GSL_RNG
+	return gsl_ran_gaussian_ziggurat(r, sigma);
+}
+double nsl_sf_ran_exponential(double mu) {
+	SETUP_GSL_RNG
+	return gsl_ran_exponential(r, mu);
+}
+double nsl_sf_ran_laplace(double a) {
+	SETUP_GSL_RNG
+	return gsl_ran_laplace(r, a);
+}
+double nsl_sf_ran_cauchy(double a) {
+	SETUP_GSL_RNG
+	return gsl_ran_cauchy(r, a);
+}
+double nsl_sf_ran_rayleigh(double sigma) {
+	SETUP_GSL_RNG
+	return gsl_ran_rayleigh(r, sigma);
+}
+double nsl_sf_ran_landau(void) {
+	SETUP_GSL_RNG
+	return gsl_ran_landau(r);
+}
+double nsl_sf_ran_levy(double c, double alpha) {
+	SETUP_GSL_RNG
+	return gsl_ran_levy(r, c, alpha);
+}
+double nsl_sf_ran_gamma(double a, double b) {
+	SETUP_GSL_RNG
+	return gsl_ran_gamma(r, a, b);
+}
+double nsl_sf_ran_flat(double a, double b) {
+	SETUP_GSL_RNG
+	return gsl_ran_flat(r, a, b);
+}
+double nsl_sf_ran_lognormal(double zeta, double sigma) {
+	SETUP_GSL_RNG
+	return gsl_ran_lognormal(r, zeta, sigma);
+}
+double nsl_sf_ran_chisq(double nu) {
+	SETUP_GSL_RNG
+	return gsl_ran_chisq(r, nu);
+}
+double nsl_sf_ran_tdist(double nu) {
+	SETUP_GSL_RNG
+	return gsl_ran_tdist(r, nu);
+}
+double nsl_sf_ran_logistic(double a) {
+	SETUP_GSL_RNG
+	return gsl_ran_logistic(r, a);
+}
+
+double nsl_sf_ran_poisson(double mu) {
+	SETUP_GSL_RNG
+	return (double)gsl_ran_poisson(r, mu);
+}
+double nsl_sf_ran_bernoulli(double p) {
+	SETUP_GSL_RNG
+	return (double)gsl_ran_bernoulli(r, p);
+}
+double nsl_sf_ran_binomial(double p, double n) {
+	SETUP_GSL_RNG
+	return (double)gsl_ran_binomial(r, p, (unsigned int)round(n));
+}
+
 /*
  * source: https://stackoverflow.com/questions/11376288/fast-computing-of-log2-for-64-bit-integers
  * source: https://graphics.stanford.edu/~seander/bithacks.html#IntegerLogLookup
@@ -230,8 +296,8 @@ double nsl_sf_voigt(double x, double sigma, double gamma) {
 #elif defined(_MSC_VER)
 	return 0.;	// not supported yet
 #else
-	COMPLEX z = (x + I*gamma)/(sqrt(2.)*sigma);
-	return creal(Faddeeva_w(z, 0))/(M_SQRT2*M_SQRTPI*sigma);
+	COMPLEX z = (x + I*gamma)/(M_SQRT2 * sigma);
+	return creal(Faddeeva_w(z, 0))/(M_SQRT2 * M_SQRTPI * sigma);
 #endif
 }
 
@@ -245,7 +311,7 @@ double nsl_sf_pseudovoigt(double x, double eta, double sigma, double gamma) {
 
 double nsl_sf_pseudovoigt1(double x, double eta, double w) {
 	// 2w - FWHM, sigma_G = w/sqrt(2ln(2))
-	return nsl_sf_pseudovoigt(x, eta, w/sqrt(2.*log(2.)), w);
+	return nsl_sf_pseudovoigt(x, eta, w/sqrt(2. * M_LN2), w);
 }
 
 /* wrapper for GSL functions with integer parameters */
@@ -314,13 +380,21 @@ double nsl_sf_taylorcoeff(double n, double x) { return gsl_sf_taylorcoeff((int)r
 
 double nsl_sf_gegenpoly_n(double n, double l, double x) { return gsl_sf_gegenpoly_n((int)round(n), l, x); }
 
+/* Hermite polynomials and functions since GSL 2.4 */
 #if (GSL_MAJOR_VERSION > 2) || (GSL_MAJOR_VERSION == 2) && (GSL_MINOR_VERSION >= 4)
 double nsl_sf_hermite_prob(double n, double x) { return gsl_sf_hermite_prob((int)round(n), x); }
-double nsl_sf_hermite_phys(double n, double x) { return gsl_sf_hermite_phys((int)round(n), x); }
 double nsl_sf_hermite_func(double n, double x) { return gsl_sf_hermite_func((int)round(n), x); }
-double nsl_sf_hermite_prob_der(double m, double n, double x) { return gsl_sf_hermite_prob_der((int)round(m), (int)round(n), x); }
-double nsl_sf_hermite_phys_der(double m, double n, double x) { return gsl_sf_hermite_phys_der((int)round(m), (int)round(n), x); }
 double nsl_sf_hermite_func_der(double m, double n, double x) { return gsl_sf_hermite_func_der((int)round(m), (int)round(n), x); }
+#if (GSL_MAJOR_VERSION == 2) && (GSL_MINOR_VERSION < 6)
+double nsl_sf_hermite(double n, double x) { return gsl_sf_hermite_phys((int)round(n), x); }
+double nsl_sf_hermite_deriv(double m, double n, double x) { return gsl_sf_hermite_phys_der((int)round(m), (int)round(n), x); }
+double nsl_sf_hermite_prob_deriv(double m, double n, double x) { return gsl_sf_hermite_prob_der((int)round(m), (int)round(n), x); }
+#else	/* renamed and added func_fast in GSL 2.6 */
+double nsl_sf_hermite(double n, double x) { return gsl_sf_hermite((int)round(n), x); }
+double nsl_sf_hermite_deriv(double m, double n, double x) { return gsl_sf_hermite_deriv((int)round(m), (int)round(n), x); }
+double nsl_sf_hermite_prob_deriv(double m, double n, double x) { return gsl_sf_hermite_prob_deriv((int)round(m), (int)round(n), x); }
+double nsl_sf_hermite_func_fast(double n, double x) { return gsl_sf_hermite_func_fast((int)round(n), x); }
+#endif
 #endif
 
 double nsl_sf_hyperg_1F1i(double m, double n, double x) { return gsl_sf_hyperg_1F1_int((int)round(m), (int)round(n), x); }
@@ -335,6 +409,15 @@ double nsl_sf_conicalP_sphreg(double l, double L, double x) { return gsl_sf_coni
 double nsl_sf_conicalP_cylreg(double m, double l, double x) { return gsl_sf_conicalP_sph_reg((int)round(m), l, x); }
 double nsl_sf_legendre_H3d(double l,  double L, double e) { return gsl_sf_legendre_H3d((int)round(l), L, e); }
 
+#if (GSL_MAJOR_VERSION >= 2)
+double nsl_sf_mathieu_a(double n, double q) { return gsl_sf_mathieu_a((int)round(n), q); }
+double nsl_sf_mathieu_b(double n, double q) { return gsl_sf_mathieu_b((int)round(n), q); }
+double nsl_sf_mathieu_ce(double n, double q, double x) { return gsl_sf_mathieu_ce((int)round(n), q, x); }
+double nsl_sf_mathieu_se(double n, double q, double x) { return gsl_sf_mathieu_se((int)round(n), q, x); }
+double nsl_sf_mathieu_Mc(double j, double n, double q, double x) { return gsl_sf_mathieu_Mc((int)round(j), (int)round(n), q, x); }
+double nsl_sf_mathieu_Ms(double j, double n, double q, double x) { return gsl_sf_mathieu_Ms((int)round(j), (int)round(n), q, x); }
+#endif
+
 double nsl_sf_psiint(double n) { return gsl_sf_psi_int((int)round(n)); }
 double nsl_sf_psi1int(double n) { return gsl_sf_psi_1_int((int)round(n)); }
 double nsl_sf_psin(double n,  double x) { return gsl_sf_psi_n((int)round(n), x); }
