@@ -1,38 +1,23 @@
-/***************************************************************************
+/*
     File                 : Spreadsheet.cpp
     Project              : LabPlot
     Description          : Aspect providing a spreadsheet table with column logic
     --------------------------------------------------------------------
-    Copyright            : (C) 2006-2008 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2006-2009 Knut Franke (knut.franke@gmx.de)
-    Copyright            : (C) 2012-2019 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2017-2020 Stefan Gerlach (stefan.gerlach@uni.kn)
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2006-2008 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2006-2009 Knut Franke <knut.franke@gmx.de>
+    SPDX-FileCopyrightText: 2012-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2017-2020 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "Spreadsheet.h"
 #include "SpreadsheetModel.h"
 #include "backend/core/AspectPrivate.h"
 #include "backend/core/AbstractAspect.h"
 #include "backend/core/column/ColumnStringIO.h"
 #include "backend/core/datatypes/DateTime2StringFilter.h"
+#include "backend/lib/trace.h"
+#include "backend/lib/XmlStreamReader.h"
 #include "backend/worksheet/plots/cartesian/CartesianPlot.h"
 #include "commonfrontend/spreadsheet/SpreadsheetView.h"
 
@@ -72,6 +57,10 @@ Spreadsheet::Spreadsheet(const QString& name, bool loading, AspectType type)
 		init();
 }
 
+Spreadsheet::~Spreadsheet() {
+	delete m_model;
+}
+
 /*!
 	initializes the spreadsheet with the default number of columns and rows
 */
@@ -83,7 +72,7 @@ void Spreadsheet::init() {
 	const int rows = group.readEntry(QLatin1String("RowCount"), 100);
 
 	for (int i = 0; i < columns; i++) {
-		Column* new_col = new Column(QString::number(i+1), AbstractColumn::ColumnMode::Numeric);
+		Column* new_col = new Column(QString::number(i+1), AbstractColumn::ColumnMode::Double);
 		new_col->setPlotDesignation(i == 0 ? AbstractColumn::PlotDesignation::X : AbstractColumn::PlotDesignation::Y);
 		addChild(new_col);
 	}
@@ -94,7 +83,7 @@ void Spreadsheet::setModel(SpreadsheetModel* model) {
 	m_model = model;
 }
 
-SpreadsheetModel* Spreadsheet::model() {
+SpreadsheetModel* Spreadsheet::model() const {
 	return m_model;
 }
 
@@ -103,28 +92,61 @@ SpreadsheetModel* Spreadsheet::model() {
   called at all. Aspects must not depend on the existence of a view for their operation.
 */
 QWidget* Spreadsheet::view() const {
+#ifndef SDK
 	if (!m_partView) {
 		bool readOnly = (this->parentAspect()->type() == AspectType::DatapickerCurve);
 		m_view = new SpreadsheetView(const_cast<Spreadsheet*>(this), readOnly);
 		m_partView = m_view;
 	}
 	return m_partView;
+#else
+	return nullptr;
+#endif
 }
 
 bool Spreadsheet::exportView() const {
+#ifndef SDK
 	return m_view->exportView();
+#else
+	return true;
+#endif
 }
 
 bool Spreadsheet::printView() {
+#ifndef SDK
 	return m_view->printView();
+#else
+	return true;
+#endif
 }
 
 bool Spreadsheet::printPreview() const {
+#ifndef SDK
 	return m_view->printPreview();
+#else
+	return true;
+#endif
 }
 
+/*!
+ * \brief Called when the application settings were changed.
+ *  adjusts the appearence of the spreadsheet header.
+ */
 void Spreadsheet::updateHorizontalHeader() {
+#ifndef SDK
+	const QString& oldHeader = m_model->headerData(0, Qt::Horizontal, Qt::DisplayRole).toString();
 	m_model->updateHorizontalHeader();
+	const QString& newHeader = m_model->headerData(0, Qt::Horizontal, Qt::DisplayRole).toString();
+
+	//if the header name of the first column has changed (column mode to be shown, etc.),
+	//reset the column widths and request the view to adjuste the column sizes to the  content
+	if (oldHeader != newHeader && m_view) {
+		const auto& columns = children<Column>();
+		for (auto col: columns)
+			col->setWidth(0);
+		m_view->resizeHeader();
+	}
+#endif
 }
 
 void Spreadsheet::updateLocale() {
@@ -245,7 +267,7 @@ void Spreadsheet::insertColumns(int before, int count) {
 	Column * before_col = column(before);
 	int rows = rowCount();
 	for (int i = 0; i < count; i++) {
-		Column * new_col = new Column(QString::number(i+1), AbstractColumn::ColumnMode::Numeric);
+		Column * new_col = new Column(QString::number(i+1), AbstractColumn::ColumnMode::Double);
 		new_col->setPlotDesignation(AbstractColumn::PlotDesignation::Y);
 		new_col->insertRows(0, rows);
 		insertChildBefore(new_col, before_col);
@@ -297,7 +319,7 @@ void Spreadsheet::clearMasks() {
 QMenu* Spreadsheet::createContextMenu() {
 	QMenu* menu = AbstractPart::createContextMenu();
 	Q_ASSERT(menu);
-	emit requestProjectContextMenu(menu);
+	Q_EMIT requestProjectContextMenu(menu);
 	return menu;
 }
 
@@ -386,9 +408,9 @@ int Spreadsheet::colY(int col) {
   If 'leading' is a null pointer, each column is sorted separately.
 */
 void Spreadsheet::sortColumns(Column* leading, const QVector<Column*>& cols, bool ascending) {
-	DEBUG("Spreadsheet::sortColumns() : ascending = " << ascending)
-	if (cols.isEmpty()) return;
-
+	DEBUG(Q_FUNC_INFO << ", ascending = " << ascending)
+	if (cols.isEmpty())
+		return;
 
 	// the normal QPair comparison does not work properly with descending sorting
 	// therefore we use our own compare functions
@@ -430,14 +452,14 @@ void Spreadsheet::sortColumns(Column* leading, const QVector<Column*>& cols, boo
 	WAIT_CURSOR;
 	beginMacro(i18n("%1: sort columns", name()));
 
-	if (leading == nullptr) { // sort separately
+	if (!leading) { // sort separately
 		DEBUG("	sort separately")
 		for (auto* col : cols) {
 			int rows = col->rowCount();
 			std::unique_ptr<Column> tempCol(new Column("temp", col->columnMode()));
 
 			switch (col->columnMode()) {
-			case AbstractColumn::ColumnMode::Numeric: {
+			case AbstractColumn::ColumnMode::Double: {
 					QVector< QPair<double, int> > map;
 
 					for (int i = 0; i < rows; i++)
@@ -554,7 +576,7 @@ void Spreadsheet::sortColumns(Column* leading, const QVector<Column*>& cols, boo
 		int rows = leading->rowCount();
 
 		switch (leading->columnMode()) {
-		case AbstractColumn::ColumnMode::Numeric: {
+		case AbstractColumn::ColumnMode::Double: {
 				QVector<QPair<double, int>> map;
 				QVector<int> invalidIndex;
 
@@ -760,7 +782,7 @@ QIcon Spreadsheet::icon() const {
 QString Spreadsheet::text(int row, int col) const {
 	Column* c = column(col);
 	if (!c)
-		return QString();
+		return {};
 
 	return c->asStringColumn()->textAt(row);
 }
@@ -773,7 +795,7 @@ void Spreadsheet::childSelected(const AbstractAspect* aspect) {
 	const Column* column = qobject_cast<const Column*>(aspect);
 	if (column) {
 		int index = indexOfChild<Column>(column);
-		emit columnSelected(index);
+		Q_EMIT columnSelected(index);
 	}
 }
 
@@ -785,7 +807,7 @@ void Spreadsheet::childDeselected(const AbstractAspect* aspect) {
 	const Column* column = qobject_cast<const Column*>(aspect);
 	if (column) {
 		int index = indexOfChild<Column>(column);
-		emit columnDeselected(index);
+		Q_EMIT columnDeselected(index);
 	}
 }
 
@@ -797,7 +819,7 @@ void Spreadsheet::childDeselected(const AbstractAspect* aspect) {
  */
 void Spreadsheet::setColumnSelectedInView(int index, bool selected) {
 	if (selected) {
-		emit childAspectSelectedInView(child<Column>(index));
+		Q_EMIT childAspectSelectedInView(child<Column>(index));
 
 		//deselect the spreadsheet in the project explorer, if a child (column) was selected
 		//and also all possible parents like folder, workbook, datapicker curve, datapicker
@@ -805,11 +827,22 @@ void Spreadsheet::setColumnSelectedInView(int index, bool selected) {
 		//if one of the parents of the selected column was also selected before.
 		AbstractAspect* parent = this;
 		while (parent) {
-			emit childAspectDeselectedInView(parent);
+			Q_EMIT childAspectDeselectedInView(parent);
 			parent = parent->parentAspect();
 		}
 	} else
-		emit childAspectDeselectedInView(child<Column>(index));
+		Q_EMIT childAspectDeselectedInView(child<Column>(index));
+}
+
+
+QVector<AspectType> Spreadsheet::pasteTypes() const {
+	return QVector<AspectType>{AspectType::Column};
+}
+
+QVector<AspectType> Spreadsheet::dropableOn() const {
+	auto vec = AbstractPart::dropableOn();
+	vec << AspectType::Workbook;
+	return vec;
 }
 
 //##############################################################################
@@ -824,8 +857,9 @@ void Spreadsheet::save(QXmlStreamWriter* writer) const {
 	writeCommentElement(writer);
 
 	//columns
-	for (auto* col : children<Column>(ChildIndexFlag::IncludeHidden))
-		col->save(writer);
+	const auto& columns = children<Column>(ChildIndexFlag::IncludeHidden);
+	for (auto* column : columns)
+		column->save(writer);
 
 	writer->writeEndElement(); // "spreadsheet"
 }
@@ -848,6 +882,7 @@ bool Spreadsheet::load(XmlStreamReader* reader, bool preview) {
 				if (!readCommentElement(reader)) return false;
 			} else if (reader->name() == "column") {
 				Column* column = new Column(QString());
+				column->setIsLoading(true);
 				if (!column->load(reader, preview)) {
 					delete column;
 					setColumnCount(0);
@@ -869,9 +904,9 @@ bool Spreadsheet::load(XmlStreamReader* reader, bool preview) {
 //##############################################################################
 int Spreadsheet::prepareImport(std::vector<void*>& dataContainer, AbstractFileFilter::ImportMode importMode,
                                int actualRows, int actualCols, QStringList colNameList, QVector<AbstractColumn::ColumnMode> columnMode) {
-	DEBUG("Spreadsheet::prepareImport()")
-	DEBUG("	resize spreadsheet to rows = " << actualRows << " and cols = " << actualCols)
-	QDEBUG("	column name list = " << colNameList)
+	PERFTRACE(Q_FUNC_INFO);
+	DEBUG(Q_FUNC_INFO << ", resize spreadsheet to rows = " << actualRows << " and cols = " << actualCols)
+	QDEBUG(Q_FUNC_INFO << ", column name list = " << colNameList)
 	int columnOffset = 0;
 	setUndoAware(false);
 	if (m_model != nullptr)
@@ -894,7 +929,7 @@ int Spreadsheet::prepareImport(std::vector<void*>& dataContainer, AbstractFileFi
 	}
 
 	if (columnMode.size() < actualCols) {
-		qWarning("columnMode[] size is too small! Giving up.");
+		DEBUG(Q_FUNC_INFO << ", columnMode[] size is too small! Giving up.");
 		return -1;
 	}
 
@@ -905,35 +940,33 @@ int Spreadsheet::prepareImport(std::vector<void*>& dataContainer, AbstractFileFi
 		DEBUG(" column " << n << " columnMode = " << static_cast<int>(columnMode[n]));
 		column->setColumnModeFast(columnMode[n]);
 
-		//in the most cases the first imported column is meant to be used as x-data.
+		//in most cases the first imported column is meant to be used as x-data.
 		//Other columns provide mostly y-data or errors.
 		//TODO: this has to be configurable for the user in the import widget,
 		//it should be possible to specify x-error plot designation, etc.
-		auto desig =  (n == 0) ? AbstractColumn::PlotDesignation::X : AbstractColumn::PlotDesignation::Y;
-		column->setPlotDesignation(desig);
+		if (n == 0 && importMode == AbstractFileFilter::ImportMode::Replace)
+			column->setPlotDesignation(AbstractColumn::PlotDesignation::X);
+		else
+			column->setPlotDesignation(AbstractColumn::PlotDesignation::Y);
 
 		switch (columnMode[n]) {
-		case AbstractColumn::ColumnMode::Numeric: {
+		case AbstractColumn::ColumnMode::Double: {
 			auto* vector = static_cast<QVector<double>*>(column->data());
-			vector->resize(actualRows);
 			dataContainer[n] = static_cast<void*>(vector);
 			break;
 		}
 		case AbstractColumn::ColumnMode::Integer: {
 			auto* vector = static_cast<QVector<int>*>(column->data());
-			vector->resize(actualRows);
 			dataContainer[n] = static_cast<void*>(vector);
 			break;
 		}
 		case AbstractColumn::ColumnMode::BigInt: {
 			auto* vector = static_cast<QVector<qint64>*>(column->data());
-			vector->resize(actualRows);
 			dataContainer[n] = static_cast<void*>(vector);
 			break;
 		}
 		case AbstractColumn::ColumnMode::Text: {
 			auto* vector = static_cast<QVector<QString>*>(column->data());
-			vector->resize(actualRows);
 			dataContainer[n] = static_cast<void*>(vector);
 			break;
 		}
@@ -941,7 +974,6 @@ int Spreadsheet::prepareImport(std::vector<void*>& dataContainer, AbstractFileFi
 		case AbstractColumn::ColumnMode::Day:
 		case AbstractColumn::ColumnMode::DateTime: {
 			auto* vector = static_cast<QVector<QDateTime>* >(column->data());
-			vector->resize(actualRows);
 			dataContainer[n] = static_cast<void*>(vector);
 			break;
 		}
@@ -949,7 +981,7 @@ int Spreadsheet::prepareImport(std::vector<void*>& dataContainer, AbstractFileFi
 	}
 //	QDEBUG("dataPointers =" << dataPointers);
 
-	DEBUG("Spreadsheet::prepareImport() DONE");
+	//DEBUG(Q_FUNC_INFO << ", DONE");
 
 	return columnOffset;
 }
@@ -959,34 +991,39 @@ int Spreadsheet::prepareImport(std::vector<void*>& dataContainer, AbstractFileFi
 	returns column offset depending on import mode
 */
 int Spreadsheet::resize(AbstractFileFilter::ImportMode mode, QStringList colNameList, int cols) {
-	DEBUG("Spreadsheet::resize()")
-	QDEBUG("	column name list = " << colNameList)
+//	PERFTRACE(Q_FUNC_INFO);
+	DEBUG(Q_FUNC_INFO << ", mode = " << ENUM_TO_STRING(AbstractFileFilter, ImportMode, mode) << ", cols = " << cols)
+	//QDEBUG("	column name list = " << colNameList)
 	// name additional columns
-	for (int k = colNameList.size(); k < cols; k++ )
+	for (int k = colNameList.size(); k < cols; k++)
 		colNameList.append( "Column " + QString::number(k+1) );
 
 	int columnOffset = 0; //indexes the "start column" in the spreadsheet. Starting from this column the data will be imported.
 
 	Column* newColumn = nullptr;
+	int rows = rowCount();
 	if (mode == AbstractFileFilter::ImportMode::Append) {
 		columnOffset = childCount<Column>();
-		for (int n = 0; n < cols; n++ ) {
-			newColumn = new Column(colNameList.at(n), AbstractColumn::ColumnMode::Numeric);
+		for (int n = 0; n < cols; n++) {
+			newColumn = new Column(colNameList.at(n), AbstractColumn::ColumnMode::Double);
+			newColumn->resizeTo(rows);
 			newColumn->setUndoAware(false);
+			newColumn->resizeTo(rows);
 			addChild(newColumn);
 		}
 	} else if (mode == AbstractFileFilter::ImportMode::Prepend) {
 		Column* firstColumn = child<Column>(0);
-		for (int n = 0; n < cols; n++ ) {
-			newColumn = new Column(colNameList.at(n), AbstractColumn::ColumnMode::Numeric);
+		for (int n = 0; n < cols; n++) {
+			newColumn = new Column(colNameList.at(n), AbstractColumn::ColumnMode::Double);
+			newColumn->resizeTo(rows);
 			newColumn->setUndoAware(false);
+			newColumn->resizeTo(rows);
 			insertChildBefore(newColumn, firstColumn);
 		}
 	} else if (mode == AbstractFileFilter::ImportMode::Replace) {
 		//replace completely the previous content of the data source with the content to be imported.
 		int columns = childCount<Column>();
 
-
 		if (columns > cols) {
 			//there're more columns in the data source then required -> remove the superfluous columns
 			for (int i = 0; i < columns-cols; i++)
@@ -994,8 +1031,10 @@ int Spreadsheet::resize(AbstractFileFilter::ImportMode mode, QStringList colName
 		} else {
 			//create additional columns if needed
 			for (int i = columns; i < cols; i++) {
-				newColumn = new Column(colNameList.at(i), AbstractColumn::ColumnMode::Numeric);
+				newColumn = new Column(colNameList.at(i), AbstractColumn::ColumnMode::Double);
+				newColumn->resizeTo(rows);
 				newColumn->setUndoAware(false);
+				newColumn->resizeTo(rows);
 				addChildFast(newColumn); //in the replace mode, we can skip checking the uniqueness of the names and use the "fast" method
 			}
 		}
@@ -1006,7 +1045,7 @@ int Spreadsheet::resize(AbstractFileFilter::ImportMode mode, QStringList colName
 		//    will not be connected again to the curves (project.cpp, descriptionChanged)
 		for (int i = 0; i < childCount<Column>(); i++) {
 			child<Column>(i)->setSuppressDataChangedSignal(true);
-			emit child<Column>(i)->reset(child<Column>(i));
+			Q_EMIT child<Column>(i)->reset(child<Column>(i));
 			child<Column>(i)->setName(colNameList.at(i));
 			child<Column>(i)->aspectDescriptionChanged(child<Column>(i));
 		}
@@ -1015,32 +1054,35 @@ int Spreadsheet::resize(AbstractFileFilter::ImportMode mode, QStringList colName
 	return columnOffset;
 }
 
-void Spreadsheet::finalizeImport(int columnOffset, int startColumn, int endColumn, const QString& dateTimeFormat, AbstractFileFilter::ImportMode importMode)  {
-	DEBUG("Spreadsheet::finalizeImport()");
+void Spreadsheet::finalizeImport(size_t columnOffset, size_t startColumn, size_t endColumn, const QString& dateTimeFormat, AbstractFileFilter::ImportMode importMode)  {
+	PERFTRACE(Q_FUNC_INFO);
+	//DEBUG(Q_FUNC_INFO << ", start/end col = " << startColumn << " / " << endColumn);
 
 	//determine the dependent plots
 	QVector<CartesianPlot*> plots;
 	if (importMode == AbstractFileFilter::ImportMode::Replace) {
-		for (int n = startColumn; n <= endColumn; n++) {
-			Column* column = this->column(columnOffset + n - startColumn);
-			column->addUsedInPlots(plots);
+		for (size_t n = startColumn; n <= endColumn; n++) {
+			Column* column = this->column((int)(columnOffset + n - startColumn));
+			if (column)
+				column->addUsedInPlots(plots);
 		}
 
 		//suppress retransform in the dependent plots
 		for (auto* plot : plots)
-			plot->setSuppressDataChangedSignal(true);
+			plot->setSuppressRetransform(true);
 	}
 
 	// set the comments for each of the columns if datasource is a spreadsheet
 	const int rows = rowCount();
-	for (int n = startColumn; n <= endColumn; n++) {
-		Column* column = this->column(columnOffset + n - startColumn);
-		DEBUG("	column " << n << " of type " << static_cast<int>(column->columnMode()));
+	for (size_t n = startColumn; n <= endColumn; n++) {
+		//DEBUG(Q_FUNC_INFO << ", column " << columnOffset + n - startColumn);
+		Column* column = this->column((int)(columnOffset + n - startColumn));
+		//DEBUG(Q_FUNC_INFO << ", type " << static_cast<int>(column->columnMode()));
 
 		QString comment;
 		switch (column->columnMode()) {
-		case AbstractColumn::ColumnMode::Numeric:
-			comment = i18np("numerical data, %1 element", "numerical data, %1 elements", rows);
+		case AbstractColumn::ColumnMode::Double:
+			comment = i18np("double precision data, %1 element", "numerical data, %1 elements", rows);
 			break;
 		case AbstractColumn::ColumnMode::Integer:
 			comment = i18np("integer data, %1 element", "integer data, %1 elements", rows);
@@ -1074,8 +1116,8 @@ void Spreadsheet::finalizeImport(int columnOffset, int startColumn, int endColum
 	if (importMode == AbstractFileFilter::ImportMode::Replace) {
 		//retransform the dependent plots
 		for (auto* plot : plots) {
-			plot->setSuppressDataChangedSignal(false);
-			plot->dataChanged();
+			plot->setSuppressRetransform(false);
+			plot->dataChanged(-1, -1); // TODO: check if all ranges must be updated
 		}
 	}
 
@@ -1087,12 +1129,13 @@ void Spreadsheet::finalizeImport(int columnOffset, int startColumn, int endColum
 	if (m_model != nullptr)
 		m_model->suppressSignals(false);
 
+#ifndef SDK
 	if (m_partView != nullptr && m_view != nullptr)
 		m_view->resizeHeader();
-
+#endif
 	//row count most probably changed after the import, notify the dock widget.
-	//no need to notify about the column cound change, this is done already because of add/removeChild signals
+	//no need to notify about the column count change, this is already done by add/removeChild signals
 	rowCountChanged(rowCount());
 
-	DEBUG("Spreadsheet::finalizeImport() DONE");
+	//DEBUG(Q_FUNC_INFO << " DONE");
 }
