@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : Spreadsheet.h
     Project              : LabPlot
     Description          : Aspect providing a spreadsheet table with column logic
     --------------------------------------------------------------------
-    Copyright            : (C) 2010-2017 Alexander Semke(alexander.semke@web.de)
-    Copyright            : (C) 2006-2008 Tilman Benkert (thzs@gmx.net)
+    SPDX-FileCopyrightText: 2010-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2006-2008 Tilman Benkert <thzs@gmx.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 #ifndef SPREADSHEET_H
 #define SPREADSHEET_H
 
@@ -42,6 +24,7 @@ class Spreadsheet : public AbstractDataSource {
 
 public:
 	explicit Spreadsheet(const QString& name, bool loading = false, AspectType type = AspectType::Spreadsheet);
+	~Spreadsheet() override;
 
 	QIcon icon() const override;
 	QMenu* createContextMenu() override;
@@ -52,7 +35,10 @@ public:
 	bool printPreview() const override;
 
 	void setModel(SpreadsheetModel*);
-	SpreadsheetModel* model();
+	SpreadsheetModel* model() const;
+
+	QVector<AspectType> pasteTypes() const override;
+	QVector<AspectType> dropableOn() const override;
 
 	void updateHorizontalHeader();
 	void updateLocale();
@@ -61,7 +47,7 @@ public:
 	int columnCount(AbstractColumn::PlotDesignation) const;
 	Column* column(int index) const;
 	Column* column(const QString&) const;
-	int rowCount() const;
+	int rowCount() const;	// TODO: should be size_t?
 
 	void removeRows(int first, int count);
 	void insertRows(int before, int count);
@@ -86,11 +72,11 @@ public:
 	//data import
 	int prepareImport(std::vector<void*>& dataContainer, AbstractFileFilter::ImportMode,
 		int rows, int cols, QStringList colNameList, QVector<AbstractColumn::ColumnMode>) override;
-	void finalizeImport(int columnOffset, int startColumn , int endColumn,
+	void finalizeImport(size_t columnOffset, size_t startColumn , size_t endColumn,
 		const QString& dateTimeFormat, AbstractFileFilter::ImportMode) override;
 	int resize(AbstractFileFilter::ImportMode, QStringList colNameList, int cols);
 
-public slots:
+public Q_SLOTS:
 	void appendRows(int);
 	void appendRow();
 	void appendColumns(int);
@@ -113,11 +99,11 @@ private:
 protected:
 	mutable SpreadsheetView* m_view{nullptr};
 
-private slots:
+private Q_SLOTS:
 	void childSelected(const AbstractAspect*) override;
 	void childDeselected(const AbstractAspect*) override;
 
-signals:
+Q_SIGNALS:
 	void requestProjectContextMenu(QMenu*);
 	void columnSelected(int);
 	void columnDeselected(int);
