@@ -1,39 +1,24 @@
-/***************************************************************************
+/*
     File                 : SpreadsheetModel.cpp
     Project              : LabPlot
     Description          : Model for the access to a Spreadsheet
     --------------------------------------------------------------------
-    Copyright            : (C) 2007 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2009 Knut Franke (knut.franke@gmx.de)
-    Copyright            : (C) 2013-2017 Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2007 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2009 Knut Franke <knut.franke@gmx.de>
+    SPDX-FileCopyrightText: 2013-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "backend/spreadsheet/Spreadsheet.h"
 #include "backend/spreadsheet/SpreadsheetModel.h"
 #include "backend/core/datatypes/Double2StringFilter.h"
+#include "backend/lib/macros.h"
+#include "backend/lib/trace.h"
 
 #include <QBrush>
 #include <QIcon>
+#include <QPalette>
 
 #include <KLocalizedString>
 
@@ -54,6 +39,7 @@
 SpreadsheetModel::SpreadsheetModel(Spreadsheet* spreadsheet) : QAbstractItemModel(nullptr),
 	m_spreadsheet(spreadsheet),
 	m_rowCount(spreadsheet->rowCount()),
+	m_verticalHeaderCount(spreadsheet->rowCount()),
 	m_columnCount(spreadsheet->columnCount()) {
 
 	updateVerticalHeader();
@@ -95,43 +81,61 @@ Qt::ItemFlags SpreadsheetModel::flags(const QModelIndex& index) const {
 		return Qt::ItemIsEnabled;
 }
 
+void SpreadsheetModel::setSearchText(const QString& text) {
+	m_searchText = text;
+}
+
+QModelIndex SpreadsheetModel::index(const QString& text) const {
+	const int colCount = m_spreadsheet->columnCount();
+	const int rowCount = m_spreadsheet->rowCount();
+	for (int col = 0; col < colCount; ++col) {
+		auto* column = m_spreadsheet->column(col)->asStringColumn();
+		for (int row = 0; row < rowCount; ++row) {
+			if (column->textAt(row).indexOf(text) != -1)
+				return createIndex(row, col);
+		}
+	}
+
+	return createIndex(-1, -1);
+}
+
 QVariant SpreadsheetModel::data(const QModelIndex& index, int role) const {
 	if ( !index.isValid() )
-		return QVariant();
+		return  {};
 
 	const int row = index.row();
 	const int col = index.column();
 	const Column* col_ptr = m_spreadsheet->column(col);
 
 	if (!col_ptr)
-		return QVariant();
+		return {};
 
 	switch (role) {
 	case Qt::ToolTipRole:
 		if (col_ptr->isValid(row)) {
 			if (col_ptr->isMasked(row))
-				return QVariant(i18n("%1, masked (ignored in all operations)", col_ptr->asStringColumn()->textAt(row)));
+				return {i18n("%1, masked (ignored in all operations)", col_ptr->asStringColumn()->textAt(row))};
 			else
-				return QVariant(col_ptr->asStringColumn()->textAt(row));
+				return {col_ptr->asStringColumn()->textAt(row)};
 		} else {
 			if (col_ptr->isMasked(row))
-				return QVariant(i18n("invalid cell, masked (ignored in all operations)"));
+				return {i18n("invalid cell, masked (ignored in all operations)")};
 			else
-				return QVariant(i18n("invalid cell (ignored in all operations)"));
+				return {i18n("invalid cell (ignored in all operations)")};
 		}
 	case Qt::EditRole:
-		if (col_ptr->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+		if (col_ptr->columnMode() == AbstractColumn::ColumnMode::Double) {
 			double value = col_ptr->valueAt(row);
 			if (std::isnan(value))
-				return QVariant("-");
+				return {"-"};
 			else if (std::isinf(value))
-				return QVariant(QLatin1String("inf"));
+				return {QLatin1String("inf")};
 			else
-				return QVariant(col_ptr->asStringColumn()->textAt(row));
+				return {col_ptr->asStringColumn()->textAt(row)};
 		}
 
 		if (col_ptr->isValid(row))
-			return QVariant(col_ptr->asStringColumn()->textAt(row));
+			return {col_ptr->asStringColumn()->textAt(row)};
 
 		//m_formula_mode is not used at the moment
 		//if (m_formula_mode)
@@ -139,44 +143,54 @@ QVariant SpreadsheetModel::data(const QModelIndex& index, int role) const {
 
 		break;
 	case Qt::DisplayRole:
-		if (col_ptr->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+		if (col_ptr->columnMode() == AbstractColumn::ColumnMode::Double) {
 			double value = col_ptr->valueAt(row);
 			if (std::isnan(value))
-				return QVariant("-");
+				return {"-"};
 			else if (std::isinf(value))
-				return QVariant(UTF8_QSTRING("∞"));
+				return {UTF8_QSTRING("∞")};
 			else
-				return QVariant(col_ptr->asStringColumn()->textAt(row));
+				return {col_ptr->asStringColumn()->textAt(row)};
 		}
 
 		if (!col_ptr->isValid(row))
-			return QVariant("-");
+			return {"-"};
 
 		//m_formula_mode is not used at the moment
 		//if (m_formula_mode)
 		//	return QVariant(col_ptr->formula(row));
 
-		return QVariant(col_ptr->asStringColumn()->textAt(row));
+		return {col_ptr->asStringColumn()->textAt(row)};
 	case Qt::ForegroundRole:
 		if (!col_ptr->isValid(row))
-			return QVariant(QBrush(Qt::red));
-		break;
+			return {QBrush(Qt::red)};
+		return color(col_ptr, row, AbstractColumn::Formatting::Foreground);
+	case Qt::BackgroundRole:
+		if (m_searchText.isEmpty())
+			return color(col_ptr, row, AbstractColumn::Formatting::Background);
+		else {
+			if (col_ptr->asStringColumn()->textAt(row).indexOf(m_searchText) == -1)
+				return color(col_ptr, row, AbstractColumn::Formatting::Background);
+			else
+				return {QApplication::palette().color(QPalette::Highlight)};
+		}
 	case static_cast<int>(CustomDataRole::MaskingRole):
-		return QVariant(col_ptr->isMasked(row));
+		return {col_ptr->isMasked(row)};
 	case static_cast<int>(CustomDataRole::FormulaRole):
-		return QVariant(col_ptr->formula(row));
-// 	case Qt::DecorationRole:
+		return {col_ptr->formula(row)};
+	case Qt::DecorationRole:
+		return color(col_ptr, row, AbstractColumn::Formatting::Icon);
 // 		if (m_formula_mode)
 // 			return QIcon(QPixmap(":/equals.png")); //TODO
 	}
 
-	return QVariant();
+	return {};
 }
 
 QVariant SpreadsheetModel::headerData(int section, Qt::Orientation orientation, int role) const {
 	if ( (orientation == Qt::Horizontal && section > m_columnCount-1)
-		|| (orientation == Qt::Vertical && section > m_rowCount-1) )
-		return QVariant();
+			|| (orientation == Qt::Vertical && section > m_rowCount-1) )
+		return {};
 
 	switch (orientation) {
 	case Qt::Horizontal:
@@ -195,20 +209,18 @@ QVariant SpreadsheetModel::headerData(int section, Qt::Orientation orientation,
 		switch (role) {
 		case Qt::DisplayRole:
 		case Qt::ToolTipRole:
-			return m_vertical_header_data.at(section);
+			return section + 1;
 		}
 	}
 
-	return QVariant();
+	return {};
 }
 
-int SpreadsheetModel::rowCount(const QModelIndex& parent) const {
-	Q_UNUSED(parent)
+int SpreadsheetModel::rowCount(const QModelIndex& /*parent*/) const {
 	return m_rowCount;
 }
 
-int SpreadsheetModel::columnCount(const QModelIndex& parent) const {
-	Q_UNUSED(parent)
+int SpreadsheetModel::columnCount(const QModelIndex& /*parent*/) const {
 	return m_columnCount;
 }
 
@@ -223,7 +235,7 @@ bool SpreadsheetModel::setData(const QModelIndex& index, const QVariant& value,
 	//DEBUG("SpreadsheetModel::setData() value = " << STDSTRING(value.toString()))
 
 	//don't do anything if no new value was provided
-	if (column->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+	if (column->columnMode() == AbstractColumn::ColumnMode::Double) {
 		bool ok;
 		double new_value = numberLocale.toDouble(value.toString(), &ok);
 		if (ok) {
@@ -258,22 +270,21 @@ bool SpreadsheetModel::setData(const QModelIndex& index, const QVariant& value,
 	return false;
 }
 
-QModelIndex SpreadsheetModel::index(int row, int column, const QModelIndex& parent) const {
-	Q_UNUSED(parent)
+QModelIndex SpreadsheetModel::index(int row, int column, const QModelIndex& /*parent*/) const {
 	return createIndex(row, column);
 }
 
-QModelIndex SpreadsheetModel::parent(const QModelIndex& child) const {
-	Q_UNUSED(child)
+QModelIndex SpreadsheetModel::parent(const QModelIndex& /*child*/) const {
 	return QModelIndex{};
 }
 
-bool SpreadsheetModel::hasChildren(const QModelIndex& parent) const {
-	Q_UNUSED(parent)
+bool SpreadsheetModel::hasChildren(const QModelIndex& /*parent*/) const {
 	return false;
 }
 
 void SpreadsheetModel::handleAspectAdded(const AbstractAspect* aspect) {
+	//PERFTRACE(Q_FUNC_INFO);
+
 	const Column* col = dynamic_cast<const Column*>(aspect);
 	if (!col || aspect->parentAspect() != m_spreadsheet)
 		return;
@@ -283,8 +294,8 @@ void SpreadsheetModel::handleAspectAdded(const AbstractAspect* aspect) {
 	connect(col, &Column::dataChanged, this, &SpreadsheetModel::handleDataChange);
 	connect(col, &Column::formatChanged, this, &SpreadsheetModel::handleDataChange);
 	connect(col, &Column::modeChanged, this, &SpreadsheetModel::handleModeChange);
-	connect(col, &Column::rowsInserted, this, &SpreadsheetModel::handleRowsInserted);
-	connect(col, &Column::rowsRemoved, this, &SpreadsheetModel::handleRowsRemoved);
+	connect(col, &Column::rowsInserted, this, &SpreadsheetModel::handleRowCountChanged);
+	connect(col, &Column::rowsRemoved, this, &SpreadsheetModel::handleRowCountChanged);
 	connect(col, &Column::maskingChanged, this, &SpreadsheetModel::handleDataChange);
 	connect(col->outputFilter(), &AbstractSimpleFilter::digitsChanged, this, &SpreadsheetModel::handleDigitsChange);
 
@@ -297,7 +308,7 @@ void SpreadsheetModel::handleAspectAdded(const AbstractAspect* aspect) {
 		int index = m_spreadsheet->indexOfChild<AbstractAspect>(aspect);
 		m_columnCount = m_spreadsheet->columnCount();
 		m_spreadsheet->emitColumnCountChanged();
-		emit headerDataChanged(Qt::Horizontal, index, m_columnCount - 1);
+		Q_EMIT headerDataChanged(Qt::Horizontal, index, m_columnCount - 1);
 	}
 }
 
@@ -313,8 +324,7 @@ void SpreadsheetModel::handleAspectAboutToBeRemoved(const AbstractAspect* aspect
 	disconnect(col, nullptr, this, nullptr);
 }
 
-void SpreadsheetModel::handleAspectRemoved(const AbstractAspect* parent, const AbstractAspect* before, const AbstractAspect* child) {
-	Q_UNUSED(before)
+void SpreadsheetModel::handleAspectRemoved(const AbstractAspect* parent, const AbstractAspect* /*before*/, const AbstractAspect* child) {
 	const Column* col = dynamic_cast<const Column*>(child);
 	if (!col || parent != m_spreadsheet)
 		return;
@@ -339,7 +349,7 @@ void SpreadsheetModel::handleDescriptionChange(const AbstractAspect* aspect) {
 	if (!m_suppressSignals) {
 		updateHorizontalHeader();
 		int index = m_spreadsheet->indexOfChild<Column>(col);
-		emit headerDataChanged(Qt::Horizontal, index, index);
+		Q_EMIT headerDataChanged(Qt::Horizontal, index, index);
 	}
 }
 
@@ -349,7 +359,7 @@ void SpreadsheetModel::handleModeChange(const AbstractColumn* col) {
 
 	updateHorizontalHeader();
 	int index = m_spreadsheet->indexOfChild<Column>(col);
-	emit headerDataChanged(Qt::Horizontal, index, index);
+	Q_EMIT headerDataChanged(Qt::Horizontal, index, index);
 	handleDataChange(col);
 
 	//output filter was changed after the mode change, update the signal-slot connection
@@ -375,7 +385,7 @@ void SpreadsheetModel::handlePlotDesignationChange(const AbstractColumn* col) {
 
 	updateHorizontalHeader();
 	int index = m_spreadsheet->indexOfChild<Column>(col);
-	emit headerDataChanged(Qt::Horizontal, index, m_columnCount-1);
+	Q_EMIT headerDataChanged(Qt::Horizontal, index, m_columnCount-1);
 }
 
 void SpreadsheetModel::handleDataChange(const AbstractColumn* col) {
@@ -383,52 +393,33 @@ void SpreadsheetModel::handleDataChange(const AbstractColumn* col) {
 		return;
 
 	int i = m_spreadsheet->indexOfChild<Column>(col);
-	emit dataChanged(index(0, i), index(m_rowCount-1, i));
+	Q_EMIT dataChanged(index(0, i), index(m_rowCount-1, i));
 }
 
-void SpreadsheetModel::handleRowsInserted(const AbstractColumn* col, int before, int count) {
+void SpreadsheetModel::handleRowCountChanged(const AbstractColumn* col, int /*before*/, int /*count*/) {
 	if (m_suppressSignals)
 		return;
 
-	Q_UNUSED(before) Q_UNUSED(count)
 	int i = m_spreadsheet->indexOfChild<Column>(col);
 	m_rowCount = col->rowCount();
-	emit dataChanged(index(0, i), index(m_rowCount-1, i));
-	updateVerticalHeader();
-	m_spreadsheet->emitRowCountChanged();
-}
-
-void SpreadsheetModel::handleRowsRemoved(const AbstractColumn* col, int first, int count) {
-	if (m_suppressSignals)
-		return;
-
-	Q_UNUSED(first) Q_UNUSED(count)
-	int i = m_spreadsheet->indexOfChild<Column>(col);
-	m_rowCount = col->rowCount();
-	emit dataChanged(index(0, i), index(m_rowCount-1, i));
+	Q_EMIT dataChanged(index(0, i), index(m_rowCount-1, i));
 	updateVerticalHeader();
 	m_spreadsheet->emitRowCountChanged();
 }
 
 void SpreadsheetModel::updateVerticalHeader() {
-	int old_rows = m_vertical_header_data.size();
+	int old_rows = m_verticalHeaderCount;
 	int new_rows = m_rowCount;
 
 	if (new_rows > old_rows) {
-		beginInsertRows(QModelIndex(), old_rows, new_rows-1);
-
-		for (int i = old_rows+1; i <= new_rows; i++)
-			m_vertical_header_data << i;
-
+		beginInsertRows(QModelIndex(), old_rows, new_rows - 1);
 		endInsertRows();
 	} else if (new_rows < old_rows) {
-		beginRemoveRows(QModelIndex(), new_rows, old_rows-1);
-
-		while (m_vertical_header_data.size() > new_rows)
-			m_vertical_header_data.removeLast();
-
+		beginRemoveRows(QModelIndex(), new_rows, old_rows - 1);
 		endRemoveRows();
 	}
+
+	m_verticalHeaderCount = m_rowCount;
 }
 
 void SpreadsheetModel::updateHorizontalHeader() {
@@ -448,64 +439,12 @@ void SpreadsheetModel::updateHorizontalHeader() {
 		Column* col = m_spreadsheet->child<Column>(i);
 		QString header = col->name();
 
-		if (showColumnType) {
-			switch (col->columnMode()) {
-			case AbstractColumn::ColumnMode::Numeric:
-				header += QLatin1String(" {") + i18n("Numeric") + QLatin1Char('}');
-				break;
-			case AbstractColumn::ColumnMode::Integer:
-				header += QLatin1String(" {") + i18n("Integer") + QLatin1Char('}');
-				break;
-			case AbstractColumn::ColumnMode::BigInt:
-				header += QLatin1String(" {") + i18n("Big Integer") + QLatin1Char('}');
-				break;
-			case AbstractColumn::ColumnMode::Text:
-				header += QLatin1String(" {") + i18n("Text") + QLatin1Char('}');
-				break;
-			case AbstractColumn::ColumnMode::Month:
-				header += QLatin1String(" {") + i18n("Month Names") + QLatin1Char('}');
-				break;
-			case AbstractColumn::ColumnMode::Day:
-				header += QLatin1String(" {") + i18n("Day Names") + QLatin1Char('}');
-				break;
-			case AbstractColumn::ColumnMode::DateTime:
-				header += QLatin1String(" {") + i18n("Date and Time") + QLatin1Char('}');
-				break;
-			}
-		}
+		if (showColumnType)
+			header += QLatin1String(" {") + col->columnModeString() + QLatin1Char('}');
 
 		if (showPlotDesignation) {
-			switch (col->plotDesignation()) {
-			case AbstractColumn::PlotDesignation::NoDesignation:
-				break;
-			case AbstractColumn::PlotDesignation::X:
-				header += QLatin1String(" [X]");
-				break;
-			case AbstractColumn::PlotDesignation::Y:
-				header += QLatin1String(" [Y]");
-				break;
-			case AbstractColumn::PlotDesignation::Z:
-				header += QLatin1String(" [Z]");
-				break;
-			case AbstractColumn::PlotDesignation::XError:
-				header += QLatin1String(" [") + i18n("X-error") + QLatin1Char(']');
-				break;
-			case AbstractColumn::PlotDesignation::XErrorPlus:
-				header += QLatin1String(" [") + i18n("X-error +") + QLatin1Char(']');
-				break;
-			case AbstractColumn::PlotDesignation::XErrorMinus:
-				header += QLatin1String(" [") + i18n("X-error -") + QLatin1Char(']');
-				break;
-			case AbstractColumn::PlotDesignation::YError:
-				header += QLatin1String(" [") + i18n("Y-error") + QLatin1Char(']');
-				break;
-			case AbstractColumn::PlotDesignation::YErrorPlus:
-				header += QLatin1String(" [") + i18n("Y-error +") + QLatin1Char(']');
-				break;
-			case AbstractColumn::PlotDesignation::YErrorMinus:
-				header += QLatin1String(" [") + i18n("Y-error -") + QLatin1Char(']');
-				break;
-			}
+			if (col->plotDesignation() != AbstractColumn::PlotDesignation::NoDesignation)
+				header += QLatin1String(" ") + col->plotDesignationString();
 		}
 		m_horizontal_header_data.replace(i, header);
 	}
@@ -520,9 +459,32 @@ void SpreadsheetModel::activateFormulaMode(bool on) {
 
 	m_formula_mode = on;
 	if (m_rowCount > 0 && m_columnCount > 0)
-		emit dataChanged(index(0,0), index(m_rowCount - 1, m_columnCount - 1));
+		Q_EMIT dataChanged(index(0,0), index(m_rowCount - 1, m_columnCount - 1));
 }
 
 bool SpreadsheetModel::formulaModeActive() const {
 	return m_formula_mode;
 }
+
+QVariant SpreadsheetModel::color(const AbstractColumn* column, int row, AbstractColumn::Formatting type) const {
+	if (!column->isNumeric()
+		|| !column->isValid(row)
+		|| !column->hasHeatmapFormat())
+		return {};
+
+	const auto& format = column->heatmapFormat();
+	if (format.type != type || format.colors.isEmpty())
+		return {};
+
+	double value = column->valueAt(row);
+	double range = (format.max - format.min)/format.colors.count();
+	int index = 0;
+	for (int i = 0; i < format.colors.count(); ++i) {
+		if (value <=  format.min + (i+1)*range) {
+			index = i;
+			break;
+		}
+	}
+
+	return {QColor(format.colors.at(index))};
+}
