@@ -1,32 +1,14 @@
-/***************************************************************************
+/*
     File                 : AbstractCoordinateSystem.cpp
     Project              : LabPlot
     Description          : Base class of all worksheet coordinate systems.
     --------------------------------------------------------------------
-    Copyright            : (C) 2009 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2012-2014 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2020 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2009 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2012-2014 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2020 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "backend/worksheet/plots/AbstractCoordinateSystem.h"
 #include "backend/worksheet/plots/AbstractPlot.h"
@@ -43,8 +25,7 @@ extern "C" {
  *  \ingroup backend\worksheet
  */
 
-AbstractCoordinateSystem::AbstractCoordinateSystem(AbstractPlot* plot) {
-	Q_UNUSED(plot)
+AbstractCoordinateSystem::AbstractCoordinateSystem(AbstractPlot*) {
 }
 
 AbstractCoordinateSystem::~AbstractCoordinateSystem() = default;
@@ -94,13 +75,15 @@ AbstractCoordinateSystem::~AbstractCoordinateSystem() = default;
  */
 
 bool AbstractCoordinateSystem::clipLineToRect(QLineF *line, const QRectF &rect, LineClipResult *clipResult) {
+//	QDEBUG(Q_FUNC_INFO << ", line = " << *line << ", rect = " << rect)
 	//we usually clip on large rectangles, so we don't need high precision here -> round to one float digit
 	//this prevents some subtle float rounding artifacts that lead to disappearance
 	//of lines along the boundaries of the rect. (e.g. axis lines).
-	qreal x1 = nsl_math_round_places(line->x1(), 1);
-	qreal x2 = nsl_math_round_places(line->x2(), 1);
-	qreal y1 = nsl_math_round_places(line->y1(), 1);
-	qreal y2 = nsl_math_round_places(line->y2(), 1);
+	qreal x1 = nsl_math_trunc_places(line->x1(), 1);
+	qreal x2 = nsl_math_trunc_places(line->x2(), 1);
+	qreal y1 = nsl_math_trunc_places(line->y1(), 1);
+	qreal y2 = nsl_math_trunc_places(line->y2(), 1);
+//	DEBUG(Q_FUNC_INFO << "x1/x2 y1/y2 = " << x1 << "/" << x2 << " " << y1 << "/" << y2)
 
 	qreal left;
 	qreal right;
