@@ -1,31 +1,14 @@
-/***************************************************************************
+/*
     File                 : AbstractPlot.cpp
     Project              : LabPlot
     Description          : Base class for plots of different types
     --------------------------------------------------------------------
-    Copyright            : (C) 2009 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2011-2017 by Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2009 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2011-2017 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2020 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "backend/worksheet/plots/AbstractPlot.h"
 #include "backend/worksheet/plots/AbstractPlotPrivate.h"
@@ -68,48 +51,60 @@ PlotArea* AbstractPlot::plotArea() {
 	return m_plotArea;
 }
 
-AbstractCoordinateSystem* AbstractPlot::coordinateSystem() const {
-	return m_coordinateSystem;
+AbstractCoordinateSystem* AbstractPlot::coordinateSystem(const int index) const {
+	// TODO: use default when not specified?
+	return m_coordinateSystems.at(index);
+}
+
+QVector<AbstractCoordinateSystem*> AbstractPlot::coordinateSystems() const {
+	return m_coordinateSystems;
 }
 
 TextLabel* AbstractPlot::title() {
 	return m_title;
 }
 
-void AbstractPlot::handleResize(double horizontalRatio, double verticalRatio, bool pageResize) {
+void AbstractPlot::handleResize(double horizontalRatio, double verticalRatio, bool /*pageResize*/) {
 	if (isLoading())
 		return;
-	DEBUG("AbstractPlot::handleResize()");
+	DEBUG(Q_FUNC_INFO);
 	Q_D(AbstractPlot);
 
-	double ratio = 0;
-	if (horizontalRatio > 1.0 || verticalRatio > 1.0)
-		ratio = qMax(horizontalRatio, verticalRatio);
-	else
-		ratio = qMin(horizontalRatio, verticalRatio);
+// 	qDebug()<<name() << ": ratios - " << horizontalRatio << "  " << verticalRatio;
 
-	d->horizontalPadding *= ratio;
-	d->verticalPadding *= ratio;
+	if (horizontalRatio < 1 && horizontalRatio > 0.2) {
+// 		qDebug()<<name() << ": old hor padding - " << d->horizontalPadding;
+		d->horizontalPadding *= horizontalRatio;
+// 		qDebug()<<name() << ": new hor padding - " << d->horizontalPadding;
+		Q_EMIT horizontalPaddingChanged(d->horizontalPadding);
+	}
 
-	WorksheetElementContainer::handleResize(horizontalRatio, verticalRatio, pageResize);
+	if (verticalRatio < 1 && verticalRatio > 0.2) {
+// 		qDebug()<<name() << ": old ver padding - " << d->verticalPadding;
+		d->verticalPadding *= verticalRatio;
+// 		qDebug()<<name() << ": new ver padding - " << d->verticalPadding;
+		Q_EMIT verticalPaddingChanged(d->verticalPadding);
+	}
+
+// 	WorksheetElementContainer::handleResize(horizontalRatio, verticalRatio, pageResize);
 }
 
-BASIC_SHARED_D_READER_IMPL(AbstractPlot, float, horizontalPadding, horizontalPadding)
-BASIC_SHARED_D_READER_IMPL(AbstractPlot, float, verticalPadding, verticalPadding)
+BASIC_SHARED_D_READER_IMPL(AbstractPlot, double, horizontalPadding, horizontalPadding)
+BASIC_SHARED_D_READER_IMPL(AbstractPlot, double, verticalPadding, verticalPadding)
 BASIC_SHARED_D_READER_IMPL(AbstractPlot, double, rightPadding, rightPadding)
 BASIC_SHARED_D_READER_IMPL(AbstractPlot, double, bottomPadding, bottomPadding)
 BASIC_SHARED_D_READER_IMPL(AbstractPlot, bool, symmetricPadding, symmetricPadding)
 
 /* ============================ setter methods and undo commands ================= */
-STD_SETTER_CMD_IMPL_F_S(AbstractPlot, SetHorizontalPadding, float, horizontalPadding, retransform)
-void AbstractPlot::setHorizontalPadding(float padding) {
+STD_SETTER_CMD_IMPL_F_S(AbstractPlot, SetHorizontalPadding, double, horizontalPadding, retransform)
+void AbstractPlot::setHorizontalPadding(double padding) {
 	Q_D(AbstractPlot);
 	if (padding != d->horizontalPadding)
 		exec(new AbstractPlotSetHorizontalPaddingCmd(d, padding, ki18n("%1: set horizontal padding")));
 }
 
-STD_SETTER_CMD_IMPL_F_S(AbstractPlot, SetVerticalPadding, float, verticalPadding, retransform)
-void AbstractPlot::setVerticalPadding(float padding) {
+STD_SETTER_CMD_IMPL_F_S(AbstractPlot, SetVerticalPadding, double, verticalPadding, retransform)
+void AbstractPlot::setVerticalPadding(double padding) {
 	Q_D(AbstractPlot);
 	if (padding != d->verticalPadding)
 		exec(new AbstractPlotSetVerticalPaddingCmd(d, padding, ki18n("%1: set vertical padding")));
@@ -142,7 +137,3 @@ void AbstractPlot::setSymmetricPadding(bool symmetric) {
 AbstractPlotPrivate::AbstractPlotPrivate(AbstractPlot *owner)
 	: WorksheetElementContainerPrivate(owner) {
 }
-
-QString AbstractPlotPrivate::name() const {
-	return q->name();
-}
