@@ -1,29 +1,12 @@
-/***************************************************************************
+/*
     File                 : PlotArea.cpp
     Project              : LabPlot
     Description          : Plot area (for background filling and clipping).
     --------------------------------------------------------------------
-    Copyright            : (C) 2011-2020 by Alexander Semke (alexander.semke@web.de)
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2011-2021 Alexander Semke <alexander.semke@web.de>
 
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "backend/worksheet/Worksheet.h"
 #include "backend/worksheet/plots/cartesian/CartesianPlot.h"
@@ -46,16 +29,15 @@
  * \ingroup worksheet
  */
 
-PlotArea::PlotArea(const QString &name, CartesianPlot* parent) : WorksheetElement(name, AspectType::PlotArea),
-	d_ptr(new PlotAreaPrivate(this)),
+PlotArea::PlotArea(const QString &name, CartesianPlot* parent) :
+	WorksheetElement(name, new PlotAreaPrivate(this), AspectType::PlotArea),
 	m_parent(parent) {
 
 	init();
 }
 
 PlotArea::PlotArea(const QString &name, CartesianPlot* parent, PlotAreaPrivate *dd)
-	: WorksheetElement(name, AspectType::PlotArea),
-	  d_ptr(dd),
+	: WorksheetElement(name, dd, AspectType::PlotArea),
 	  m_parent(parent) {
 
 	init();
@@ -76,9 +58,9 @@ void PlotArea::init() {
 	KConfigGroup group = config.group("PlotArea");
 
 	//Background
-	d->backgroundType = (PlotArea::BackgroundType) group.readEntry("BackgroundType", static_cast<int>(BackgroundType::Color));
-	d->backgroundColorStyle = (PlotArea::BackgroundColorStyle) group.readEntry("BackgroundColorStyle", static_cast<int>(BackgroundColorStyle::SingleColor));
-	d->backgroundImageStyle = (PlotArea::BackgroundImageStyle) group.readEntry("BackgroundImageStyle", static_cast<int>(BackgroundImageStyle::Scaled));
+	d->backgroundType = (WorksheetElement::BackgroundType) group.readEntry("BackgroundType", static_cast<int>(BackgroundType::Color));
+	d->backgroundColorStyle = (WorksheetElement::BackgroundColorStyle) group.readEntry("BackgroundColorStyle", static_cast<int>(BackgroundColorStyle::SingleColor));
+	d->backgroundImageStyle = (WorksheetElement::BackgroundImageStyle) group.readEntry("BackgroundImageStyle", static_cast<int>(BackgroundImageStyle::Scaled));
 	d->backgroundBrushStyle = (Qt::BrushStyle) group.readEntry("BackgroundBrushStyle", static_cast<int>(Qt::SolidPattern));
 	d->backgroundFileName = group.readEntry("BackgroundFileName", QString());
 	d->backgroundFirstColor = group.readEntry("BackgroundFirstColor", QColor(Qt::white));
@@ -86,6 +68,13 @@ void PlotArea::init() {
 	d->backgroundOpacity = group.readEntry("BackgroundOpacity", 1.0);
 
 	//Border
+	PlotArea::BorderType type; //default value
+	type.setFlag(PlotArea::BorderTypeFlags::BorderLeft);
+	type.setFlag(PlotArea::BorderTypeFlags::BorderTop);
+	type.setFlag(PlotArea::BorderTypeFlags::BorderRight);
+	type.setFlag(PlotArea::BorderTypeFlags::BorderBottom);
+	d->borderType = static_cast<PlotArea::BorderType>(group.readEntry("BorderType", static_cast<int>(type)));
+
 	d->borderPen = QPen(group.readEntry("BorderColor", QColor(Qt::black)),
 	                    group.readEntry("BorderWidth", Worksheet::convertToSceneUnits(1.0, Worksheet::Unit::Point)),
 	                    (Qt::PenStyle) group.readEntry("BorderStyle", (int)Qt::SolidLine));
@@ -93,37 +82,21 @@ void PlotArea::init() {
 	d->borderOpacity = group.readEntry("BorderOpacity", 1.0);
 }
 
-QGraphicsItem *PlotArea::graphicsItem() const {
+QGraphicsItem* PlotArea::graphicsItem() const {
 	return d_ptr;
 }
 
-STD_SWAP_METHOD_SETTER_CMD_IMPL(PlotArea, SetVisible, bool, swapVisible)
-void PlotArea::setVisible(bool on) {
-	Q_D(PlotArea);
-	exec(new PlotAreaSetVisibleCmd(d, on, on ? ki18n("%1: set visible") : ki18n("%1: set invisible")));
-}
-
-bool PlotArea::isVisible() const {
-	Q_D(const PlotArea);
-	return d->isVisible();
-}
-
 bool PlotArea::isHovered() const {
 	return m_parent->isHovered();
 }
 
-bool PlotArea::isPrinted() const {
-	return m_parent->isPrinted();
-}
-
 bool PlotArea::isSelected() const {
 	return m_parent->isSelected();
 }
 
-void PlotArea::handleResize(double horizontalRatio, double verticalRatio, bool pageResize) {
-	DEBUG("PlotArea::handleResize()");
+void PlotArea::handleResize(double horizontalRatio, double verticalRatio, bool /*pageResize*/) {
+	DEBUG(Q_FUNC_INFO);
 	Q_D(PlotArea);
-	Q_UNUSED(pageResize);
 
 	d->rect.setWidth(d->rect.width()*horizontalRatio);
 	d->rect.setHeight(d->rect.height()*verticalRatio);
@@ -132,29 +105,31 @@ void PlotArea::handleResize(double horizontalRatio, double verticalRatio, bool p
 }
 
 void PlotArea::retransform() {
+	Q_D(PlotArea);
+	d->retransform();
 }
 
 /* ============================ getter methods ================= */
 BASIC_SHARED_D_READER_IMPL(PlotArea, bool, clippingEnabled, clippingEnabled())
-CLASS_SHARED_D_READER_IMPL(PlotArea, QRectF, rect, rect)
+BASIC_SHARED_D_READER_IMPL(PlotArea, QRectF, rect, rect)
 
-BASIC_SHARED_D_READER_IMPL(PlotArea, PlotArea::BackgroundType, backgroundType, backgroundType)
-BASIC_SHARED_D_READER_IMPL(PlotArea, PlotArea::BackgroundColorStyle, backgroundColorStyle, backgroundColorStyle)
-BASIC_SHARED_D_READER_IMPL(PlotArea, PlotArea::BackgroundImageStyle, backgroundImageStyle, backgroundImageStyle)
-CLASS_SHARED_D_READER_IMPL(PlotArea, Qt::BrushStyle, backgroundBrushStyle, backgroundBrushStyle)
-CLASS_SHARED_D_READER_IMPL(PlotArea, QColor, backgroundFirstColor, backgroundFirstColor)
-CLASS_SHARED_D_READER_IMPL(PlotArea, QColor, backgroundSecondColor, backgroundSecondColor)
-CLASS_SHARED_D_READER_IMPL(PlotArea, QString, backgroundFileName, backgroundFileName)
+BASIC_SHARED_D_READER_IMPL(PlotArea, WorksheetElement::BackgroundType, backgroundType, backgroundType)
+BASIC_SHARED_D_READER_IMPL(PlotArea, WorksheetElement::BackgroundColorStyle, backgroundColorStyle, backgroundColorStyle)
+BASIC_SHARED_D_READER_IMPL(PlotArea, WorksheetElement::BackgroundImageStyle, backgroundImageStyle, backgroundImageStyle)
+BASIC_SHARED_D_READER_IMPL(PlotArea, Qt::BrushStyle, backgroundBrushStyle, backgroundBrushStyle)
+BASIC_SHARED_D_READER_IMPL(PlotArea, QColor, backgroundFirstColor, backgroundFirstColor)
+BASIC_SHARED_D_READER_IMPL(PlotArea, QColor, backgroundSecondColor, backgroundSecondColor)
+BASIC_SHARED_D_READER_IMPL(PlotArea, QString, backgroundFileName, backgroundFileName)
 BASIC_SHARED_D_READER_IMPL(PlotArea, qreal, backgroundOpacity, backgroundOpacity)
 
-CLASS_SHARED_D_READER_IMPL(PlotArea, QPen, borderPen, borderPen)
+BASIC_SHARED_D_READER_IMPL(PlotArea, PlotArea::BorderType, borderType, borderType)
+BASIC_SHARED_D_READER_IMPL(PlotArea, QPen, borderPen, borderPen)
 BASIC_SHARED_D_READER_IMPL(PlotArea, qreal, borderCornerRadius, borderCornerRadius)
 BASIC_SHARED_D_READER_IMPL(PlotArea, qreal, borderOpacity, borderOpacity)
 
-
 /* ============================ setter methods and undo commands ================= */
 
-STD_SWAP_METHOD_SETTER_CMD_IMPL(PlotArea, SetClippingEnabled, bool, toggleClipping);
+STD_SWAP_METHOD_SETTER_CMD_IMPL(PlotArea, SetClippingEnabled, bool, toggleClipping)
 void PlotArea::setClippingEnabled(bool on) {
 	Q_D(PlotArea);
 
@@ -171,22 +146,22 @@ void PlotArea::setRect(const QRectF &newRect) {
 }
 
 //Background
-STD_SETTER_CMD_IMPL_F_S(PlotArea, SetBackgroundType, PlotArea::BackgroundType, backgroundType, update)
-void PlotArea::setBackgroundType(BackgroundType type) {
+STD_SETTER_CMD_IMPL_F_S(PlotArea, SetBackgroundType, WorksheetElement::BackgroundType, backgroundType, update)
+void PlotArea::setBackgroundType(WorksheetElement::BackgroundType type) {
 	Q_D(PlotArea);
 	if (type != d->backgroundType)
 		exec(new PlotAreaSetBackgroundTypeCmd(d, type, ki18n("%1: background type changed")));
 }
 
-STD_SETTER_CMD_IMPL_F_S(PlotArea, SetBackgroundColorStyle, PlotArea::BackgroundColorStyle, backgroundColorStyle, update)
-void PlotArea::setBackgroundColorStyle(BackgroundColorStyle style) {
+STD_SETTER_CMD_IMPL_F_S(PlotArea, SetBackgroundColorStyle, WorksheetElement::BackgroundColorStyle, backgroundColorStyle, update)
+void PlotArea::setBackgroundColorStyle(WorksheetElement::BackgroundColorStyle style) {
 	Q_D(PlotArea);
 	if (style != d->backgroundColorStyle)
 		exec(new PlotAreaSetBackgroundColorStyleCmd(d, style, ki18n("%1: background color style changed")));
 }
 
-STD_SETTER_CMD_IMPL_F_S(PlotArea, SetBackgroundImageStyle, PlotArea::BackgroundImageStyle, backgroundImageStyle, update)
-void PlotArea::setBackgroundImageStyle(PlotArea::BackgroundImageStyle style) {
+STD_SETTER_CMD_IMPL_F_S(PlotArea, SetBackgroundImageStyle, WorksheetElement::BackgroundImageStyle, backgroundImageStyle, update)
+void PlotArea::setBackgroundImageStyle(WorksheetElement::BackgroundImageStyle style) {
 	Q_D(PlotArea);
 	if (style != d->backgroundImageStyle)
 		exec(new PlotAreaSetBackgroundImageStyleCmd(d, style, ki18n("%1: background image style changed")));
@@ -228,6 +203,13 @@ void PlotArea::setBackgroundOpacity(qreal opacity) {
 }
 
 //Border
+STD_SETTER_CMD_IMPL_F_S(PlotArea, SetBorderType, PlotArea::BorderType, borderType, update)
+void PlotArea::setBorderType(BorderType type) {
+	Q_D(PlotArea);
+	if (type != d->borderType)
+		exec(new PlotAreaSetBorderTypeCmd(d, type, ki18n("%1: border type changed")));
+}
+
 STD_SETTER_CMD_IMPL_F_S(PlotArea, SetBorderPen, QPen, borderPen, update)
 void PlotArea::setBorderPen(const QPen &pen) {
 	Q_D(PlotArea);
@@ -252,11 +234,7 @@ void PlotArea::setBorderOpacity(qreal opacity) {
 //#####################################################################
 //################### Private implementation ##########################
 //#####################################################################
-PlotAreaPrivate::PlotAreaPrivate(PlotArea *owner) : q(owner) {
-}
-
-QString PlotAreaPrivate::name() const {
-	return q->name();
+PlotAreaPrivate::PlotAreaPrivate(PlotArea *owner) : WorksheetElementPrivate(owner), q(owner) {
 }
 
 bool PlotAreaPrivate::clippingEnabled() const {
@@ -269,23 +247,20 @@ bool PlotAreaPrivate::toggleClipping(bool on) {
 	return oldValue;
 }
 
-bool PlotAreaPrivate::swapVisible(bool on) {
-	bool oldValue = isVisible();
-	setVisible(on);
-	return oldValue;
-}
-
 void PlotAreaPrivate::setRect(const QRectF& r) {
 	prepareGeometryChange();
 	rect = mapRectFromScene(r);
 }
 
 QRectF PlotAreaPrivate::boundingRect () const {
-	float width = rect.width();
-	float height = rect.height();
-	float penWidth = borderPen.width();
-	return QRectF{-width/2 - penWidth/2, -height/2 - penWidth/2,
-	              width + penWidth, height + penWidth};
+	if (borderPen.style() != Qt::NoPen){
+		const qreal width = rect.width();
+		const qreal height = rect.height();
+		const double penWidth = borderPen.width();
+		return QRectF{-width/2 - penWidth/2, -height/2 - penWidth/2,
+					width + penWidth, height + penWidth};
+	} else
+		return rect;
 }
 
 QPainterPath PlotAreaPrivate::shape() const {
@@ -298,52 +273,48 @@ QPainterPath PlotAreaPrivate::shape() const {
 	return path;
 }
 
-void PlotAreaPrivate::paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget *widget) {
-// 	DEBUG("PlotAreaPrivate::paint()");
-	Q_UNUSED(option)
-	Q_UNUSED(widget)
-
+void PlotAreaPrivate::paint(QPainter* painter, const QStyleOptionGraphicsItem* /*option*/, QWidget*) {
 	if (!isVisible())
 		return;
 
 	//draw the area
 	painter->setOpacity(backgroundOpacity);
 	painter->setPen(Qt::NoPen);
-	if (backgroundType == PlotArea::BackgroundType::Color) {
+	if (backgroundType == WorksheetElement::BackgroundType::Color) {
 		switch (backgroundColorStyle) {
-		case PlotArea::BackgroundColorStyle::SingleColor: {
+		case WorksheetElement::BackgroundColorStyle::SingleColor: {
 			painter->setBrush(QBrush(backgroundFirstColor));
 			break;
 		}
-		case PlotArea::BackgroundColorStyle::HorizontalLinearGradient: {
+		case WorksheetElement::BackgroundColorStyle::HorizontalLinearGradient: {
 			QLinearGradient linearGrad(rect.topLeft(), rect.topRight());
 			linearGrad.setColorAt(0, backgroundFirstColor);
 			linearGrad.setColorAt(1, backgroundSecondColor);
 			painter->setBrush(QBrush(linearGrad));
 			break;
 		}
-		case PlotArea::BackgroundColorStyle::VerticalLinearGradient: {
+		case WorksheetElement::BackgroundColorStyle::VerticalLinearGradient: {
 			QLinearGradient linearGrad(rect.topLeft(), rect.bottomLeft());
 			linearGrad.setColorAt(0, backgroundFirstColor);
 			linearGrad.setColorAt(1, backgroundSecondColor);
 			painter->setBrush(QBrush(linearGrad));
 			break;
 		}
-		case PlotArea::BackgroundColorStyle::TopLeftDiagonalLinearGradient: {
+		case WorksheetElement::BackgroundColorStyle::TopLeftDiagonalLinearGradient: {
 			QLinearGradient linearGrad(rect.topLeft(), rect.bottomRight());
 			linearGrad.setColorAt(0, backgroundFirstColor);
 			linearGrad.setColorAt(1, backgroundSecondColor);
 			painter->setBrush(QBrush(linearGrad));
 			break;
 		}
-		case PlotArea::BackgroundColorStyle::BottomLeftDiagonalLinearGradient: {
+		case WorksheetElement::BackgroundColorStyle::BottomLeftDiagonalLinearGradient: {
 			QLinearGradient linearGrad(rect.bottomLeft(), rect.topRight());
 			linearGrad.setColorAt(0, backgroundFirstColor);
 			linearGrad.setColorAt(1, backgroundSecondColor);
 			painter->setBrush(QBrush(linearGrad));
 			break;
 		}
-		case PlotArea::BackgroundColorStyle::RadialGradient: {
+		case WorksheetElement::BackgroundColorStyle::RadialGradient: {
 			QRadialGradient radialGrad(rect.center(), rect.width()/2);
 			radialGrad.setColorAt(0, backgroundFirstColor);
 			radialGrad.setColorAt(1, backgroundSecondColor);
@@ -351,78 +322,88 @@ void PlotAreaPrivate::paint(QPainter* painter, const QStyleOptionGraphicsItem* o
 			break;
 		}
 		}
-	} else if (backgroundType == PlotArea::BackgroundType::Image) {
+	} else if (backgroundType == WorksheetElement::BackgroundType::Image) {
 		if ( !backgroundFileName.trimmed().isEmpty() ) {
 			QPixmap pix(backgroundFileName);
 			switch (backgroundImageStyle) {
-			case PlotArea::BackgroundImageStyle::ScaledCropped:
+			case WorksheetElement::BackgroundImageStyle::ScaledCropped:
 				pix = pix.scaled(rect.size().toSize(),Qt::KeepAspectRatioByExpanding,Qt::SmoothTransformation);
 				painter->setBrush(QBrush(pix));
 				painter->setBrushOrigin(pix.size().width()/2,pix.size().height()/2);
 				painter->drawRoundedRect(rect, borderCornerRadius, borderCornerRadius);
 				break;
-			case PlotArea::BackgroundImageStyle::Scaled:
+			case WorksheetElement::BackgroundImageStyle::Scaled:
 				pix = pix.scaled(rect.size().toSize(),Qt::IgnoreAspectRatio,Qt::SmoothTransformation);
 				painter->setBrush(QBrush(pix));
 				painter->setBrushOrigin(pix.size().width()/2,pix.size().height()/2);
 				painter->drawRoundedRect(rect, borderCornerRadius, borderCornerRadius);
 				break;
-			case PlotArea::BackgroundImageStyle::ScaledAspectRatio:
+			case WorksheetElement::BackgroundImageStyle::ScaledAspectRatio:
 				pix = pix.scaled(rect.size().toSize(),Qt::KeepAspectRatio,Qt::SmoothTransformation);
 				painter->setBrush(QBrush(pix));
 				painter->setBrushOrigin(pix.size().width()/2,pix.size().height()/2);
 				painter->drawRoundedRect(rect, borderCornerRadius, borderCornerRadius);
 				break;
-			case PlotArea::BackgroundImageStyle::Centered:
+			case WorksheetElement::BackgroundImageStyle::Centered:
 				painter->drawPixmap(QPointF(rect.center().x()-pix.size().width()/2,rect.center().y()-pix.size().height()/2),pix);
 				break;
-			case PlotArea::BackgroundImageStyle::Tiled:
+			case WorksheetElement::BackgroundImageStyle::Tiled:
 				painter->setBrush(QBrush(pix));
 				painter->drawRoundedRect(rect, borderCornerRadius, borderCornerRadius);
 				break;
-			case PlotArea::BackgroundImageStyle::CenterTiled:
+			case WorksheetElement::BackgroundImageStyle::CenterTiled:
 				painter->setBrush(QBrush(pix));
 				painter->setBrushOrigin(pix.size().width()/2,pix.size().height()/2);
 				painter->drawRoundedRect(rect, borderCornerRadius, borderCornerRadius);
 			}
 		}
-	} else if (backgroundType == PlotArea::BackgroundType::Pattern) {
+	} else if (backgroundType == WorksheetElement::BackgroundType::Pattern) {
 		painter->setBrush(QBrush(backgroundFirstColor,backgroundBrushStyle));
 	}
 
+
+	//draw the background
 	if ( qFuzzyIsNull(borderCornerRadius) )
 		painter->drawRect(rect);
 	else
 		painter->drawRoundedRect(rect, borderCornerRadius, borderCornerRadius);
 
 	//draw the border
-	if (borderPen.style() != Qt::NoPen && !q->isHovered() && !isSelected()) {
+	if (borderPen.style() != Qt::NoPen) {
 		painter->setPen(borderPen);
 		painter->setBrush(Qt::NoBrush);
 		painter->setOpacity(borderOpacity);
-		if ( qFuzzyIsNull(borderCornerRadius) )
-			painter->drawRect(rect);
-		else
+		if ( qFuzzyIsNull(borderCornerRadius) ) {
+			const double w = rect.width();
+			const double h = rect.height();
+			if (borderType.testFlag(PlotArea::BorderTypeFlags::BorderLeft))
+				painter->drawLine(-w/2, -h/2, -w/2, h/2);
+			if (borderType.testFlag(PlotArea::BorderTypeFlags::BorderTop))
+				painter->drawLine(-w/2, -h/2, w/2 , -h/2);
+			if (borderType.testFlag(PlotArea::BorderTypeFlags::BorderRight))
+				painter->drawLine(-w/2 + w, -h/2, w/2, h/2);
+			if (borderType.testFlag(PlotArea::BorderTypeFlags::BorderBottom))
+				painter->drawLine(w/2, h/2, -w/2, h/2);
+		} else
 			painter->drawRoundedRect(rect, borderCornerRadius, borderCornerRadius);
 	}
 
-	double penWidth = 6.;
-	QRectF rect = boundingRect();
-	rect = QRectF(-rect.width()/2 + penWidth / 2, -rect.height()/2 + penWidth / 2,
-				  rect.width() - penWidth, rect.height() - penWidth);
+	if (q->isHovered() || q->isSelected()) {
+		const double penWidth = 6.;
+		QRectF rect = boundingRect();
+		rect = QRectF(-rect.width()/2 + penWidth / 2, -rect.height()/2 + penWidth / 2,
+					rect.width() - penWidth, rect.height() - penWidth);
 
-	if (q->isHovered() && !q->isSelected() && !q->isPrinted()) {
-		painter->setPen(QPen(QApplication::palette().color(QPalette::Shadow), penWidth, Qt::SolidLine));
-		painter->drawRect(rect);
+		if (q->isHovered() && !q->isSelected() && !q->isPrinting()) {
+			painter->setPen(QPen(QApplication::palette().color(QPalette::Shadow), penWidth, Qt::SolidLine));
+			painter->drawRect(rect);
+		}
+
+		if (q->isSelected() && !q->isPrinting()) {
+			painter->setPen(QPen(QApplication::palette().color(QPalette::Highlight), penWidth, Qt::SolidLine));
+			painter->drawRect(rect);
+		}
 	}
-
-	if (q->isSelected() && !q->isPrinted()) {
-		painter->setPen(QPen(QApplication::palette().color(QPalette::Highlight), penWidth, Qt::SolidLine));
-		painter->drawRect(rect);
-	}
-
-
-// 	DEBUG("PlotAreaPrivate::paint() DONE");
 }
 
 //##############################################################################
@@ -455,6 +436,7 @@ void PlotArea::save(QXmlStreamWriter* writer) const {
 	//border
 	writer->writeStartElement( "border" );
 	WRITE_QPEN(d->borderPen);
+	writer->writeAttribute( "borderType", QString::number(d->borderType) );
 	writer->writeAttribute( "borderOpacity", QString::number(d->borderOpacity) );
 	writer->writeAttribute( "borderCornerRadius", QString::number(d->borderCornerRadius) );
 	writer->writeEndElement();
@@ -490,19 +472,19 @@ bool PlotArea::load(XmlStreamReader* reader, bool preview) {
 			if (str.isEmpty())
 				reader->raiseWarning(attributeWarning.subs("type").toString());
 			else
-				d->backgroundType = PlotArea::BackgroundType(str.toInt());
+				d->backgroundType = WorksheetElement::BackgroundType(str.toInt());
 
 			str = attribs.value("colorStyle").toString();
 			if (str.isEmpty())
 				reader->raiseWarning(attributeWarning.subs("colorStyle").toString());
 			else
-				d->backgroundColorStyle = PlotArea::BackgroundColorStyle(str.toInt());
+				d->backgroundColorStyle = WorksheetElement::BackgroundColorStyle(str.toInt());
 
 			str = attribs.value("imageStyle").toString();
 			if (str.isEmpty())
 				reader->raiseWarning(attributeWarning.subs("imageStyle").toString());
 			else
-				d->backgroundImageStyle = PlotArea::BackgroundImageStyle(str.toInt());
+				d->backgroundImageStyle = WorksheetElement::BackgroundImageStyle(str.toInt());
 
 			str = attribs.value("brushStyle").toString();
 			if (str.isEmpty())
@@ -557,6 +539,7 @@ bool PlotArea::load(XmlStreamReader* reader, bool preview) {
 		} else if (!preview && reader->name() == "border") {
 			attribs = reader->attributes();
 
+			READ_INT_VALUE("borderType", borderType, PlotArea::BorderType);
 			READ_QPEN(d->borderPen);
 
 			str = attribs.value("borderOpacity").toString();
@@ -587,9 +570,9 @@ void PlotArea::loadThemeConfig(const KConfig& config) {
 		group = config.group("PlotArea");
 
 	//background
-	this->setBackgroundType((PlotArea::BackgroundType) group.readEntry("BackgroundType", static_cast<int>(PlotArea::BackgroundType::Color)));
-	this->setBackgroundColorStyle((PlotArea::BackgroundColorStyle) group.readEntry("BackgroundColorStyle", static_cast<int>(PlotArea::BackgroundColorStyle::SingleColor)));
-	this->setBackgroundImageStyle((PlotArea::BackgroundImageStyle) group.readEntry("BackgroundImageStyle", static_cast<int>(PlotArea::BackgroundImageStyle::Scaled)));
+	this->setBackgroundType((WorksheetElement::BackgroundType) group.readEntry("BackgroundType", static_cast<int>(WorksheetElement::BackgroundType::Color)));
+	this->setBackgroundColorStyle((WorksheetElement::BackgroundColorStyle) group.readEntry("BackgroundColorStyle", static_cast<int>(WorksheetElement::BackgroundColorStyle::SingleColor)));
+	this->setBackgroundImageStyle((WorksheetElement::BackgroundImageStyle) group.readEntry("BackgroundImageStyle", static_cast<int>(WorksheetElement::BackgroundImageStyle::Scaled)));
 	this->setBackgroundBrushStyle((Qt::BrushStyle) group.readEntry("BackgroundBrushStyle", static_cast<int>(Qt::SolidPattern)));
 	this->setBackgroundFirstColor(group.readEntry("BackgroundFirstColor", QColor(Qt::white)));
 	this->setBackgroundSecondColor(group.readEntry("BackgroundSecondColor", QColor(Qt::black)));
