@@ -1,37 +1,20 @@
-/***************************************************************************
+/*
     File                 : Axis.h
     Project              : LabPlot
     Description          : Axis for cartesian coordinate systems.
     --------------------------------------------------------------------
-    Copyright            : (C) 2009 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2011-2018 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2013 Stefan Gerlach (stefan.gerlach@uni.kn)
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2009 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2011-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2013-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef AXISNEW_H
 #define AXISNEW_H
 
 #include "backend/worksheet/WorksheetElement.h"
-#include "backend/lib/macros.h"
+#include "backend/lib/Range.h"
 
 class CartesianPlot;
 class TextLabel;
@@ -43,8 +26,10 @@ class Axis: public WorksheetElement {
 	Q_OBJECT
 
 public:
-	enum class Position {Top, Bottom, Left, Right, Centered, Custom};
-	enum class LabelsFormat {Decimal, ScientificE, Powers10, Powers2, PowersE, MultipliesPi};
+	enum class RangeType {Auto, AutoData, Custom};
+	enum class Position {Top, Bottom, Left, Right, Centered, Custom, Logical};
+	enum class LabelsFormat {Decimal, ScientificE, Powers10, Powers2, PowersE, MultipliesPi, Scientific};
+	Q_ENUM(LabelsFormat)
 	enum TicksFlags {
 		noTicks = 0x00,
 		ticksIn = 0x01,
@@ -56,14 +41,55 @@ public:
 	enum class TicksType {TotalNumber, Spacing, CustomColumn, CustomValues};
 	enum class ArrowType {NoArrow, SimpleSmall, SimpleBig, FilledSmall, FilledBig, SemiFilledSmall, SemiFilledBig};
 	enum class ArrowPosition {Left, Right, Both};
-	enum class Scale {Linear, Log10, Log2, Ln, Sqrt, X2};
 	enum class LabelsPosition {NoLabels, In, Out};
+	enum class LabelsTextType {PositionValues, CustomValues};
 	enum class LabelsBackgroundType {Transparent, Color};
 
-	explicit Axis(const QString&, Orientation orientation = Orientation::Horizontal);
+	// LabelsFormat <-> index, see AxisDock::init()
+	static int labelsFormatToIndex(LabelsFormat format) {
+		switch (format) {
+		case LabelsFormat::Decimal:
+			return 0;
+		case LabelsFormat::Scientific:
+			return 1;
+		case LabelsFormat::ScientificE:
+			return 2;
+		case LabelsFormat::Powers10:
+			return 3;
+		case LabelsFormat::Powers2:
+			return 4;
+		case LabelsFormat::PowersE:
+			return 5;
+		case LabelsFormat::MultipliesPi:
+			return 6;
+		}
+		return 0;
+	}
+	static LabelsFormat indexToLabelsFormat(int index) {
+		switch (index) {
+		case 0:
+			return LabelsFormat::Decimal;
+		case 1:
+			return LabelsFormat::Scientific;
+		case 2:
+			return LabelsFormat::ScientificE;
+		case 3:
+			return LabelsFormat::Powers10;
+		case 4:
+			return LabelsFormat::Powers2;
+		case 5:
+			return LabelsFormat::PowersE;
+		case 6:
+			return LabelsFormat::MultipliesPi;
+		}
+		return LabelsFormat::Decimal;
+	}
+
+	typedef AxisPrivate Private;	// for Axis::Private used in macros instead of AxisPrivate
+
+	explicit Axis(const QString&, Orientation = Orientation::Horizontal);
 	~Axis() override;
 
-	void finalizeAdd() override;
 	QIcon icon() const override;
 	QMenu* createContextMenu() override;
 
@@ -75,16 +101,20 @@ public:
 	void loadThemeConfig(const KConfig&) override;
 	void saveThemeConfig(const KConfig&) override;
 
-	BASIC_D_ACCESSOR_DECL(bool, autoScale, AutoScale)
+	BASIC_D_ACCESSOR_DECL(RangeType, rangeType, RangeType)
 	BASIC_D_ACCESSOR_DECL(Orientation, orientation, Orientation)
 	BASIC_D_ACCESSOR_DECL(Position, position, Position)
-	BASIC_D_ACCESSOR_DECL(Scale, scale, Scale)
-	BASIC_D_ACCESSOR_DECL(double, start, Start)
-	BASIC_D_ACCESSOR_DECL(double, end, End)
-	void setOffset(const double, const bool=true);
+	BASIC_D_ACCESSOR_DECL(RangeT::Scale, scale, Scale)
+	BASIC_D_ACCESSOR_DECL(Range<double>, range, Range)
+	void setStart(const double);
+	void setEnd(const double);
+	void setRange(const double, const double);
+	void setOffset(const double, const bool = true);
 	double offset() const;
 	BASIC_D_ACCESSOR_DECL(qreal, scalingFactor, ScalingFactor)
 	BASIC_D_ACCESSOR_DECL(qreal, zeroOffset, ZeroOffset)
+	BASIC_D_ACCESSOR_DECL(bool, showScaleOffset, ShowScaleOffset)
+	BASIC_D_ACCESSOR_DECL(double, logicalPosition, LogicalPosition)
 
 	POINTER_D_ACCESSOR_DECL(TextLabel, title, Title)
 	BASIC_D_ACCESSOR_DECL(double, titleOffsetX, TitleOffsetX)
@@ -100,8 +130,9 @@ public:
 	BASIC_D_ACCESSOR_DECL(TicksType, majorTicksType, MajorTicksType)
 	BASIC_D_ACCESSOR_DECL(int, majorTicksNumber, MajorTicksNumber)
 	BASIC_D_ACCESSOR_DECL(qreal, majorTicksSpacing, MajorTicksSpacing)
+	BASIC_D_ACCESSOR_DECL(qreal, majorTickStartOffset, MajorTickStartOffset)
 	POINTER_D_ACCESSOR_DECL(const AbstractColumn, majorTicksColumn, MajorTicksColumn)
-	QString& majorTicksColumnPath() const;
+	QString &majorTicksColumnPath() const;
 	CLASS_D_ACCESSOR_DECL(QPen, majorTicksPen, MajorTicksPen)
 	BASIC_D_ACCESSOR_DECL(qreal, majorTicksLength, MajorTicksLength)
 	BASIC_D_ACCESSOR_DECL(qreal, majorTicksOpacity, MajorTicksOpacity)
@@ -111,7 +142,7 @@ public:
 	BASIC_D_ACCESSOR_DECL(int, minorTicksNumber, MinorTicksNumber)
 	BASIC_D_ACCESSOR_DECL(qreal, minorTicksSpacing, MinorTicksSpacing)
 	POINTER_D_ACCESSOR_DECL(const AbstractColumn, minorTicksColumn, MinorTicksColumn)
-	QString& minorTicksColumnPath() const;
+	QString &minorTicksColumnPath() const;
 	CLASS_D_ACCESSOR_DECL(QPen, minorTicksPen, MinorTicksPen)
 	BASIC_D_ACCESSOR_DECL(qreal, minorTicksLength, MinorTicksLength)
 	BASIC_D_ACCESSOR_DECL(qreal, minorTicksOpacity, MinorTicksOpacity)
@@ -123,6 +154,10 @@ public:
 	BASIC_D_ACCESSOR_DECL(LabelsPosition, labelsPosition, LabelsPosition)
 	BASIC_D_ACCESSOR_DECL(qreal, labelsOffset, LabelsOffset)
 	BASIC_D_ACCESSOR_DECL(qreal, labelsRotationAngle, LabelsRotationAngle)
+	BASIC_D_ACCESSOR_DECL(LabelsTextType, labelsTextType, LabelsTextType)
+	POINTER_D_ACCESSOR_DECL(const AbstractColumn, labelsTextColumn, LabelsTextColumn)
+	QString& labelsTextColumnPath() const;
+	QVector<double> tickLabelValues() const;
 	CLASS_D_ACCESSOR_DECL(QColor, labelsColor, LabelsColor)
 	CLASS_D_ACCESSOR_DECL(QFont, labelsFont, LabelsFont)
 	BASIC_D_ACCESSOR_DECL(LabelsBackgroundType, labelsBackgroundType, LabelsBackgroundType)
@@ -136,29 +171,24 @@ public:
 	CLASS_D_ACCESSOR_DECL(QPen, minorGridPen, MinorGridPen)
 	BASIC_D_ACCESSOR_DECL(qreal, minorGridOpacity, MinorGridOpacity)
 
+	bool isNumeric() const;
+
 	void setDefault(bool);
 	bool isDefault() const;
 
-	void setVisible(bool) override;
-	bool isVisible() const override;
-
-	void setPrinting(bool) override;
 	bool isHovered() const;
 	void setSuppressRetransform(bool);
 	void retransform() override;
 	void retransformTickLabelStrings();
 	void handleResize(double horizontalRatio, double verticalRatio, bool pageResize) override;
 
-	typedef AxisPrivate Private;
-
 protected:
-	AxisPrivate* const d_ptr;
 	Axis(const QString&, Orientation, AxisPrivate*);
 	TextLabel* m_title;
 
 private:
 	Q_DECLARE_PRIVATE(Axis)
-	void init();
+	void init(Orientation);
 	void initActions();
 	void initMenus();
 
@@ -175,7 +205,7 @@ private:
 	QMenu* lineStyleMenu{nullptr};
 	QMenu* lineColorMenu{nullptr};
 
-private slots:
+private Q_SLOTS:
 	void labelChanged();
 	void retransformTicks();
 	void majorTicksColumnAboutToBeRemoved(const AbstractAspect*);
@@ -187,16 +217,19 @@ private slots:
 	void lineColorChanged(QAction*);
 	void visibilityChangedSlot();
 
-signals:
+Q_SIGNALS:
 	void orientationChanged(Orientation);
 	void positionChanged(Position);
 	void positionChanged(double);
-	void scaleChanged(Scale);
+	void scaleChanged(RangeT::Scale);
 	void startChanged(double);
-	void autoScaleChanged(bool);
+	void rangeTypeChanged(RangeType);
 	void endChanged(double);
+	void rangeChanged(Range<double>);
 	void zeroOffsetChanged(qreal);
 	void scalingFactorChanged(qreal);
+	void showScaleOffsetChanged(bool);
+	void logicalPositionChanged(double);
 
 	//title
 	void titleOffsetXChanged(qreal);
@@ -205,23 +238,24 @@ signals:
 	// line
 	void linePenChanged(const QPen&);
 	void lineOpacityChanged(qreal);
-	void arrowTypeChanged(Axis::ArrowType);
-	void arrowPositionChanged(Axis::ArrowPosition);
+	void arrowTypeChanged(ArrowType);
+	void arrowPositionChanged(ArrowPosition);
 	void arrowSizeChanged(qreal);
 
 	// major ticks
-	void majorTicksDirectionChanged(Axis::TicksDirection);
-	void majorTicksTypeChanged(Axis::TicksType);
+	void majorTicksDirectionChanged(TicksDirection);
+	void majorTicksTypeChanged(TicksType);
 	void majorTicksNumberChanged(int);
 	void majorTicksSpacingChanged(qreal);
 	void majorTicksColumnChanged(const AbstractColumn*);
+	void majorTickStartOffsetChanged(qreal);
 	void majorTicksPenChanged(QPen);
 	void majorTicksLengthChanged(qreal);
 	void majorTicksOpacityChanged(qreal);
 
 	// minor ticks
-	void minorTicksDirectionChanged(Axis::TicksDirection);
-	void minorTicksTypeChanged(Axis::TicksType);
+	void minorTicksDirectionChanged(TicksDirection);
+	void minorTicksTypeChanged(TicksType);
 	void minorTicksNumberChanged(int);
 	void minorTicksIncrementChanged(qreal);
 	void minorTicksColumnChanged(const AbstractColumn*);
@@ -230,16 +264,18 @@ signals:
 	void minorTicksOpacityChanged(qreal);
 
 	//labels
-	void labelsFormatChanged(Axis::LabelsFormat);
+	void labelsFormatChanged(LabelsFormat);
 	void labelsAutoPrecisionChanged(bool);
 	void labelsPrecisionChanged(int);
 	void labelsDateTimeFormatChanged(const QString&);
-	void labelsPositionChanged(Axis::LabelsPosition);
+	void labelsPositionChanged(LabelsPosition);
 	void labelsOffsetChanged(double);
 	void labelsRotationAngleChanged(qreal);
+	void labelsTextTypeChanged(LabelsTextType);
+	void labelsTextColumnChanged(const AbstractColumn*);
 	void labelsColorChanged(QColor);
 	void labelsFontChanged(QFont);
-	void labelsBackgroundTypeChanged(Axis::LabelsBackgroundType);
+	void labelsBackgroundTypeChanged(LabelsBackgroundType);
 	void labelsBackgroundColorChanged(QColor);
 	void labelsPrefixChanged(QString);
 	void labelsSuffixChanged(QString);
@@ -249,8 +285,6 @@ signals:
 	void majorGridOpacityChanged(qreal);
 	void minorGridPenChanged(QPen);
 	void minorGridOpacityChanged(qreal);
-
-	void visibilityChanged(bool);
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Axis::TicksDirection)
