@@ -1,55 +1,37 @@
-/***************************************************************************
+/*
     File                 : AxisPrivate.h
     Project              : LabPlot
     Description          : Private members of Axis.
     --------------------------------------------------------------------
-    Copyright            : (C) 2011-2018 Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2011-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2020-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #ifndef AXISPRIVATE_H
 #define AXISPRIVATE_H
 
-#include <QGraphicsItem>
+#include "Axis.h"
+
+#include "backend/worksheet/WorksheetElementPrivate.h"
 #include <QPen>
 #include <QFont>
-#include "Axis.h"
 
 class QGraphicsSceneHoverEvent;
 
 class AxisGrid;
-class CartesianPlot;
-class CartesianCoordinateSystem;
 class TextLabel;
 
-class AxisPrivate: public QGraphicsItem {
+class AxisPrivate: public WorksheetElementPrivate {
 public:
 	explicit AxisPrivate(Axis*);
 
 	QRectF boundingRect() const override;
 	QPainterPath shape() const override;
 
-	QString name() const;
-	void retransform();
+	void retransform() override;
+	void retransformRange();
 	void retransformLine();
 	void retransformArrow();
 	void retransformTicks();
@@ -59,22 +41,23 @@ public:
 	void retransformMajorGrid();
 	void updateGrid();
 	bool swapVisible(bool);
-	void recalcShapeAndBoundingRect();
-	void setPrinting(bool);
+	void recalcShapeAndBoundingRect() override;
 	bool isHovered() const;
 
 	bool isDefault{false};
 
 	//general
-	bool autoScale;
+	Axis::RangeType rangeType;
 	Axis::Orientation orientation; //!< horizontal or vertical
 	Axis::Position position; //!< left, right, bottom, top or custom (usually not changed after creation)
-	Axis::Scale scale;
-	double offset; //!< offset from zero in the direction perpendicular to the axis
-	double start; //!< start coordinate of the axis line
-	double end; //!< end coordinate of the axis line
-	qreal scalingFactor;
-	qreal zeroOffset;
+	RangeT::Scale scale;
+	double offset{0}; //!< offset from zero in the direction perpendicular to the axis
+	Range<double> range; //!< coordinate range of the axis line
+	qreal majorTickStartOffset{0};
+	qreal scalingFactor{1};
+	qreal zeroOffset{0};
+	bool showScaleOffset{true};
+	double logicalPosition{0};
 
 	//line
 	QVector<QLineF> lines;
@@ -116,6 +99,9 @@ public:
 	bool labelsAutoPrecision;
 	QString labelsDateTimeFormat;
 	Axis::LabelsPosition labelsPosition;
+	Axis::LabelsTextType labelsTextType;
+	const AbstractColumn* labelsTextColumn{nullptr};
+	QString labelsTextColumnPath;
 	qreal labelsRotationAngle;
 	QColor labelsColor;
 	QFont labelsFont;
@@ -138,14 +124,20 @@ public:
 	QPainterPath linePath;
 	QPainterPath majorGridPath;
 	QPainterPath minorGridPath;
-	bool suppressRetransform{false};
-	bool labelsFormatDecimalOverruled{false};
+	bool labelsFormatOverruled{false};
 	bool labelsFormatAutoChanged{false};
 
-	CartesianPlot* plot{nullptr};
-	const CartesianCoordinateSystem* cSystem{nullptr};
+	QVector<QPointF> majorTickPoints;//!< position of the major ticks  on the axis.
+	QVector<QPointF> minorTickPoints;//!< position of the major ticks  on the axis.
+	QVector<QPointF> tickLabelPoints; //!< position of the major tick labels (left lower edge of label's bounding rect)
+	QVector<double> tickLabelValues; //!< major tick labels values
+	QVector<QString> tickLabelValuesString; //!<major tick labels used when a custom text column is selected
+	QVector<QString> tickLabelStrings; //!< the actual text of the major tick labels
 
 private:
+	CartesianPlot* plot() const {
+		return q->m_plot;    // convenience method
+	}
 	void contextMenuEvent(QGraphicsSceneContextMenuEvent*) override;
 	void hoverEnterEvent(QGraphicsSceneHoverEvent*) override;
 	void hoverLeaveEvent(QGraphicsSceneHoverEvent*) override;
@@ -165,15 +157,8 @@ private:
 	QRectF boundingRectangle;
 	QPainterPath axisShape;
 
-	QVector<QPointF> majorTickPoints;//!< position of the major ticks  on the axis.
-	QVector<QPointF> minorTickPoints;//!< position of the major ticks  on the axis.
-	QVector<QPointF> tickLabelPoints; //!< position of the major tick labels (left lower edge of label's bounding rect)
-	QVector<double> tickLabelValues; //!< major tick labels values
-	QVector<QString> tickLabelStrings; //!< the actual text of the major tick labels
-
 	bool m_hovered{false};
 	bool m_suppressRecalc{false};
-	bool m_printing{false};
 	bool m_panningStarted{false};
 	QPointF m_panningStart;
 };
