@@ -1,232 +1,25 @@
-
-/***************************************************************************
+/*
     File                 : CartesianCoordinateSystem.cpp
     Project              : LabPlot
     Description          : Cartesian coordinate system for plots.
     --------------------------------------------------------------------
-    Copyright            : (C) 2012-2016 by Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2012-2016 Alexander Semke <alexander.semke@web.de>
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "backend/worksheet/plots/cartesian/CartesianCoordinateSystem.h"
+#include "backend/worksheet/plots/cartesian/CartesianCoordinateSystemPrivate.h"
 #include "backend/worksheet/plots/cartesian/CartesianPlot.h"
 #include "backend/lib/macros.h"
 
 extern "C" {
-#include "gsl/gsl_math.h"
 #include "backend/nsl/nsl_math.h"
 }
 
-/* ============================================================================ */
-/* =================================== scales ================================= */
-/* ============================================================================ */
-/**
- * \class CartesianScale
- * \brief Base class for cartesian coordinate system scales.
- */
-CartesianScale::CartesianScale(ScaleType type, const Interval<double> &interval, double a, double b, double c)
-	: m_type(type), m_interval(interval), m_a(a), m_b(b), m_c(c) {
-}
-
-CartesianScale::~CartesianScale() = default;
-
-void CartesianScale::getProperties(ScaleType *type, Interval<double> *interval,
-		double *a, double *b, double *c) const {
-	if (type)
-		*type = m_type;
-	if (interval)
-		*interval = m_interval;
-	if (a)
-		*a = m_a;
-	if (b)
-		*b = m_b;
-	if (c)
-		*c = m_c;
-}
-
-double CartesianScale::start() const {
-	return m_interval.start();
-}
-
-double CartesianScale::end() const {
-	return m_interval.end();
-}
-
-bool CartesianScale::contains(double value) const {
-	return m_interval.contains(value);
-}
-
-/**
- * \class CartesianCoordinateSystem::LinearScale
- * \brief implementation of the linear scale for cartesian coordinate system.
- */
-class LinearScale : public CartesianScale {
-public:
-	LinearScale(const Interval<double> &interval, double offset, double gradient)
-		: CartesianScale(ScaleType::ScaleLinear, interval, offset, gradient, 0) {
-			Q_ASSERT(gradient != 0.0);
-
-		}
-
-	~LinearScale() override = default;
-
-	bool map(double *value) const override {
-		*value = *value * m_b + m_a;
-		return true;
-	}
-
-	bool inverseMap(double *value) const override {
-		if (m_b == 0.0)
-			return false;
-		*value = (*value - m_a) / m_b;
-		return true;
-	}
-
-	int direction() const override {
-		return m_b < 0 ? -1 : 1;
-	}
-};
-
-/**
- * \class CartesianCoordinateSystem::LinearScale
- * \brief implementation of the linear scale for cartesian coordinate system.
- */
-class LogScale : public CartesianScale {
-public:
-	LogScale(const Interval<double> &interval, double offset, double scaleFactor, double base, bool abs)
-		: CartesianScale(ScaleType::ScaleLog, interval, offset, scaleFactor, base), m_abs(abs) {
-			Q_ASSERT(scaleFactor != 0.0);
-			Q_ASSERT(base > 0.0);
-	}
-
-	~LogScale() override = default;
-
-	bool map(double *value) const override {
-		if (*value > 0.0)
-			*value = log(*value)/log(m_c) * m_b + m_a;
-		else if (m_abs)
-			*value = log(fabs(*value))/log(m_c) * m_b + m_a;
-		else
-			return false;
-
-		return true;
-	}
-
-	bool inverseMap(double *value) const override {
-		if (m_a == 0.0)
-			return false;
-		if (m_c <= 0.0)
-			return false;
-
-		*value = pow(m_c, (*value - m_a) / m_b);
-		return true;
-	}
-	int direction() const override {
-		return m_b < 0 ? -1 : 1;
-	}
-
-private:
-	bool m_abs;
-};
-
-/**
- * \class CartesianCoordinateSystem::SqrtScale
- * \brief implementation of a square-root scale for cartesian coordinate systems
- * y = TODO. a - offset, b - scaleFactor
- */
-class SqrtScale : public CartesianScale {
-public:
-	SqrtScale(const Interval<double> &range, double offset, double scaleFactor)
-		: CartesianScale(ScaleType::ScaleSqrt, range, offset, scaleFactor, 0) {
-			Q_ASSERT(scaleFactor != 0.0);
-	}
-
-	~SqrtScale() override = default;
-
-	bool map(double *value) const override {
-		*value = sqrt(qAbs(*value)) * m_b + m_a;
-		return true;
-	}
-
-	bool inverseMap(double *value) const override {
-		if (m_b == 0)
-			return false;
-
-		*value = gsl_pow_2((*value - m_a) / m_b);
-		return true;
-	}
-	int direction() const override {
-		return m_b < 0 ? -1 : 1;
-	}
-};
-
-/**
- * \class CartesianCoordinateSystem::SquareScale
- * \brief implementation of a square scale for cartesian coordinate systems
- * y = TODO. a - offset, b - scaleFactor
- */
-class SquareScale : public CartesianScale {
-public:
-	SquareScale(const Interval<double> &range, double offset, double scaleFactor)
-		: CartesianScale(ScaleType::ScaleSquare, range, offset, scaleFactor, 0) {
-			Q_ASSERT(scaleFactor != 0.0);
-	}
-
-	~SquareScale() override = default;
-
-	bool map(double *value) const override {
-		*value = gsl_pow_2(*value) * m_b + m_a;
-		return true;
-	}
-
-	bool inverseMap(double *value) const override {
-		if (m_b == 0)
-			return false;
-
-		*value = sqrt(qAbs((*value - m_a) / m_b));
-		return true;
-	}
-	int direction() const override {
-		return m_b < 0 ? -1 : 1;
-	}
-};
-
-
-
 /* ============================================================================ */
 /* ========================= coordinate system ================================ */
 /* ============================================================================ */
-//TODO: own header
-class CartesianCoordinateSystemPrivate {
-public:
-	explicit CartesianCoordinateSystemPrivate(CartesianCoordinateSystem *owner);
-	~CartesianCoordinateSystemPrivate();
-
-	CartesianCoordinateSystem* const q;
-	CartesianPlot* plot{nullptr};
-	QVector<CartesianScale*> xScales;
-	QVector<CartesianScale*> yScales;
-};
-
 /**
  * \class CartesianCoordinateSystem
  * \brief Cartesian coordinate system for plots.
@@ -241,84 +34,30 @@ CartesianCoordinateSystem::~CartesianCoordinateSystem() {
 	delete d;
 }
 
-CartesianScale* CartesianScale::createLinearScale(const Interval<double> &interval,
-		double sceneStart, double sceneEnd, double logicalStart, double logicalEnd) {
+QString CartesianCoordinateSystem::info() const {
+	DEBUG(Q_FUNC_INFO)
+	if (d->plot)
+		return QString(QLatin1String("x = ") + d->plot->xRange(d->xIndex).toString()
+				   + QLatin1String(", y = ") + d->plot->yRange(d->yIndex).toString());
 
-	double lDiff = logicalEnd - logicalStart;
-	if (lDiff == 0.0)
-		return nullptr;
-
-	double b = (sceneEnd - sceneStart) / lDiff;
-	double a = sceneStart - b * logicalStart;
-
-	return new LinearScale(interval, a, b);
+	return i18n("no info available");
 }
 
-CartesianScale* CartesianScale::createLogScale(const Interval<double> &interval,
-		double sceneStart, double sceneEnd, double logicalStart, double logicalEnd, CartesianPlot::Scale type) {
-
-	double base;
-	if (type == CartesianPlot::Scale::Log10 || type == CartesianPlot::Scale::Log10Abs)
-		base = 10.0;
-	else if (type == CartesianPlot::Scale::Log2 || type == CartesianPlot::Scale::Log2Abs)
-		base = 2.0;
-	else
-		base = M_E;
-
-
-	if (logicalStart <= 0.0 || logicalEnd <= 0.0)
-		return nullptr;
-
-	double lDiff = (log(logicalEnd) - log(logicalStart)) / log(base);
-	if (lDiff == 0.0)
-		return nullptr;
-
-	double b = (sceneEnd - sceneStart) / lDiff;
-	double a = sceneStart - b * log(logicalStart)/log(base);
-
-	bool abs = (type == CartesianPlot::Scale::Log10Abs || type == CartesianPlot::Scale::Log2Abs || type == CartesianPlot::Scale::LnAbs);
-	return new LogScale(interval, a, b, base, abs);
-}
-
-CartesianScale* CartesianScale::createSqrtScale(const Interval<double> &range,
-		double sceneStart, double sceneEnd, double logicalStart, double logicalEnd) {
-
-	if (logicalStart < 0.0 || logicalEnd < 0.0 || logicalStart == logicalEnd) {
-		DEBUG(Q_FUNC_INFO << ", WARNING: invalid range for sqrt scale : " << logicalStart << " .. " << logicalEnd)
-		return nullptr;
-	}
-
-	const double lDiff = sqrt(logicalEnd) - sqrt(logicalStart);
-	double b = (sceneEnd - sceneStart) / lDiff;
-	double a = sceneStart - b * sqrt(logicalStart);
-
-	return new SqrtScale(range, a, b);
-}
-
-CartesianScale* CartesianScale::createSquareScale(const Interval<double> &range,
-		double sceneStart, double sceneEnd, double logicalStart, double logicalEnd) {
-
-	const double lDiff = logicalEnd*logicalEnd - logicalStart*logicalStart;
-	double b = (sceneEnd - sceneStart) / lDiff;
-	double a = sceneStart - b * logicalStart*logicalStart;
-
-	return new SquareScale(range, a, b);
-}
-
-
 //##############################################################################
 //######################### logical to scene mappers ###########################
 //##############################################################################
-QVector<QPointF> CartesianCoordinateSystem::mapLogicalToScene(const QVector<QPointF>& points, MappingFlags flags) const {
+Points CartesianCoordinateSystem::mapLogicalToScene(const Points& points, MappingFlags flags) const {
 	//DEBUG(Q_FUNC_INFO << ", (points with flags)")
 	const QRectF pageRect = d->plot->dataRect();
-	bool noPageClipping = pageRect.isNull() || (flags & MappingFlag::SuppressPageClipping);
+	const bool noPageClipping = pageRect.isNull() || (flags & MappingFlag::SuppressPageClipping);
 	const bool noPageClippingY = flags & MappingFlag::SuppressPageClippingY;
 	const bool limit = flags & MappingFlag::Limit;
 	const double xPage = pageRect.x(), yPage = pageRect.y();
 	const double w = pageRect.width(), h = pageRect.height();
 
-	QVector<QPointF> result;
+	//DEBUG(Q_FUNC_INFO << ", xScales/YScales size: " << d->xScales.size() << '/' << d->yScales.size())
+
+	Points result;
 	result.reserve(points.size());
 	for (const auto* xScale : d->xScales) {
 		if (!xScale) continue;
@@ -361,9 +100,9 @@ QVector<QPointF> CartesianCoordinateSystem::mapLogicalToScene(const QVector<QPoi
 	@param visiblePoints List for the logical coordinates restricted to the current region of the coordinate system
 	@param flags
  */
-void CartesianCoordinateSystem::mapLogicalToScene(const QVector<QPointF>& logicalPoints,
-		QVector<QPointF>& scenePoints, std::vector<bool>& visiblePoints, MappingFlags flags) const {
-	DEBUG(Q_FUNC_INFO << ", (curve with all points)")
+void CartesianCoordinateSystem::mapLogicalToScene(const Points& logicalPoints,
+		Points& scenePoints, std::vector<bool>& visiblePoints, MappingFlags flags) const {
+	//DEBUG(Q_FUNC_INFO << ", (curve with all points)")
 	const QRectF pageRect = d->plot->dataRect();
 	const bool noPageClipping = pageRect.isNull() || (flags & MappingFlag::SuppressPageClipping);
 	const bool noPageClippingY = flags & MappingFlag::SuppressPageClippingY;
@@ -371,6 +110,8 @@ void CartesianCoordinateSystem::mapLogicalToScene(const QVector<QPointF>& logica
 	const double xPage = pageRect.x(), yPage = pageRect.y();
 	const double w = pageRect.width(), h = pageRect.height();
 
+	//DEBUG(Q_FUNC_INFO << ", xScales/YScales size: " << d->xScales.size() << '/' << d->yScales.size())
+
 	for (const auto* xScale : d->xScales) {
 		if (!xScale) continue;
 
@@ -397,8 +138,10 @@ void CartesianCoordinateSystem::mapLogicalToScene(const QVector<QPointF>& logica
 				const QPointF mappedPoint(x, y);
 				if (noPageClipping || limit || rectContainsPoint(pageRect, mappedPoint)) {
 					scenePoints.append(mappedPoint);
-					visiblePoints[i] = !visiblePoints.at(i);
-				}
+					visiblePoints[i] = true;
+				} else
+					visiblePoints[i] = false;
+
 				i++;
 			}
 		}
@@ -411,11 +154,10 @@ void CartesianCoordinateSystem::mapLogicalToScene(const QVector<QPointF>& logica
 	@param logicalPoints List of points in logical coordinates
 	@param scenePoints List for the points in scene coordinates
 	@param visiblePoints List for the logical coordinates restricted to the current region of the coordinate system
-	@param scenePointsUsed List of bools which scene point was already used
  */
-void CartesianCoordinateSystem::mapLogicalToScene(int startIndex, int endIndex, const QVector<QPointF>& logicalPoints, QVector<QPointF>& scenePoints,
-		QVector<bool>& visiblePoints, QVector<QVector<bool>>& scenePointsUsed, double minLogicalDiffX, double minLogicalDiffY, MappingFlags flags) const {
-	DEBUG(Q_FUNC_INFO << ", (curve points)")
+void CartesianCoordinateSystem::mapLogicalToScene(int startIndex, int endIndex, const Points& logicalPoints, Points& scenePoints,
+		std::vector<bool>& visiblePoints, MappingFlags flags) const {
+	//DEBUG(Q_FUNC_INFO << ", (curve points)")
 	const QRectF pageRect = d->plot->dataRect();
 	const bool noPageClipping = pageRect.isNull() || (flags & MappingFlag::SuppressPageClipping);
 	const bool noPageClippingY = flags & MappingFlag::SuppressPageClippingY;
@@ -423,13 +165,29 @@ void CartesianCoordinateSystem::mapLogicalToScene(int startIndex, int endIndex,
 	const double xPage = pageRect.x(), yPage = pageRect.y();
 	const double w = pageRect.width(), h = pageRect.height();
 
+	const int numberOfPixelX = pageRect.width();
+	const int numberOfPixelY = pageRect.height();
+
+	if (numberOfPixelX <= 0 || numberOfPixelY <= 0)
+		return;
+
+	// eliminate multiple scene points (size (numberOfPixelX + 1) * (numberOfPixelY + 1))
+	QVector<QVector<bool>> scenePointsUsed(numberOfPixelX + 1);
+	for (auto& col: scenePointsUsed)
+		col.resize(numberOfPixelY + 1);
+
+	const double minLogicalDiffX = pageRect.width()/numberOfPixelX;
+	const double minLogicalDiffY = pageRect.height()/numberOfPixelY;
+
+	//DEBUG(Q_FUNC_INFO << ", xScales/YScales size: " << d->xScales.size() << '/' << d->yScales.size())
+
 	for (const auto* xScale : d->xScales) {
 		if (!xScale) continue;
 
 		for (const auto* yScale : d->yScales) {
 			if (!yScale) continue;
 
-			for (int i = startIndex; i <= endIndex; ++i) {
+			for (int i = startIndex; i <= endIndex; i++) {
 				const QPointF& point = logicalPoints.at(i);
 
 				double x = point.x(), y = point.y();
@@ -453,15 +211,15 @@ void CartesianCoordinateSystem::mapLogicalToScene(int startIndex, int endIndex,
 					//TODO: check
 					const int indexX = qRound((x - xPage) / minLogicalDiffX);
 					const int indexY = qRound((y - yPage) / minLogicalDiffY);
-					//DEBUG()
 					if (scenePointsUsed.at(indexX).at(indexY))
 						continue;
 
 					scenePointsUsed[indexX][indexY] = true;
 					scenePoints.append(mappedPoint);
 					//DEBUG(mappedPoint.x() << ' ' << mappedPoint.y())
-					visiblePoints[i] = !visiblePoints.at(i);
-				}
+					visiblePoints[i] = true;
+				} else
+					visiblePoints[i] = false;
 			}
 		}
 	}
@@ -470,7 +228,7 @@ void CartesianCoordinateSystem::mapLogicalToScene(int startIndex, int endIndex,
 /*
  * Map a single point
  * */
-QPointF CartesianCoordinateSystem::mapLogicalToScene(QPointF logicalPoint, MappingFlags flags) const {
+QPointF CartesianCoordinateSystem::mapLogicalToScene(QPointF logicalPoint, bool& visible, MappingFlags flags) const {
 	//DEBUG(Q_FUNC_INFO << ", (single point)")
 	const QRectF pageRect = d->plot->dataRect();
 	const bool noPageClipping = pageRect.isNull() || (flags & MappingFlag::SuppressPageClipping);
@@ -481,6 +239,8 @@ QPointF CartesianCoordinateSystem::mapLogicalToScene(QPointF logicalPoint, Mappi
 	const double xPage = pageRect.x(), yPage = pageRect.y();
 	const double w = pageRect.width(), h = pageRect.height();
 
+	//DEBUG(Q_FUNC_INFO << ", xScales/YScales size: " << d->xScales.size() << '/' << d->yScales.size())
+
 	for (const auto* xScale : d->xScales) {
 		if (!xScale) continue;
 
@@ -502,23 +262,28 @@ QPointF CartesianCoordinateSystem::mapLogicalToScene(QPointF logicalPoint, Mappi
 				y = pageRect.y() + h/2.;
 
 			QPointF mappedPoint(x, y);
-			if (noPageClipping || limit || rectContainsPoint(pageRect, mappedPoint))
+			if (noPageClipping || limit || rectContainsPoint(pageRect, mappedPoint)) {
+				visible = true;
 				return mappedPoint;
+			}
 		}
 	}
 
+	visible = false;
 	return QPointF{};
 }
 
-QVector<QLineF> CartesianCoordinateSystem::mapLogicalToScene(const QVector<QLineF> &lines, MappingFlags flags) const {
+Lines CartesianCoordinateSystem::mapLogicalToScene(const Lines& lines, MappingFlags flags) const {
 	QRectF pageRect = d->plot->dataRect();
-	QVector<QLineF> result;
+	Lines result;
 	const bool doPageClipping = !pageRect.isNull() && !(flags & MappingFlag::SuppressPageClipping);
 
-	double xGapBefore = NAN;
-	double xGapAfter = NAN;
-	double yGapBefore = NAN;
-	double yGapAfter = NAN;
+	double xGapBefore;
+	double xGapAfter = qQNaN();
+	double yGapBefore;
+	double yGapAfter = qQNaN();
+
+	DEBUG(Q_FUNC_INFO << ", xScales/yScales size: " << d->xScales.size() << '/' << d->yScales.size())
 
  	QVectorIterator<CartesianScale *> xIterator(d->xScales);
 	while (xIterator.hasNext()) {
@@ -529,8 +294,8 @@ QVector<QLineF> CartesianCoordinateSystem::mapLogicalToScene(const QVector<QLine
 		if (xIterator.hasNext()) {
 			const CartesianScale* nextXScale = xIterator.peekNext();
 			if (!nextXScale) continue;
-			Interval<double> nextXInterval;
-			nextXScale->getProperties(nullptr, &nextXInterval);
+			Range<double> nextXRange;
+			nextXScale->getProperties(&nextXRange);
 
 			double x1 = xScale->end();
 			double x2 = nextXScale->start();
@@ -541,9 +306,9 @@ QVector<QLineF> CartesianCoordinateSystem::mapLogicalToScene(const QVector<QLine
 			if (valid)
 				xGapAfter = x2 - x1;
 			else
-				xGapAfter = NAN;
+				xGapAfter = qQNaN();
 		} else
-			xGapAfter = NAN;
+			xGapAfter = qQNaN();
 
 		QVectorIterator<CartesianScale*> yIterator(d->yScales);
 		while (yIterator.hasNext()) {
@@ -564,14 +329,15 @@ QVector<QLineF> CartesianCoordinateSystem::mapLogicalToScene(const QVector<QLine
 				if (valid)
 					yGapAfter = y2 - y1;
 				else
-					yGapAfter = NAN;
+					yGapAfter = qQNaN();
 			} else
-				yGapAfter = NAN;
+				yGapAfter = qQNaN();
 
 			const QRectF scaleRect = QRectF(xScale->start(), yScale->start(),
-								xScale->end() - xScale->start(), yScale->end() - yScale->start()).normalized();
+							xScale->end() - xScale->start(), yScale->end() - yScale->start()).normalized();
 
 			for (auto line : lines) {
+				// QDEBUG(Q_FUNC_INFO << ", LINE " << line)
 				LineClipResult clipResult;
 				if (!AbstractCoordinateSystem::clipLineToRect(&line, scaleRect, &clipResult))
 					continue;
@@ -652,10 +418,13 @@ QVector<QLineF> CartesianCoordinateSystem::mapLogicalToScene(const QVector<QLine
 
 				QLineF mappedLine(QPointF(x1, y1), QPointF(x2, y2));
 				if (doPageClipping) {
-					if (!AbstractCoordinateSystem::clipLineToRect(&mappedLine, pageRect))
+					if (!AbstractCoordinateSystem::clipLineToRect(&mappedLine, pageRect)) {
+						DEBUG(Q_FUNC_INFO << ", WARNING: OMIT mapped line!")
 						continue;
+					}
 				}
 
+//				QDEBUG(Q_FUNC_INFO << ", append line " << mappedLine)
 				result.append(mappedLine);
 			}
 		}
@@ -667,9 +436,9 @@ QVector<QLineF> CartesianCoordinateSystem::mapLogicalToScene(const QVector<QLine
 //##############################################################################
 //######################### scene to logical mappers ###########################
 //##############################################################################
-QVector<QPointF> CartesianCoordinateSystem::mapSceneToLogical(const QVector<QPointF>& points, MappingFlags flags) const {
+Points CartesianCoordinateSystem::mapSceneToLogical(const Points& points, MappingFlags flags) const {
 	QRectF pageRect = d->plot->dataRect();
-	QVector<QPointF> result;
+	Points result;
 	const bool noPageClipping = pageRect.isNull() || (flags & MappingFlag::SuppressPageClipping);
 	const bool limit = flags & MappingFlag::Limit;
 	const bool noPageClippingY = flags & MappingFlag::SuppressPageClippingY;
@@ -678,6 +447,7 @@ QVector<QPointF> CartesianCoordinateSystem::mapSceneToLogical(const QVector<QPoi
 	const double w = pageRect.width();
 	const double h = pageRect.height();
 
+	//DEBUG(Q_FUNC_INFO << ", xScales/YScales size: " << d->xScales.size() << '/' << d->yScales.size())
 
 	for (const auto& point : points) {
 		double x = point.x();
@@ -748,26 +518,24 @@ QPointF CartesianCoordinateSystem::mapSceneToLogical(QPointF logicalPoint, Mappi
 	if (noPageClippingY)
 		logicalPoint.setY(pageRect.y() + pageRect.height()/2.);
 
+	//DEBUG(Q_FUNC_INFO << ", xScales/YScales size: " << d->xScales.size() << '/' << d->yScales.size())
+
 	if (noPageClipping || limit || pageRect.contains(logicalPoint)) {
 		double x = logicalPoint.x();
 		double y = logicalPoint.y();
+		//DEBUG(Q_FUNC_INFO << ", x/y = " << x << " " << y)
 
 		for (const auto* xScale : d->xScales) {
-			if (!xScale) continue;
-
+			if (!xScale)
+				continue;
 			for (const auto* yScale : d->yScales) {
-				if (!yScale) continue;
-
-				if (!xScale->inverseMap(&x))
+				if (!yScale)
 					continue;
 
-				if (!yScale->inverseMap(&y))
+				if (!xScale->inverseMap(&x) || !yScale->inverseMap(&y))
 					continue;
 
-				if (!xScale->contains(x))
-					continue;
-
-				if (!yScale->contains(y))
+				if (!xScale->contains(x) || !yScale->contains(y))
 					continue;
 
 				result.setX(x);
@@ -789,8 +557,10 @@ QPointF CartesianCoordinateSystem::mapSceneToLogical(QPointF logicalPoint, Mappi
  * \return 1 or -1
  */
 int CartesianCoordinateSystem::xDirection() const {
-	if (d->xScales.isEmpty())
+	if (d->xScales.isEmpty() || !d->xScales.at(0)) {
+		DEBUG(Q_FUNC_INFO << ", WARNING: no x scale!")
 		return 1;
+	}
 
 	return d->xScales.at(0)->direction();
 }
@@ -802,14 +572,17 @@ int CartesianCoordinateSystem::xDirection() const {
  * \return 1 or -1
  */
 int CartesianCoordinateSystem::yDirection() const {
-	if (d->yScales.isEmpty())
+	if (d->yScales.isEmpty() || !d->yScales.at(0)) {
+		DEBUG(Q_FUNC_INFO << ", WARNING: no y scale!")
 		return 1;
+	}
 
 	return d->yScales.at(0)->direction();
 }
 
 // TODO: design elegant, flexible and undo-aware API for changing scales
 bool CartesianCoordinateSystem::setXScales(const QVector<CartesianScale *> &scales) {
+	DEBUG(Q_FUNC_INFO)
 	while (!d->xScales.isEmpty())
 		delete d->xScales.takeFirst();
 
@@ -818,10 +591,12 @@ bool CartesianCoordinateSystem::setXScales(const QVector<CartesianScale *> &scal
 }
 
 QVector<CartesianScale*> CartesianCoordinateSystem::xScales() const {
+	DEBUG(Q_FUNC_INFO)
 	return d->xScales; // TODO: should rather return a copy of the scales here
 }
 
 bool CartesianCoordinateSystem::setYScales(const QVector<CartesianScale*> &scales) {
+	DEBUG(Q_FUNC_INFO)
 	while (!d->yScales.isEmpty())
 		delete d->yScales.takeFirst();
 
@@ -830,9 +605,24 @@ bool CartesianCoordinateSystem::setYScales(const QVector<CartesianScale*> &scale
 }
 
 QVector<CartesianScale*> CartesianCoordinateSystem::yScales() const {
+	DEBUG(Q_FUNC_INFO)
 	return d->yScales; // TODO: should rather return a copy of the scales here
 }
 
+int CartesianCoordinateSystem::xIndex() const {
+	return d->xIndex;
+}
+void CartesianCoordinateSystem::setXIndex(int index) {
+	d->xIndex = index;
+}
+
+int CartesianCoordinateSystem::yIndex() const {
+	return d->yIndex;
+}
+void CartesianCoordinateSystem::setYIndex(int index) {
+	d->yIndex = index;
+}
+
 /*!
  * Adjusted the function QRectF::contains(QPointF) from Qt 4.8.4 to handle the
  * comparison of float numbers correctly.
