@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : XYAnalysisCurve.h
     Project              : LabPlot
     Description          : Base class for all analysis curves
     --------------------------------------------------------------------
-    Copyright            : (C) 2017-2018 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2018 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2017-2018 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2018-2022 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 /*!
   \class XYAnalysisCurve
@@ -37,8 +19,11 @@
 #include "XYAnalysisCurve.h"
 #include "XYAnalysisCurvePrivate.h"
 #include "backend/core/column/Column.h"
+#include "backend/core/Project.h"
 #include "backend/lib/commandtemplates.h"
 #include "backend/lib/macros.h"
+#include "backend/lib/XmlStreamReader.h"
+#include "backend/worksheet/plots/cartesian/Symbol.h"
 
 #include <KLocalizedString>
 #include <QDateTime>
@@ -62,22 +47,26 @@ XYAnalysisCurve::~XYAnalysisCurve() = default;
 void XYAnalysisCurve::init() {
 	Q_D(XYAnalysisCurve);
 	d->lineType = XYCurve::LineType::Line;
-	d->symbolsStyle = Symbol::Style::NoSymbols;
+	d->symbol->setStyle(Symbol::Style::NoSymbols);
 }
 
+// copy valid data from x/y data columns to x/y data vectors
+// for analysis functions
+// avgUniqueX: average y values for duplicate x values
 void XYAnalysisCurve::copyData(QVector<double>& xData, QVector<double>& yData,
-							   const AbstractColumn* xDataColumn, const AbstractColumn* yDataColumn,
-							   double xMin, double xMax) {
+		const AbstractColumn* xDataColumn, const AbstractColumn* yDataColumn,
+		double xMin, double xMax, bool avgUniqueX) {
 
-	int rowCount = qMin(xDataColumn->rowCount(), yDataColumn->rowCount());
+	const int rowCount = qMin(xDataColumn->rowCount(), yDataColumn->rowCount());
+	bool uniqueX = true;
 	for (int row = 0; row < rowCount; ++row) {
 		if (!xDataColumn->isValid(row) || xDataColumn->isMasked(row) ||
 				!yDataColumn->isValid(row) || yDataColumn->isMasked(row))
 			continue;
 
-		double x = NAN;
+		double x = qQNaN();
 		switch (xDataColumn->columnMode()) {
-		case AbstractColumn::ColumnMode::Numeric:
+		case AbstractColumn::ColumnMode::Double:
 			x = xDataColumn->valueAt(row);
 			break;
 		case AbstractColumn::ColumnMode::Integer:
@@ -94,9 +83,9 @@ void XYAnalysisCurve::copyData(QVector<double>& xData, QVector<double>& yData,
 			x = xDataColumn->dateTimeAt(row).toMSecsSinceEpoch();
 		}
 
-		double y = NAN;
+		double y = qQNaN();
 		switch (yDataColumn->columnMode()) {
-		case AbstractColumn::ColumnMode::Numeric:
+		case AbstractColumn::ColumnMode::Double:
 			y = yDataColumn->valueAt(row);
 			break;
 		case AbstractColumn::ColumnMode::Integer:
@@ -115,10 +104,51 @@ void XYAnalysisCurve::copyData(QVector<double>& xData, QVector<double>& yData,
 
 		// only when inside given range
 		if (x >= xMin && x <= xMax) {
+			if (xData.contains(x))
+				uniqueX = false;
 			xData.append(x);
 			yData.append(y);
 		}
 	}
+
+	if (uniqueX || !avgUniqueX)
+		return;
+
+	//for (int i = 0; i < xData.size(); i++)
+	//	WARN( xData.at(i) << " " << yData.at(i))
+
+	// average values for consecutive same x value
+	double oldX = qQNaN(), sum = 0.;
+	int count = 1;
+	for (int i = 0; i < xData.size(); i++) {
+		//WARN(" i = " << i)
+		const double x = xData.at(i);
+		const double y = yData.at(i);
+		//WARN(x << " / " << y << ": " << sum << " " << oldX  << " " << count)
+		if(x == oldX) {	// same x, but not last
+			//DEBUG(" same x")
+			sum += y;
+			count++;
+			if (i < xData.size() - 1) {
+				continue;
+			}
+		}
+
+		//WARN(" next/last x")
+		if (count > 1) {	// average and remove duplicate
+			//WARN("average: " << sum/count)
+			const int index = i - count + 1;
+			yData[index - 1] = sum/count;
+			//WARN("remove at " << index << ", count = " << count-1)
+			xData.remove(index, count - 1);
+			yData.remove(index, count - 1);
+
+			i -= count - 1;
+			count = 1;
+		}
+		sum = y;
+		oldX = x;
+	}
 }
 
 //##############################################################################
@@ -127,15 +157,21 @@ void XYAnalysisCurve::copyData(QVector<double>& xData, QVector<double>& yData,
 BASIC_SHARED_D_READER_IMPL(XYAnalysisCurve, XYAnalysisCurve::DataSourceType, dataSourceType, dataSourceType)
 BASIC_SHARED_D_READER_IMPL(XYAnalysisCurve, const XYCurve*, dataSourceCurve, dataSourceCurve)
 const QString& XYAnalysisCurve::dataSourceCurvePath() const {
-	return d_ptr->dataSourceCurvePath;
+	D(XYAnalysisCurve);
+	return d->dataSourceCurvePath;
 }
 
 BASIC_SHARED_D_READER_IMPL(XYAnalysisCurve, const AbstractColumn*, xDataColumn, xDataColumn)
 BASIC_SHARED_D_READER_IMPL(XYAnalysisCurve, const AbstractColumn*, yDataColumn, yDataColumn)
 BASIC_SHARED_D_READER_IMPL(XYAnalysisCurve, const AbstractColumn*, y2DataColumn, y2DataColumn)
-CLASS_SHARED_D_READER_IMPL(XYAnalysisCurve, QString, xDataColumnPath, xDataColumnPath)
-CLASS_SHARED_D_READER_IMPL(XYAnalysisCurve, QString, yDataColumnPath, yDataColumnPath)
-CLASS_SHARED_D_READER_IMPL(XYAnalysisCurve, QString, y2DataColumnPath, y2DataColumnPath)
+BASIC_SHARED_D_READER_IMPL(XYAnalysisCurve, QString, xDataColumnPath, xDataColumnPath)
+BASIC_SHARED_D_READER_IMPL(XYAnalysisCurve, QString, yDataColumnPath, yDataColumnPath)
+BASIC_SHARED_D_READER_IMPL(XYAnalysisCurve, QString, y2DataColumnPath, y2DataColumnPath)
+
+
+bool XYAnalysisCurve::saveCalculations() const {
+	return const_cast<XYAnalysisCurve*>(this)->project()->saveCalculations();
+}
 
 //##############################################################################
 //#################  setter methods and undo commands ##########################
@@ -245,7 +281,7 @@ void XYAnalysisCurve::setY2DataColumnPath(const QString& path) {
 void XYAnalysisCurve::handleSourceDataChanged() {
 	Q_D(XYAnalysisCurve);
 	d->sourceDataChangedSinceLastRecalc = true;
-	emit sourceDataChanged();
+	Q_EMIT sourceDataChanged();
 }
 
 void XYAnalysisCurve::xDataColumnAboutToBeRemoved(const AbstractAspect* aspect) {
