@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : XYAnalysisCurve.h
     Project              : LabPlot
     Description          : Base class for all analysis curves
     --------------------------------------------------------------------
-    Copyright            : (C) 2017 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2018 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2017-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2018-2022 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #ifndef XYANALYSISCURVE_H
 #define XYANALYSISCURVE_H
@@ -38,12 +20,17 @@ class XYAnalysisCurve : public XYCurve {
 	Q_OBJECT
 
 public:
-	enum class DataSourceType {Spreadsheet, Curve};
+	enum class DataSourceType {Spreadsheet, Curve, Histogram};
+	enum class AnalysisAction {DataReduction,
+		Differentiation, Integration, Interpolation, Smoothing,
+		FitLinear, FitPower, FitExp1, FitExp2, FitInvExp, FitGauss, FitCauchyLorentz, FitTan, FitTanh, FitErrFunc, FitCustom,
+		FourierFilter};
 
 	XYAnalysisCurve(const QString&, AspectType type);
 	~XYAnalysisCurve() override;
 
-	static void copyData(QVector<double>& xData, QVector<double>& yData, const AbstractColumn* xDataColumn, const AbstractColumn* yDataColumn, double xMin, double xMax);
+	static void copyData(QVector<double>& xData, QVector<double>& yData, const AbstractColumn* xDataColumn,
+				const AbstractColumn* yDataColumn, double xMin, double xMax, bool avgUniqueX = false);
 
 	virtual void recalculate() = 0;
 	void save(QXmlStreamWriter*) const override;
@@ -60,6 +47,8 @@ public:
 	CLASS_D_ACCESSOR_DECL(QString, yDataColumnPath, YDataColumnPath)
 	CLASS_D_ACCESSOR_DECL(QString, y2DataColumnPath, Y2DataColumnPath)
 
+	bool saveCalculations() const;
+
 	typedef XYAnalysisCurvePrivate Private;
 
 protected:
@@ -69,9 +58,9 @@ private:
 	Q_DECLARE_PRIVATE(XYAnalysisCurve)
 	void init();
 
-public slots:
+public Q_SLOTS:
 	void handleSourceDataChanged();
-private slots:
+private Q_SLOTS:
 	void xDataColumnAboutToBeRemoved(const AbstractAspect*);
 	void yDataColumnAboutToBeRemoved(const AbstractAspect*);
 	void y2DataColumnAboutToBeRemoved(const AbstractAspect*);
@@ -79,7 +68,7 @@ private slots:
 	void yDataColumnNameChanged();
 	void y2DataColumnNameChanged();
 
-signals:
+Q_SIGNALS:
 	void sourceDataChanged(); //emitted when the source data used in the analysis curves was changed to enable the recalculation in the dock widgets
 	void dataSourceTypeChanged(XYAnalysisCurve::DataSourceType);
 	void dataSourceCurveChanged(const XYCurve*);
