@@ -1,49 +1,35 @@
-/***************************************************************************
+/*
     File                 : XYCurve.h
     Project              : LabPlot
     Description          : A xy-curve
     --------------------------------------------------------------------
-    Copyright            : (C) 2010-2020 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2013 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2010-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2013-2020 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #ifndef XYCURVE_H
 #define XYCURVE_H
 
+#include "Curve.h"
 #include "backend/worksheet/WorksheetElement.h"
-#include "backend/worksheet/plots/cartesian/Curve.h"
-#include "backend/worksheet/plots/cartesian/Symbol.h"
-#include "backend/worksheet/plots/PlotArea.h"
+#include "backend/lib/Range.h"
 #include "backend/lib/macros.h"
-#include "backend/lib/macrosXYCurve.h"
-#include "backend/core/AbstractColumn.h"
 
 #include <QFont>
 #include <QPen>
 
+class AbstractColumn;
+class Symbol;
 class XYCurvePrivate;
 
-class XYCurve: public WorksheetElement, public Curve {
+#ifdef SDK
+#include "labplot_export.h"
+class LABPLOT_EXPORT XYCurve : public WorksheetElement, public Curve {
+#else
+class XYCurve : public WorksheetElement, public Curve {
+#endif
 	Q_OBJECT
 
 public:
@@ -67,7 +53,6 @@ public:
 	explicit XYCurve(const QString &name, AspectType type = AspectType::XYCurve);
 	~XYCurve() override;
 
-	void finalizeAdd() override;
 	QIcon icon() const override;
 	QMenu* createContextMenu() override;
 	QGraphicsItem* graphicsItem() const override;
@@ -77,9 +62,11 @@ public:
 	void saveThemeConfig(const KConfig&) override;
 	double y(double x, bool &valueFound) const;
 	QDateTime yDateTime(double x, bool &valueFound) const;
-	bool minMax(const AbstractColumn *column1, const AbstractColumn *column2, const ErrorType errorType, const AbstractColumn *errorPlusColumn, const AbstractColumn *errorMinusColumn, int indexMin, int indexMax, double& yMin, double& yMax, bool includeErrorBars) const;
-	bool minMaxX(int indexMin, int indexMax, double& yMin, double& yMax, bool includeErrorBars = true) const;
-	bool minMaxY(int indexMin, int indexMax, double& yMin, double& yMax, bool includeErrorBars = true) const;
+	bool minMax(const AbstractColumn *column1, const AbstractColumn *column2, const ErrorType errorType,
+			const AbstractColumn *errorPlusColumn, const AbstractColumn *errorMinusColumn,
+			const Range<int>& indexRange, Range<double>& yRange, bool includeErrorBars) const;
+	bool minMaxX(const Range<int>& indexRange, Range<double>& xRange, bool includeErrorBars = true) const;
+	bool minMaxY(const Range<int>& indexRange, Range<double>& yRange, bool includeErrorBars = true) const;
 
 	bool activateCurve(QPointF mouseScenePos, double maxDist = -1) override;
 	void setHover(bool on) override;
@@ -88,6 +75,7 @@ public:
 	POINTER_D_ACCESSOR_DECL(const AbstractColumn, yColumn, YColumn)
 	CLASS_D_ACCESSOR_DECL(QString, xColumnPath, XColumnPath)
 	CLASS_D_ACCESSOR_DECL(QString, yColumnPath, YColumnPath)
+	BASIC_D_ACCESSOR_DECL(bool, legendVisible, LegendVisible)
 
 	BASIC_D_ACCESSOR_DECL(LineType, lineType, LineType)
 	BASIC_D_ACCESSOR_DECL(bool, lineSkipGaps, LineSkipGaps)
@@ -96,17 +84,12 @@ public:
 	CLASS_D_ACCESSOR_DECL(QPen, linePen, LinePen)
 	BASIC_D_ACCESSOR_DECL(qreal, lineOpacity, LineOpacity)
 
+	Symbol* symbol() const;
+
 	BASIC_D_ACCESSOR_DECL(DropLineType, dropLineType, DropLineType)
 	CLASS_D_ACCESSOR_DECL(QPen, dropLinePen, DropLinePen)
 	BASIC_D_ACCESSOR_DECL(qreal, dropLineOpacity, DropLineOpacity)
 
-	BASIC_D_ACCESSOR_DECL(Symbol::Style, symbolsStyle, SymbolsStyle)
-	BASIC_D_ACCESSOR_DECL(qreal, symbolsOpacity, SymbolsOpacity)
-	BASIC_D_ACCESSOR_DECL(qreal, symbolsRotationAngle, SymbolsRotationAngle)
-	BASIC_D_ACCESSOR_DECL(qreal, symbolsSize, SymbolsSize)
-	CLASS_D_ACCESSOR_DECL(QBrush, symbolsBrush, SymbolsBrush)
-	CLASS_D_ACCESSOR_DECL(QPen, symbolsPen, SymbolsPen)
-
 	BASIC_D_ACCESSOR_DECL(ValuesType, valuesType, ValuesType)
 	POINTER_D_ACCESSOR_DECL(const AbstractColumn, valuesColumn, ValuesColumn)
 	CLASS_D_ACCESSOR_DECL(QString, valuesColumnPath, ValuesColumnPath)
@@ -123,9 +106,9 @@ public:
 	CLASS_D_ACCESSOR_DECL(QFont, valuesFont, ValuesFont)
 
 	BASIC_D_ACCESSOR_DECL(FillingPosition, fillingPosition, FillingPosition)
-	BASIC_D_ACCESSOR_DECL(PlotArea::BackgroundType, fillingType, FillingType)
-	BASIC_D_ACCESSOR_DECL(PlotArea::BackgroundColorStyle, fillingColorStyle, FillingColorStyle)
-	BASIC_D_ACCESSOR_DECL(PlotArea::BackgroundImageStyle, fillingImageStyle, FillingImageStyle)
+	BASIC_D_ACCESSOR_DECL(WorksheetElement::BackgroundType, fillingType, FillingType)
+	BASIC_D_ACCESSOR_DECL(WorksheetElement::BackgroundColorStyle, fillingColorStyle, FillingColorStyle)
+	BASIC_D_ACCESSOR_DECL(WorksheetElement::BackgroundImageStyle, fillingImageStyle, FillingImageStyle)
 	BASIC_D_ACCESSOR_DECL(Qt::BrushStyle, fillingBrushStyle, FillingBrushStyle)
 	CLASS_D_ACCESSOR_DECL(QColor, fillingFirstColor, FillingFirstColor)
 	CLASS_D_ACCESSOR_DECL(QColor, fillingSecondColor, FillingSecondColor)
@@ -148,9 +131,13 @@ public:
 	CLASS_D_ACCESSOR_DECL(QPen, errorBarsPen, ErrorBarsPen)
 	BASIC_D_ACCESSOR_DECL(qreal, errorBarsOpacity, ErrorBarsOpacity)
 
-	void setVisible(bool on) override;
-	bool isVisible() const override;
-	void setPrinting(bool on) override;
+	//margin plots
+	BASIC_D_ACCESSOR_DECL(bool, rugEnabled, RugEnabled)
+	BASIC_D_ACCESSOR_DECL(WorksheetElement::Orientation, rugOrientation, RugOrientation)
+	BASIC_D_ACCESSOR_DECL(double, rugOffset, RugOffset)
+	BASIC_D_ACCESSOR_DECL(double, rugLength, RugLength)
+	BASIC_D_ACCESSOR_DECL(double, rugWidth, RugWidth)
+
 	void suppressRetransform(bool);
 	bool isSourceDataChangedSinceLastRecalc() const;
 
@@ -159,8 +146,10 @@ public:
 	void retransform() override;
 	void recalcLogicalPoints();
 	void handleResize(double horizontalRatio, double verticalRatio, bool pageResize) override;
+	double y(double x, double &x_new, bool &valueFound) const;
+	int getNextValue(double xpos, int index, double& x, double& y, bool& valueFound) const;
 
-private slots:
+private Q_SLOTS:
 	void updateValues();
 	void updateErrorBars();
 	void xColumnAboutToBeRemoved(const AbstractAspect*);
@@ -178,30 +167,28 @@ private slots:
 	void yErrorMinusColumnNameChanged();
 	void valuesColumnNameChanged();
 	//SLOTs for changes triggered via QActions in the context menu
-	void visibilityChanged();
 	void navigateTo();
 
 protected:
 	XYCurve(const QString& name, XYCurvePrivate* dd, AspectType type);
-	XYCurvePrivate* const d_ptr;
 
 private:
 	Q_DECLARE_PRIVATE(XYCurve)
 	void init();
 	void initActions();
-	XYCURVE_COLUMN_CONNECT(x)
-	XYCURVE_COLUMN_CONNECT(y)
-	XYCURVE_COLUMN_CONNECT(xErrorPlus)
-	XYCURVE_COLUMN_CONNECT(xErrorMinus)
-	XYCURVE_COLUMN_CONNECT(yErrorPlus)
-	XYCURVE_COLUMN_CONNECT(yErrorMinus)
-	XYCURVE_COLUMN_CONNECT(values)
+	void connectxColumn(const AbstractColumn*);
+	void connectyColumn(const AbstractColumn*);
+	void connectxErrorPlusColumn(const AbstractColumn*);
+	void connectxErrorMinusColumn(const AbstractColumn*);
+	void connectyErrorPlusColumn(const AbstractColumn*);
+	void connectyErrorMinusColumn(const AbstractColumn*);
+	void connectvaluesColumn(const AbstractColumn*);
 
 	QAction* visibilityAction{nullptr};
 	QAction* navigateToAction{nullptr};
 	bool m_menusInitialized{false};
 
-signals:
+Q_SIGNALS:
 	//General-Tab
 	void dataChanged(); //emitted when the actual curve data to be plotted was changed to re-adjust the plot
 	void xDataChanged();
@@ -211,7 +198,8 @@ signals:
 	void yErrorPlusDataChanged();
 	void yErrorMinusDataChanged();
 	void valuesDataChanged();
-	void visibilityChanged(bool);
+	void legendVisibleChanged(bool);
+	void selected(double pos);
 
 	void xColumnChanged(const AbstractColumn*);
 	void yColumnChanged(const AbstractColumn*);
@@ -227,14 +215,6 @@ signals:
 	void dropLinePenChanged(const QPen&);
 	void dropLineOpacityChanged(qreal);
 
-	//Symbol-Tab
-	void symbolsStyleChanged(Symbol::Style);
-	void symbolsSizeChanged(qreal);
-	void symbolsRotationAngleChanged(qreal);
-	void symbolsOpacityChanged(qreal);
-	void symbolsBrushChanged(QBrush);
-	void symbolsPenChanged(const QPen&);
-
 	//Values-Tab
 	void valuesTypeChanged(XYCurve::ValuesType);
 	void valuesColumnChanged(const AbstractColumn*);
@@ -252,9 +232,9 @@ signals:
 
 	//Filling
 	void fillingPositionChanged(XYCurve::FillingPosition);
-	void fillingTypeChanged(PlotArea::BackgroundType);
-	void fillingColorStyleChanged(PlotArea::BackgroundColorStyle);
-	void fillingImageStyleChanged(PlotArea::BackgroundImageStyle);
+	void fillingTypeChanged(WorksheetElement::BackgroundType);
+	void fillingColorStyleChanged(WorksheetElement::BackgroundColorStyle);
+	void fillingImageStyleChanged(WorksheetElement::BackgroundImageStyle);
 	void fillingBrushStyleChanged(Qt::BrushStyle);
 	void fillingFirstColorChanged(QColor&);
 	void fillingSecondColorChanged(QColor&);
@@ -272,6 +252,13 @@ signals:
 	void errorBarsTypeChanged(XYCurve::ErrorBarsType);
 	void errorBarsPenChanged(QPen);
 	void errorBarsOpacityChanged(qreal);
+
+	//Margin Plots
+	void rugEnabledChanged(bool);
+	void rugOrientationChanged(WorksheetElement::Orientation);
+	void rugLengthChanged(double);
+	void rugWidthChanged(double);
+	void rugOffsetChanged(double);
 };
 
 #endif
