@@ -1,30 +1,12 @@
-/***************************************************************************
+/*
     File                 : XYEquationCurve.cpp
     Project              : LabPlot
     Description          : A xy-curve defined by a mathematical equation
     --------------------------------------------------------------------
-    Copyright            : (C) 2014-2017 Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2014-2017 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 /*!
   \class XYEquationCurve
@@ -38,7 +20,9 @@
 #include "backend/core/AbstractColumn.h"
 #include "backend/core/column/Column.h"
 #include "backend/lib/commandtemplates.h"
+#include "backend/lib/XmlStreamReader.h"
 #include "backend/gsl/ExpressionParser.h"
+#include "backend/worksheet/plots/cartesian/Symbol.h"
 
 #include <QIcon>
 #include <KLocalizedString>
@@ -70,7 +54,7 @@ void XYEquationCurve::init() {
 
 	//TODO: read from the saved settings for XYEquationCurve?
 	d->lineType = XYCurve::LineType::Line;
-	d->symbolsStyle = Symbol::Style::NoSymbols;
+	d->symbol->setStyle(Symbol::Style::NoSymbols);
 
 	setUndoAware(false);
 	suppressRetransform(true);
@@ -100,7 +84,7 @@ BASIC_SHARED_D_READER_IMPL(XYEquationCurve, XYEquationCurve::EquationData, equat
 //##############################################################################
 //#################  setter methods and undo commands ##########################
 //##############################################################################
-STD_SETTER_CMD_IMPL_F_S(XYEquationCurve, SetEquationData, XYEquationCurve::EquationData, equationData, recalculate);
+STD_SETTER_CMD_IMPL_F_S(XYEquationCurve, SetEquationData, XYEquationCurve::EquationData, equationData, recalculate)
 void XYEquationCurve::setEquationData(const XYEquationCurve::EquationData& equationData) {
 	Q_D(XYEquationCurve);
 	if ( (equationData.expression1 != d->equationData.expression1)
@@ -115,8 +99,8 @@ void XYEquationCurve::setEquationData(const XYEquationCurve::EquationData& equat
 //######################### Private implementation #############################
 //##############################################################################
 XYEquationCurvePrivate::XYEquationCurvePrivate(XYEquationCurve* owner) : XYCurvePrivate(owner),
-	xColumn(new Column("x", AbstractColumn::ColumnMode::Numeric)),
-	yColumn(new Column("y", AbstractColumn::ColumnMode::Numeric)),
+	xColumn(new Column("x", AbstractColumn::ColumnMode::Double)),
+	yColumn(new Column("y", AbstractColumn::ColumnMode::Double)),
 	xVector(static_cast<QVector<double>* >(xColumn->data())),
 	yVector(static_cast<QVector<double>* >(yColumn->data())),
 	q(owner)  {
@@ -138,9 +122,11 @@ void XYEquationCurvePrivate::recalculate() {
 			xVector->clear();
 			yVector->clear();
 			recalcLogicalPoints();
-			emit q->dataChanged();
+			Q_EMIT q->dataChanged();
 			return;
 		}
+		xColumn->invalidateProperties();
+		yColumn->invalidateProperties();
 	} else {
 		if (equationData.count < 1)
 			return;
@@ -164,9 +150,11 @@ void XYEquationCurvePrivate::recalculate() {
 		xVector->clear();
 		yVector->clear();
 	}
+	xColumn->invalidateProperties();
+	yColumn->invalidateProperties();
 
 	recalcLogicalPoints();
-	emit q->dataChanged();
+	Q_EMIT q->dataChanged();
 }
 
 //##############################################################################
@@ -186,7 +174,7 @@ void XYEquationCurve::save(QXmlStreamWriter* writer) const{
 	writer->writeAttribute( "type", QString::number(static_cast<int>(d->equationData.type)) );
 	writer->writeAttribute( "expression1", d->equationData.expression1 );
 	writer->writeAttribute( "expression2", d->equationData.expression2 );
-	writer->writeAttribute( "min", d->equationData.min);
+	writer->writeAttribute( "min", d->equationData.min );
 	writer->writeAttribute( "max", d->equationData.max );
 	writer->writeAttribute( "count", QString::number(d->equationData.count) );
 	writer->writeEndElement();
