@@ -1,32 +1,13 @@
-
-/***************************************************************************
+/*
     File                 : XYFitCurve.cpp
     Project              : LabPlot
     Description          : A xy-curve defined by a fit model
     --------------------------------------------------------------------
-    Copyright            : (C) 2014-2017 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2016-2020 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2014-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2016-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 /*!
   \class XYFitCurve
@@ -40,9 +21,11 @@
 #include "backend/core/AbstractColumn.h"
 #include "backend/core/column/Column.h"
 #include "backend/lib/commandtemplates.h"
+#include "backend/lib/XmlStreamReader.h"
 #include "backend/lib/macros.h"
 #include "backend/gsl/errors.h"
 #include "backend/gsl/ExpressionParser.h"
+#include "backend/worksheet/plots/cartesian/Histogram.h"
 
 extern "C" {
 #include <gsl/gsl_blas.h>
@@ -90,9 +73,9 @@ void XYFitCurve::initStartValues(const XYCurve* curve) {
 }
 
 void XYFitCurve::initStartValues(XYFitCurve::FitData& fitData, const XYCurve* curve) {
-	DEBUG("XYFitCurve::initStartValues()");
+	DEBUG(Q_FUNC_INFO);
 	if (!curve) {
-		DEBUG("	no curve given");
+		DEBUG(Q_FUNC_INFO << ", WARNING: no curve given");
 		return;
 	}
 
@@ -219,56 +202,56 @@ void XYFitCurve::initStartValues(XYFitCurve::FitData& fitData, const XYCurve* cu
 /*!
  * sets the parameter names for given model category, model type and degree in \c fitData for given action
  */
-void XYFitCurve::initFitData(PlotDataDialog::AnalysisAction action) {
+void XYFitCurve::initFitData(XYAnalysisCurve::AnalysisAction action) {
 	//TODO: exclude others too?
-	if (action == PlotDataDialog::AnalysisAction::DataReduction)
+	if (action == XYAnalysisCurve::AnalysisAction::DataReduction)
 		return;
 
 	Q_D(XYFitCurve);
 	XYFitCurve::FitData& fitData = d->fitData;
-	if (action == PlotDataDialog::AnalysisAction::FitLinear) {
+	if (action == XYAnalysisCurve::AnalysisAction::FitLinear) {
 		//Linear
 		fitData.modelCategory = nsl_fit_model_basic;
 		fitData.modelType = (int)nsl_fit_model_polynomial;
 		fitData.degree = 1;
-	} else if (action == PlotDataDialog::AnalysisAction::FitPower) {
+	} else if (action == XYAnalysisCurve::AnalysisAction::FitPower) {
 		//Power
 		fitData.modelCategory = nsl_fit_model_basic;
 		fitData.modelType = (int)nsl_fit_model_power;
 		fitData.degree = 1;
-	} else if (action == PlotDataDialog::AnalysisAction::FitExp1) {
+	} else if (action == XYAnalysisCurve::AnalysisAction::FitExp1) {
 		//Exponential (degree 1)
 		fitData.modelCategory = nsl_fit_model_basic;
 		fitData.modelType = (int)nsl_fit_model_exponential;
 		fitData.degree = 1;
-	} else if (action == PlotDataDialog::AnalysisAction::FitExp2) {
+	} else if (action == XYAnalysisCurve::AnalysisAction::FitExp2) {
 		//Exponential (degree 2)
 		fitData.modelCategory = nsl_fit_model_basic;
 		fitData.modelType = (int)nsl_fit_model_exponential;
 		fitData.degree = 2;
-	} else if (action == PlotDataDialog::AnalysisAction::FitInvExp) {
+	} else if (action == XYAnalysisCurve::AnalysisAction::FitInvExp) {
 		//Inverse exponential
 		fitData.modelCategory = nsl_fit_model_basic;
 		fitData.modelType = (int)nsl_fit_model_inverse_exponential;
-	} else if (action == PlotDataDialog::AnalysisAction::FitGauss) {
+	} else if (action == XYAnalysisCurve::AnalysisAction::FitGauss) {
 		//Gauss
 		fitData.modelCategory = nsl_fit_model_peak;
 		fitData.modelType = (int)nsl_fit_model_gaussian;
 		fitData.degree = 1;
-	} else if (action == PlotDataDialog::AnalysisAction::FitCauchyLorentz) {
+	} else if (action == XYAnalysisCurve::AnalysisAction::FitCauchyLorentz) {
 		//Cauchy-Lorentz
 		fitData.modelCategory = nsl_fit_model_peak;
 		fitData.modelType = (int)nsl_fit_model_lorentz;
 		fitData.degree = 1;
-	} else if (action == PlotDataDialog::AnalysisAction::FitTan) {
+	} else if (action == XYAnalysisCurve::AnalysisAction::FitTan) {
 		//Arc tangent
 		fitData.modelCategory = nsl_fit_model_growth;
 		fitData.modelType = (int)nsl_fit_model_atan;
-	} else if (action == PlotDataDialog::AnalysisAction::FitTanh) {
+	} else if (action == XYAnalysisCurve::AnalysisAction::FitTanh) {
 		//Hyperbolic tangent
 		fitData.modelCategory = nsl_fit_model_growth;
 		fitData.modelType = (int)nsl_fit_model_tanh;
-	} else if (action == PlotDataDialog::AnalysisAction::FitErrFunc) {
+	} else if (action == XYAnalysisCurve::AnalysisAction::FitErrFunc) {
 		//Error function
 		fitData.modelCategory = nsl_fit_model_growth;
 		fitData.modelType = (int)nsl_fit_model_erf;
@@ -471,7 +454,7 @@ void XYFitCurve::initFitData(XYFitCurve::FitData& fitData) {
 		case nsl_fit_model_pseudovoigt1:
 			switch (degree) {
 			case 1:
-				paramNames << "a" << "et" << "w" << "mu";	// eta function exists!
+				paramNames << "a" << "et" << "w" << "mu";	// eta already exists as function!
 				paramNamesUtf8 << "A" << UTF8_QSTRING("η") << "w" << UTF8_QSTRING("μ");
 				break;
 			default:
@@ -674,6 +657,12 @@ BASIC_SHARED_D_READER_IMPL(XYFitCurve, const AbstractColumn*, yErrorColumn, yErr
 const QString& XYFitCurve::xErrorColumnPath() const { Q_D(const XYFitCurve); return d->xErrorColumnPath; }
 const QString& XYFitCurve::yErrorColumnPath() const { Q_D(const XYFitCurve); return d->yErrorColumnPath; }
 
+BASIC_SHARED_D_READER_IMPL(XYFitCurve, const Histogram*, dataSourceHistogram, dataSourceHistogram)
+const QString& XYFitCurve::dataSourceHistogramPath() const {
+	Q_D(const XYFitCurve);
+	return d->dataSourceHistogramPath;
+}
+
 BASIC_SHARED_D_READER_IMPL(XYFitCurve, XYFitCurve::FitData, fitData, fitData)
 
 const XYFitCurve::FitResult& XYFitCurve::fitResult() const {
@@ -684,6 +673,18 @@ const XYFitCurve::FitResult& XYFitCurve::fitResult() const {
 //##############################################################################
 //#################  setter methods and undo commands ##########################
 //##############################################################################
+STD_SETTER_CMD_IMPL_F_S(XYFitCurve, SetDataSourceHistogram, const Histogram*, dataSourceHistogram, retransform)
+void XYFitCurve::setDataSourceHistogram(const Histogram* histogram) {
+	Q_D(XYFitCurve);
+	if (histogram != d->dataSourceHistogram) {
+		exec(new XYFitCurveSetDataSourceHistogramCmd(d, histogram, ki18n("%1: data source histogram changed")));
+		handleSourceDataChanged();
+
+		connect(histogram, &Histogram::dataChanged, this, &XYFitCurve::handleSourceDataChanged);
+// 		//TODO: add disconnect in the undo-function
+	}
+}
+
 STD_SETTER_CMD_IMPL_S(XYFitCurve, SetXErrorColumn, const AbstractColumn*, xErrorColumn)
 void XYFitCurve::setXErrorColumn(const AbstractColumn* column) {
 	Q_D(XYFitCurve);
@@ -749,7 +750,7 @@ struct data {
  * \param f vector with the weighted residuals weight[i]*(Yi - y[i])
  */
 int func_f(const gsl_vector* paramValues, void* params, gsl_vector* f) {
-	//DEBUG("func_f");
+	//DEBUG(Q_FUNC_INFO);
 	size_t n = ((struct data*)params)->n;
 	double* x = ((struct data*)params)->x;
 	double* y = ((struct data*)params)->y;
@@ -783,13 +784,16 @@ int func_f(const gsl_vector* paramValues, void* params, gsl_vector* f) {
 		}
 
 		assign_symbol("x", x[i]);
-		//DEBUG("evaluate function \"" << func << "\" @ x = " << x[i] << ":");
+		//DEBUG("evaluate function \"" << STDSTRING(func) << "\" @ x = " << x[i] << ":");
 		double Yi = parse(qPrintable(func), qPrintable(numberLocale.name()));
+		if (parse_errors() > 0)	// fallback to default locale
+			Yi = parse(qPrintable(func), "en_US");
 		//DEBUG("	f(x["<< i <<"]) = " << Yi);
 
 		if (parse_errors() > 0)
 			return GSL_EINVAL;
 
+		//DEBUG("	weight["<< i <<"]) = " << weight[i]);
 		gsl_vector_set(f, i, sqrt(weight[i]) * (Yi - y[i]));
 	}
 
@@ -803,7 +807,7 @@ int func_f(const gsl_vector* paramValues, void* params, gsl_vector* f) {
  * \param J Jacobian matrix
  * */
 int func_df(const gsl_vector* paramValues, void* params, gsl_matrix* J) {
-	//DEBUG("func_df");
+	//DEBUG(Q_FUNC_INFO);
 	const size_t n = ((struct data*)params)->n;
 	double* xVector = ((struct data*)params)->x;
 	double* weight = ((struct data*)params)->weight;
@@ -1007,10 +1011,10 @@ int func_df(const gsl_vector* paramValues, void* params, gsl_matrix* J) {
 					const double w = nsl_fit_map_bound(gsl_vector_get(paramValues, 4*j+2), min[4*j+2], max[4*j+2]);
 					const double mu = nsl_fit_map_bound(gsl_vector_get(paramValues, 4*j+3), min[4*j+3], max[4*j+3]);
 
-					gsl_matrix_set(J, (size_t)i, (size_t)(4*j), nsl_fit_model_voigt_param_deriv(0, x, a, eta, w, mu, weight[i]));
-					gsl_matrix_set(J, (size_t)i, (size_t)(4*j+1), nsl_fit_model_voigt_param_deriv(1, x, a, eta, w, mu, weight[i]));
-					gsl_matrix_set(J, (size_t)i, (size_t)(4*j+2), nsl_fit_model_voigt_param_deriv(2, x, a, eta, w, mu, weight[i]));
-					gsl_matrix_set(J, (size_t)i, (size_t)(4*j+3), nsl_fit_model_voigt_param_deriv(3, x, a, eta, w, mu, weight[i]));
+					gsl_matrix_set(J, (size_t)i, (size_t)(4*j), nsl_fit_model_pseudovoigt1_param_deriv(0, x, a, eta, w, mu, weight[i]));
+					gsl_matrix_set(J, (size_t)i, (size_t)(4*j+1), nsl_fit_model_pseudovoigt1_param_deriv(1, x, a, eta, w, mu, weight[i]));
+					gsl_matrix_set(J, (size_t)i, (size_t)(4*j+2), nsl_fit_model_pseudovoigt1_param_deriv(2, x, a, eta, w, mu, weight[i]));
+					gsl_matrix_set(J, (size_t)i, (size_t)(4*j+3), nsl_fit_model_pseudovoigt1_param_deriv(3, x, a, eta, w, mu, weight[i]));
 				}
 				for (unsigned int j = 0; j < 4*degree; j++)
 					if (fixed[j])
@@ -1482,14 +1486,18 @@ int func_df(const gsl_vector* paramValues, void* params, gsl_matrix* J) {
 
 				value = nsl_fit_map_bound(gsl_vector_get(paramValues, j), min[j], max[j]);
 				assign_symbol(qPrintable(paramNames->at(j)), value);
-				const double f_p = parse(qPrintable(func), qPrintable(numberLocale.name()));
+				double f_p = parse(qPrintable(func), qPrintable(numberLocale.name()));
+				if (parse_errors() > 0)	// fallback to default locale
+					f_p = parse(qPrintable(func), "en_US");
 
 				double eps = 1.e-9;
 				if (std::abs(f_p) > 0)
 					eps *= std::abs(f_p);	// scale step size with function value
 				value += eps;
 				assign_symbol(qPrintable(paramNames->at(j)), value);
-				const double f_pdp = parse(qPrintable(func), qPrintable(numberLocale.name()));
+				double f_pdp = parse(qPrintable(func), qPrintable(numberLocale.name()));
+				if (parse_errors() > 0)	// fallback to default locale
+					f_pdp = parse(qPrintable(func), "en_US");
 
 //				DEBUG("evaluate deriv"<<func<<": f(x["<<i<<"]) ="<<QString::number(f_p, 'g', 15));
 //				DEBUG("evaluate deriv"<<func<<": f(x["<<i<<"]+dx) ="<<QString::number(f_pdp, 'g', 15));
@@ -1507,7 +1515,7 @@ int func_df(const gsl_vector* paramValues, void* params, gsl_matrix* J) {
 }
 
 int func_fdf(const gsl_vector* x, void* params, gsl_vector* f, gsl_matrix* J) {
-	//DEBUG("func_fdf");
+	//DEBUG(Q_FUNC_INFO);
 	func_f(x, params, f);
 	func_df(x, params, J);
 
@@ -1516,13 +1524,13 @@ int func_fdf(const gsl_vector* x, void* params, gsl_vector* f, gsl_matrix* J) {
 
 /* prepare the fit result columns */
 void XYFitCurvePrivate::prepareResultColumns() {
-	DEBUG("XYFitCurvePrivate::prepareResultColumns()")
+	//DEBUG(Q_FUNC_INFO)
 	//create fit result columns if not available yet, clear them otherwise
 	if (!xColumn) {	// all columns are treated together
 		DEBUG("	Creating columns")
-		xColumn = new Column("x", AbstractColumn::ColumnMode::Numeric);
-		yColumn = new Column("y", AbstractColumn::ColumnMode::Numeric);
-		residualsColumn = new Column("residuals", AbstractColumn::ColumnMode::Numeric);
+		xColumn = new Column("x", AbstractColumn::ColumnMode::Double);
+		yColumn = new Column("y", AbstractColumn::ColumnMode::Double);
+		residualsColumn = new Column("residuals", AbstractColumn::ColumnMode::Double);
 		xVector = static_cast<QVector<double>* >(xColumn->data());
 		yVector = static_cast<QVector<double>* >(yColumn->data());
 		residualsVector = static_cast<QVector<double>* >(residualsColumn->data());
@@ -1533,6 +1541,7 @@ void XYFitCurvePrivate::prepareResultColumns() {
 		yColumn->setHidden(true);
 		q->addChild(yColumn);
 
+		residualsColumn->setFixed(true); //visible in the project explorer but cannot be modified (renamed, deleted, etc.)
 		q->addChild(residualsColumn);
 
 		q->setUndoAware(false);
@@ -1555,13 +1564,17 @@ void XYFitCurvePrivate::recalculate() {
 	const AbstractColumn* tmpXDataColumn = nullptr;
 	const AbstractColumn* tmpYDataColumn = nullptr;
 	if (dataSourceType == XYAnalysisCurve::DataSourceType::Spreadsheet) {
-		DEBUG(Q_FUNC_INFO << ", spreadsheet columns as data source");
+		DEBUG(Q_FUNC_INFO << ", SPREADSHEET columns as data source");
 		tmpXDataColumn = xDataColumn;
 		tmpYDataColumn = yDataColumn;
-	} else {
-		DEBUG(Q_FUNC_INFO << ", curve columns as data source");
+	} else if (dataSourceType == XYAnalysisCurve::DataSourceType::Curve) {
+		DEBUG(Q_FUNC_INFO << ", CURVE columns as data source");
 		tmpXDataColumn = dataSourceCurve->xColumn();
 		tmpYDataColumn = dataSourceCurve->yColumn();
+	} else {
+		DEBUG(Q_FUNC_INFO << ", HISTOGRAM columns as data source");
+		tmpXDataColumn = dataSourceHistogram->bins();
+		tmpYDataColumn = dataSourceHistogram->binValues();
 	}
 
 	// clear the previous result
@@ -1569,7 +1582,7 @@ void XYFitCurvePrivate::recalculate() {
 
 	if (!tmpXDataColumn || !tmpYDataColumn) {
 		DEBUG(Q_FUNC_INFO << ", ERROR: Preparing source data columns failed!");
-		emit q->dataChanged();
+		Q_EMIT q->dataChanged();
 		sourceDataChangedSinceLastRecalc = false;
 		return;
 	}
@@ -1581,10 +1594,11 @@ void XYFitCurvePrivate::recalculate() {
 	const double delta = fitData.eps;		//fit tolerance
 	const unsigned int np = fitData.paramNames.size(); //number of fit parameters
 	if (np == 0) {
+		DEBUG(Q_FUNC_INFO << ", WARNING: no parameter found.")
 		fitResult.available = true;
 		fitResult.valid = false;
 		fitResult.status = i18n("Model has no parameters.");
-		emit q->dataChanged();
+		Q_EMIT q->dataChanged();
 		sourceDataChangedSinceLastRecalc = false;
 		return;
 	}
@@ -1594,7 +1608,7 @@ void XYFitCurvePrivate::recalculate() {
 			fitResult.available = true;
 			fitResult.valid = false;
 			fitResult.status = i18n("Not sufficient weight data points provided.");
-			emit q->dataChanged();
+			Q_EMIT q->dataChanged();
 			sourceDataChangedSinceLastRecalc = false;
 			return;
 		}
@@ -1610,10 +1624,10 @@ void XYFitCurvePrivate::recalculate() {
 		fitData.fitRange = xRange;
 	} else { 			// custom x range of data to fit
 		if (!fitData.fitRange.isZero())  // avoid problems with user specified zero range
-			xRange.setRange(fitData.fitRange.min(), fitData.fitRange.max());
+			xRange.setRange(fitData.fitRange.start(), fitData.fitRange.end());
 	}
-	DEBUG(Q_FUNC_INFO << ", fit range = " << xRange.min() << " .. " << xRange.max());
-	DEBUG(Q_FUNC_INFO << ", fitData range = " << fitData.fitRange.min() << " .. " << fitData.fitRange.max());
+	DEBUG(Q_FUNC_INFO << ", fit range = " << xRange.start() << " .. " << xRange.end());
+	DEBUG(Q_FUNC_INFO << ", fitData range = " << fitData.fitRange.start() << " .. " << fitData.fitRange.end());
 
 	//logic from XYAnalysisCurve::copyData(), extended by the handling of error columns.
 	//TODO: decide how to deal with non-numerical error columns
@@ -1624,9 +1638,9 @@ void XYFitCurvePrivate::recalculate() {
 				!tmpYDataColumn->isValid(row) || tmpYDataColumn->isMasked(row))
 			continue;
 
-		double x = NAN;
+		double x = qQNaN();
 		switch (tmpXDataColumn->columnMode()) {
-		case AbstractColumn::ColumnMode::Numeric:
+		case AbstractColumn::ColumnMode::Double:
 			x = tmpXDataColumn->valueAt(row);
 			break;
 		case AbstractColumn::ColumnMode::Integer:
@@ -1643,9 +1657,9 @@ void XYFitCurvePrivate::recalculate() {
 			x = tmpXDataColumn->dateTimeAt(row).toMSecsSinceEpoch();
 		}
 
-		double y = NAN;
+		double y = qQNaN();
 		switch (tmpYDataColumn->columnMode()) {
-		case AbstractColumn::ColumnMode::Numeric:
+		case AbstractColumn::ColumnMode::Double:
 			y = tmpYDataColumn->valueAt(row);
 			break;
 		case AbstractColumn::ColumnMode::Integer:
@@ -1662,7 +1676,7 @@ void XYFitCurvePrivate::recalculate() {
 			y = tmpYDataColumn->dateTimeAt(row).toMSecsSinceEpoch();
 		}
 
-		if (x >= xRange.min() && x <= xRange.max()) {	// only when inside given range
+		if (x >= xRange.start() && x <= xRange.end()) {	// only when inside given range
 			if ((!xErrorColumn && !yErrorColumn) || !fitData.useDataErrors) {	// x-y
 				xdataVector.append(x);
 				ydataVector.append(y);
@@ -1683,6 +1697,8 @@ void XYFitCurvePrivate::recalculate() {
 		}
 	}
 
+	//QDEBUG(Q_FUNC_INFO << ", data: " << ydataVector)
+
 	//number of data points to fit
 	const size_t n = xdataVector.size();
 	DEBUG(Q_FUNC_INFO << ", number of data points: " << n);
@@ -1690,7 +1706,7 @@ void XYFitCurvePrivate::recalculate() {
 		fitResult.available = true;
 		fitResult.valid = false;
 		fitResult.status = i18n("No data points available.");
-		emit q->dataChanged();
+		Q_EMIT q->dataChanged();
 		sourceDataChangedSinceLastRecalc = false;
 		return;
 	}
@@ -1699,7 +1715,7 @@ void XYFitCurvePrivate::recalculate() {
 		fitResult.available = true;
 		fitResult.valid = false;
 		fitResult.status = i18n("The number of data points (%1) must be greater than or equal to the number of parameters (%2).", n, np);
-		emit q->dataChanged();
+		Q_EMIT q->dataChanged();
 		sourceDataChangedSinceLastRecalc = false;
 		return;
 	}
@@ -1708,7 +1724,7 @@ void XYFitCurvePrivate::recalculate() {
 		fitResult.available = true;
 		fitResult.valid = false;
 		fitResult.status = i18n("Fit model not specified.");
-		emit q->dataChanged();
+		Q_EMIT q->dataChanged();
 		sourceDataChangedSinceLastRecalc = false;
 		return;
 	}
@@ -2035,7 +2051,7 @@ void XYFitCurvePrivate::recalculate() {
 		xVector->resize(tmpXDataColumn->rowCount());
 		auto mode = tmpXDataColumn->columnMode();
 		for (int i = 0; i < tmpXDataColumn->rowCount(); i++)
-			if (mode == AbstractColumn::ColumnMode::Numeric)
+			if (mode == AbstractColumn::ColumnMode::Double)
 				(*xVector)[i] = tmpXDataColumn->valueAt(i);
 			else if (mode == AbstractColumn::ColumnMode::Integer)
 				(*xVector)[i] = tmpXDataColumn->integerAt(i);
@@ -2057,7 +2073,7 @@ void XYFitCurvePrivate::recalculate() {
 	} else {	// only selected range
 		size_t j = 0;
 		for (int i = 0; i < tmpXDataColumn->rowCount(); i++) {
-			if (tmpXDataColumn->valueAt(i) >= xRange.min() && tmpXDataColumn->valueAt(i) <= xRange.max())
+			if (tmpXDataColumn->valueAt(i) >= xRange.start() && tmpXDataColumn->valueAt(i) <= xRange.end())
 				residualsVector->data()[i] = - gsl_vector_get(s->f, j++);
 			else	// outside range
 				residualsVector->data()[i] = 0;
@@ -2085,16 +2101,20 @@ void XYFitCurvePrivate::evaluate(bool preview) {
 	if (dataSourceType == XYAnalysisCurve::DataSourceType::Spreadsheet) {
 		DEBUG(Q_FUNC_INFO << ", spreadsheet columns as data source");
 		tmpXDataColumn = xDataColumn;
-	} else {
+	} else if (dataSourceType == XYAnalysisCurve::DataSourceType::Curve) {
 		DEBUG(Q_FUNC_INFO << ", curve columns as data source");
 		if (dataSourceCurve)
 			tmpXDataColumn = dataSourceCurve->xColumn();
+	} else {
+		DEBUG(Q_FUNC_INFO << ", histogram as data source");
+		if (dataSourceHistogram)
+			tmpXDataColumn = dataSourceHistogram->bins();
 	}
 
 	if (!tmpXDataColumn) {
 		DEBUG("	ERROR: Preparing source data column failed!");
 		recalcLogicalPoints();
-		emit q->dataChanged();
+		Q_EMIT q->dataChanged();
 		return;
 	}
 
@@ -2106,14 +2126,14 @@ void XYFitCurvePrivate::evaluate(bool preview) {
 	if (!xVector || !yVector) {
 		DEBUG(Q_FUNC_INFO << ", xVector or yVector not defined!");
 		recalcLogicalPoints();
-		emit q->dataChanged();
+		Q_EMIT q->dataChanged();
 		return;
 	}
 
 	if (fitData.model.simplified().isEmpty()) {
 		DEBUG(Q_FUNC_INFO << ", no fit-model specified.");
 		recalcLogicalPoints();
-		emit q->dataChanged();
+		Q_EMIT q->dataChanged();
 		return;
 	}
 
@@ -2132,7 +2152,8 @@ void XYFitCurvePrivate::evaluate(bool preview) {
 	if (preview)	// results not available yet
 		paramValues = fitData.paramStartValues;
 
-	bool rc = parser->evaluateCartesian(fitData.model, QString::number(xRange.min()), QString::number(xRange.max()), (int)fitData.evaluatedPoints,
+	SET_NUMBER_LOCALE
+	bool rc = parser->evaluateCartesian(fitData.model, numberLocale.toString(xRange.start()), numberLocale.toString(xRange.end()), (int)fitData.evaluatedPoints,
 						xVector, yVector, fitData.paramNames, paramValues);
 	if (!rc) {
 		DEBUG(Q_FUNC_INFO << ", ERROR: Parsing fit function failed")
@@ -2142,7 +2163,7 @@ void XYFitCurvePrivate::evaluate(bool preview) {
 	}
 
 	recalcLogicalPoints();
-	emit q->dataChanged();
+	Q_EMIT q->dataChanged();
 }
 
 /*!
@@ -2161,7 +2182,7 @@ void XYFitCurvePrivate::writeSolverState(gsl_multifit_fdfsolver* s, double chi)
 	}
 
 	//current value of chi
-	if (isnan(chi))
+	if (std::isnan(chi))
 		chi = gsl_blas_dnrm2(s->f);
 	state += QString::number(chi*chi);
 	state += ';';
@@ -2189,9 +2210,10 @@ void XYFitCurve::save(QXmlStreamWriter* writer) const {
 	writer->writeStartElement("fitData");
 	WRITE_COLUMN(d->xErrorColumn, xErrorColumn);
 	WRITE_COLUMN(d->yErrorColumn, yErrorColumn);
+	WRITE_PATH(d->dataSourceHistogram, dataSourceHistogram);
 	writer->writeAttribute("autoRange", QString::number(d->fitData.autoRange));
-	writer->writeAttribute("fitRangeMin", QString::number(d->fitData.fitRange.min(), 'g', 15));
-	writer->writeAttribute("fitRangeMax", QString::number(d->fitData.fitRange.max(), 'g', 15));
+	writer->writeAttribute("fitRangeMin", QString::number(d->fitData.fitRange.start(), 'g', 15));
+	writer->writeAttribute("fitRangeMax", QString::number(d->fitData.fitRange.end(), 'g', 15));
 	writer->writeAttribute("modelCategory", QString::number(d->fitData.modelCategory));
 	writer->writeAttribute("modelType", QString::number(d->fitData.modelType));
 	writer->writeAttribute("xWeightsType", QString::number(d->fitData.xWeightsType));
@@ -2203,8 +2225,8 @@ void XYFitCurve::save(QXmlStreamWriter* writer) const {
 	writer->writeAttribute("eps", QString::number(d->fitData.eps, 'g', 15));
 	writer->writeAttribute("evaluatedPoints", QString::number(d->fitData.evaluatedPoints));
 	writer->writeAttribute("autoEvalRange", QString::number(d->fitData.autoEvalRange));
-	writer->writeAttribute("evalRangeMin", QString::number(d->fitData.evalRange.min(), 'g', 15));
-	writer->writeAttribute("evalRangeMax", QString::number(d->fitData.evalRange.max(), 'g', 15));
+	writer->writeAttribute("evalRangeMin", QString::number(d->fitData.evalRange.start(), 'g', 15));
+	writer->writeAttribute("evalRangeMax", QString::number(d->fitData.evalRange.end(), 'g', 15));
 	writer->writeAttribute("useDataErrors", QString::number(d->fitData.useDataErrors));
 	writer->writeAttribute("useResults", QString::number(d->fitData.useResults));
 	writer->writeAttribute("previewEnabled", QString::number(d->fitData.previewEnabled));
@@ -2296,7 +2318,7 @@ void XYFitCurve::save(QXmlStreamWriter* writer) const {
 	writer->writeEndElement();
 
 	//save calculated columns if available
-	if (d->xColumn && d->yColumn && d->residualsColumn) {
+	if (saveCalculations() && d->xColumn && d->yColumn && d->residualsColumn) {
 		d->xColumn->save(writer);
 		d->yColumn->save(writer);
 		d->residualsColumn->save(writer);
@@ -2312,7 +2334,7 @@ bool XYFitCurve::load(XmlStreamReader* reader, bool preview) {
 
 	KLocalizedString attributeWarning = ki18n("Attribute '%1' missing or empty, default value is used");
 	QXmlStreamAttributes attribs;
-	QString str;
+	QString str, model;
 
 	while (!reader->atEnd()) {
 		reader->readNext();
@@ -2330,29 +2352,31 @@ bool XYFitCurve::load(XmlStreamReader* reader, bool preview) {
 
 			READ_COLUMN(xErrorColumn);
 			READ_COLUMN(yErrorColumn);
+			READ_PATH(dataSourceHistogram);
 
 			READ_INT_VALUE("autoRange", fitData.autoRange, bool);
-			READ_DOUBLE_VALUE("xRangeMin", fitData.fitRange.min());	// old name
-			READ_DOUBLE_VALUE("xRangeMax", fitData.fitRange.max());	// old name
-			READ_DOUBLE_VALUE("fitRangeMin", fitData.fitRange.min());
-			READ_DOUBLE_VALUE("fitRangeMax", fitData.fitRange.max());
+			READ_DOUBLE_VALUE("xRangeMin", fitData.fitRange.start());	// old name
+			READ_DOUBLE_VALUE("xRangeMax", fitData.fitRange.end());	// old name
+			READ_DOUBLE_VALUE("fitRangeMin", fitData.fitRange.start());
+			READ_DOUBLE_VALUE("fitRangeMax", fitData.fitRange.end());
 			READ_INT_VALUE("modelCategory", fitData.modelCategory, nsl_fit_model_category);
 			READ_INT_VALUE("modelType", fitData.modelType, int);
 			READ_INT_VALUE("xWeightsType", fitData.xWeightsType, nsl_fit_weight_type);
 			READ_INT_VALUE("weightsType", fitData.yWeightsType, nsl_fit_weight_type);
 			READ_INT_VALUE("degree", fitData.degree, int);
-			if (d->fitData.modelCategory == nsl_fit_model_custom) {
-				READ_STRING_VALUE("model", fitData.model);
-				DEBUG("read model = " << STDSTRING(d->fitData.model));
-			}
+			// older projects have custom models with category == type == 0! So read the model
+			READ_STRING_VALUE("model", fitData.model);
+			model = d->fitData.model;
+			DEBUG("got model = " << STDSTRING(model));
+
 			READ_INT_VALUE("maxIterations", fitData.maxIterations, int);
 			READ_DOUBLE_VALUE("eps", fitData.eps);
 			READ_INT_VALUE("fittedPoints", fitData.evaluatedPoints, size_t);	// old name
 			READ_INT_VALUE("evaluatedPoints", fitData.evaluatedPoints, size_t);
 			READ_INT_VALUE("evaluateFullRange", fitData.autoEvalRange, bool);	// old name
 			READ_INT_VALUE("autoEvalRange", fitData.autoEvalRange, bool);
-			READ_DOUBLE_VALUE("evalRangeMin", fitData.evalRange.min());
-			READ_DOUBLE_VALUE("evalRangeMax", fitData.evalRange.max());
+			READ_DOUBLE_VALUE("evalRangeMin", fitData.evalRange.start());
+			READ_DOUBLE_VALUE("evalRangeMax", fitData.evalRange.end());
 			READ_INT_VALUE("useDataErrors", fitData.useDataErrors, bool);
 			READ_INT_VALUE("useResults", fitData.useResults, bool);
 			READ_INT_VALUE("previewEnabled", fitData.previewEnabled, bool);
@@ -2420,7 +2444,7 @@ bool XYFitCurve::load(XmlStreamReader* reader, bool preview) {
 			READ_DOUBLE_VALUE("bic", fitResult.bic);
 			READ_STRING_VALUE("solverOutput", fitResult.solverOutput);
 		} else if (reader->name() == "column") {
-			Column* column = new Column(QString(), AbstractColumn::ColumnMode::Numeric);
+			Column* column = new Column(QString(), AbstractColumn::ColumnMode::Double);
 			if (!column->load(reader, preview)) {
 				delete column;
 				return false;
@@ -2458,10 +2482,17 @@ bool XYFitCurve::load(XmlStreamReader* reader, bool preview) {
 	while (d->fitData.paramNames.size() > d->fitData.paramStartValues.size())
 		d->fitData.paramNames.removeLast();
 
-	// not present in old projects
+	// Utf8 names missing in old projects
 	if (d->fitData.paramNamesUtf8.isEmpty())
 		d->fitData.paramNamesUtf8 << d->fitData.paramNames;
 
+	// if we have more paramNames than the saved model type, we have a custom model
+	if (d->fitData.paramNamesUtf8.size() < d->fitData.paramNames.size()) {
+		d->fitData.modelCategory = nsl_fit_model_custom;
+		d->fitData.model = model;
+		d->fitData.paramNamesUtf8 = d->fitData.paramNames;
+	}
+
 	// not present in old projects
 	int np = d->fitResult.paramValues.size();
 	if (d->fitResult.tdist_tValues.size() == 0)
@@ -2471,9 +2502,10 @@ bool XYFitCurve::load(XmlStreamReader* reader, bool preview) {
 	if (d->fitResult.tdist_marginValues.size() == 0)
 		d->fitResult.tdist_marginValues.resize(np);
 	if (d->fitResult.correlationMatrix.size() == 0)
-		d->fitResult.correlationMatrix.resize(np*(np+1)/2);
+		d->fitResult.correlationMatrix.resize(np * (np + 1) / 2);
 
 	// Loading done. Check some parameter
+	DEBUG(Q_FUNC_INFO << ", model category = " << d->fitData.modelCategory);
 	DEBUG(Q_FUNC_INFO << ", model type = " << d->fitData.modelType);
 	DEBUG(Q_FUNC_INFO << ", # params = " << d->fitData.paramNames.size());
 	DEBUG(Q_FUNC_INFO << ", # start values = " << d->fitData.paramStartValues.size());
@@ -2499,8 +2531,8 @@ bool XYFitCurve::load(XmlStreamReader* reader, bool preview) {
 		d->yVector = static_cast<QVector<double>* >(d->yColumn->data());
 		d->residualsVector = static_cast<QVector<double>* >(d->residualsColumn->data());
 
-		XYCurve::d_ptr->xColumn = d->xColumn;
-		XYCurve::d_ptr->yColumn = d->yColumn;
+		static_cast<XYCurvePrivate*>(d_ptr)->xColumn = d->xColumn;
+		static_cast<XYCurvePrivate*>(d_ptr)->yColumn = d->yColumn;
 
 		recalcLogicalPoints();
 	}
