@@ -1,51 +1,38 @@
-/***************************************************************************
+/*
     File                 : XYFitCurve.h
     Project              : LabPlot
     Description          : A xy-curve defined by a fit model
     --------------------------------------------------------------------
-    Copyright            : (C) 2014-2017 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2016-2020 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2014-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2016-2020 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #ifndef XYFITCURVE_H
 #define XYFITCURVE_H
 
 #include "backend/lib/Range.h"
 #include "backend/worksheet/plots/cartesian/XYAnalysisCurve.h"
-#include "kdefrontend/spreadsheet/PlotDataDialog.h" //for PlotDataDialog::AnalysisAction. TODO: find a better place for this enum.
 
 extern "C" {
 #include "backend/nsl/nsl_fit.h"
 }
 
 class XYFitCurvePrivate;
+class Histogram;
 
+#ifdef SDK
+#include "labplot_export.h"
+class LABPLOT_EXPORT XYFitCurve : public XYAnalysisCurve {
+#else
 class XYFitCurve : public XYAnalysisCurve {
+#endif
 	Q_OBJECT
 
 public:
 	struct FitData {
-		FitData() {};
+		FitData() {}
 
 		nsl_fit_model_category modelCategory{nsl_fit_model_basic};
 		int modelType{0};
@@ -75,7 +62,7 @@ public:
 	};
 
 	struct FitResult {
-		FitResult() {};
+		FitResult() {}
 
 		bool available{false};
 		bool valid{false};
@@ -112,9 +99,12 @@ public:
 	explicit XYFitCurve(const QString& name);
 	~XYFitCurve() override;
 
+	POINTER_D_ACCESSOR_DECL(const Histogram, dataSourceHistogram, DataSourceHistogram)
+	const QString& dataSourceHistogramPath() const;
+
 	void recalculate() override;
 	void evaluate(bool preview);
-	void initFitData(PlotDataDialog::AnalysisAction);
+	void initFitData(XYAnalysisCurve::AnalysisAction);
 	static void initFitData(XYFitCurve::FitData&);
 	void initStartValues(const XYCurve*);
 	static void initStartValues(XYFitCurve::FitData&, const XYCurve*);
@@ -139,7 +129,8 @@ protected:
 private:
 	Q_DECLARE_PRIVATE(XYFitCurve)
 
-signals:
+Q_SIGNALS:
+	void dataSourceHistogramChanged(const Histogram*);
 	void xErrorColumnChanged(const AbstractColumn*);
 	void yErrorColumnChanged(const AbstractColumn*);
 	void fitDataChanged(const XYFitCurve::FitData&);
