@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : XYInterpolationCurve.cpp
     Project              : LabPlot
     Description          : A xy-curve defined by an interpolation
     --------------------------------------------------------------------
-    Copyright            : (C) 2016 Stefan Gerlach (stefan.gerlach@uni.kn)
-    Copyright            : (C) 2016-2017 Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2016-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-FileCopyrightText: 2016-2017 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 /*!
   \class XYInterpolationCurve
@@ -40,6 +22,7 @@
 #include "backend/core/column/Column.h"
 #include "backend/lib/commandtemplates.h"
 #include "backend/lib/macros.h"
+#include "backend/lib/XmlStreamReader.h"
 #include "backend/gsl/errors.h"
 
 extern "C" {
@@ -90,7 +73,7 @@ const XYInterpolationCurve::InterpolationResult& XYInterpolationCurve::interpola
 //##############################################################################
 //#################  setter methods and undo commands ##########################
 //##############################################################################
-STD_SETTER_CMD_IMPL_F_S(XYInterpolationCurve, SetInterpolationData, XYInterpolationCurve::InterpolationData, interpolationData, recalculate);
+STD_SETTER_CMD_IMPL_F_S(XYInterpolationCurve, SetInterpolationData, XYInterpolationCurve::InterpolationData, interpolationData, recalculate)
 void XYInterpolationCurve::setInterpolationData(const XYInterpolationCurve::InterpolationData& interpolationData) {
 	Q_D(XYInterpolationCurve);
 	exec(new XYInterpolationCurveSetInterpolationDataCmd(d, interpolationData, ki18n("%1: set options and perform the interpolation")));
@@ -112,8 +95,8 @@ void XYInterpolationCurvePrivate::recalculate() {
 
 	//create interpolation result columns if not available yet, clear them otherwise
 	if (!xColumn) {
-		xColumn = new Column("x", AbstractColumn::ColumnMode::Numeric);
-		yColumn = new Column("y", AbstractColumn::ColumnMode::Numeric);
+		xColumn = new Column("x", AbstractColumn::ColumnMode::Double);
+		yColumn = new Column("y", AbstractColumn::ColumnMode::Double);
 		xVector = static_cast<QVector<double>* >(xColumn->data());
 		yVector = static_cast<QVector<double>* >(yColumn->data());
 
@@ -138,18 +121,16 @@ void XYInterpolationCurvePrivate::recalculate() {
 	const AbstractColumn* tmpXDataColumn = nullptr;
 	const AbstractColumn* tmpYDataColumn = nullptr;
 	if (dataSourceType == XYAnalysisCurve::DataSourceType::Spreadsheet) {
-		//spreadsheet columns as data source
 		tmpXDataColumn = xDataColumn;
 		tmpYDataColumn = yDataColumn;
-	} else {
-		//curve columns as data source
+	} else { // curve columns as data source
 		tmpXDataColumn = dataSourceCurve->xColumn();
 		tmpYDataColumn = dataSourceCurve->yColumn();
 	}
 
 	if (!tmpXDataColumn || !tmpYDataColumn) {
 		recalcLogicalPoints();
-		emit q->dataChanged();
+		Q_EMIT q->dataChanged();
 		sourceDataChangedSinceLastRecalc = false;
 		return;
 	}
@@ -160,7 +141,7 @@ void XYInterpolationCurvePrivate::recalculate() {
 		interpolationResult.valid = false;
 		interpolationResult.status = i18n("Number of x and y data points must be equal.");
 		recalcLogicalPoints();
-		emit q->dataChanged();
+		Q_EMIT q->dataChanged();
 		sourceDataChangedSinceLastRecalc = false;
 		return;
 	}
@@ -169,9 +150,8 @@ void XYInterpolationCurvePrivate::recalculate() {
 	QVector<double> xdataVector;
 	QVector<double> ydataVector;
 
-	double xmin;
-	double xmax;
-	if (interpolationData.autoRange) {
+	double xmin, xmax;
+	if (interpolationData.autoRange) {	// all points
 		xmin = tmpXDataColumn->minimum();
 		xmax = tmpXDataColumn->maximum();
 	} else {
@@ -181,6 +161,18 @@ void XYInterpolationCurvePrivate::recalculate() {
 
 	XYAnalysisCurve::copyData(xdataVector, ydataVector, tmpXDataColumn, tmpYDataColumn, xmin, xmax);
 
+	// only use range of valid data points
+	const double validXMin = *std::min_element(xdataVector.constBegin(), xdataVector.constEnd());
+	const double validXMax = *std::max_element(xdataVector.constBegin(), xdataVector.constEnd());
+	if (interpolationData.autoRange) {
+		xmin = validXMin;
+		xmax = validXMax;
+	} else {
+		xmin = qMax(xmin, validXMin);
+		xmax = qMin(xmax, validXMax);
+	}
+	DEBUG(Q_FUNC_INFO << ", x range = " << xmin << " .. " << xmax)
+
 	//number of data points to interpolate
 	const size_t n = (size_t)xdataVector.size();
 	if (n < 2) {
@@ -188,7 +180,7 @@ void XYInterpolationCurvePrivate::recalculate() {
 		interpolationResult.valid = false;
 		interpolationResult.status = i18n("Not enough data points available.");
 		recalcLogicalPoints();
-		emit q->dataChanged();
+		Q_EMIT q->dataChanged();
 		sourceDataChangedSinceLastRecalc = false;
 		return;
 	}
@@ -196,6 +188,15 @@ void XYInterpolationCurvePrivate::recalculate() {
 	double* xdata = xdataVector.data();
 	double* ydata = ydataVector.data();
 
+	for(unsigned int i = 1; i < n; i++) {
+		if (xdata[i-1] >= xdata[i]) {
+			DEBUG("ERROR: x data not strictly increasing: x_{i-1} >= x_i @ i = " << i << ": " << xdata[i-1] << " >= " << xdata[i])
+			interpolationResult.status = i18n("interpolation failed since x data is not strictly monotonic increasing!");
+			interpolationResult.available = true;
+			return;
+		}
+	}
+
 	// interpolation settings
 	const nsl_interp_type type = interpolationData.type;
 	const nsl_interp_pch_variant variant = interpolationData.variant;
@@ -205,10 +206,11 @@ void XYInterpolationCurvePrivate::recalculate() {
 	const nsl_interp_evaluate evaluate = interpolationData.evaluate;
 	const size_t npoints = interpolationData.npoints;
 
-	DEBUG("type:"<<nsl_interp_type_name[type]);
-	DEBUG("cubic Hermite variant:"<<nsl_interp_pch_variant_name[variant]<<tension<<continuity<<bias);
-	DEBUG("evaluate:"<<nsl_interp_evaluate_name[evaluate]);
-	DEBUG("npoints ="<<npoints);
+	DEBUG(Q_FUNC_INFO << ", type = " << nsl_interp_type_name[type]);
+	DEBUG(Q_FUNC_INFO << ", cubic Hermite variant: " << nsl_interp_pch_variant_name[variant] << " (" << tension << continuity << bias << ")");
+	DEBUG(Q_FUNC_INFO << ", evaluate: " << nsl_interp_evaluate_name[evaluate]);
+	DEBUG(Q_FUNC_INFO << ", npoints = " << npoints);
+	DEBUG(Q_FUNC_INFO << ", data points = " << n);
 
 ///////////////////////////////////////////////////////////
 	int status = 0;
@@ -256,9 +258,9 @@ void XYInterpolationCurvePrivate::recalculate() {
 	xVector->resize((int)npoints);
 	yVector->resize((int)npoints);
 	for (unsigned int i = 0; i < npoints; i++) {
-		size_t a = 0, b = n-1;
+		size_t a = 0, b = n - 1;
 
-		double x = xmin + i*(xmax-xmin)/(npoints-1);
+		double x = xmin + i * (xmax - xmin) / (npoints - 1);
 		(*xVector)[(int)i] = x;
 
 		// find index a,b for interval [x[a],x[b]] around x[i] using bisection
@@ -416,7 +418,7 @@ void XYInterpolationCurvePrivate::recalculate() {
 
 	//redraw the curve
 	recalcLogicalPoints();
-	emit q->dataChanged();
+	Q_EMIT q->dataChanged();
 	sourceDataChangedSinceLastRecalc = false;
 }
 
@@ -456,7 +458,7 @@ void XYInterpolationCurve::save(QXmlStreamWriter* writer) const {
 	writer->writeAttribute( "time", QString::number(d->interpolationResult.elapsedTime) );
 
 	//save calculated columns if available
-	if (d->xColumn) {
+	if (saveCalculations() && d->xColumn) {
 		d->xColumn->save(writer);
 		d->yColumn->save(writer);
 	}
@@ -504,7 +506,7 @@ bool XYInterpolationCurve::load(XmlStreamReader* reader, bool preview) {
 			READ_STRING_VALUE("status", interpolationResult.status);
 			READ_INT_VALUE("time", interpolationResult.elapsedTime, int);
 		} else if (reader->name() == "column") {
-			Column* column = new Column(QString(), AbstractColumn::ColumnMode::Numeric);
+			Column* column = new Column(QString(), AbstractColumn::ColumnMode::Double);
 			if (!column->load(reader, preview)) {
 				delete column;
 				return false;
@@ -532,8 +534,8 @@ bool XYInterpolationCurve::load(XmlStreamReader* reader, bool preview) {
 		d->xVector = static_cast<QVector<double>* >(d->xColumn->data());
 		d->yVector = static_cast<QVector<double>* >(d->yColumn->data());
 
-		XYCurve::d_ptr->xColumn = d->xColumn;
-		XYCurve::d_ptr->yColumn = d->yColumn;
+		static_cast<XYCurvePrivate*>(d_ptr)->xColumn = d->xColumn;
+		static_cast<XYCurvePrivate*>(d_ptr)->yColumn = d->yColumn;
 
 		recalcLogicalPoints();
 	}
