@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : XYSmoothCurve.cpp
     Project              : LabPlot
     Description          : A xy-curve defined by a smooth
     --------------------------------------------------------------------
-    Copyright            : (C) 2016 Stefan Gerlach (stefan.gerlach@uni.kn)
-    Copyright            : (C) 2017 by Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2016 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 /*!
   \class XYSmoothCurve
@@ -39,6 +21,7 @@
 #include "backend/core/column/Column.h"
 #include "backend/lib/commandtemplates.h"
 #include "backend/lib/macros.h"
+#include "backend/lib/XmlStreamReader.h"
 
 #include <KLocalizedString>
 
@@ -89,7 +72,7 @@ const XYSmoothCurve::SmoothResult& XYSmoothCurve::smoothResult() const {
 //##############################################################################
 //#################  setter methods and undo commands ##########################
 //##############################################################################
-STD_SETTER_CMD_IMPL_F_S(XYSmoothCurve, SetSmoothData, XYSmoothCurve::SmoothData, smoothData, recalculate);
+STD_SETTER_CMD_IMPL_F_S(XYSmoothCurve, SetSmoothData, XYSmoothCurve::SmoothData, smoothData, recalculate)
 void XYSmoothCurve::setSmoothData(const XYSmoothCurve::SmoothData& smoothData) {
 	Q_D(XYSmoothCurve);
 	exec(new XYSmoothCurveSetSmoothDataCmd(d, smoothData, ki18n("%1: set options and perform the smooth")));
@@ -106,14 +89,14 @@ XYSmoothCurvePrivate::XYSmoothCurvePrivate(XYSmoothCurve* owner) : XYAnalysisCur
 XYSmoothCurvePrivate::~XYSmoothCurvePrivate() = default;
 
 void XYSmoothCurvePrivate::recalculate() {
-	DEBUG("XYSmoothCurvePrivate::recalculate()")
+	DEBUG(Q_FUNC_INFO)
 	QElapsedTimer timer;
 	timer.start();
 
 	//create smooth result columns if not available yet, clear them otherwise
 	if (!xColumn) {
-		xColumn = new Column("x", AbstractColumn::ColumnMode::Numeric);
-		yColumn = new Column("y", AbstractColumn::ColumnMode::Numeric);
+		xColumn = new Column("x", AbstractColumn::ColumnMode::Double);
+		yColumn = new Column("y", AbstractColumn::ColumnMode::Double);
 
 		xVector = static_cast<QVector<double>* >(xColumn->data());
 		yVector = static_cast<QVector<double>* >(yColumn->data());
@@ -136,7 +119,8 @@ void XYSmoothCurvePrivate::recalculate() {
 	}
 
 	if (!roughColumn) {
-		roughColumn = new Column("rough", AbstractColumn::ColumnMode::Numeric);
+		roughColumn = new Column("rough", AbstractColumn::ColumnMode::Double);
+		roughColumn->setFixed(true); //visible in the project explorer but cannot be modified (renamed, deleted, etc.)
 		roughVector = static_cast<QVector<double>* >(roughColumn->data());
 		q->addChild(roughColumn);
 	}
@@ -158,7 +142,7 @@ void XYSmoothCurvePrivate::recalculate() {
 	}
 
 	if (!tmpXDataColumn || !tmpYDataColumn) {
-		emit q->dataChanged();
+		Q_EMIT q->dataChanged();
 		sourceDataChangedSinceLastRecalc = false;
 		return;
 	}
@@ -169,7 +153,7 @@ void XYSmoothCurvePrivate::recalculate() {
 		smoothResult.valid = false;
 		smoothResult.status = i18n("Number of x and y data points must be equal.");
 		recalcLogicalPoints();
-		emit q->dataChanged();
+		Q_EMIT q->dataChanged();
 		sourceDataChangedSinceLastRecalc = false;
 		return;
 	}
@@ -197,7 +181,7 @@ void XYSmoothCurvePrivate::recalculate() {
 		smoothResult.valid = false;
 		smoothResult.status = i18n("Not enough data points available.");
 		recalcLogicalPoints();
-		emit q->dataChanged();
+		Q_EMIT q->dataChanged();
 		sourceDataChangedSinceLastRecalc = false;
 		return;
 	}
@@ -259,16 +243,18 @@ void XYSmoothCurvePrivate::recalculate() {
 	smoothResult.elapsedTime = timer.elapsed();
 
 	//fill rough vector
-	roughVector->resize((int)n);
-	for (int i = 0; i < (int)n; ++i)
-		roughVector->data()[i] = ydataOriginal[i] - ydata[i];
-	roughColumn->setChanged();
+	if (roughVector) {
+		roughVector->resize((int)n);
+		for (int i = 0; i < (int)n; ++i)
+			roughVector->data()[i] = ydataOriginal[i] - ydata[i];
+		roughColumn->setChanged();
+	}
 
 	delete [] ydataOriginal;
 
 	//redraw the curve
 	recalcLogicalPoints();
-	emit q->dataChanged();
+	Q_EMIT q->dataChanged();
 	sourceDataChangedSinceLastRecalc = false;
 }
 
@@ -308,7 +294,7 @@ void XYSmoothCurve::save(QXmlStreamWriter* writer) const{
 	writer->writeAttribute( "time", QString::number(d->smoothResult.elapsedTime) );
 
 	//save calculated columns if available
-	if (d->xColumn) {
+	if (saveCalculations() && d->xColumn) {
 		d->xColumn->save(writer);
 		d->yColumn->save(writer);
 	}
@@ -360,7 +346,7 @@ bool XYSmoothCurve::load(XmlStreamReader* reader, bool preview) {
 			READ_STRING_VALUE("status", smoothResult.status);
 			READ_INT_VALUE("time", smoothResult.elapsedTime, int);
 		} else if (!preview && reader->name() == "column") {
-			Column* column = new Column(QString(), AbstractColumn::ColumnMode::Numeric);
+			Column* column = new Column(QString(), AbstractColumn::ColumnMode::Double);
 			if (!column->load(reader, preview)) {
 				delete column;
 				return false;
@@ -390,8 +376,8 @@ bool XYSmoothCurve::load(XmlStreamReader* reader, bool preview) {
 		d->xVector = static_cast<QVector<double>* >(d->xColumn->data());
 		d->yVector = static_cast<QVector<double>* >(d->yColumn->data());
 
-		XYCurve::d_ptr->xColumn = d->xColumn;
-		XYCurve::d_ptr->yColumn = d->yColumn;
+		static_cast<XYCurvePrivate*>(d_ptr)->xColumn = d->xColumn;
+		static_cast<XYCurvePrivate*>(d_ptr)->yColumn = d->yColumn;
 
 		recalcLogicalPoints();
 	}
