@@ -1,33 +1,16 @@
-
-/***************************************************************************
+/*
     File                 : ProjectExplorer.cpp
     Project              : LabPlot
     Description       	 : A tree view for displaying and editing an AspectTreeModel.
     --------------------------------------------------------------------
-    Copyright            : (C) 2007-2008 by Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2010-2018 Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2007-2008 Tilman Benkert <thzs@gmx.net>
+    SPDX-FileCopyrightText: 2010-2021 Alexander Semke <alexander.semke@web.de>
 
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 #include "ProjectExplorer.h"
+#include "backend/core/column/Column.h"
 #include "backend/core/AspectTreeModel.h"
 #include "backend/core/AbstractPart.h"
 #include "backend/core/Project.h"
@@ -35,6 +18,7 @@
 #include "backend/worksheet/plots/cartesian/CartesianPlot.h"
 #include "commonfrontend/core/PartMdiView.h"
 
+#include <QClipboard>
 #include <QContextMenuEvent>
 #include <QDrag>
 #include <QHeaderView>
@@ -43,15 +27,23 @@
 #include <QMenu>
 #include <QMimeData>
 #include <QPushButton>
-#include <QToolButton>
 #include <QTreeView>
 #include <QVBoxLayout>
 
 #include <KConfig>
 #include <KConfigGroup>
-#include <KSharedConfig>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <KMessageWidget>
+#include <KSharedConfig>
+
+#include <kcoreaddons_version.h>
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 79, 0)
+#define HAS_FUZZY_MATCHER true
+#include <KFuzzyMatcher>
+#else
+#define HAS_FUZZY_MATCHER false
+#endif
 
 /*!
   \class ProjectExplorer
@@ -82,9 +74,10 @@ ProjectExplorer::ProjectExplorer(QWidget* parent) :
 	m_leFilter->setPlaceholderText(i18n("Search/Filter"));
 	layoutFilter->addWidget(m_leFilter);
 
-	bFilterOptions = new QToolButton(m_frameFilter);
+	bFilterOptions = new QPushButton(m_frameFilter);
 	bFilterOptions->setIcon(QIcon::fromTheme("configure"));
 	bFilterOptions->setCheckable(true);
+	bFilterOptions->setFlat(true);
 	layoutFilter->addWidget(bFilterOptions);
 
 	layout->addWidget(m_frameFilter);
@@ -104,8 +97,6 @@ ProjectExplorer::ProjectExplorer(QWidget* parent) :
 
 	layout->addWidget(m_treeView);
 
-	this->createActions();
-
 	connect(m_leFilter, &QLineEdit::textChanged, this, &ProjectExplorer::filterTextChanged);
 	connect(bFilterOptions, &QPushButton::toggled, this, &ProjectExplorer::toggleFilterOptionsMenu);
 }
@@ -125,16 +116,6 @@ ProjectExplorer::~ProjectExplorer() {
 }
 
 void ProjectExplorer::createActions() {
-	caseSensitiveAction = new QAction(i18n("Case Sensitive"), this);
-	caseSensitiveAction->setCheckable(true);
-	caseSensitiveAction->setChecked(false);
-	connect(caseSensitiveAction, &QAction::triggered, this, &ProjectExplorer::toggleFilterCaseSensitivity);
-
-	matchCompleteWordAction = new QAction(i18n("Match Complete Word"), this);
-	matchCompleteWordAction->setCheckable(true);
-	matchCompleteWordAction->setChecked(false);
-	connect(matchCompleteWordAction, &QAction::triggered, this, &ProjectExplorer::toggleFilterMatchCompleteWord);
-
 	expandTreeAction = new QAction(QIcon::fromTheme(QLatin1String("expand-all")), i18n("Expand All"), this);
 	connect(expandTreeAction, &QAction::triggered, m_treeView, &QTreeView::expandAll);
 
@@ -150,14 +131,10 @@ void ProjectExplorer::createActions() {
 	deleteSelectedTreeAction = new QAction(QIcon::fromTheme("edit-delete"), i18n("Delete Selected"), this);
 	connect(deleteSelectedTreeAction, &QAction::triggered, this, &ProjectExplorer::deleteSelected);
 
-	toggleFilterAction = new QAction(QIcon::fromTheme(QLatin1String("view-filter")), i18n("Hide Search/Filter Options"), this);
-	connect(toggleFilterAction, &QAction::triggered, this, &ProjectExplorer::toggleFilterWidgets);
-
-	showAllColumnsAction = new QAction(i18n("Show All"),this);
-	showAllColumnsAction->setCheckable(true);
-	showAllColumnsAction->setChecked(true);
-	showAllColumnsAction->setEnabled(false);
-	connect(showAllColumnsAction, &QAction::triggered, this, &ProjectExplorer::showAllColumns);
+	toggleFilterAction = new QAction(QIcon::fromTheme(QLatin1String("view-filter")), i18n("Search/Filter Options"), this);
+	toggleFilterAction->setCheckable(true);
+	toggleFilterAction->setChecked(true);
+	connect(toggleFilterAction, &QAction::triggered, this, [=]() {m_frameFilter->setVisible(!m_frameFilter->isVisible());});
 }
 
 /*!
@@ -168,40 +145,62 @@ void ProjectExplorer::contextMenuEvent(QContextMenuEvent *event) {
 	if (!m_treeView->model())
 		return;
 
-	const QModelIndex& index = m_treeView->indexAt(m_treeView->viewport()->mapFrom(this, event->pos()));
+	if (!expandTreeAction)
+		createActions();
+
+	const auto& index = m_treeView->indexAt(m_treeView->viewport()->mapFrom(this, event->pos()));
 	if (!index.isValid())
 		m_treeView->clearSelection();
 
-	const QModelIndexList& items = m_treeView->selectionModel()->selectedIndexes();
+	const auto& items = m_treeView->selectionModel()->selectedIndexes();
 	QMenu* menu = nullptr;
 	if (items.size()/4 == 1) {
 		auto* aspect = static_cast<AbstractAspect*>(index.internalPointer());
 		menu = aspect->createContextMenu();
+
+		if (aspect == m_project) {
+			auto* firstAction = menu->actions().at(2);
+			menu->insertSeparator(firstAction);
+			menu->insertAction(firstAction, expandTreeAction);
+			menu->insertAction(firstAction, collapseTreeAction);
+		}
 	} else {
 		menu = new QMenu();
 
-		QMenu* projectMenu = m_project->createContextMenu();
-		projectMenu->setTitle(m_project->name());
-		menu->addMenu(projectMenu);
-		menu->addSeparator();
-
 		if (items.size()/4 > 1) {
-			menu->addAction(expandSelectedTreeAction);
-			menu->addAction(collapseSelectedTreeAction);
-			menu->addSeparator();
+			//add "expand/collapse" entries if the selected indices have children
+			bool hasChildren = false;
+			for (int i = 0; i < items.size()/4; ++i) {
+				const auto& index = items.at(i*4);
+				const auto* aspect = static_cast<AbstractAspect*>(index.internalPointer());
+				if (aspect->childCount<AbstractAspect>()) {
+					hasChildren = true;
+					break;
+				}
+			}
+			if (hasChildren) {
+				menu->addAction(expandSelectedTreeAction);
+				menu->addAction(collapseSelectedTreeAction);
+				menu->addSeparator();
+			}
+
 			menu->addAction(deleteSelectedTreeAction);
-			menu->addSeparator();
 		} else {
+			QMenu* projectMenu = m_project->createContextMenu();
+			projectMenu->setTitle(m_project->name());
+			menu->addMenu(projectMenu);
+
+			menu->addSeparator();
 			menu->addAction(expandTreeAction);
 			menu->addAction(collapseTreeAction);
 			menu->addSeparator();
 			menu->addAction(toggleFilterAction);
 
 			//Menu for showing/hiding the columns in the tree view
-			QMenu* columnsMenu = menu->addMenu(i18n("Show/Hide columns"));
+			QMenu* columnsMenu = menu->addMenu(i18n("Columns"));
 			columnsMenu->addAction(showAllColumnsAction);
 			columnsMenu->addSeparator();
-			for (auto* action : list_showColumnActions)
+			for (auto* action : qAsConst(list_showColumnActions))
 				columnsMenu->addAction(action);
 
 			//TODO
@@ -223,9 +222,14 @@ void ProjectExplorer::setCurrentAspect(const AbstractAspect* aspect) {
 	if (m_project->aspectAddedSignalSuppressed())
 		return;
 
-	const AspectTreeModel* tree_model = qobject_cast<AspectTreeModel*>(m_treeView->model());
-	if (tree_model)
-		m_treeView->setCurrentIndex(tree_model->modelIndexOfAspect(aspect));
+	const auto* tree_model = dynamic_cast<AspectTreeModel*>(m_treeView->model());
+	if (tree_model) {
+		const auto& index = tree_model->modelIndexOfAspect(aspect);
+//TODO: This crashes on Windows in Debug mode
+#if !defined(HAVE_WINDOWS) || defined(NDEBUG)
+		m_treeView->setCurrentIndex(index);
+#endif
+	}
 }
 
 /*!
@@ -240,7 +244,6 @@ void ProjectExplorer::setModel(AspectTreeModel* treeModel) {
 	connect(treeModel, &AspectTreeModel::indexDeselected, this, &ProjectExplorer::deselectIndex);
 	connect(treeModel, &AspectTreeModel::hiddenAspectSelected, this, &ProjectExplorer::hiddenAspectSelected);
 
-	connect(m_treeView->selectionModel(), &QItemSelectionModel::currentChanged, this, &ProjectExplorer::currentChanged);
 	connect(m_treeView->selectionModel(), &QItemSelectionModel::selectionChanged, this, &ProjectExplorer::selectionChanged);
 
 	//create action for showing/hiding the columns in the tree.
@@ -256,6 +259,14 @@ void ProjectExplorer::setModel(AspectTreeModel* treeModel) {
 				checkedActions << strList.at(i).toInt();
 		}
 
+		if (!showAllColumnsAction) {
+			showAllColumnsAction = new QAction(i18n("Show All"),this);
+			showAllColumnsAction->setCheckable(true);
+			showAllColumnsAction->setChecked(true);
+			showAllColumnsAction->setEnabled(false);
+			connect(showAllColumnsAction, &QAction::triggered, this, &ProjectExplorer::showAllColumns);
+		}
+
 		if (checkedActions.size() != m_treeView->model()->columnCount()) {
 			showAllColumnsAction->setEnabled(true);
 			showAllColumnsAction->setChecked(false);
@@ -296,7 +307,6 @@ void ProjectExplorer::setProject(Project* project) {
 	connect(project, &Project::requestSaveState, this, &ProjectExplorer::save);
 	connect(project, &Project::requestLoadState, this, &ProjectExplorer::load);
 	connect(project, &Project::requestNavigateTo, this, &ProjectExplorer::navigateTo);
-	connect(project, &Project::loaded, this, &ProjectExplorer::projectLoaded);
 	m_project = project;
 
 	//for newly created projects, resize the header to fit the size of the header section names.
@@ -309,6 +319,12 @@ QModelIndex ProjectExplorer::currentIndex() const {
 	return m_treeView->currentIndex();
 }
 
+AbstractAspect* ProjectExplorer::currentAspect() const {
+	if (!currentIndex().isValid())
+		return nullptr;
+	return static_cast<AbstractAspect*>(currentIndex().internalPointer());
+}
+
 void ProjectExplorer::search() {
 	m_leFilter->setFocus();
 }
@@ -324,7 +340,7 @@ bool ProjectExplorer::eventFilter(QObject* obj, QEvent* event) {
 		columnsMenu->addSection(i18n("Columns"));
 		columnsMenu->addAction(showAllColumnsAction);
 		columnsMenu->addSeparator();
-		for (auto* action : list_showColumnActions)
+		for (auto* action : qAsConst(list_showColumnActions))
 			columnsMenu->addAction(action);
 
 		auto* e = static_cast<QContextMenuEvent*>(event);
@@ -438,9 +454,13 @@ bool ProjectExplorer::eventFilter(QObject* obj, QEvent* event) {
 			if (!index.isValid())
 				return false;
 
-			//process the droped objects
+			//process the dropped objects
 			auto* aspect = static_cast<AbstractAspect*>(index.internalPointer());
 			aspect->processDropEvent(vec);
+
+			//expand the current aspect to see the dropped objects
+			const auto* model = static_cast<const AspectTreeModel*>(m_treeView->model());
+			m_treeView->setExpanded(model->modelIndexOfAspect(aspect), true);
 		}
 	}
 
@@ -448,31 +468,78 @@ bool ProjectExplorer::eventFilter(QObject* obj, QEvent* event) {
 }
 
 void ProjectExplorer::keyPressEvent(QKeyEvent* event) {
+	//current selected aspect
+	auto* aspect = static_cast<AbstractAspect*>(m_treeView->currentIndex().internalPointer());
+
 	if (event->matches(QKeySequence::Delete))
 		deleteSelected();
-	else if (event->key() == 32) {
-		auto* aspect = static_cast<AbstractAspect*>(m_treeView->currentIndex().internalPointer());
+	else if (event->matches(QKeySequence::Copy)) {
+		//copy
+		if (aspect != m_project) {
+			aspect->copy();
+			showErrorMessage(QString());
+		}
+	} else if (event->matches(QKeySequence::Paste)) {
+		//paste
+		QString name;
+		if (!name.isEmpty()) {
+			auto t = AbstractAspect::clipboardAspectType(name);
+			if (t != AspectType::AbstractAspect && aspect->pasteTypes().indexOf(t) != -1) {
+				aspect->paste();
+				showErrorMessage(QString());
+			} else {
+				QString msg = i18n("The data cannot be pasted into %2.", name, aspect->name());
+				showErrorMessage(msg);
+			}
+		} else {
+			//no name is available, we are copy&pasting the content of a columm ("the data") and not the column itself
+			const QMimeData* mimeData = QApplication::clipboard()->mimeData();
+			if (!mimeData->hasFormat("text/plain"))
+				return;
+
+			//pasting is allowed into spreadsheet columns only
+			if (aspect->type() == AspectType::Column || aspect->parentAspect()->type() == AspectType::Spreadsheet) {
+				auto* column = static_cast<Column*>(aspect);
+				column->pasteData();
+			} else {
+				QString msg = i18n("Data cannot be pasted into %2 directly. Select a spreadsheet column for this.", name, aspect->name());
+				showErrorMessage(msg);
+			}
+		}
+
+	} else if ( (event->modifiers() & Qt::ControlModifier) && (event->key() == Qt::Key_D)) {
+		//duplicate
+		if (aspect != m_project) {
+			aspect->copy();
+			aspect->parentAspect()->paste(true);
+			showErrorMessage(QString());
+		}
+	} else if (event->key() == 32) {
+		//space key - hide/show the current object
 		auto* we = dynamic_cast<WorksheetElement*>(aspect);
 		if (we)
 			we->setVisible(!we->isVisible());
 	}
 }
 
+void ProjectExplorer::showErrorMessage(const QString& message) {
+	if (message.isEmpty()) {
+		if (m_messageWidget && m_messageWidget->isVisible())
+			m_messageWidget->close();
+	} else {
+		if (!m_messageWidget) {
+			m_messageWidget = new KMessageWidget(this);
+			m_messageWidget->setMessageType(KMessageWidget::Error);
+			layout()->addWidget(m_messageWidget);
+		}
+		m_messageWidget->setText(message);
+		m_messageWidget->animatedShow();
+	}
+}
+
 //##############################################################################
 //#################################  SLOTS  ####################################
 //##############################################################################
-/*!
- * called after the project was loaded.
- * resize the header of the view to adjust to the content
- * and re-select the currently selected object to show
- * its final properties in the dock widget after in Project::load() all
- * pointers were restored, relative paths replaced by absolute, etc.
- */
-void ProjectExplorer::projectLoaded() {
-	resizeHeader();
-	selectionChanged(m_treeView->selectionModel()->selection(), QItemSelection());
-}
-
 /*!
   expand the aspect \c aspect (the tree index corresponding to it) in the tree view
   and makes it visible and selected. Called when a new aspect is added to the project.
@@ -488,11 +555,11 @@ void ProjectExplorer::aspectAdded(const AbstractAspect* aspect) {
 
 	//don't do anything for newly added data spreadsheets of data picker curves
 	if (aspect->inherits(AspectType::Spreadsheet) &&
-	    aspect->parentAspect()->inherits(AspectType::DatapickerCurve))
+		aspect->parentAspect()->inherits(AspectType::DatapickerCurve))
 		return;
 
-	const AspectTreeModel* tree_model = qobject_cast<AspectTreeModel*>(m_treeView->model());
-	const QModelIndex& index =  tree_model->modelIndexOfAspect(aspect);
+	const auto* tree_model = qobject_cast<AspectTreeModel*>(m_treeView->model());
+	const auto& index =  tree_model->modelIndexOfAspect(aspect);
 
 	//expand and make the aspect visible
 	m_treeView->setExpanded(index, true);
@@ -510,9 +577,11 @@ void ProjectExplorer::aspectAdded(const AbstractAspect* aspect) {
 }
 
 void ProjectExplorer::navigateTo(const QString& path) {
-	const AspectTreeModel* tree_model = qobject_cast<AspectTreeModel*>(m_treeView->model());
+	const auto* tree_model = dynamic_cast<AspectTreeModel*>(m_treeView->model());
 	if (tree_model) {
-		const QModelIndex& index = tree_model->modelIndexOfAspect(path);
+		const auto& index = tree_model->modelIndexOfAspect(path);
+		if (!index.isValid())
+			return;
 		m_treeView->scrollTo(index);
 		m_treeView->setCurrentIndex(index);
 		auto* aspect = static_cast<AbstractAspect*>(index.internalPointer());
@@ -520,18 +589,10 @@ void ProjectExplorer::navigateTo(const QString& path) {
 	}
 }
 
-void ProjectExplorer::currentChanged(const QModelIndex & current, const QModelIndex & previous) {
-	if (m_project->isLoading())
-		return;
-
-	Q_UNUSED(previous);
-	emit currentAspectChanged(static_cast<AbstractAspect*>(current.internalPointer()));
-}
-
 void ProjectExplorer::toggleColumn(int index) {
 	//determine the total number of checked column actions
 	int checked = 0;
-	for (const auto* action : list_showColumnActions) {
+	for (const auto* action : qAsConst(list_showColumnActions)) {
 		if (action->isChecked())
 			checked++;
 	}
@@ -541,7 +602,7 @@ void ProjectExplorer::toggleColumn(int index) {
 		m_treeView->header()->resizeSection(0,0 );
 		m_treeView->header()->resizeSections(QHeaderView::ResizeToContents);
 
-		for (auto* action : list_showColumnActions)
+		for (auto* action : qAsConst(list_showColumnActions))
 			action->setEnabled(true);
 
 		//deactivate the "show all column"-action, if all actions are checked
@@ -574,31 +635,51 @@ void ProjectExplorer::showAllColumns() {
 	}
 	showAllColumnsAction->setEnabled(false);
 
-	for (auto* action : list_showColumnActions) {
+	for (auto* action : qAsConst(list_showColumnActions)) {
 		action->setEnabled(true);
 		action->setChecked(true);
 	}
 }
 
-/*!
-  shows/hides the frame with the search/filter widgets
-*/
-void ProjectExplorer::toggleFilterWidgets() {
-	if (m_frameFilter->isVisible()) {
-		m_frameFilter->hide();
-		toggleFilterAction->setText(i18n("Show Search/Filter Options"));
-	} else {
-		m_frameFilter->show();
-		toggleFilterAction->setText(i18n("Hide Search/Filter Options"));
-	}
-}
-
 /*!
   toggles the menu for the filter/search options
 */
 void ProjectExplorer::toggleFilterOptionsMenu(bool checked) {
+	if (!checked)
+		return;
+
+	if (!caseSensitiveAction) {
+		caseSensitiveAction = new QAction(i18n("Case Sensitive"), this);
+		caseSensitiveAction->setCheckable(true);
+		caseSensitiveAction->setChecked(false);
+		connect(caseSensitiveAction, &QAction::triggered, this, [=](){ filterTextChanged(m_leFilter->text()); });
+
+		matchCompleteWordAction = new QAction(i18n("Match Complete Word"), this);
+		matchCompleteWordAction->setCheckable(true);
+		matchCompleteWordAction->setChecked(false);
+		connect(matchCompleteWordAction, &QAction::triggered, this, [=](){ filterTextChanged(m_leFilter->text()); });
+
+#if HAS_FUZZY_MATCHER
+		fuzzyMatchingAction = new QAction(i18n("Fuzzy Matching"), this);
+		fuzzyMatchingAction->setCheckable(true);
+		fuzzyMatchingAction->setChecked(true);
+		connect(fuzzyMatchingAction, &QAction::triggered, this, [=]() {
+			bool enabled  = !fuzzyMatchingAction->isChecked();
+			caseSensitiveAction->setEnabled(enabled);
+			matchCompleteWordAction->setEnabled(enabled);
+			filterTextChanged(m_leFilter->text());
+		});
+		caseSensitiveAction->setEnabled(false);
+		matchCompleteWordAction->setEnabled(false);
+#endif
+	}
+
 	if (checked) {
-		QMenu menu;
+	QMenu menu;
+#if HAS_FUZZY_MATCHER
+		menu.addAction(fuzzyMatchingAction);
+		menu.addSeparator();
+#endif
 		menu.addAction(caseSensitiveAction);
 		menu.addAction(matchCompleteWordAction);
 		connect(&menu, &QMenu::aboutToHide, bFilterOptions, &QPushButton::toggle);
@@ -620,21 +701,41 @@ void ProjectExplorer::filterTextChanged(const QString& text) {
 }
 
 bool ProjectExplorer::filter(const QModelIndex& index, const QString& text) {
-	Qt::CaseSensitivity sensitivity = caseSensitiveAction->isChecked() ? Qt::CaseSensitive : Qt::CaseInsensitive;
-	bool matchCompleteWord = matchCompleteWordAction->isChecked();
+#if HAS_FUZZY_MATCHER
+	bool fuzzyFiltering = true;
+	if (fuzzyMatchingAction && !fuzzyMatchingAction->isChecked())
+		fuzzyFiltering = false;
+#endif
 
 	bool childVisible = false;
 	const int rows = index.model()->rowCount(index);
 	for (int i = 0; i < rows; i++) {
-		QModelIndex child = index.model()->index(i, 0, index);
+		const auto& child = index.model()->index(i, 0, index);
 		auto* aspect =  static_cast<AbstractAspect*>(child.internalPointer());
 		bool visible;
 		if (text.isEmpty())
 			visible = true;
-		else if (matchCompleteWord)
-			visible = aspect->name().startsWith(text, sensitivity);
-		else
-			visible = aspect->name().contains(text, sensitivity);
+		else {
+#if HAS_FUZZY_MATCHER
+			if (fuzzyFiltering)
+				visible = KFuzzyMatcher::matchSimple(text, aspect->name());
+			else
+#endif
+			{
+				bool matchCompleteWord = false;
+				if (matchCompleteWordAction && matchCompleteWordAction->isChecked())
+					matchCompleteWord = true;
+
+				Qt::CaseSensitivity sensitivity = Qt::CaseInsensitive;
+				if (caseSensitiveAction && caseSensitiveAction->isChecked())
+					sensitivity = Qt::CaseSensitive;
+
+				if (matchCompleteWord)
+					visible = aspect->name().startsWith(text, sensitivity);
+				else
+					visible = aspect->name().contains(text, sensitivity);
+			}
+		}
 
 		if (visible) {
 			//current item is visible -> make all its children visible without applying the filter
@@ -658,18 +759,12 @@ bool ProjectExplorer::filter(const QModelIndex& index, const QString& text) {
 	return childVisible;
 }
 
-void ProjectExplorer::toggleFilterCaseSensitivity() {
-	filterTextChanged(m_leFilter->text());
-}
-
-void ProjectExplorer::toggleFilterMatchCompleteWord() {
-	filterTextChanged(m_leFilter->text());
-}
-
 void ProjectExplorer::selectIndex(const QModelIndex&  index) {
 	if (m_project->isLoading())
 		return;
 
+	DEBUG(Q_FUNC_INFO)
+
 	if ( !m_treeView->selectionModel()->isSelected(index) ) {
 		m_changeSelectionFromView = true;
 		m_treeView->selectionModel()->select(index, QItemSelectionModel::Select | QItemSelectionModel::Rows);
@@ -689,38 +784,50 @@ void ProjectExplorer::deselectIndex(const QModelIndex & index) {
 }
 
 void ProjectExplorer::selectionChanged(const QItemSelection &selected, const QItemSelection &deselected) {
+	if (m_project->isLoading())
+		return;
+
+	//QDEBUG(Q_FUNC_INFO << ", selected/deselected = " << selected << "/" << deselected)
+
 	QModelIndex index;
-	QModelIndexList items;
 	AbstractAspect* aspect = nullptr;
 
 	//there are four model indices in each row
 	//-> divide by 4 to obtain the number of selected rows (=aspects)
-	items = selected.indexes();
-	for (int i = 0; i < items.size()/4; ++i) {
-		index = items.at(i*4);
+	const auto& sitems = selected.indexes();
+	for (int i = 0; i < sitems.size()/4; ++i) {
+		index = sitems.at(i*4);
 		aspect = static_cast<AbstractAspect*>(index.internalPointer());
+		QDEBUG("sitems ASPECT =" << aspect)
 		aspect->setSelected(true);
 	}
 
-	items = deselected.indexes();
-	for (int i = 0; i < items.size()/4; ++i) {
-		index = items.at(i*4);
+	const auto& ditems = deselected.indexes();
+	for (int i = 0; i < ditems.size()/4; ++i) {
+		index = ditems.at(i*4);
 		aspect = static_cast<AbstractAspect*>(index.internalPointer());
+		QDEBUG("ditems ASPECT =" << aspect)
 		aspect->setSelected(false);
 	}
 
-	items = m_treeView->selectionModel()->selectedRows();
+	const auto& items = m_treeView->selectionModel()->selectedRows();
 	QList<AbstractAspect*> selectedAspects;
-	for (const QModelIndex& index : items) {
+	for (const auto& index : items) {
 		aspect = static_cast<AbstractAspect*>(index.internalPointer());
-		selectedAspects<<aspect;
+		QDEBUG("items ASPECT =" << aspect)
+		selectedAspects << aspect;
 	}
 
-	emit selectedAspectsChanged(selectedAspects);
+	//notify GuiObserver about the new selection
+	Q_EMIT selectedAspectsChanged(selectedAspects);
+
+	//notify MainWin about the new current aspect (last selected aspect).
+	if (!selectedAspects.isEmpty())
+		Q_EMIT currentAspectChanged(selectedAspects.last());
 
 	//emitting the signal above is done to show the properties widgets for the selected aspect(s).
 	//with this the project explorer looses the focus and don't react on the key events like DEL key press, etc.
-	//If we explicitely select an item in the project explorer (not via a selection in the view), we want to keep the focus here.
+	//If we explicitly select an item in the project explorer (not via a selection in the view), we want to keep the focus here.
 	//TODO: after the focus is set again we react on DEL in the event filter, but navigation with the arrow keys in the table
 	//is still not possible. Looks like we need to set the selection again...
 	if (!m_changeSelectionFromView)
@@ -729,37 +836,24 @@ void ProjectExplorer::selectionChanged(const QItemSelection &selected, const QIt
 		m_changeSelectionFromView = false;
 }
 
-/*!
- * Used to udpate the cursor Dock
- */
-void ProjectExplorer::updateSelectedAspects() {
-	QModelIndexList items = m_treeView->selectionModel()->selectedRows();
-	QList<AbstractAspect*> selectedAspects;
-	for (const QModelIndex& index : items)
-		selectedAspects << static_cast<AbstractAspect*>(index.internalPointer());
-
-	emit selectedAspectsChanged(selectedAspects);
-}
-
 void ProjectExplorer::expandSelected() {
-	const QModelIndexList items = m_treeView->selectionModel()->selectedIndexes();
+	const auto& items = m_treeView->selectionModel()->selectedIndexes();
 	for (const auto& index : items)
 		m_treeView->setExpanded(index, true);
 }
 
 void ProjectExplorer::collapseSelected() {
-	const QModelIndexList items = m_treeView->selectionModel()->selectedIndexes();
+	const auto& items = m_treeView->selectionModel()->selectedIndexes();
 	for (const auto& index : items)
 		m_treeView->setExpanded(index, false);
 }
 
 void ProjectExplorer::deleteSelected() {
-	const QModelIndexList items = m_treeView->selectionModel()->selectedIndexes();
+	const auto& items = m_treeView->selectionModel()->selectedIndexes();
 	if (!items.size())
 		return;
 
-
-	//determine all selected aspect
+	//determine all selected aspects
 	QVector<AbstractAspect*> aspects;
 	for (int i = 0; i < items.size()/4; ++i) {
 		const QModelIndex& index = items.at(i*4);
@@ -820,94 +914,95 @@ struct ViewState {
  * (expanded items and the currently selected item) as XML
  */
 void ProjectExplorer::save(QXmlStreamWriter* writer) const {
-	auto* model = qobject_cast<AspectTreeModel*>(m_treeView->model());
-	QList<int> selected;
-	QList<int> expanded;
-	QList<int> withView;
-	QVector<ViewState> viewStates;
-
-	int currentRow = -1; //row corresponding to the current index in the tree view, -1 for the root element (=project)
-	QModelIndexList selectedRows = m_treeView->selectionModel()->selectedRows();
-
-	//check whether the project node itself is expanded
-	if (m_treeView->isExpanded(m_treeView->model()->index(0,0)))
-		expanded.push_back(-1);
-
-	int row = 0;
-	for (const auto* aspect : m_project->children(AspectType::AbstractAspect, AbstractAspect::ChildIndexFlag::Recursive)) {
-		const QModelIndex& index = model->modelIndexOfAspect(aspect);
-
-		const auto* part = dynamic_cast<const AbstractPart*>(aspect);
-		if (part && part->hasMdiSubWindow()) {
-			withView.push_back(row);
-			ViewState s = {part->view()->windowState(), part->view()->geometry()};
-			viewStates.push_back(s);
-		}
-
-		if (model->rowCount(index)>0 && m_treeView->isExpanded(index))
-			expanded.push_back(row);
-
-		if (selectedRows.indexOf(index) != -1)
-			selected.push_back(row);
-
-		if (index == m_treeView->currentIndex())
-			currentRow = row;
-
-		row++;
-	}
+	const auto* model = static_cast<AspectTreeModel*>(m_treeView->model());
+	const auto& selectedRows = m_treeView->selectionModel()->selectedRows();
 
 	writer->writeStartElement("state");
 
-	writer->writeStartElement("expanded");
-	for (const auto e : expanded)
-		writer->writeTextElement("row", QString::number(e));
-	writer->writeEndElement();
-
-	writer->writeStartElement("selected");
-	for (const auto s : selected)
-		writer->writeTextElement("row", QString::number(s));
-	writer->writeEndElement();
-
-	writer->writeStartElement("view");
-	for (int i = 0; i < withView.size(); ++i) {
-		writer->writeStartElement("row");
-		const ViewState& s = viewStates.at(i);
-		writer->writeAttribute( "state", QString::number(s.state) );
-		writer->writeAttribute( "x", QString::number(s.geometry.x()) );
-		writer->writeAttribute( "y", QString::number(s.geometry.y()) );
-		writer->writeAttribute( "width", QString::number(s.geometry.width()) );
-		writer->writeAttribute( "height", QString::number(s.geometry.height()) );
-		writer->writeCharacters(QString::number(withView.at(i)));
+	//check whether the project node itself is expanded or selected or current
+	const auto& index = m_treeView->model()->index(0,0);
+	if (m_treeView->isExpanded(index)) {
+		writer->writeStartElement("expanded");
+		writer->writeAttribute("path", m_project->path());
 		writer->writeEndElement();
 	}
-	writer->writeEndElement();
 
-	writer->writeStartElement("current");
-	writer->writeTextElement("row", QString::number(currentRow));
-	writer->writeEndElement();
+	if (selectedRows.indexOf(index) != -1) {
+		writer->writeStartElement("selected");
+		writer->writeAttribute("path", m_project->path());
+		writer->writeEndElement();
+	}
 
-	writer->writeEndElement();
+	if (index == m_treeView->currentIndex()) {
+		writer->writeStartElement("current");
+		writer->writeAttribute("path", m_project->path());
+		writer->writeEndElement();
+	}
+
+	//traverse the children nodes
+	const auto& children = m_project->children<AbstractAspect>(AbstractAspect::ChildIndexFlag::Recursive);
+	for (const auto* aspect : children) {
+		const QString& path = aspect->path();
+		const auto* part = dynamic_cast<const AbstractPart*>(aspect);
+
+		if (part && part->hasMdiSubWindow()) {
+			writer->writeStartElement("view");
+			const auto& geometry = part->mdiSubWindow()->geometry();
+			writer->writeAttribute("path", path);
+			writer->writeAttribute("state", QString::number(part->view()->windowState()) );
+			writer->writeAttribute("x", QString::number(geometry.x()) );
+			writer->writeAttribute("y", QString::number(geometry.y()) );
+			writer->writeAttribute("width", QString::number(geometry.width()) );
+			writer->writeAttribute("height", QString::number(geometry.height()) );
+			writer->writeEndElement();
+		}
+
+		const auto& index = model->modelIndexOfAspect(aspect);
+		if (model->rowCount(index)>0 && m_treeView->isExpanded(index)) {
+			writer->writeStartElement("expanded");
+			writer->writeAttribute("path", path);
+			writer->writeEndElement();
+		}
+
+		if (selectedRows.indexOf(index) != -1) {
+			writer->writeStartElement("selected");
+			writer->writeAttribute("path", path);
+			writer->writeEndElement();
+		}
+
+		if (index == m_treeView->currentIndex()) {
+			writer->writeStartElement("current");
+			writer->writeAttribute("path", path);
+			writer->writeEndElement();
+		}
+	}
+
+	writer->writeEndElement(); //"state"
 }
 
 /**
  * \brief Load from XML
  */
 bool ProjectExplorer::load(XmlStreamReader* reader) {
-	const AspectTreeModel* model = qobject_cast<AspectTreeModel*>(m_treeView->model());
-	const auto aspects = m_project->children(AspectType::AbstractAspect, AbstractAspect::ChildIndexFlag::Recursive);
+	const auto* model = static_cast<AspectTreeModel*>(m_treeView->model());
+	QList<QModelIndex> selected;
+	QList<QModelIndex> expanded;
+	QModelIndex currentIndex;
+	QString str;
+	KLocalizedString attributeWarning = ki18n("Attribute '%1' missing or empty, default value is used");
 
+	//xmlVersion < 3: old logic where the "rows" for the selected and expanded items were saved
+	//ignoring the sub-folder structure. Remove it later.
+	if (Project::xmlVersion() < 3) {
+
+	const auto& aspects = m_project->children<AbstractAspect>(AbstractAspect::ChildIndexFlag::Recursive);
 	bool expandedItem = false;
 	bool selectedItem = false;
 	bool viewItem = false;
 	(void)viewItem; // because of a strange g++-warning about unused viewItem
 	bool currentItem = false;
-	QModelIndex currentIndex;
-	QString str;
 	int row;
-	QVector<QModelIndex> selected;
-	QList<QModelIndex> expanded;
 	QXmlStreamAttributes attribs;
-	KLocalizedString attributeWarning = ki18n("Attribute '%1' missing or empty, default value is used");
 
 	while (!reader->atEnd()) {
 		reader->readNext();
@@ -945,7 +1040,7 @@ bool ProjectExplorer::load(XmlStreamReader* reader) {
 			QModelIndex index;
 			if (row == -1)
 				index = model->modelIndexOfAspect(m_project); //-1 corresponds to the project-item (s.a. ProjectExplorer::save())
-			else if (row >= aspects.size() || row < 0 /* checking for <0 to protect against wrong values in the XML */)
+			else if (row >= aspects.size() || row < 0) //checking for <0 to protect against wrong values in the XML
 				continue;
 			else
 				index = model->modelIndexOfAspect(aspects.at(row));
@@ -964,7 +1059,75 @@ bool ProjectExplorer::load(XmlStreamReader* reader) {
 				if (!part)
 					continue; //TODO: add error/warning message here?
 
-				emit activateView(part); //request to show the view in MainWin
+				Q_EMIT activateView(part); //request to show the view in MainWin
+
+				str = attribs.value("state").toString();
+				if (str.isEmpty())
+					reader->raiseWarning(attributeWarning.subs("state").toString());
+				else {
+					part->view()->setWindowState(Qt::WindowStates(str.toInt()));
+					part->mdiSubWindow()->setWindowState(Qt::WindowStates(str.toInt()));
+				}
+
+				if (str != "0")
+					continue; //no geometry settings required for maximized/minimized windows
+
+				QRect geometry;
+				str = attribs.value("x").toString();
+				if (str.isEmpty())
+					reader->raiseWarning(attributeWarning.subs("x").toString());
+				else
+					geometry.setX(str.toInt());
+
+				str = attribs.value("y").toString();
+				if (str.isEmpty())
+					reader->raiseWarning(attributeWarning.subs("y").toString());
+				else
+					geometry.setY(str.toInt());
+
+				str = attribs.value("width").toString();
+				if (str.isEmpty())
+					reader->raiseWarning(attributeWarning.subs("width").toString());
+				else
+					geometry.setWidth(str.toInt());
+
+				str = attribs.value("height").toString();
+				if (str.isEmpty())
+					reader->raiseWarning(attributeWarning.subs("height").toString());
+				else
+					geometry.setHeight(str.toInt());
+
+				part->mdiSubWindow()->setGeometry(geometry);
+			}
+		}
+	}
+
+	} else {
+		while (!reader->atEnd()) {
+			reader->readNext();
+			if (reader->isEndElement() && reader->name() == "state")
+				break;
+
+			if (!reader->isStartElement())
+				continue;
+
+			const auto& attribs = reader->attributes();
+			const auto& path = attribs.value("path").toString();
+			const auto& index = model->modelIndexOfAspect(path);
+
+			if (reader->name() == "expanded")
+				expanded << index;
+			else if (reader->name() == "selected")
+				selected << index;
+			else if (reader->name() == "current")
+				currentIndex = index;
+			else if (reader->name() == "view") {
+				auto* aspect = static_cast<AbstractAspect*>(index.internalPointer());
+				auto* part = dynamic_cast<AbstractPart*>(aspect);
+				if (!part)
+					continue; //TODO: add error/warning message here?
+
+				Q_EMIT activateView(part); //request to show the view in MainWin
 
 				str = attribs.value("state").toString();
 				if (str.isEmpty())
@@ -1018,23 +1181,27 @@ bool ProjectExplorer::load(XmlStreamReader* reader) {
 	m_treeView->setCurrentIndex(currentIndex);
 	m_treeView->scrollTo(currentIndex);
 	auto* aspect = static_cast<AbstractAspect*>(currentIndex.internalPointer());
-	emit currentAspectChanged(aspect);
+	if (aspect)
+		aspect->setSelected(true);
+	Q_EMIT currentAspectChanged(aspect); //notify MainWin to bring up the proper view
+	Q_EMIT selectedAspectsChanged(QList<AbstractAspect*>()<<aspect); //notify GuiObserver to bring up the proper dock widget
 
-	//when setting the current index above it gets expanded, collapse all parent indices if they are were not expanded when saved
+	//when setting the current index above it gets expanded, collapse all parent indices if they were not expanded when saved
 	collapseParents(currentIndex, expanded);
 
+	//resize the header of the view to adjust to the content
+	resizeHeader();
+
 	return true;
 }
 
 void ProjectExplorer::collapseParents(const QModelIndex& index, const QList<QModelIndex>& expanded) {
-	//root index doesn't have any parents - this case is not caught by the second if-statement below
-	if (index.column() == 0 && index.row() == 0)
-		return;
-
-	const QModelIndex parent = index.parent();
-	if (parent == QModelIndex())
-		return;
-
-	if (expanded.indexOf(parent) == -1)
-		m_treeView->collapse(parent);
+	if (index.column() == 0 && index.row() == 0) { //root/project index, doesn't have any parent
+		if (expanded.indexOf(index) == -1)
+			m_treeView->collapse(index);
+	} else {
+		const auto& parent = index.parent();
+		if (parent != QModelIndex() && expanded.indexOf(parent) == -1)
+			m_treeView->collapse(parent);
+	}
 }
