@@ -1,30 +1,13 @@
-/***************************************************************************
+/*
     File                 : DatapickerImageView.cpp
     Project              : LabPlot
     Description          : DatapickerImage view for datapicker
     --------------------------------------------------------------------
-    Copyright            : (C) 2015 by Ankit Wagadre (wagadre.ankit@gmail.com)
-    Copyright            : (C) 2015-2016 by Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+    SPDX-FileCopyrightText: 2015-2016 Alexander Semke <alexander.semke@web.de>
 
- ***************************************************************************/
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "commonfrontend/datapicker/DatapickerImageView.h"
 #include "backend/worksheet/Worksheet.h"
@@ -55,7 +38,7 @@
  */
 
 /*!
-  Constructur of the class.
+  Constructor of the class.
   Creates a view for the DatapickerImage \c image and initializes the internal model.
 */
 DatapickerImageView::DatapickerImageView(DatapickerImage* image) : QGraphicsView(),
@@ -365,8 +348,8 @@ void DatapickerImageView::drawBackground(QPainter* painter, const QRectF& rect)
 void DatapickerImageView::wheelEvent(QWheelEvent* event) {
 	//https://wiki.qt.io/Smooth_Zoom_In_QGraphicsView
 	if (m_mouseMode == MouseMode::ZoomSelection || (QApplication::keyboardModifiers() & Qt::ControlModifier)) {
-		int numDegrees = event->delta() / 8;
-		int numSteps = numDegrees / 15; // see QWheelEvent documentation
+		QPoint numDegrees = event->angleDelta() / 8;
+		int numSteps = numDegrees.y() / 15; // see QWheelEvent documentation
 		zoom(numSteps);
 	} else
 		QGraphicsView::wheelEvent(event);
@@ -412,28 +395,45 @@ void DatapickerImageView::mousePressEvent(QMouseEvent* event) {
 		return;
 	}
 
-	QPointF eventPos = mapToScene(event->pos());
+	const auto eventPos = mapToScene(event->pos());
+	const auto type = m_image->plotPointsType();
 	bool entryMode = (m_mouseMode == MouseMode::ReferencePointsEntry
 					  || m_mouseMode == MouseMode::CurvePointsEntry || m_mouseMode == MouseMode::CurveSegmentsEntry);
 
 	//check whether there is a point item under the cursor
 	bool pointsUnderCursor = false;
-	auto items = this->items(event->pos());
+	const auto& items = this->items(event->pos());
+	const auto& referencePoints = m_image->children<DatapickerPoint>(AbstractAspect::ChildIndexFlag::IncludeHidden);
 	for (auto* item : items) {
-		if (item != m_image->m_magnificationWindow) {
-			pointsUnderCursor = true;
-			break;
+		if (item == m_image->m_magnificationWindow)
+			continue;
+
+		//when entering curve points, ignore the reference points under the cursor,
+		//it should be possible to place curve points close to or over the reference points.
+		if (type == DatapickerImage::PointsType::CurvePoints) {
+			bool referenceItem = false;
+			for (auto* point : referencePoints) {
+				if (point->graphicsItem() == item) {
+					referenceItem = true;
+					break;
+				}
+			}
+
+			if (referenceItem)
+				continue;
 		}
+
+		pointsUnderCursor = true;
+		break;
 	}
 
 	if (entryMode && !pointsUnderCursor && m_image->isLoaded && sceneRect().contains(eventPos)) {
-		if ( m_image->plotPointsType() == DatapickerImage::PointsType::AxisPoints ) {
+		if (type == DatapickerImage::PointsType::AxisPoints) {
 			int childCount = m_image->childCount<DatapickerPoint>(AbstractAspect::ChildIndexFlag::IncludeHidden);
 			if (childCount < 3)
 				m_datapicker->addNewPoint(eventPos, m_image);
-		} else if ( m_image->plotPointsType() == DatapickerImage::PointsType::CurvePoints && m_datapicker->activeCurve() ) {
+		} else if (type == DatapickerImage::PointsType::CurvePoints && m_datapicker->activeCurve())
 			m_datapicker->addNewPoint(eventPos, m_datapicker->activeCurve());
-		}
 
 		if (m_image->m_magnificationWindow && m_image->m_magnificationWindow->isVisible())
 			updateMagnificationWindow();
@@ -441,7 +441,7 @@ void DatapickerImageView::mousePressEvent(QMouseEvent* event) {
 
 	// make sure the datapicker (or its currently active curve) is selected in the project explorer if the view was clicked.
 	// We need this for the case when we change from the project-node in the project explorer to the datapicker node by clicking the view.
-	if (m_datapicker->activeCurve() && m_image->plotPointsType() != DatapickerImage::PointsType::AxisPoints) {
+	if (m_datapicker->activeCurve() && type != DatapickerImage::PointsType::AxisPoints) {
 		m_datapicker->setSelectedInView(false);
 		m_datapicker->activeCurve()->setSelectedInView(true);
 	} else {
@@ -488,7 +488,7 @@ void DatapickerImageView::mouseMoveEvent(QMouseEvent* event) {
 	if (m_image->plotPointsType() == DatapickerImage::PointsType::CurvePoints) {
 		QVector3D logicalPos = m_transform->mapSceneToLogical(pos, m_image->axisPoints());
 		if (m_image->axisPoints().type == DatapickerImage::GraphType::Ternary) {
-			emit statusInfo( "a =" + QString::number(logicalPos.x()) + ", b =" + QString::number(logicalPos.y()) + ", c =" + QString::number(logicalPos.z()));
+			Q_EMIT statusInfo( "a =" + QString::number(logicalPos.x()) + ", b =" + QString::number(logicalPos.y()) + ", c =" + QString::number(logicalPos.z()));
 		} else {
 			QString xLabel('x');
 			QString yLabel('y');
@@ -501,15 +501,20 @@ void DatapickerImageView::mouseMoveEvent(QMouseEvent* event) {
 			}
 
 			if (m_datapicker->activeCurve()) {
-				QString statusText = i18n("%1, active curve \"%2\": %3=%4, %5=%6", m_datapicker->name(), m_datapicker->activeCurve()->name(), xLabel, QString::number(logicalPos.x()), yLabel, QString::number(logicalPos.y()));
-				emit statusInfo(statusText);
+				QString statusText = i18n("%1, active curve \"%2\": %3=%4, %5=%6",
+										  m_datapicker->name(),
+										  m_datapicker->activeCurve()->name(),
+										  xLabel,
+										  QString::number(logicalPos.x()),
+										  yLabel,
+										  QString::number(logicalPos.y()));
+				Q_EMIT statusInfo(statusText);
 			}
 		}
 	}
 
 	//show the magnification window
 	if ( magnificationFactor && m_image->isLoaded && sceneRect().contains(pos) ) {
-
 		if (!m_image->m_magnificationWindow) {
 			m_image->m_magnificationWindow = new QGraphicsPixmapItem;
 			scene()->addItem(m_image->m_magnificationWindow);
@@ -517,9 +522,8 @@ void DatapickerImageView::mouseMoveEvent(QMouseEvent* event) {
 		}
 
 		updateMagnificationWindow();
-	} else if (m_image->m_magnificationWindow) {
+	} else if (m_image->m_magnificationWindow)
 		m_image->m_magnificationWindow->setVisible(false);
-	}
 
 	QGraphicsView::mouseMoveEvent(event);
 }
@@ -550,8 +554,7 @@ void DatapickerImageView::updateMagnificationWindow() {
 	m_image->m_magnificationWindow->setVisible(true);
 }
 
-void DatapickerImageView::contextMenuEvent(QContextMenuEvent* e) {
-	Q_UNUSED(e);
+void DatapickerImageView::contextMenuEvent(QContextMenuEvent*) {
 	//no need to propagate the event to the scene and graphics items
 	QMenu *menu = new QMenu(this);
 	this->createContextMenu(menu);
@@ -695,7 +698,7 @@ void DatapickerImageView::magnificationChanged(QAction* action) {
 
 void DatapickerImageView::addCurve() {
 	m_datapicker->beginMacro(i18n("%1: add new curve.", m_datapicker->name()));
-	DatapickerCurve* curve = new DatapickerCurve(i18n("Curve"));
+	auto* curve = new DatapickerCurve(i18n("Curve"));
 	curve->addDatasheet(m_image->axisPoints().type);
 	m_datapicker->addChild(curve);
 	m_datapicker->endMacro();
@@ -801,7 +804,37 @@ void DatapickerImageView::exportToFile(const QString& path, const WorksheetView:
 		exportPaint(&painter, targetRect, sourceRect);
 		painter.end();
 
-		image.save(path, "png");
+		if (!path.isEmpty()) {
+			bool rc{false};
+			switch (format) {
+			case WorksheetView::ExportFormat::PNG:
+				rc = image.save(path, "PNG");
+				break;
+			case WorksheetView::ExportFormat::JPG:
+				rc = image.save(path, "JPG");
+				break;
+			case WorksheetView::ExportFormat::BMP:
+				rc = image.save(path, "BMP");
+				break;
+			case WorksheetView::ExportFormat::PPM:
+				rc = image.save(path, "PPM");
+				break;
+			case WorksheetView::ExportFormat::XBM:
+				rc = image.save(path, "XBM");
+				break;
+			case WorksheetView::ExportFormat::XPM:
+				rc = image.save(path, "XPM");
+				break;
+			case WorksheetView::ExportFormat::PDF:
+			case WorksheetView::ExportFormat::SVG:
+				break;
+			}
+
+			if (!rc) {
+				RESET_CURSOR;
+				QMessageBox::critical(nullptr, i18n("Failed to export"), i18n("Failed to write to '%1'. Please check the path.", path));
+			}
+		}
 	}
 }
 
