@@ -1,30 +1,13 @@
-/***************************************************************************
+/*
     File                 : DatapickerView.cpp
     Project              : LabPlot
     Description          : View class for Datapicker
     --------------------------------------------------------------------
-    Copyright            : (C) 2015 by Ankit Wagadre (wagadre.ankit@gmail.com)
-    Copyright            : (C) 2015-2020 by Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+    SPDX-FileCopyrightText: 2015-2021 Alexander Semke <alexander.semke@web.de>
 
- ***************************************************************************/
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "DatapickerView.h"
 #include "backend/datapicker/Datapicker.h"
@@ -49,14 +32,12 @@
     \ingroup commonfrontend
  */
 DatapickerView::DatapickerView(Datapicker* datapicker) : QWidget(),
-	m_tabWidget(new QTabWidget(this)),
-	m_datapicker(datapicker) {
+		m_tabWidget(new QTabWidget(this)), m_datapicker(datapicker) {
 
 	m_tabWidget->setTabPosition(QTabWidget::South);
 	m_tabWidget->setTabShape(QTabWidget::Rounded);
 //     m_tabWidget->setMovable(true);
 	m_tabWidget->setContextMenuPolicy(Qt::CustomContextMenu);
-	m_tabWidget->setMinimumSize(600, 600);
 
 	auto* layout = new QHBoxLayout(this);
 	layout->setContentsMargins(0, 0, 0, 0);
@@ -66,12 +47,16 @@ DatapickerView::DatapickerView(Datapicker* datapicker) : QWidget(),
 	m_initializing = true;
 	for (const auto* aspect : m_datapicker->children<AbstractAspect>(AbstractAspect::ChildIndexFlag::IncludeHidden)) {
 		handleAspectAdded(aspect);
-		for (const auto* child : aspect->children<AbstractAspect>()) {
+		for (const auto* child : aspect->children<AbstractAspect>())
 			handleAspectAdded(child);
-		}
 	}
 	m_initializing = false;
 
+	if (!m_datapicker->isLoading()) {
+		const auto& size = m_datapicker->image()->view()->size();
+		resize(size.width() * 1.1, size.height() * 1.1);
+	}
+
 	//SIGNALs/SLOTs
 	connect(m_datapicker, &Datapicker::aspectDescriptionChanged, this, &DatapickerView::handleDescriptionChanged);
 	connect(m_datapicker, &Datapicker::aspectAdded, this, &DatapickerView::handleAspectAdded);
@@ -119,10 +104,7 @@ int DatapickerView::currentIndex() const {
   or of a \c DatapickerImage object to \c Datapicker.
 */
 void DatapickerView::tabChanged(int index) {
-	if (m_initializing)
-		return;
-
-	if (index == -1)
+	if (m_initializing || index == -1)
 		return;
 
 	m_datapicker->setChildSelectedInView(lastSelectedIndex, false);
@@ -130,9 +112,7 @@ void DatapickerView::tabChanged(int index) {
 	lastSelectedIndex = index;
 }
 
-void DatapickerView::tabMoved(int from, int to) {
-	Q_UNUSED(from);
-	Q_UNUSED(to);
+void DatapickerView::tabMoved(int /*from*/, int /*to*/) {
 	//TODO:
 // 	AbstractAspect* aspect = m_datapicker->child<AbstractAspect>(to);
 // 	if (aspect) {
@@ -192,15 +172,14 @@ void DatapickerView::handleDescriptionChanged(const AbstractAspect* aspect) {
 }
 
 void DatapickerView::handleAspectAdded(const AbstractAspect* aspect) {
-	int index;
+	int index = 0;
 	QString name;
 	const AbstractPart* part = dynamic_cast<const DatapickerImage*>(aspect);
 	if (part) {
-		index = 0;
 		name = aspect->name();
 	} else if (dynamic_cast<const DatapickerCurve*>(aspect)) {
 		index = m_datapicker->indexOfChild<AbstractAspect>(aspect, AbstractAspect::ChildIndexFlag::IncludeHidden);
-		const Spreadsheet* spreadsheet = static_cast<const Spreadsheet*>(aspect->child<AbstractAspect>(0));
+		const auto* spreadsheet = static_cast<const Spreadsheet*>(aspect->child<AbstractAspect>(0));
 		part = spreadsheet;
 		name = aspect->name() + ": " + spreadsheet->name();
 	} else
