@@ -1,40 +1,19 @@
-/***************************************************************************
+/*
     File                 : MatrixView.cpp
     Project              : LabPlot
     Description          : View class for Matrix
     --------------------------------------------------------------------
-    Copyright            : (C) 2015-2019 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2008-2009 Tilman Benkert (thzs@gmx.net)
+    SPDX-FileCopyrightText: 2015-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2008-2009 Tilman Benkert <thzs@gmx.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #ifndef MATRIXVIEW_H
 #define MATRIXVIEW_H
 
 #include <QWidget>
-#include <QList>
-#include <QShortcut>
-#include "backend/datasources/filters/FITSFilter.h"
-#include "kdefrontend/widgets/FITSHeaderEditWidget.h"
+#include <QLocale>
 
 class Matrix;
 class MatrixModel;
@@ -76,15 +55,14 @@ public:
                            const bool entire, const bool captions) const;
 	void exportToFits(const QString& fileName, const int exportTo) const;
 
-public slots:
-	void createContextMenu(QMenu*) const;
+public Q_SLOTS:
+	void createContextMenu(QMenu*);
 	void print(QPrinter*) const;
 
 private:
 	void init();
 	void initActions();
 	void initMenus();
-	void connectActions();
 	void goToCell(int row, int col);
 	void updateImage();
 
@@ -142,15 +120,13 @@ private:
 	QAction* action_fill_const;
 
 	//Menus
-	QMenu* m_selectionMenu;
-	QMenu* m_columnMenu;
-	QMenu* m_rowMenu;
-	QMenu* m_matrixMenu;
-	QMenu* m_headerFormatMenu;
+	QMenu* m_selectionMenu{nullptr};
+	QMenu* m_columnMenu{nullptr};
+	QMenu* m_rowMenu{nullptr};
+	QMenu* m_matrixMenu{nullptr};
+	QMenu* m_headerFormatMenu{nullptr};
 
-	QShortcut* sel_all;
-
-private slots:
+private Q_SLOTS:
 	void goToCell();
 	void advanceCell();
 	void handleHorizontalSectionResized(int logicalIndex, int oldSize, int newSize);
