@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : SpreadsheetHeaderView.cpp
     Project              : LabPlot
-    --------------------------------------------------------------------
-    Copyright            : (C) 2016 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2007 Tilman Benkert (thzs@gmx.net)
     Description          : Horizontal header for SpreadsheetView displaying comments in a second header
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2016 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2007 Tilman Benkert <thzs@gmx.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "SpreadsheetHeaderView.h"
 #include "SpreadsheetCommentsHeaderModel.h"
@@ -151,9 +133,7 @@ void SpreadsheetHeaderView::refresh() {
 /*!
   Reacts to a header data change.
 */
-void SpreadsheetHeaderView::headerDataChanged(Qt::Orientation orientation, int logicalFirst, int logicalLast) {
-	Q_UNUSED(logicalFirst);
-	Q_UNUSED(logicalLast);
+void SpreadsheetHeaderView::headerDataChanged(Qt::Orientation orientation, int /*logicalFirst*/, int /*logicalLast*/) {
 	if (orientation == Qt::Horizontal)
 		refresh();
 }
