@@ -1,30 +1,12 @@
-/***************************************************************************
+/*
     File                 : SpreadsheetView.h
     Project              : LabPlot
     Description          : View class for Spreadsheet
     --------------------------------------------------------------------
-    Copyright            : (C) 2010-2020 by Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2010-2022 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #ifndef SPREADSHEETVIEW_H
 #define SPREADSHEETVIEW_H
@@ -33,23 +15,26 @@
 
 #include "backend/core/AbstractColumn.h"
 #include "backend/lib/IntervalAttribute.h"
+#include <QLocale>
 
 class AbstractAspect;
 class Column;
 class Spreadsheet;
-class SpreadsheetItemDelegate;
 class SpreadsheetHeaderView;
 class SpreadsheetModel;
 
 class QActionGroup;
+class QFrame;
 class QItemSelection;
+class QLineEdit;
 class QMenu;
 class QPrinter;
 class QModelIndex;
+class QResizeEvent;
 class QTableView;
 class QToolBar;
 
-#ifdef Q_OS_MAC
+#ifdef HAVE_TOUCHBAR
 	class KDMacTouchBar;
 #endif
 
@@ -59,7 +44,7 @@ class SpreadsheetView : public QWidget {
 	friend class SpreadsheetTest;
 
 public:
-	explicit SpreadsheetView(Spreadsheet* spreadsheet, bool readOnly = false);
+	explicit SpreadsheetView(Spreadsheet*, bool readOnly = false);
 	~SpreadsheetView() override;
 
 	void resizeHeader();
@@ -88,6 +73,9 @@ public:
 	bool printView();
 	bool printPreview();
 
+protected:
+	void resizeEvent(QResizeEvent*) override;
+
 private:
 	void init();
 	void initActions();
@@ -108,12 +96,16 @@ private:
 	void insertRowsAbove(int);
 	void insertRowsBelow(int);
 
-	QTableView* m_tableView;
+	void updateFrozenTableGeometry();
+
+	QTableView* m_tableView{nullptr};
+	QTableView* m_frozenTableView{nullptr};
 	bool m_editorEntered{false};
 	Spreadsheet* m_spreadsheet;
-	SpreadsheetItemDelegate* m_delegate;
 	SpreadsheetModel* m_model;
 	SpreadsheetHeaderView* m_horizontalHeader;
+	QFrame* m_frameSearch{nullptr};
+	QLineEdit* m_leSearch{nullptr};
 	bool m_suppressSelectionChangedEvent{false};
 	bool m_readOnly;
 	bool eventFilter(QObject*, QEvent*) override;
@@ -143,7 +135,10 @@ private:
 	QAction* action_clear_spreadsheet;
 	QAction* action_clear_masks;
 	QAction* action_sort_spreadsheet;
+	QAction* action_formatting_heatmap;
+	QAction* action_formatting_remove;
 	QAction* action_go_to_cell;
+	QAction* action_search;
 	QAction* action_statistics_all_columns;
 
 	//column related actions
@@ -178,6 +173,7 @@ private:
 	QAction* action_sort_asc_column;
 	QAction* action_sort_desc_column;
 	QAction* action_statistics_columns;
+	QAction* action_freeze_columns;
 
 	//row related actions
 	QAction* action_insert_row_above;
@@ -191,6 +187,7 @@ private:
 	//analysis and plot data menu actions
 	QAction* action_plot_data_xycurve;
 	QAction* action_plot_data_histogram;
+	QAction* action_plot_data_boxplot;
 	QAction* addDataOperationAction;
 	QAction* addDataReductionAction;
 	QAction* addDifferentiationAction;
@@ -201,46 +198,53 @@ private:
 	QAction* addFourierFilterAction;
 
 	//Menus
-	QMenu* m_selectionMenu{nullptr};;
-	QMenu* m_columnMenu{nullptr};;
+	QMenu* m_selectionMenu{nullptr};
+	QMenu* m_formattingMenu{nullptr};
+	QMenu* m_columnMenu{nullptr};
 	QMenu* m_columnSetAsMenu{nullptr};
 	QMenu* m_columnGenerateDataMenu{nullptr};
 	QMenu* m_columnManipulateDataMenu;
 	QMenu* m_columnNormalizeMenu{nullptr};
 	QMenu* m_columnLadderOfPowersMenu{nullptr};
 	QMenu* m_columnSortMenu{nullptr};
-	QMenu* m_rowMenu{nullptr};;
-	QMenu* m_spreadsheetMenu{nullptr};;
-	QMenu* m_plotDataMenu{nullptr};;
-	QMenu* m_analyzePlotMenu{nullptr};;
+	QMenu* m_rowMenu{nullptr};
+	QMenu* m_spreadsheetMenu{nullptr};
+	QMenu* m_plotDataMenu{nullptr};
+	QMenu* m_analyzePlotMenu{nullptr};
 
-public slots:
+public Q_SLOTS:
 	void createContextMenu(QMenu*);
 	void fillToolBar(QToolBar*);
-#ifdef Q_OS_MAC
+#ifdef HAVE_TOUCHBAR
 	void fillTouchBar(KDMacTouchBar*);
 #endif
 	void print(QPrinter*) const;
+	void pasteIntoSelection();
 
-private slots:
+private Q_SLOTS:
 	void createColumnContextMenu(QMenu*);
 	void goToCell(int row, int col);
+	void showSearch();
 	void toggleComments();
 	void goToNextColumn();
 	void goToPreviousColumn();
 	void goToCell();
 	void sortSpreadsheet();
 	void sortDialog(const QVector<Column*>&);
+	void searchTextChanged(const QString&);
+	void searchReturnPressed();
+	void formatHeatmap();
+	void removeFormat();
 
 	void cutSelection();
 	void copySelection();
 	void clearSelectedCells();
 	void maskSelection();
 	void unmaskSelection();
-	void pasteIntoSelection();
 // 		void recalculateSelectedCells();
 
 	void plotData();
+	void plotAnalysisData();
 
 	void fillSelectedCellsWithRowNumbers();
 	void fillWithRowNumbers();
@@ -263,6 +267,7 @@ private slots:
 	void insertColumnsRight();
 	void removeSelectedColumns();
 	void clearSelectedColumns();
+	void toggleFreezeColumn();
 
 	void modifyValues();
 	void reverseColumns();
@@ -287,11 +292,11 @@ private slots:
 	void handleHorizontalSectionResized(int logicalIndex, int oldSize, int newSize);
 	void handleHorizontalSectionMoved(int index, int from, int to);
 	void handleHorizontalHeaderDoubleClicked(int index);
-	void handleHeaderDataChanged(Qt::Orientation orientation, int first, int last);
+	void handleHeaderDataChanged(Qt::Orientation, int first, int last);
 	void currentColumnChanged(const QModelIndex& current, const QModelIndex & previous);
 	void handleAspectAdded(const AbstractAspect*);
 	void handleAspectAboutToBeRemoved(const AbstractAspect*);
-	void updateHeaderGeometry(Qt::Orientation o, int first, int last);
+	void updateHeaderGeometry(Qt::Orientation, int first, int last);
 
 	void selectColumn(int);
 	void deselectColumn(int);
