@@ -1,30 +1,12 @@
-/***************************************************************************
+/*
 	File                 : DateTimeSpinBox.cpp
 	Project              : LabPlot
 	Description          : widget for setting datetimes with a spinbox
 	--------------------------------------------------------------------
-	Copyright            : (C) 2019 Martin Marmsoler (martin.marmsoler@gmail.com)
+    SPDX-FileCopyrightText: 2019 Martin Marmsoler <martin.marmsoler@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "DateTimeSpinBox.h"
 
@@ -92,7 +74,7 @@ void DateTimeSpinBox::writeValue() {
 						QString("%1").arg(m_minute, 2, 10, QLatin1Char('0')) + QLatin1Char(':') +
 						QString("%1").arg(m_second, 2, 10, QLatin1Char('0')) + QLatin1Char('.') +
 						QString("%1").arg(m_millisecond, 3, 10, QLatin1Char('0')));
-	emit valueChanged();
+	Q_EMIT valueChanged();
 }
 
 void DateTimeSpinBox::setValue(qint64 increment) {
@@ -168,7 +150,7 @@ void DateTimeSpinBox::getValue() {
 		}
 	}
 
-	emit valueChanged();
+	Q_EMIT valueChanged();
 }
 
 void DateTimeSpinBox::setCursorPosition(Type type) {
