@@ -1,35 +1,18 @@
-/***************************************************************************
+/*
     File                 : TreeViewComboBox.cpp
     Project              : LabPlot
     Description          : Provides a QTreeView in a QComboBox
     --------------------------------------------------------------------
-    Copyright            : (C) 2008-2016 by Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2008 Tilman Benkert (thzs@gmx.net)
+    SPDX-FileCopyrightText: 2008-2016 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2008 Tilman Benkert <thzs@gmx.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "commonfrontend/widgets/TreeViewComboBox.h"
 #include "backend/core/AbstractAspect.h"
 #include "backend/core/AspectTreeModel.h"
+#include "backend/core/AbstractColumn.h"
 #include "backend/lib/macros.h"
 
 #include <QEvent>
@@ -84,8 +67,7 @@ TreeViewComboBox::TreeViewComboBox(QWidget* parent) : QComboBox(parent),
 	connect(m_lineEdit, &QLineEdit::textChanged, this, &TreeViewComboBox::filterChanged);
 }
 
-void TreeViewComboBox::setTopLevelClasses(const QList<AspectType>& list)
-{
+void TreeViewComboBox::setTopLevelClasses(const QList<AspectType>& list) {
 	m_topLevelClasses = list;
 }
 
@@ -96,7 +78,8 @@ void TreeViewComboBox::setHiddenAspects(const QList<const AbstractAspect*>& list
 /*!
 	Sets the \a model for the view to present.
 */
-void TreeViewComboBox::setModel(QAbstractItemModel* model) {
+void TreeViewComboBox::setModel(AspectTreeModel* model) {
+	m_model = model;
 	m_treeView->setModel(model);
 
 	//show only the first column in the combo box
@@ -150,8 +133,7 @@ void TreeViewComboBox::showPopup() {
 	TODO: why do I have to reimplement paintEvent. It should work
 	also without
 */
-void TreeViewComboBox::paintEvent(QPaintEvent *)
-{
+void TreeViewComboBox::paintEvent(QPaintEvent*) {
 	QStylePainter painter(this);
 	painter.setPen(palette().color(QPalette::Text));
 	// draw the combobox frame, focusrect and selected etc.
@@ -192,8 +174,8 @@ QString TreeViewComboBox::currentText() const {
 		return itemText(currentIndex());
 	else if (!m_useCurrentIndexText)
 		return m_lineEditText;
-	else
-		return QString();
+
+	return {};
 }
 
 void TreeViewComboBox::setText(const QString& text) {
@@ -202,13 +184,13 @@ void TreeViewComboBox::setText(const QString& text) {
 
 void TreeViewComboBox::setInvalid(bool invalid, const QString& tooltip) {
 	if (invalid) {
-		setStyleSheet("background: red;");
-		setToolTip(tooltip);
-		return;
-	}
+		SET_WARNING_PALETTE
 
-	setToolTip("");
-	setStyleSheet("");
+		setToolTip(tooltip);
+	} else {
+		setPalette(qApp->palette());
+		setToolTip("");
+	}
 }
 
 /*!
@@ -241,7 +223,7 @@ void TreeViewComboBox::treeViewIndexActivated(const QModelIndex& index) {
 	if (index.internalPointer()) {
 		QComboBox::setCurrentIndex(0);
 		QComboBox::setItemText(0, index.data().toString());
-		emit currentModelIndexChanged(index);
+		Q_EMIT currentModelIndexChanged(index);
 		m_groupBox->hide();
 		return;
 	}
@@ -249,7 +231,7 @@ void TreeViewComboBox::treeViewIndexActivated(const QModelIndex& index) {
 	m_treeView->setCurrentIndex(QModelIndex());
 	setCurrentIndex(0);
 	QComboBox::setItemText(0, QString());
-	emit currentModelIndexChanged(QModelIndex());
+	Q_EMIT currentModelIndexChanged(QModelIndex());
 	m_groupBox->hide();
 }
 
@@ -293,11 +275,29 @@ bool TreeViewComboBox::filter(const QModelIndex& index, const QString& text) {
 
 /*!
 	checks whether \c aspect is one of the allowed top level types
+	and has selectable children
 */
 bool TreeViewComboBox::isTopLevel(const AbstractAspect* aspect) const {
+	const auto& selectableTypes = m_model->selectableAspects();
 	for (AspectType type : m_topLevelClasses) {
-		if (aspect->type() == type)
-			return true;
+		if (aspect->type() == type) {
+			//curent aspect is a top level aspect,
+			//check whether its selectable
+			if (selectableTypes.indexOf(type) != -1)
+				return true;
+
+			//check whether the current aspect has selectable children
+			bool hasSelectableAspects = false;
+			for (auto selectableType : selectableTypes) {
+				const auto&  children = aspect->children(selectableType, AbstractAspect::ChildIndexFlag::Recursive);
+				if (!children.isEmpty()) {
+					hasSelectableAspects = true;
+					break;
+				}
+			}
+
+			return hasSelectableAspects;
+		}
 
 		if (type == AspectType::XYAnalysisCurve)
 			if (aspect->inherits(AspectType::XYAnalysisCurve))
@@ -309,3 +309,35 @@ bool TreeViewComboBox::isTopLevel(const AbstractAspect* aspect) const {
 bool TreeViewComboBox::isHidden(const AbstractAspect* aspect) const {
 	return (m_hiddenAspects.indexOf(aspect) != -1);
 }
+
+void TreeViewComboBox::setAspect(const AbstractAspect* aspect) {
+	if (aspect)
+		setCurrentModelIndex(m_model->modelIndexOfAspect(aspect));
+	else
+		setCurrentModelIndex(QModelIndex());
+}
+
+AbstractAspect* TreeViewComboBox::currentAspect() const {
+	return static_cast<AbstractAspect*>(currentModelIndex().internalPointer());
+}
+
+void TreeViewComboBox::setColumn(const AbstractColumn* column, const QString& path) {
+	DEBUG(Q_FUNC_INFO)
+	setAspect(column);
+
+	// don't make the combobox red for initially created curves
+	if (!column && path.isEmpty()) {
+		setText("");
+		setInvalid(false);
+		return;
+	}
+
+	if (column) {
+		useCurrentIndexText(true);
+		setInvalid(false);
+	} else {
+		useCurrentIndexText(false);
+		setInvalid(true, i18n("The column \"%1\"\nis not available anymore. It will be automatically used once it is created again.", path));
+	}
+	setText(path.split('/').last());
+}
