@@ -1,54 +1,130 @@
+/*
+ * SPDX-FileCopyrightText: 2006-2011 the LibQxt project <http://libqxt.org, foundation@libqxt.org>
+ * SPDX-License-Identifier: BSD-3-Clause
+*/
+
 #include "qxtspanslider.h"
-/****************************************************************************
-** Copyright (c) 2006 - 2011, the LibQxt project.
-** See the Qxt AUTHORS file for a list of authors and copyright holders.
-** All rights reserved.
-**
-** Redistribution and use in source and binary forms, with or without
-** modification, are permitted provided that the following conditions are met:
-**     * Redistributions of source code must retain the above copyright
-**       notice, this list of conditions and the following disclaimer.
-**     * Redistributions in binary form must reproduce the above copyright
-**       notice, this list of conditions and the following disclaimer in the
-**       documentation and/or other materials provided with the distribution.
-**     * Neither the name of the LibQxt project nor the
-**       names of its contributors may be used to endorse or promote products
-**       derived from this software without specific prior written permission.
-**
-** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
-** ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-** WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-** DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
-** DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
-** (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
-** LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-** ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-** SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-**
-** <http://libqxt.org>  <foundation@libqxt.org>
-*****************************************************************************/
 
 #include "qxtspanslider_p.h"
 #include <QKeyEvent>
 #include <QMouseEvent>
 #include <QStylePainter>
 #include <QStyleOptionSlider>
+#include <QHBoxLayout>
+#include <QSpinBox>
 
-QxtSpanSliderPrivate::QxtSpanSliderPrivate() :
-	lower(0),
-	upper(0),
-	lowerPos(0),
-	upperPos(0),
-	offset(0),
-	position(0),
-	lastPressed(QxtSpanSlider::NoHandle),
-	mainControl(QxtSpanSlider::LowerHandle),
-	lowerPressed(QStyle::SC_None),
-	upperPressed(QStyle::SC_None),
-	movement(QxtSpanSlider::FreeMovement),
-	firstMovement(false),
-	blockTracking(false) {
+// Copied from BaseDock
+struct Lock {
+	inline explicit Lock(bool& variable)
+		: variable(variable = true) {
+	}
+
+	inline ~Lock() {
+		variable = false;
+	}
+
+private:
+	bool& variable;
+};
+
+SpanSlider::SpanSlider(Qt::Orientation orientation, QWidget* parent): QWidget(parent) {
+
+	sbMin = new QSpinBox(this);
+	sbMax = new QSpinBox(this);
+	spanslider = new QxtSpanSlider(this);
+	spanslider->setOrientation(orientation);
+
+	QBoxLayout* l;
+	if (orientation == Qt::Orientation::Horizontal) {
+		l = new QHBoxLayout();
+		l->addWidget(sbMin);
+		l->addWidget(spanslider);
+		l->addWidget(sbMax);
+
+		auto policy = spanslider->sizePolicy();
+		policy.setHorizontalPolicy(QSizePolicy::Policy::Expanding);
+		spanslider->setSizePolicy(policy);
+	} else {
+		l = new QVBoxLayout();
+		l->addWidget(sbMax);
+		l->addWidget(spanslider);
+		l->addWidget(sbMin);
+	}
+
+	connect(sbMin, QOverload<int>::of(&QSpinBox::valueChanged), this, &SpanSlider::spinBoxMinChanged);
+	connect(sbMax, QOverload<int>::of(&QSpinBox::valueChanged), this, &SpanSlider::spinBoxMaxChanged);
+	connect(spanslider, &QxtSpanSlider::spanChanged, this, &SpanSlider::spanChanged);
+
+	setLayout(l);
+}
+
+void SpanSlider::sliderSpanChanged(int min, int max) {
+	if (mInitializing)
+		return;
+
+	Lock lock(mInitializing);
+
+	sbMin->setValue(min);
+	sbMax->setValue(max);
+
+	emit spanChanged(min, max);
+}
+
+void SpanSlider::spinBoxMinChanged(int min) {
+	if (mInitializing)
+		return;
+
+	Lock lock(mInitializing);
+
+	spanslider->setSpan(min, sbMax->value());
+
+	emit spanChanged(min, sbMax->value());
+}
+
+void SpanSlider::spinBoxMaxChanged(int max) {
+	if (mInitializing)
+		return;
+
+	Lock lock(mInitializing);
+
+	spanslider->setSpan(sbMin->value(), max);
+
+	emit spanChanged(sbMin->value(), max);
+}
+
+void SpanSlider::setToolTip(const QString& str) {
+	spanslider->setToolTip(str);
+}
+
+void SpanSlider::setRange(int min, int max) {
+	if (mInitializing)
+		return;
+
+	Lock lock(mInitializing);
+
+	sbMin->setMinimum(min);
+	sbMin->setMaximum(max);
+	sbMax->setMinimum(min);
+	sbMax->setMaximum(max);
+	spanslider->setRange(min, max);
+}
+
+void SpanSlider::setSpan(int min, int max) {
+	if (mInitializing)
+		return;
+
+	Lock lock(mInitializing);
+
+	spanslider->setSpan(min, max);
+	sbMin->setValue(min);
+	sbMax->setValue(max);
+}
+
+// ####################################################################################################################
+// QxtSpanSlider
+// ####################################################################################################################
+
+QxtSpanSliderPrivate::QxtSpanSliderPrivate() {
 }
 
 void QxtSpanSliderPrivate::initStyleOption(QStyleOptionSlider* option, QxtSpanSlider::SpanHandle handle) const {
@@ -93,7 +169,7 @@ void QxtSpanSliderPrivate::handleMousePress(QPoint pos, QStyle::SubControl& cont
 		offset = pick(pos - sr.topLeft());
 		lastPressed = handle;
 		p->setSliderDown(true);
-		emit p->sliderPressed(handle);
+		Q_EMIT p->sliderPressed(handle);
 	}
 	if (control != oldControl)
 		p->update(sr);
@@ -235,9 +311,7 @@ void QxtSpanSliderPrivate::swapControls() {
 	mainControl = (mainControl == QxtSpanSlider::LowerHandle ? QxtSpanSlider::UpperHandle : QxtSpanSlider::LowerHandle);
 }
 
-void QxtSpanSliderPrivate::updateRange(int min, int max) {
-	Q_UNUSED(min);
-	Q_UNUSED(max);
+void QxtSpanSliderPrivate::updateRange(int /*min*/, int /*max*/) {
 	// setSpan() takes care of keeping span in range
 	qxt_p().setSpan(lower, upper);
 }
@@ -434,14 +508,14 @@ void QxtSpanSlider::setSpan(int lower, int upper) {
 		if (low != qxt_d().lower) {
 			qxt_d().lower = low;
 			qxt_d().lowerPos = low;
-			emit lowerValueChanged(low);
+			Q_EMIT lowerValueChanged(low);
 		}
 		if (upp != qxt_d().upper) {
 			qxt_d().upper = upp;
 			qxt_d().upperPos = upp;
-			emit upperValueChanged(upp);
+			Q_EMIT upperValueChanged(upp);
 		}
-		emit spanChanged(qxt_d().lower, qxt_d().upper);
+		Q_EMIT spanChanged(qxt_d().lower, qxt_d().upper);
 		update();
 	}
 }
@@ -460,7 +534,7 @@ void QxtSpanSlider::setLowerPosition(int lower) {
 		if (!hasTracking())
 			update();
 		if (isSliderDown())
-			emit lowerPositionChanged(lower);
+			Q_EMIT lowerPositionChanged(lower);
 		if (hasTracking() && !qxt_d().blockTracking) {
 			bool main = (qxt_d().mainControl == QxtSpanSlider::LowerHandle);
 			qxt_d().triggerAction(SliderMove, main);
@@ -482,7 +556,7 @@ void QxtSpanSlider::setUpperPosition(int upper) {
 		if (!hasTracking())
 			update();
 		if (isSliderDown())
-			emit upperPositionChanged(upper);
+			Q_EMIT upperPositionChanged(upper);
 		if (hasTracking() && !qxt_d().blockTracking) {
 			bool main = (qxt_d().mainControl == QxtSpanSlider::UpperHandle);
 			qxt_d().triggerAction(SliderMove, main);
@@ -619,8 +693,7 @@ void QxtSpanSlider::mouseReleaseEvent(QMouseEvent* event) {
 /*!
     \reimp
  */
-void QxtSpanSlider::paintEvent(QPaintEvent* event) {
-	Q_UNUSED(event);
+void QxtSpanSlider::paintEvent(QPaintEvent*) {
 	QStylePainter painter(this);
 
 	// groove & ticks
