@@ -1,30 +1,12 @@
-/***************************************************************************
+/*
     File                 : WorkbookView.cpp
     Project              : LabPlot
     Description          : View class for Workbook
     --------------------------------------------------------------------
-    Copyright            : (C) 2015-2020 by Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2015-2020 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "WorkbookView.h"
 #include "backend/core/AbstractAspect.h"
@@ -68,8 +50,8 @@ WorkbookView::WorkbookView(Workbook* workbook) : QWidget(),
 	m_initializing = false;
 
 	//Actions
-	action_add_spreadsheet = new QAction(QIcon::fromTheme("labplot-spreadsheet"), i18n("Add new Spreadsheet"), this);
-	action_add_matrix = new QAction(QIcon::fromTheme("labplot-matrix"), i18n("Add new Matrix"), this);
+	action_add_spreadsheet = new QAction(QIcon::fromTheme("labplot-spreadsheet"), i18n("Spreadsheet"), this);
+	action_add_matrix = new QAction(QIcon::fromTheme("labplot-matrix"), i18n("Matrix"), this);
 	connect(action_add_spreadsheet, &QAction::triggered, this, &WorkbookView::addSpreadsheet);
 	connect(action_add_matrix, &QAction::triggered, this, &WorkbookView::addMatrix);
 
@@ -117,9 +99,7 @@ void WorkbookView::tabChanged(int index) {
 	lastSelectedIndex = index;
 }
 
-void WorkbookView::tabMoved(int from, int to) {
-	Q_UNUSED(from);
-	Q_UNUSED(to);
+void WorkbookView::tabMoved(int /*from*/, int /*to*/) {
 	//TODO:
 // 	AbstractAspect* aspect = m_workbook->child<AbstractAspect>(to);
 // 	if (aspect) {
@@ -151,11 +131,14 @@ void WorkbookView::createContextMenu(QMenu* menu) const {
 	// if we're populating the context menu for the project explorer, then
 	//there're already actions available there. Skip the first title-action
 	//and insert the action at the beginning of the menu.
-	if (menu->actions().size()>1)
+	if (menu->actions().size() > 1)
 		firstAction = menu->actions().at(1);
 
-	menu->insertAction(firstAction, action_add_spreadsheet);
-	menu->insertAction(firstAction, action_add_matrix);
+	auto* addNewMenu = new QMenu(i18n("Add New"));
+	addNewMenu->setIcon(QIcon::fromTheme("list-add"));
+	addNewMenu->addAction(action_add_spreadsheet);
+	addNewMenu->addAction(action_add_matrix);
+	menu->insertMenu(firstAction, addNewMenu);
 	menu->insertSeparator(firstAction);
 }
 
@@ -181,7 +164,7 @@ void WorkbookView::addMatrix() {
 }
 
 void WorkbookView::addSpreadsheet() {
-	Spreadsheet* spreadsheet = new Spreadsheet(i18n("Spreadsheet"));
+	auto* spreadsheet = new Spreadsheet(i18n("Spreadsheet"));
 	m_workbook->addChild(spreadsheet);
 }
 
