@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : WorksheetView.h
     Project              : LabPlot
     Description          : Worksheet view
     --------------------------------------------------------------------
-    Copyright            : (C) 2009-2019 by Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2018 by Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2009-2019 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #ifndef WORKSHEETVIEW_H
 #define WORKSHEETVIEW_H
@@ -44,8 +26,8 @@ class QTimeLine;
 class AbstractAspect;
 class WorksheetElement;
 
-#ifdef Q_OS_MAC
-	class KDMacTouchBar;
+#ifdef HAVE_TOUCHBAR
+class KDMacTouchBar;
 #endif
 
 class WorksheetView : public QGraphicsView {
@@ -78,6 +60,8 @@ public:
 	void setCartesianPlotCursorMode(Worksheet::CartesianPlotActionMode mode);
 	void setPlotLock(bool lock);
 	void suppressSelectionChangedEvent(bool);
+	WorksheetElement* selectedElement() const;
+	QList<QGraphicsItem*> selectedItems() const;
 
 	Worksheet::CartesianPlotActionMode getCartesianPlotActionMode();
 	void registerShortcuts();
@@ -95,6 +79,12 @@ private:
 	CartesianPlot* plotAt(QPoint) const;
 	void exportPaint(QPainter* painter, const QRectF& targetRect, const QRectF& sourceRect, const bool);
 	void cartesianPlotAdd(CartesianPlot*, QAction*);
+	void handleAxisSelected(const Axis* a);
+	void handleCartesianPlotSelected(const CartesianPlot *plot);
+	void handleXYCurveSelected();
+	void handleReferenceLineSelected();
+	bool eventFilter(QObject *watched, QEvent *event) override;
+	void updateLabelsZoom() const;
 
 	//events
 	void resizeEvent(QResizeEvent*) override;
@@ -116,15 +106,19 @@ private:
 	bool m_selectionBandIsShown{false};
 	QPoint m_selectionStart;
 	QPoint m_selectionEnd;
+	QPointF m_cursorPos;
+	bool m_calledFromContextMenu{false};
 	int magnificationFactor{0};
 	QGraphicsPixmapItem* m_magnificationWindow{nullptr};
 	GridSettings m_gridSettings;
 	QList<QGraphicsItem*> m_selectedItems;
+	WorksheetElement* m_selectedElement{nullptr}; // used to determine which range should be used for navigation
 	bool m_suppressSelectionChangedEvent{false};
 	WorksheetElement* lastAddedWorksheetElement{nullptr};
 	QTimeLine* m_fadeInTimeLine{nullptr};
 	QTimeLine* m_fadeOutTimeLine{nullptr};
 	bool m_isClosing{false};
+	bool m_isPrinting{false};
 	bool m_actionsInitialized{false};
 	bool m_menusInitialized{false};
 	int m_numScheduledScalings{0};
@@ -176,7 +170,7 @@ private:
 	QAction* addCartesianPlot4Action{nullptr};
 	QAction* addTextLabelAction{nullptr};
 	QAction* addImageAction{nullptr};
-	QAction* addHistogram{nullptr};
+	QAction* addGlobalInfoElementAction{nullptr};
 
 	QAction* verticalLayoutAction{nullptr};
 	QAction* horizontalLayoutAction{nullptr};
@@ -203,9 +197,12 @@ private:
 	//Actions for cartesian plots
 	QAction* cartesianPlotApplyToSelectionAction{nullptr};
 	QAction* cartesianPlotApplyToAllAction{nullptr};
+	QAction* cartesianPlotApplyToAllXAction{nullptr};
+	QAction* cartesianPlotApplyToAllYAction{nullptr};
 	QAction* cartesianPlotApplyToAllCursor{nullptr};
 	QAction* cartesianPlotApplyToSelectionCursor{nullptr};
 	QAction* cartesianPlotSelectionModeAction{nullptr};
+	QAction* cartesianPlotCrosshairModeAction{nullptr};
 	QAction* cartesianPlotZoomSelectionModeAction{nullptr};
 	QAction* cartesianPlotZoomXSelectionModeAction{nullptr};
 	QAction* cartesianPlotZoomYSelectionModeAction{nullptr};
@@ -213,6 +210,7 @@ private:
 
 	QAction* addCurveAction{nullptr};
 	QAction* addHistogramAction{nullptr};
+	QAction* addBoxPlotAction{nullptr};
 	QAction* addEquationCurveAction{nullptr};
 	QAction* addDataOperationCurveAction{nullptr};
 	QAction* addDataReductionCurveAction{nullptr};
@@ -257,23 +255,25 @@ private:
 	QAction* addFitAction{nullptr};
 	QAction* addFourierFilterAction{nullptr};
 	QAction* addFourierTransformAction{nullptr};
+	QAction* addHilbertTransformAction{nullptr};
 	QAction* addConvolutionAction{nullptr};
 	QAction* addCorrelationAction{nullptr};
 
-public slots:
+public Q_SLOTS:
 	void createContextMenu(QMenu*);
 	void createAnalysisMenu(QMenu*);
 	void fillToolBar(QToolBar*);
-#ifdef Q_OS_MAC
+#ifdef HAVE_TOUCHBAR
 	void fillTouchBar(KDMacTouchBar*);
 #endif
 	void fillCartesianPlotToolBar(QToolBar*);
 	void print(QPrinter*);
 	void selectItem(QGraphicsItem*);
 	void presenterMode();
-	void cartesianPlotMouseModeChangedSlot(CartesianPlot::MouseMode mouseMode); // from cartesian Plot
+	void cartesianPlotMouseModeChangedSlot(CartesianPlot::MouseMode mouseMode); // from cartesian plot
+	void cartesianPlotMouseModeChanged(QAction*);
 
-private slots:
+private Q_SLOTS:
 	void addNew(QAction*);
 	void aspectAboutToBeRemoved(const AbstractAspect*);
 	void selectAllElements();
@@ -303,12 +303,11 @@ private slots:
 	//SLOTs for cartesian plots
 	void cartesianPlotActionModeChanged(QAction*);
 	void cartesianPlotCursorModeChanged(QAction*);
-	void cartesianPlotMouseModeChanged(QAction*);
 	void cartesianPlotNavigationChanged(QAction*);
 	void cartesianPlotAddNew(QAction*);
 	void handleCartesianPlotActions();
 
-signals:
+Q_SIGNALS:
 	void statusInfo(const QString&);
 	void propertiesExplorerRequested();
 };
