@@ -1,32 +1,14 @@
-/***************************************************************************
-File                 : GuiObserver.cpp
-Project              : LabPlot
-Description 	     : GUI observer
---------------------------------------------------------------------
-Copyright            : (C) 2010-2015 Alexander Semke (alexander.semke@web.de)
-Copyright            : (C) 2015-2018 Stefan Gerlach (stefan.gerlach@uni.kn)
-Copyright            : (C) 2016 Garvit Khatri (garvitdelhi@gmail.com)
+/*
+    File                 : GuiObserver.cpp
+    Project              : LabPlot
+    Description 	     : GUI observer
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2010-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2015-2018 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-FileCopyrightText: 2016 Garvit Khatri <garvitdelhi@gmail.com>
 
-***************************************************************************/
-
-/***************************************************************************
-*                                                                         *
-*  This program is free software; you can redistribute it and/or modify   *
-*  it under the terms of the GNU General Public License as published by   *
-*  the Free Software Foundation; either version 2 of the License, or      *
-*  (at your option) any later version.                                    *
-*                                                                         *
-*  This program is distributed in the hope that it will be useful,        *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
-*  GNU General Public License for more details.                           *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the Free Software           *
-*   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
-*   Boston, MA  02110-1301  USA                                           *
-*                                                                         *
-***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kdefrontend/GuiObserver.h"
 #include "backend/core/AspectTreeModel.h"
@@ -42,7 +24,9 @@ Copyright            : (C) 2016 Garvit Khatri (garvitdelhi@gmail.com)
 #include "backend/worksheet/plots/cartesian/CustomPoint.h"
 #include "backend/worksheet/plots/cartesian/ReferenceLine.h"
 #include "backend/worksheet/plots/cartesian/Histogram.h"
+#include "backend/worksheet/plots/cartesian/BoxPlot.h"
 #include "backend/worksheet/Image.h"
+#include "backend/worksheet/InfoElement.h"
 #include "backend/worksheet/TextLabel.h"
 #ifdef HAVE_CANTOR_LIBS
 #include "backend/cantorWorksheet/CantorWorksheet.h"
@@ -58,7 +42,9 @@ Copyright            : (C) 2016 Garvit Khatri (garvitdelhi@gmail.com)
 #include "backend/datapicker/DatapickerCurve.h"
 #include "commonfrontend/ProjectExplorer.h"
 #include "kdefrontend/MainWin.h"
+#include "kdefrontend/dockwidgets/AspectDock.h"
 #include "kdefrontend/dockwidgets/AxisDock.h"
+#include "kdefrontend/dockwidgets/InfoElementDock.h"
 #include "kdefrontend/dockwidgets/NoteDock.h"
 #include "kdefrontend/dockwidgets/CursorDock.h"
 #include "kdefrontend/dockwidgets/CartesianPlotDock.h"
@@ -71,6 +57,7 @@ Copyright            : (C) 2016 Garvit Khatri (garvitdelhi@gmail.com)
 #include "kdefrontend/dockwidgets/SpreadsheetDock.h"
 #include "kdefrontend/dockwidgets/XYCurveDock.h"
 #include "kdefrontend/dockwidgets/HistogramDock.h"
+#include "kdefrontend/dockwidgets/BoxPlotDock.h"
 #include "kdefrontend/dockwidgets/XYEquationCurveDock.h"
 #include "kdefrontend/dockwidgets/XYDataReductionCurveDock.h"
 #include "kdefrontend/dockwidgets/XYDifferentiationCurveDock.h"
@@ -80,6 +67,7 @@ Copyright            : (C) 2016 Garvit Khatri (garvitdelhi@gmail.com)
 #include "kdefrontend/dockwidgets/XYFitCurveDock.h"
 #include "kdefrontend/dockwidgets/XYFourierFilterCurveDock.h"
 #include "kdefrontend/dockwidgets/XYFourierTransformCurveDock.h"
+#include "kdefrontend/dockwidgets/XYHilbertTransformCurveDock.h"
 #include "kdefrontend/dockwidgets/XYConvolutionCurveDock.h"
 #include "kdefrontend/dockwidgets/XYCorrelationCurveDock.h"
 #include "kdefrontend/dockwidgets/CustomPointDock.h"
@@ -173,6 +161,7 @@ GuiObserver::GuiObserver(MainWin* mainWin) {
   and activates the corresponding dockwidgets, toolbars etc.
 */
 void GuiObserver::selectedAspectsChanged(QList<AbstractAspect*>& selectedAspects) const {
+	DEBUG(Q_FUNC_INFO)
 	auto clearDock = [&]() {
 		if (m_mainWindow->stackedWidget->currentWidget())
 			m_mainWindow->stackedWidget->currentWidget()->hide();
@@ -180,23 +169,23 @@ void GuiObserver::selectedAspectsChanged(QList<AbstractAspect*>& selectedAspects
 		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Properties"));
 	};
 
-	if (selectedAspects.isEmpty()) {
+	if (selectedAspects.isEmpty() || selectedAspects.front() == nullptr) {
 		clearDock();
 		return;
 	}
 
 	const AspectType type{ selectedAspects.front()->type() };
-	DEBUG(Q_FUNC_INFO << ", type: " << std::hex << static_cast<quint64>(type))
+	DEBUG(Q_FUNC_INFO << ", type: " << STDSTRING(AbstractAspect::typeName(type)))
 
 	// update cursor dock
 	if (m_mainWindow->cursorWidget) {
 		if (type == AspectType::Worksheet) {
-			Worksheet* worksheet = static_cast<Worksheet*>(selectedAspects.front());
+			auto* worksheet = static_cast<Worksheet*>(selectedAspects.front());
 			m_mainWindow->cursorWidget->setWorksheet(worksheet);
 		} else {
-			AbstractAspect* parent = selectedAspects.front()->parent(AspectType::Worksheet);
+			auto* parent = selectedAspects.front()->parent(AspectType::Worksheet);
 			if (parent) {
-				Worksheet* worksheet = static_cast<Worksheet*>(parent);
+				auto* worksheet = static_cast<Worksheet*>(parent);
 				m_mainWindow->cursorWidget->setWorksheet(worksheet);
 			}
 		}
@@ -217,11 +206,23 @@ void GuiObserver::selectedAspectsChanged(QList<AbstractAspect*>& selectedAspects
 		raiseDockConnect(m_mainWindow->spreadsheetDock, m_mainWindow->statusBar(), m_mainWindow->stackedWidget);
 		m_mainWindow->spreadsheetDock->setSpreadsheets(castList<Spreadsheet>(selectedAspects));
 		break;
-	case AspectType::Column:
-		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Column"));
-		raiseDockConnect(m_mainWindow->columnDock, m_mainWindow->statusBar(), m_mainWindow->stackedWidget);
-		m_mainWindow->columnDock->setColumns(castList<Column>(selectedAspects));
+	case AspectType::Column: {
+#ifdef HAVE_CANTOR_LIBS
+		auto* casParent = dynamic_cast<CantorWorksheet*>(selectedAspects.first()->parentAspect());
+		if (casParent) {
+			//a column from a CAS-worksheets was selected, show the dock widget for the CAS worksheet
+			raiseDockConnect(m_mainWindow->cantorWorksheetDock, m_mainWindow->statusBar(), m_mainWindow->stackedWidget);
+			m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window %1 is a Cantor backend", "%1 Worksheet", casParent->backendName()));
+			m_mainWindow->cantorWorksheetDock->setCantorWorksheets(QList<CantorWorksheet*>{casParent});
+		} else
+#endif
+		{
+			m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Column"));
+			raiseDockConnect(m_mainWindow->columnDock, m_mainWindow->statusBar(), m_mainWindow->stackedWidget);
+			m_mainWindow->columnDock->setColumns(castList<Column>(selectedAspects));
+		}
 		break;
+	}
 	case AspectType::Matrix:
 		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Matrix"));
 		raiseDockConnect(m_mainWindow->matrixDock, m_mainWindow->statusBar(), m_mainWindow->stackedWidget);
@@ -307,12 +308,17 @@ void GuiObserver::selectedAspectsChanged(QList<AbstractAspect*>& selectedAspects
 		raiseDockSetupConnect(m_mainWindow->xyFourierTransformCurveDock, m_mainWindow->statusBar(), m_mainWindow->stackedWidget);
 		m_mainWindow->xyFourierTransformCurveDock->setCurves(castList<XYCurve>(selectedAspects));
 		break;
+	case AspectType::XYHilbertTransformCurve:
+		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Hilbert Transform"));
+		raiseDockSetupConnect(m_mainWindow->xyHilbertTransformCurveDock, m_mainWindow->statusBar(), m_mainWindow->stackedWidget);
+		m_mainWindow->xyHilbertTransformCurveDock->setCurves(castList<XYCurve>(selectedAspects));
+		break;
 	case AspectType::XYFourierFilterCurve:
 		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Fourier Filter"));
 		raiseDockSetupConnect(m_mainWindow->xyFourierFilterCurveDock, m_mainWindow->statusBar(), m_mainWindow->stackedWidget);
 		m_mainWindow->xyFourierFilterCurveDock->setCurves(castList<XYCurve>(selectedAspects));
 		break;
-	case AspectType::XYConvolution:
+	case AspectType::XYConvolutionCurve:
 		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Convolution/Deconvolution"));
 		raiseDockSetupConnect(m_mainWindow->xyConvolutionCurveDock, m_mainWindow->statusBar(), m_mainWindow->stackedWidget);
 		m_mainWindow->xyConvolutionCurveDock->setCurves(castList<XYCurve>(selectedAspects));
@@ -327,6 +333,11 @@ void GuiObserver::selectedAspectsChanged(QList<AbstractAspect*>& selectedAspects
 		raiseDockConnect(m_mainWindow->histogramDock, m_mainWindow->statusBar(), m_mainWindow->stackedWidget);
 		m_mainWindow->histogramDock->setCurves(castList<Histogram>(selectedAspects));
 		break;
+	case AspectType::BoxPlot:
+		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Box Plot"));
+		raiseDock(m_mainWindow->boxPlotDock, m_mainWindow->stackedWidget);
+		m_mainWindow->boxPlotDock->setBoxPlots(castList<BoxPlot>(selectedAspects));
+		break;
 	case AspectType::TextLabel:
 		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Text Label"));
 		raiseDock(m_mainWindow->textLabelDock, m_mainWindow->stackedWidget);
@@ -353,9 +364,8 @@ void GuiObserver::selectedAspectsChanged(QList<AbstractAspect*>& selectedAspects
 		m_mainWindow->datapickerCurveDock->setCurves(castList<DatapickerCurve>(selectedAspects));
 		break;
 	case AspectType::Datapicker:
-		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Datapicker"));
+		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Data Extractor"));
 		raiseDock(m_mainWindow->datapickerImageDock, m_mainWindow->stackedWidget);
-
 		{
 			QList<DatapickerImage*> list;
 			for (auto* aspect : selectedAspects)
@@ -371,13 +381,12 @@ void GuiObserver::selectedAspectsChanged(QList<AbstractAspect*>& selectedAspects
 	case AspectType::CantorWorksheet:
 #ifdef HAVE_CANTOR_LIBS
 		raiseDockConnect(m_mainWindow->cantorWorksheetDock, m_mainWindow->statusBar(), m_mainWindow->stackedWidget);
-
 		{
-			QList<CantorWorksheet*> list = castList<CantorWorksheet>(selectedAspects);
+			auto list = castList<CantorWorksheet>(selectedAspects);
 			if (list.size() == 1)
-				m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window %1 is a Cantor backend", "%1 Properties", list.first()->backendName()));
+				m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window %1 is a Cantor backend", "%1 Notebook", list.first()->backendName()));
 			else
-				m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "CAS Properties"));
+				m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Notebook"));
 			m_mainWindow->cantorWorksheetDock->setCantorWorksheets(list);
 		}
 #endif
@@ -387,6 +396,12 @@ void GuiObserver::selectedAspectsChanged(QList<AbstractAspect*>& selectedAspects
 		raiseDock(m_mainWindow->notesDock, m_mainWindow->stackedWidget);
 		m_mainWindow->notesDock->setNotesList(castList<Note>(selectedAspects));
 		break;
+	case AspectType::InfoElement: {
+			m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Info Element"));
+			raiseDock(m_mainWindow->infoElementDock, m_mainWindow->stackedWidget);
+			m_mainWindow->infoElementDock->setInfoElements(castList<InfoElement>(selectedAspects));
+			break;
+		}
 	case AspectType::MQTTClient:
 #ifdef HAVE_MQTT
 		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "MQTT Data Source"));
@@ -423,9 +438,17 @@ void GuiObserver::selectedAspectsChanged(QList<AbstractAspect*>& selectedAspects
 	case AspectType::DatapickerImage:
 	case AspectType::DatapickerPoint:
 	case AspectType::Folder:
+		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Folder"));
+		raiseDock(m_mainWindow->aspectDock, m_mainWindow->stackedWidget);
+		m_mainWindow->aspectDock->setAspects(selectedAspects);
+		break;
 	case AspectType::PlotArea:
 	case AspectType::SimpleFilterColumn:
 	case AspectType::Workbook:
+		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Workbook"));
+		raiseDock(m_mainWindow->aspectDock, m_mainWindow->stackedWidget);
+		m_mainWindow->aspectDock->setAspects(selectedAspects);
+		break;
 	case AspectType::WorksheetElement:
 	case AspectType::WorksheetElementContainer:
 	case AspectType::WorksheetElementGroup:
@@ -473,4 +496,3 @@ void GuiObserver::hiddenAspectSelected(const AbstractAspect* aspect) const {
 		break;
 	}
 }
-
