@@ -1,43 +1,35 @@
-/***************************************************************************
+/*
     File                 : GuiTools.cpp
     Project              : LabPlot
-    --------------------------------------------------------------------
-    Copyright            : (C) 2011-2013 Alexander Semke (alexander.semke*web.de)
-                           (replace * with @ in the email addresses)
     Description          :  contains several static functions which are used on frequently throughout the kde frontend.
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2011-2013 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "GuiTools.h"
+#include "backend/worksheet/plots/cartesian/Symbol.h"
+
 #include <KI18n/KLocalizedString>
 
-#include <array>
 #include <QApplication>
+#include <QDesktopWidget>
+#include <QColor>
 #include <QComboBox>
+#include <QFileDialog>
+#include <QImageReader>
 #include <QLineEdit>
 #include <QMenu>
-#include <QColor>
 #include <QPainter>
 
+#ifdef HAVE_POPPLER
+#include <poppler-qt5.h>
+#endif
+
+#include <array>
+
 static const int colorsCount = 26;
 static std::array<QColor, colorsCount> colors = {QColor(255,255,255), QColor(0,0,0),
 							QColor(192,0,0), QColor(255,0,0), QColor(255,192,192), //red
@@ -98,7 +90,7 @@ void GuiTools::updatePenStyles(QMenu* menu, QActionGroup* actionGroup, const QCo
 	QAction* action;
 	if (actionGroup->actions().isEmpty()) {
 		//TODO setting of the icon size doesn't work here
-		menu->setStyleSheet( "QMenu::icon { width:50px; height:10px; }" );
+		menu->setStyleSheet( QLatin1String("QMenu::icon { width:50px; height:10px; }") );
 
 		for (int i = 0; i < 6; i++) {
 			pm.fill(Qt::transparent);
@@ -187,7 +179,7 @@ void GuiTools::fillColorMenu(QMenu* menu, QActionGroup* actionGroup) {
 	QPainter p(&pix);
 	for (int i = 0; i < colorsCount; ++i) {
 		p.fillRect(pix.rect(), colors[i]);
-		QAction* action = new QAction(QIcon(pix), colorNames[i], actionGroup);
+		auto* action = new QAction(QIcon(pix), colorNames[i], actionGroup);
 		action->setCheckable(true);
 		menu->addAction(action);
 	}
@@ -233,7 +225,129 @@ QColor& GuiTools::colorFromAction(QActionGroup* actionGroup, QAction* action) {
 
 void GuiTools::highlight(QLineEdit* le, bool invalid) {
 	if (invalid)
-		le->setStyleSheet(QStringLiteral("QLineEdit{color:red;}"));
+		SET_WARNING_STYLE(le)
 	else
 		le->setStyleSheet(QString());
 }
+
+void GuiTools::addSymbolStyles(QComboBox* cb) {
+	QPainter pa;
+	QPen pen(Qt::SolidPattern, 0);
+	const QColor& color = (QApplication::palette().color(QPalette::Base).lightness() < 128) ? Qt::white : Qt::black;
+	pen.setColor(color);
+	pa.setPen(pen);
+
+	int iconSize = 20;
+	QPixmap pm(iconSize, iconSize);
+	cb->setIconSize(QSize(iconSize, iconSize));
+	QTransform trafo;
+	trafo.scale(15, 15);
+
+	for (int i = 0; i < Symbol::stylesCount(); ++i) {
+		//get styles in order
+		const auto style = Symbol::indexToStyle(i);
+		pm.fill(Qt::transparent);
+		pa.begin(&pm);
+		pa.setPen(pen);
+		pa.setRenderHint(QPainter::Antialiasing);
+		pa.translate(iconSize/2,iconSize/2);
+		pa.drawPath(trafo.map(Symbol::stylePath(style)));
+		pa.end();
+		cb->addItem(QIcon(pm), Symbol::styleName(style), (int)style);
+	}
+}
+
+QString GuiTools::openImageFile(const QString& className) {
+	KConfigGroup conf(KSharedConfig::openConfig(), className);
+	const QString& dir = conf.readEntry(QLatin1String("LastImageDir"), QString());
+
+	QString formats;
+	for (const QByteArray& format : QImageReader::supportedImageFormats()) {
+		QString f = QLatin1String("*.") + QLatin1String(format.constData());
+		if (f == QLatin1String("*.svg"))
+			continue;
+		formats += f + QLatin1Char(' ');
+	}
+
+	const QString& path = QFileDialog::getOpenFileName(nullptr, i18nc("@title:window", "Open Image File"), dir, i18n("Images (%1)", formats));
+	if (!path.isEmpty()) {
+		int pos = path.lastIndexOf(QLatin1String("/"));
+		if (pos != -1) {
+			QString newDir = path.left(pos);
+			if (newDir != dir)
+				conf.writeEntry(QLatin1String("LastImageDir"), newDir);
+		}
+	}
+
+	return path;
+}
+
+// convert PDF to QImage using Poppler
+QImage GuiTools::importPDFFile(const QString& fileName) {
+	//DEBUG(Q_FUNC_INFO << ", PDF file name = " << STDSTRING(fileName));
+#ifdef HAVE_POPPLER
+	auto* document = Poppler::Document::load(fileName);
+	if (!document) {
+		WARN("Failed to process PDF file" << STDSTRING(fileName));
+		delete document;
+		return {};
+	}
+
+	auto* page = document->page(0);
+	if (!page) {
+		WARN("Failed to process the first page in the PDF file.")
+		delete document;
+		return {};
+	}
+
+	document->setRenderHint(Poppler::Document::TextAntialiasing);
+	document->setRenderHint(Poppler::Document::Antialiasing);
+	document->setRenderHint(Poppler::Document::TextHinting);
+	document->setRenderHint(Poppler::Document::TextSlightHinting);
+	document->setRenderHint(Poppler::Document::ThinLineSolid);
+
+	const static int dpi = QApplication::desktop()->logicalDpiX();
+	QImage image = page->renderToImage(dpi, dpi);
+
+	delete page;
+	delete document;
+
+	return image;
+#else
+	return {};
+#endif
+}
+
+QImage GuiTools::imageFromPDFData(const QByteArray& data, double zoomFactor) {
+#ifdef HAVE_POPPLER
+	auto* document = Poppler::Document::loadFromData(data);
+	if (!document) {
+		WARN("Failed to process the byte array");
+		delete document;
+		return {};
+	}
+
+	auto* page = document->page(0);
+	if (!page) {
+		WARN("Failed to process the first page in the PDF file.")
+		delete document;
+		return {};
+	}
+
+	document->setRenderHint(Poppler::Document::TextAntialiasing);
+	document->setRenderHint(Poppler::Document::Antialiasing);
+	document->setRenderHint(Poppler::Document::TextHinting);
+	document->setRenderHint(Poppler::Document::TextSlightHinting);
+	document->setRenderHint(Poppler::Document::ThinLineSolid);
+
+	const static int dpi = QApplication::desktop()->logicalDpiX();
+	QImage image = page->renderToImage(zoomFactor * dpi , zoomFactor * dpi);
+
+	delete page;
+	delete document;
+
+	return image;
+#else
+	return {};
+#endif
+}
