@@ -1,30 +1,12 @@
-/***************************************************************************
+/*
     File                 : HistoryDialog.cpp
     Project              : LabPlot
     Description          : history dialog
     --------------------------------------------------------------------
-    Copyright            : (C) 2012-2019 by Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2012-2019 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 #include "HistoryDialog.h"
 
 #include <QDialogButtonBox>
@@ -48,13 +30,13 @@
 HistoryDialog::HistoryDialog(QWidget* parent, QUndoStack* stack, const QString& emptyLabel) : QDialog(parent),
 	m_undoStack(stack) {
 	auto* undoView = new QUndoView(stack, this);
-	undoView->setCleanIcon( QIcon::fromTheme("edit-clear-history") );
+	undoView->setCleanIcon( QIcon::fromTheme(QLatin1String("edit-clear-history")) );
 	undoView->setEmptyLabel(emptyLabel);
 	undoView->setMinimumWidth(350);
 	undoView->setWhatsThis(i18n("List of all performed steps/actions.\n"
 	                            "Select an item in the list to navigate to the corresponding step."));
 
-	setWindowIcon( QIcon::fromTheme("view-history") );
+	setWindowIcon( QIcon::fromTheme(QLatin1String("view-history")) );
 	setWindowTitle(i18nc("@title:window", "Undo/Redo History"));
 	setAttribute(Qt::WA_DeleteOnClose);
 	auto* btnBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
@@ -69,11 +51,11 @@ HistoryDialog::HistoryDialog(QWidget* parent, QUndoStack* stack, const QString&
 		btnBox->addButton(m_clearUndoStackButton, QDialogButtonBox::ActionRole);
 		m_clearUndoStackButton->setText(i18n("&Clear"));
 		m_clearUndoStackButton->setToolTip(i18n("Clears the undo history. Commands are not undone or redone; the state of the project remains unchanged."));
-		m_clearUndoStackButton->setIcon(QIcon::fromTheme("edit-clear"));
+		m_clearUndoStackButton->setIcon( QIcon::fromTheme(QLatin1String("edit-clear")) );
 		connect(m_clearUndoStackButton, &QPushButton::clicked, this, &HistoryDialog::clearUndoStack);
 	}
 
-	QFrame* line = new QFrame;
+	auto* line = new QFrame;
 	line->setFrameShape(QFrame::HLine);
 	line->setFrameShadow(QFrame::Sunken);
 
