@@ -1,30 +1,13 @@
-/***************************************************************************
+/*
     File                 : MainWin.h
     Project              : LabPlot
-    --------------------------------------------------------------------
-    Copyright            : (C) 2011-2020 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2008-2018 by Stefan Gerlach (stefan.gerlach@uni.kn)
     Description          : Main window of the application
- ***************************************************************************/
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2011-2020 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2008-2018 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef MAINWIN_H
 #define MAINWIN_H
 
@@ -45,12 +28,14 @@ class Datapicker;
 class Spreadsheet;
 class Matrix;
 class GuiObserver;
+class AspectDock;
 class AxisDock;
 class CursorDock;
+class InfoElementDock;
 class NoteDock;
 class CartesianPlotDock;
 class HistogramDock;
-class BarChartPlotDock;
+class BoxPlotDock;
 class CartesianPlotLegendDock;
 class CustomPointDock;
 class ReferenceLineDock;
@@ -69,6 +54,7 @@ class XYSmoothCurveDock;
 class XYFitCurveDock;
 class XYFourierFilterCurveDock;
 class XYFourierTransformCurveDock;
+class XYHilbertTransformCurveDock;
 class XYConvolutionCurveDock;
 class XYCorrelationCurveDock;
 class WorksheetDock;
@@ -78,6 +64,7 @@ class DatapickerImageWidget;
 class DatapickerCurveWidget;
 class MemoryWidget;
 class CartesianPlot;
+class InfoElementDialog;
 
 #ifdef HAVE_CANTOR_LIBS
 class CantorWorksheet;
@@ -98,14 +85,16 @@ class QToolButton;
 class QQuickWidget;
 
 class KColorSchemeManager;
+class KHamburgerMenu;
 class KRecentFilesAction;
+class KToggleAction;
 class KToggleFullScreenAction;
 
 #ifdef HAVE_KUSERFEEDBACK
 #include <KUserFeedback/Provider>
 #endif
 
-#ifdef Q_OS_MAC
+#ifdef HAVE_TOUCHBAR
 	class KDMacTouchBar;
 #endif
 
@@ -113,7 +102,7 @@ class MainWin : public KXmlGuiWindow {
 	Q_OBJECT
 
 public:
-	explicit MainWin(QWidget* parent = nullptr, const QString& filename = nullptr);
+	explicit MainWin(QWidget* parent = nullptr, const QString& filename = QString());
 	~MainWin() override;
 
 	void showPresenter();
@@ -121,7 +110,7 @@ public:
 	Project* project() const;
 	void addAspectToProject(AbstractAspect*);
 
-	enum class LoadOnStart {Nothing, NewProject, NewProjectWorksheet, LastProject, WelcomeScreen};
+	enum class LoadOnStart {Nothing, NewProject, NewProjectWorksheet, NewProjectSpreadsheet, LastProject, WelcomeScreen};
 	enum class TitleBarMode {ShowFilePath, ShowFileName, ShowProjectName};
 
 #ifdef HAVE_KUSERFEEDBACK
@@ -139,7 +128,6 @@ private:
 	QDockWidget* m_propertiesDock{nullptr};
 	AbstractAspect* m_currentAspect{nullptr};
 	Folder* m_currentFolder{nullptr};
-	QString m_currentFileName;
 	QString m_undoViewEmptyLabel;
 	bool m_suppressCurrentSubWindowChangedEvent{false};
 	bool m_closing{false};
@@ -154,6 +142,8 @@ private:
 // 	WelcomeScreenHelper* m_welcomeScreenHelper{nullptr};
 	ImportDatasetWidget* m_importDatasetWidget{nullptr};
 	QString m_lastOpenFileFilter;
+	const Worksheet* m_lastWorksheet{nullptr};
+	const Spreadsheet* m_lastSpreadsheet{nullptr};
 	TitleBarMode m_titleBarMode{TitleBarMode::ShowFilePath};
 
 #ifdef HAVE_KUSERFEEDBACK
@@ -161,17 +151,21 @@ private:
 #endif
 
 #ifdef Q_OS_MAC
+#ifdef HAVE_TOUCHBAR
 	KDMacTouchBar* m_touchBar;
+#endif
 	QAction* m_undoIconOnlyAction;
 	QAction* m_redoIconOnlyAction;
 #endif
 
 	KRecentFilesAction* m_recentProjectsAction;
+	QAction* m_searchAction;
 	QAction* m_saveAction;
 	QAction* m_saveAsAction;
 	QAction* m_printAction;
 	QAction* m_printPreviewAction;
 	QAction* m_importFileAction;
+	QAction* m_importFileAction_2;
 	QAction* m_importSqlAction;
 	QAction* m_importDatasetAction;
 	QAction* m_importLabPlotAction;
@@ -199,12 +193,11 @@ private:
 	QAction* m_nextWindowAction;
 	QAction* m_prevWindowAction;
 	QAction* m_newDatapickerAction;
-	QAction* m_editFitsFileAction;
 
-	//toggling doch widgets and the status bar
+	//toggling dock widgets, status bar and full screen
 	QAction* m_toggleProjectExplorerDockAction;
 	QAction* m_togglePropertiesDockAction;
-	QAction* m_toggleStatusBarAction;
+	KToggleAction* m_toggleStatusBarAction;
 	QAction* m_toggleMemoryInfoAction;
 	KToggleFullScreenAction* m_toggleFullScreenAction;
 
@@ -216,15 +209,17 @@ private:
 	//Menus
 	QMenu* m_visibilityMenu{nullptr};
 	QMenu* m_newMenu{nullptr};
-	QMenu* m_importMenu;
-	QMenu* m_editMenu{nullptr};
+	QMenu* m_importMenu{nullptr};
+	KHamburgerMenu* m_hamburgerMenu{nullptr};
 
 	//Docks
 	QStackedWidget* stackedWidget{nullptr};
+	AspectDock* aspectDock{nullptr};
 	AxisDock* axisDock{nullptr};
 	QDockWidget* cursorDock{nullptr};
 	CursorDock* cursorWidget{nullptr};
 	NoteDock* notesDock{nullptr};
+	InfoElementDock* infoElementDock{nullptr};
 	CartesianPlotDock* cartesianPlotDock{nullptr};
 	CartesianPlotLegendDock* cartesianPlotLegendDock{nullptr};
 	ColumnDock* columnDock{nullptr};
@@ -242,9 +237,11 @@ private:
 	XYFitCurveDock* xyFitCurveDock{nullptr};
 	XYFourierFilterCurveDock* xyFourierFilterCurveDock{nullptr};
 	XYFourierTransformCurveDock* xyFourierTransformCurveDock{nullptr};
+	XYHilbertTransformCurveDock* xyHilbertTransformCurveDock{nullptr};
 	XYConvolutionCurveDock* xyConvolutionCurveDock{nullptr};
 	XYCorrelationCurveDock* xyCorrelationCurveDock{nullptr};
 	HistogramDock* histogramDock{nullptr};
+	BoxPlotDock* boxPlotDock{nullptr};
 	WorksheetDock* worksheetDock{nullptr};
 	LabelWidget* textLabelDock{nullptr};
 	ImageDock* imageDock{nullptr};
@@ -265,7 +262,6 @@ private:
 
 	//Cantor
 #ifdef HAVE_CANTOR_LIBS
-	QMenu* m_newCantorWorksheetMenu;
 	CantorWorksheetDock* cantorWorksheetDock{nullptr};
 #endif
 
@@ -277,7 +273,7 @@ protected:
 	void dragEnterEvent(QDragEnterEvent*) override;
 	void dropEvent(QDropEvent*) override;
 
-private slots:
+private Q_SLOTS:
 	void initGUI(const QString&);
 // 	QQuickWidget* createWelcomeScreen();
 // 	void resetWelcomeScreen();
@@ -326,7 +322,7 @@ private slots:
 	void newNotes();
 	void newDatapicker();
 	//TODO: void newScript();
-	void newLiveDataSourceActionTriggered();
+	void newLiveDataSource();
 
 	void createContextMenu(QMenu*) const;
 	void createFolderContextMenu(const Folder*, QMenu*) const;
@@ -334,7 +330,7 @@ private slots:
 	void handleAspectAdded(const AbstractAspect*);
 	void handleAspectAboutToBeRemoved(const AbstractAspect*);
 	void handleAspectRemoved(const AbstractAspect*,const AbstractAspect*,const AbstractAspect*);
-	void handleCurrentAspectChanged(AbstractAspect* );
+	void handleCurrentAspectChanged(AbstractAspect*);
 	void handleCurrentSubWindowChanged(QMdiSubWindow*);
 	void handleShowSubWindowRequested();
 
@@ -343,7 +339,8 @@ private slots:
 	void setMdiWindowVisibility(QAction*);
 	void updateMdiWindowVisibility() const;
 	void toggleDockWidget(QAction*);
-	void toggleStatusBar();
+	void toggleStatusBar(bool);
+	void toggleMenuBar(bool);
 	void toggleMemoryInfo();
 	void toggleFullScreen(bool);
 	void projectExplorerDockVisibilityChanged(bool);
