@@ -1,30 +1,13 @@
-/***************************************************************************
+/*
     File                 : SettingsWorksheetPage.cpp
     Project              : LabPlot
     Description          : settings page for Worksheet
     --------------------------------------------------------------------
-    Copyright            : (C) 2008-2017 Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2008-2017 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "SettingsWorksheetPage.h"
 #include "tools/TeXRenderer.h"
@@ -63,8 +46,8 @@ SettingsWorksheetPage::SettingsWorksheetPage(QWidget* parent) : SettingsPage(par
 		ui.cbTexEngine->addItem(QLatin1String("LaTeX"), QLatin1String("latex"));
 
 	connect(m_cbThemes, &ThemesComboBox::currentThemeChanged, this, &SettingsWorksheetPage::changed);
-	connect(ui.chkPresenterModeInteractive, &QCheckBox::stateChanged, this, &SettingsWorksheetPage::changed);
-	connect(ui.chkDoubleBuffering, &QCheckBox::stateChanged, this, &SettingsWorksheetPage::changed);
+	connect(ui.chkPresenterModeInteractive, &QCheckBox::toggled, this, &SettingsWorksheetPage::changed);
+	connect(ui.chkDoubleBuffering, &QCheckBox::toggled, this, &SettingsWorksheetPage::changed);
 	connect(ui.cbTexEngine, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &SettingsWorksheetPage::changed);
 	connect(ui.cbTexEngine, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &SettingsWorksheetPage::checkTeX);
 
@@ -138,7 +121,7 @@ void SettingsWorksheetPage::loadSettings() {
 
 void SettingsWorksheetPage::changed() {
 	m_changed = true;
-	emit settingsChanged();
+	Q_EMIT settingsChanged();
 }
 
 /*!
@@ -152,37 +135,36 @@ void SettingsWorksheetPage::checkTeX(int engineIndex) {
 		return;
 	}
 
-	//engine found, check the presence of other required tools (s.a. TeXRenderer.cpp):
-	//to convert the generated PDF/PS files to PNG we need 'convert' from the ImageMagic package
-	if (!TeXRenderer::executableExists(QLatin1String("convert"))) {
-		ui.lLatexWarning->show();
-		ui.lLatexWarning->setToolTip(i18n("No 'convert' found. LaTeX typesetting not possible."));
-		return;
-	}
-
 	QString engine = ui.cbTexEngine->itemData(engineIndex).toString();
+
 	if (engine == "latex") {
+		// need convert to convert to PNG
+		if (!TeXRenderer::executableExists(QLatin1String("convert"))) {
+			ui.lLatexWarning->show();
+			ui.lLatexWarning->setToolTip(i18n("No 'convert' found. LaTeX typesetting not possible."));
+			return;
+		}
 		//to convert the generated PS files to DVI we need 'dvips'
 		if (!TeXRenderer::executableExists(QLatin1String("dvips"))) {
 			ui.lLatexWarning->show();
 			ui.lLatexWarning->setToolTip(i18n("No 'dvips' found. LaTeX typesetting not possible."));
 			return;
 		}
-	}
 
 #if defined(_WIN64)
-	if (!TeXRenderer::executableExists(QLatin1String("gswin64c"))) {
-		ui.lLatexWarning->show();
-		ui.lLatexWarning->setToolTip(i18n("No Ghostscript found. LaTeX typesetting not possible."));
-		return;
-	}
+		if (!TeXRenderer::executableExists(QLatin1String("gswin64c"))) {
+			ui.lLatexWarning->show();
+			ui.lLatexWarning->setToolTip(i18n("No Ghostscript found. LaTeX typesetting not possible."));
+			return;
+		}
 #elif defined(HAVE_WINDOWS)
-	if (!TeXRenderer::executableExists(QLatin1String("gswin32c"))) {
-		ui.lLatexWarning->show();
-		ui.lLatexWarning->setToolTip(i18n("No Ghostscript found. LaTeX typesetting not possible."));
-		return;
-	}
+		if (!TeXRenderer::executableExists(QLatin1String("gswin32c"))) {
+			ui.lLatexWarning->show();
+			ui.lLatexWarning->setToolTip(i18n("No Ghostscript found. LaTeX typesetting not possible."));
+			return;
+		}
 #endif
+	}
 
 	ui.lLatexWarning->hide();
 }
