@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : TemplateHandler.cpp
     Project              : LabPlot
     Description          : Widget for handling saving and loading of templates
     --------------------------------------------------------------------
-    Copyright            : (C) 2012 by Stefan Gerlach (stefan.gerlach@uni.kn)
-    Copyright            : (C) 2012-2020 by Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2012 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-FileCopyrightText: 2012-2020 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "TemplateHandler.h"
 
@@ -254,8 +236,8 @@ void TemplateHandler::loadMenu() {
 void TemplateHandler::loadMenuSelected(QAction* action) {
 	QString configFile = m_dirName + m_subDirNames.at(static_cast<int>(m_className)) + '/' + action->data().toString();
 	KConfig config(configFile, KConfig::SimpleConfig);
-	emit loadConfigRequested(config);
-	emit info( i18n("Template \"%1\" was loaded.", action->text().remove('&')) );
+	Q_EMIT loadConfigRequested(config);
+	Q_EMIT info( i18n("Template \"%1\" was loaded.", action->text().remove('&')) );
 }
 
 void TemplateHandler::saveMenu() {
@@ -281,7 +263,7 @@ void TemplateHandler::saveMenu() {
 	QLabel* label = new QLabel(i18n("New:"), frame);
 	layout->addWidget(label);
 
-	QLineEdit* leFilename = new QLineEdit(QString(), frame);
+	auto* leFilename = new QLineEdit(QString(), frame);
 	layout->addWidget(leFilename);
 	connect(leFilename, &QLineEdit::returnPressed, this, [=]() {saveNewSelected(leFilename->text());} );
 	connect(leFilename, &QLineEdit::returnPressed, &menu, &QMenu::close);
@@ -303,8 +285,8 @@ void TemplateHandler::saveMenu() {
 void TemplateHandler::saveNewSelected(const QString& filename) {
 	QString path = m_dirName + m_subDirNames.at(static_cast<int>(m_className)) + '/' + filename;
 	KConfig config(path, KConfig::SimpleConfig);
-	emit saveConfigRequested(config);
-	emit info( i18n("New template \"%1\" was saved.", filename) );
+	Q_EMIT saveConfigRequested(config);
+	Q_EMIT info( i18n("New template \"%1\" was saved.", filename) );
 
 	//we have at least one saved template now -> enable the load button
 	m_tbLoad->setEnabled(true);
@@ -316,8 +298,8 @@ void TemplateHandler::saveNewSelected(const QString& filename) {
  */
 void TemplateHandler::saveMenuSelected(QAction* action) {
 	KConfig config(action->data().toString()+'/'+action->text(), KConfig::SimpleConfig);
-	emit saveConfigRequested(config);
-	emit info( i18n("Template \"%1\" was saved.", action->text()) );
+	Q_EMIT saveConfigRequested(config);
+	Q_EMIT info( i18n("Template \"%1\" was saved.", action->text()) );
 }
 
 /*!
@@ -326,6 +308,6 @@ void TemplateHandler::saveMenuSelected(QAction* action) {
  */
 void TemplateHandler::saveDefaults() {
 	KConfig config;
-	emit saveConfigRequested(config);
-	emit info( i18n("New default template was saved.") );
+	Q_EMIT saveConfigRequested(config);
+	Q_EMIT info( i18n("New default template was saved.") );
 }
