@@ -1,32 +1,14 @@
-/***************************************************************************
+/*
     File                 : ThemeHandler.cpp
     Project              : LabPlot
     Description          : Widget for handling saving and loading of themes
     --------------------------------------------------------------------
-    Copyright            : (C) 2016 Prakriti Bhardwaj (p_bhardwaj14@informatik.uni-kl.de)
-    Copyright            : (C) 2016-2017 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2018 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2016 Prakriti Bhardwaj <p_bhardwaj14@informatik.uni-kl.de>
+    SPDX-FileCopyrightText: 2016-2017 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "ThemeHandler.h"
 #include "widgets/ThemesWidget.h"
@@ -44,7 +26,7 @@
 #include <KConfigGroup>
 #include <KLocalizedString>
 
-#include <KMessageBox>
+// #include <KMessageBox>
 // #include <KNS3/UploadDialog>
 
 /*!
@@ -64,7 +46,8 @@ ThemeHandler::ThemeHandler(QWidget* parent) : QWidget(parent) {
 
 	m_pbLoadTheme = new QPushButton(this);
 	horizontalLayout->addWidget(m_pbLoadTheme);
-	m_pbLoadTheme->setText(i18n("Apply Theme"));
+	m_pbLoadTheme->setText(i18n("Theme"));
+	m_pbLoadTheme->setIcon(QIcon::fromTheme("color-management"));
 
 // 	pbSaveTheme = new QPushButton(this);
 // 	horizontalLayout->addWidget(pbSaveTheme);
@@ -127,6 +110,8 @@ QStringList ThemeHandler::themes() {
 		QDEBUG("	themes = " << themes);
 	}
 
+	themes.sort();
+
 	return themes;
 }
 
@@ -153,10 +138,10 @@ const QString ThemeHandler::themeFilePath(const QString& name) {
 
 void ThemeHandler::setCurrentTheme(const QString& name) {
 	if (!name.isEmpty()) {
-		m_pbLoadTheme->setText(i18n("Apply theme [active '%1']", name));
+		m_pbLoadTheme->setText(i18n("Theme '%1'", name));
 		m_pbLoadTheme->setToolTip(i18n("Theme '%1' is active. Click on the button to change the theme.", name));
 	} else {
-		m_pbLoadTheme->setText(i18n("Apply Theme"));
+		m_pbLoadTheme->setText(i18n("Theme"));
 		m_pbLoadTheme->setToolTip(i18n("No theme is active. Click on the button to select a theme."));
 	}
 
@@ -164,13 +149,13 @@ void ThemeHandler::setCurrentTheme(const QString& name) {
 }
 
 void ThemeHandler::loadSelected(const QString& name) {
-	emit loadThemeRequested(name);
+	Q_EMIT loadThemeRequested(name);
 	this->setCurrentTheme(name);
 
 	if (!name.isEmpty())
-		emit info( i18n("Theme \"%1\" was loaded.", name) );
+		Q_EMIT info( i18n("Theme \"%1\" was loaded.", name) );
 	else
-		emit info( i18n("Theming deactivated.") );
+		Q_EMIT info( i18n("Theming deactivated.") );
 
 	//in case a local theme file was loaded (we have write access), allow to publish it
 	//TODO: activate this later
@@ -184,6 +169,7 @@ void ThemeHandler::loadSelected(const QString& name) {
 }
 
 void ThemeHandler::showPanel() {
+#ifndef SDK
 	QMenu menu;
 	ThemesWidget themeWidget(&menu);
 	themeWidget.setFixedMode();
@@ -197,6 +183,7 @@ void ThemeHandler::showPanel() {
 
 	QPoint pos(-menu.sizeHint().width()+m_pbLoadTheme->width(),-menu.sizeHint().height());
 	menu.exec(m_pbLoadTheme->mapToGlobal(pos));
+#endif
 }
 
 // void ThemeHandler::saveMenu() {
@@ -226,8 +213,8 @@ void ThemeHandler::showPanel() {
 
 // void ThemeHandler::saveNewSelected(const QString& filename) {
 // 	KConfig config(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + '/' + "themes" + '/' + filename, KConfig::SimpleConfig);
-// 	emit saveThemeRequested(config);
-// 	emit info( i18n("New theme \"%1\" was saved.", filename) );
+// 	Q_EMIT saveThemeRequested(config);
+// 	Q_EMIT info( i18n("New theme \"%1\" was saved.", filename) );
 //
 // 	m_currentLocalTheme = filename;
 // 	m_themeList.append(config.name());
