@@ -1,30 +1,11 @@
-/***************************************************************************
-File                 : DatabaseManagerWidget.cpp
-Project              : LabPlot
-Description          : widget for managing database connections
---------------------------------------------------------------------
-Copyright            : (C) 2017-2018 Alexander Semke (alexander.semke@web.de)
-
-***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+/*
+    File                 : DatabaseManagerWidget.cpp
+    Project              : LabPlot
+    Description          : widget for managing database connections
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2017-2018 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "DatabaseManagerWidget.h"
 #include "backend/lib/macros.h"
@@ -42,9 +23,9 @@ Copyright            : (C) 2017-2018 Alexander Semke (alexander.semke@web.de)
 #include <QSqlError>
 
 #ifdef HAVE_KF5_SYNTAX_HIGHLIGHTING
-#include <KF5/KSyntaxHighlighting/SyntaxHighlighter>
-#include <KF5/KSyntaxHighlighting/Definition>
-#include <KF5/KSyntaxHighlighting/Theme>
+#include <KSyntaxHighlighting/SyntaxHighlighter>
+#include <KSyntaxHighlighting/Definition>
+#include <KSyntaxHighlighting/Theme>
 #endif
 
 /*!
@@ -54,10 +35,9 @@ Copyright            : (C) 2017-2018 Alexander Semke (alexander.semke@web.de)
    \ingroup kdefrontend
 */
 DatabaseManagerWidget::DatabaseManagerWidget(QWidget* parent, QString conn) : QWidget(parent),
+	m_configPath(QStandardPaths::standardLocations(QStandardPaths::AppDataLocation).constFirst() +  "sql_connections"),
 	m_initConnName(std::move(conn)) {
 
-	m_configPath = QStandardPaths::standardLocations(QStandardPaths::AppDataLocation).constFirst() +  "sql_connections";
-
 	ui.setupUi(this);
 
 	ui.tbAdd->setIcon(QIcon::fromTheme("list-add"));
@@ -79,13 +59,13 @@ DatabaseManagerWidget::DatabaseManagerWidget(QWidget* parent, QString conn) : QW
 	connect(ui.tbDelete, &QToolButton::clicked, this, &DatabaseManagerWidget::deleteConnection);
 	connect(ui.bTestConnection, &QPushButton::clicked, this, &DatabaseManagerWidget::testConnection);
 	connect(ui.bOpen, &QPushButton::clicked, this, &DatabaseManagerWidget::selectFile);
-	connect(ui.cbDriver, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &DatabaseManagerWidget::driverChanged);
+	connect(ui.cbDriver, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &DatabaseManagerWidget::driverChanged);
 
 	connect(ui.leName, &QLineEdit::textChanged, this, &DatabaseManagerWidget::nameChanged);
 	connect(ui.leDatabase, &QLineEdit::textChanged, this, &DatabaseManagerWidget::databaseNameChanged);
 	connect(ui.leHost, &QLineEdit::textChanged, this, &DatabaseManagerWidget::hostChanged);
-	connect(ui.sbPort, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &DatabaseManagerWidget::portChanged);
-	connect(ui.chkCustomConnection, &QCheckBox::stateChanged, this, &DatabaseManagerWidget::customConnectionEnabledChanged);
+	connect(ui.sbPort, QOverload<int>::of(&QSpinBox::valueChanged), this, &DatabaseManagerWidget::portChanged);
+	connect(ui.chkCustomConnection, &QCheckBox::toggled, this, &DatabaseManagerWidget::customConnectionEnabledChanged);
 	connect(ui.teCustomConnection, &QPlainTextEdit::textChanged, this, &DatabaseManagerWidget::customConnectionChanged);
 	connect(ui.leUserName, &QLineEdit::textChanged, this, &DatabaseManagerWidget::userNameChanged);
 	connect(ui.lePassword, &QLineEdit::textChanged, this, &DatabaseManagerWidget::passwordChanged);
@@ -96,8 +76,7 @@ DatabaseManagerWidget::DatabaseManagerWidget(QWidget* parent, QString conn) : QW
 QString DatabaseManagerWidget::connection() const {
 	if (ui.lwConnections->currentItem())
 		return ui.lwConnections->currentItem()->text();
-	else
-		return QString();
+	return {};
 }
 
 /*!
@@ -159,7 +138,7 @@ void DatabaseManagerWidget::nameChanged(const QString& name) {
 
 			if (!m_initializing) {
 				m_current_connection->name = name;
-				emit changed();
+				Q_EMIT changed();
 			}
 		}
 	} else
@@ -226,13 +205,13 @@ void DatabaseManagerWidget::driverChanged() {
 
 	if (m_current_connection)
 		m_current_connection->driver = driver;
-	emit changed();
+	Q_EMIT changed();
 }
 
 void DatabaseManagerWidget::selectFile() {
 	KConfigGroup conf(KSharedConfig::openConfig(), QLatin1String("DatabaseManagerWidget"));
 	QString dir = conf.readEntry(QLatin1String("LastDir"), "");
-	QString path = QFileDialog::getOpenFileName(this, i18n("Select the database file"), dir);
+	QString path = QFileDialog::getOpenFileName(this, i18nc("@title:window", "Select the Database File"), dir);
 	if (path.isEmpty())
 		return; //cancel was clicked in the file-dialog
 
@@ -256,7 +235,7 @@ void DatabaseManagerWidget::hostChanged() {
 	//don't allow to try to connect if no hostname provided
 	ui.bTestConnection->setEnabled( !ui.leHost->text().simplified().isEmpty() );
 
-	emit changed();
+	Q_EMIT changed();
 }
 
 void DatabaseManagerWidget::portChanged() {
@@ -265,7 +244,7 @@ void DatabaseManagerWidget::portChanged() {
 
 	if (m_current_connection)
 		m_current_connection->port = ui.sbPort->value();
-	emit changed();
+	Q_EMIT changed();
 }
 
 void DatabaseManagerWidget::databaseNameChanged() {
@@ -296,30 +275,30 @@ void DatabaseManagerWidget::databaseNameChanged() {
 
 	if (m_current_connection)
 		m_current_connection->dbName = dbName;
-	emit changed();
+	Q_EMIT changed();
 }
 
-void DatabaseManagerWidget::customConnectionEnabledChanged(int state) {
+void DatabaseManagerWidget::customConnectionEnabledChanged(bool state) {
 	//in case custom connection string is provided:
 	//disable the line edit for the database name
 	//and hide the textedit for the connection string
-	ui.leDatabase->setEnabled(state != Qt::Checked);
-	ui.teCustomConnection->setVisible(state == Qt::Checked);
+	ui.leDatabase->setEnabled(!state);
+	ui.teCustomConnection->setVisible(state);
 
-	if (state == Qt::Checked)
+	if (state)
 		ui.teCustomConnection->setFocus();
 	else
 		ui.leDatabase->setFocus();
 
 	if (m_current_connection)
-		m_current_connection->customConnectionEnabled = (state == Qt::Checked);
-	emit changed();
+		m_current_connection->customConnectionEnabled = state;
+	Q_EMIT changed();
 }
 
 void DatabaseManagerWidget::customConnectionChanged() {
 	if (m_current_connection)
 		m_current_connection->customConnectionString = ui.teCustomConnection->toPlainText();
-	emit changed();
+	Q_EMIT changed();
 }
 
 void DatabaseManagerWidget::userNameChanged() {
@@ -328,7 +307,7 @@ void DatabaseManagerWidget::userNameChanged() {
 
 	if (m_current_connection)
 		m_current_connection->userName = ui.leUserName->text();
-	emit changed();
+	Q_EMIT changed();
 }
 
 void DatabaseManagerWidget::passwordChanged() {
@@ -337,7 +316,7 @@ void DatabaseManagerWidget::passwordChanged() {
 
 	if (m_current_connection)
 		m_current_connection->password = ui.lePassword->text();
-	emit changed();
+	Q_EMIT changed();
 }
 
 void DatabaseManagerWidget::addConnection() {
@@ -414,7 +393,7 @@ void DatabaseManagerWidget::deleteConnection() {
 		m_initializing = false;
 	}
 
-	emit changed();
+	Q_EMIT changed();
 }
 
 void DatabaseManagerWidget::loadConnections() {
