@@ -1,30 +1,11 @@
-/***************************************************************************
-File                 : DatasetMetadataManagerWidget.cpp
-Project              : LabPlot
-Description          : widget for managing a metadata file of a dataset
---------------------------------------------------------------------
-Copyright            : (C) 2019 Ferencz Kovacs (kferike98@gmail.com)
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+/*
+    File                 : DatasetMetadataManagerWidget.cpp
+    Project              : LabPlot
+    Description          : widget for managing a metadata file of a dataset
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2019 Ferencz Kovacs <kferike98@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "backend/datasources/filters/AsciiFilter.h"
 #include "src/kdefrontend/DatasetModel.h"
@@ -69,20 +50,20 @@ DatasetMetadataManagerWidget::DatasetMetadataManagerWidget(QWidget* parent, cons
 	ui.cbDateTimeFormat->addItems(AbstractColumn::dateTimeFormats());
 
 	connect(ui.leDatasetName, &QLineEdit::textChanged, [this] {
-		emit checkOk();
+		Q_EMIT checkOk();
 	});
 	connect(ui.leDownloadURL, &QLineEdit::textChanged, [this] {
-		emit checkOk();
+		Q_EMIT checkOk();
 	});
 	connect(ui.teDescription, &QTextEdit::textChanged, [this] {
-		emit checkOk();
+		Q_EMIT checkOk();
 	});
 	connect(ui.leFileName, &QLineEdit::textChanged, [this] {
-		emit checkOk();
+		Q_EMIT checkOk();
 	});
 
 	connect(ui.cbSubcategory, &QComboBox::currentTextChanged, [this] {
-		emit checkOk();
+		Q_EMIT checkOk();
 	});
 
 	connect(ui.cbCollection, &QComboBox::currentTextChanged, this, &DatasetMetadataManagerWidget::updateCategories);
@@ -210,7 +191,7 @@ bool DatasetMetadataManagerWidget::urlExists() {
 	} else {
 		QPalette palette;
 		palette.setColor(QPalette::Base, m_baseColor);
-		palette.setColor(QPalette::Text, m_textColor);;
+		palette.setColor(QPalette::Text, m_textColor);
 		ui.leDownloadURL->setPalette(palette);
 		ui.leDownloadURL->setToolTip("");
 	}
@@ -330,7 +311,7 @@ void DatasetMetadataManagerWidget::updateCategories(const QString& collection) {
 	if( m_datasetModel->collections().contains(collection))
 		ui.cbCategory->addItems(m_datasetModel->categories(collection));
 
-	emit checkOk();
+	Q_EMIT checkOk();
 }
 
 /**
@@ -342,7 +323,7 @@ void DatasetMetadataManagerWidget::updateSubcategories(const QString& category)
 	if( m_datasetModel->categories(collection).contains(category))
 		ui.cbSubcategory->addItems(m_datasetModel->subcategories(collection, category));
 
-	emit checkOk();
+	Q_EMIT checkOk();
 }
 
 /**
@@ -535,9 +516,9 @@ QJsonObject DatasetMetadataManagerWidget::createDatasetObject() {
  * @brief Adds a new QLineEdit so the user can set a new column description.
  */
 void DatasetMetadataManagerWidget::addColumnDescription() {
-	QLabel* label = new QLabel();
+	auto* label = new QLabel();
 	label->setText(i18n("Description for column %1", m_columnDescriptions.size() + 1));
-	QLineEdit* lineEdit = new QLineEdit;
+	auto* lineEdit = new QLineEdit();
 
 	int layoutIndex = m_columnDescriptions.size() + 1;
 	ui.columnLayout->addWidget(label, layoutIndex, 0);
