@@ -1,35 +1,18 @@
-/***************************************************************************
+/*
 	File                 : ImportDatasetWidget.cpp
 	Project              : LabPlot
 	Description          : import online dataset widget
 	--------------------------------------------------------------------
-	Copyright            : (C) 2019 Kovacs Ferencz (kferike98@gmail.com)
-	Copyright            : (C) 2019 by Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2019 Kovacs Ferencz <kferike98@gmail.com>
+    SPDX-FileCopyrightText: 2019 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
-***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "backend/datasources/DatasetHandler.h"
 #include "kdefrontend/datasources/ImportDatasetWidget.h"
 #include "kdefrontend/DatasetModel.h"
+#include "backend/lib/macros.h"
 
 #include <QCompleter>
 #include <QDir>
@@ -71,7 +54,7 @@ ImportDatasetWidget::ImportDatasetWidget(QWidget* parent) : QWidget(parent),
 	ui.leSearch->setPlaceholderText(i18n("Search..."));
 	ui.leSearch->setFocus();
 
-	connect(ui.cbCollections, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
+	connect(ui.cbCollections, QOverload<int>::of(&QComboBox::currentIndexChanged),
 			this, &ImportDatasetWidget::collectionChanged);
 	connect(ui.twCategories, &QTreeWidget::itemDoubleClicked, this, &ImportDatasetWidget::updateDatasets);
 	connect(ui.twCategories, &QTreeWidget::itemSelectionChanged, [this] {
@@ -84,7 +67,7 @@ ImportDatasetWidget::ImportDatasetWidget(QWidget* parent) : QWidget(parent),
 		if (!m_initializing)
 			datasetChanged();
 	});
-	connect(ui.lwDatasets, &QListWidget::doubleClicked, [this]() {emit datasetDoubleClicked(); });
+	connect(ui.lwDatasets, &QListWidget::doubleClicked, [this]() {Q_EMIT datasetDoubleClicked(); });
 	connect(m_networkManager, &QNetworkAccessManager::finished, this, &ImportDatasetWidget::downloadFinished);
 
 	//select the last used collection
@@ -377,8 +360,7 @@ void ImportDatasetWidget::addDatasetItems(const QString& collection, const QStri
 QString ImportDatasetWidget::getSelectedDataset() const {
 	if (!ui.lwDatasets->selectedItems().isEmpty())
 		return ui.lwDatasets->selectedItems().at(0)->text();
-	else
-		return QString();
+	return {};
 }
 
 /**
@@ -386,7 +368,7 @@ QString ImportDatasetWidget::getSelectedDataset() const {
  * @param datasetHandler the DatasetHanlder that downloads processes the dataset
  */
 void ImportDatasetWidget::import(DatasetHandler* datasetHandler) {
-	datasetHandler->processMetadata(m_datasetObject);
+	datasetHandler->processMetadata(m_datasetObject, m_datasetDescription);
 }
 
 /**
@@ -407,7 +389,7 @@ QJsonObject ImportDatasetWidget::loadDatasetObject() {
 				file.close();
 				if (!doc.isObject()) {
 					DEBUG("The " <<  STDSTRING(collection) << ".json file is invalid");
-					return QJsonObject();
+					return {};
 				}
 
 				QJsonArray categoryArray = doc.object().value(QLatin1String("categories")).toArray();
@@ -449,7 +431,7 @@ QJsonObject ImportDatasetWidget::loadDatasetObject() {
 		}
 	}
 
-	return QJsonObject();
+	return {};
 }
 
 /**
@@ -550,21 +532,20 @@ void ImportDatasetWidget::datasetChanged() {
 		info += m_datasetObject[QLatin1String("name")].toString();
 		info += QLatin1String("<br><br>");
 
-		if (m_datasetObject.contains(QLatin1String("description_url"))) {
+		if (m_datasetObject.contains(QLatin1String("description_url"))
+				&& m_networkManager->networkAccessible() == QNetworkAccessManager::Accessible) {
 			WAIT_CURSOR;
-			if (m_networkManager->networkAccessible() == QNetworkAccessManager::Accessible)
-				m_networkManager->get(QNetworkRequest(QUrl(m_datasetObject[QLatin1String("description_url")].toString())));
-			else
-				info += m_datasetObject[QLatin1String("description")].toString();
+			m_networkManager->get(QNetworkRequest(QUrl(m_datasetObject[QLatin1String("description_url")].toString())));
 		} else {
 			info += QLatin1String("<b>") + i18n("Description") + QLatin1String(":</b><br>");
-			info += m_datasetObject[QLatin1String("description")].toString();
+			m_datasetDescription = m_datasetObject[QLatin1String("description")].toString();
 		}
+		info += m_datasetDescription;
 	} else
 		m_datasetObject = QJsonObject();
 
 	ui.lInfo->setText(info);
-	emit datasetSelected();
+	Q_EMIT datasetSelected();
 }
 
 void ImportDatasetWidget::downloadFinished(QNetworkReply* reply) {
@@ -618,9 +599,11 @@ void ImportDatasetWidget::downloadFinished(QNetworkReply* reply) {
 			info = info.replace(QLatin1String("SUBMITTED BY:"), QLatin1String("<b>SUBMITTED BY:</b>"), Qt::CaseSensitive);
 		}
 		ui.lInfo->setText(ui.lInfo->text() + info);
+		m_datasetDescription = info;
 	} else {
 		DEBUG("Failed to fetch the description.");
-		ui.lInfo->setText(ui.lInfo->text() + m_datasetObject[QLatin1String("description")].toString());
+		m_datasetDescription =  m_datasetObject[QLatin1String("description")].toString();
+		ui.lInfo->setText(ui.lInfo->text() + m_datasetDescription);
 	}
 	reply->deleteLater();
 	RESET_CURSOR;
