@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : ImportDialog.cc
     Project              : LabPlot
     Description          : import file data dialog
     --------------------------------------------------------------------
-    Copyright            : (C) 2008-2018 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2008-2015 by Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2008-2018 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2008-2015 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "ImportDialog.h"
 #include "backend/core/AspectTreeModel.h"
@@ -90,7 +72,7 @@ void ImportDialog::setModel() {
 	frameAddTo = new QGroupBox(this);
 	frameAddTo->setTitle(i18n("Import to"));
 
-	auto* label = new QLabel(i18n("Data container"));
+	auto* label = new QLabel(i18n("Data container:"));
 	label->setToolTip(i18n("Data container where the data has to be imported into"));
 
 	auto* grid = new QGridLayout(frameAddTo);
@@ -117,7 +99,7 @@ void ImportDialog::setModel() {
 	tbNewDataContainer->setToolTip(i18n("Add new data container to the project"));
 	grid->addWidget( tbNewDataContainer, 0, 2);
 
-	lPosition = new QLabel(i18n("Position"), frameAddTo);
+	lPosition = new QLabel(i18n("Position:"), frameAddTo);
 	lPosition->setEnabled(false);
 	grid->addWidget(lPosition, 1, 0);
 
@@ -148,9 +130,9 @@ void ImportDialog::setCurrentIndex(const QModelIndex& index) {
 }
 
 void ImportDialog::newDataContainer(QAction* action) {
-	DEBUG("ImportDialog::newDataContainer()");
+	DEBUG(Q_FUNC_INFO);
 	QString name = selectedObject();
-	QString type = action->iconText().split(' ')[1];
+	QString type = action->iconText().split(' ').at(1);
 	if (name.isEmpty())
 		name = action->iconText();
 
