@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : ImportDialog.cc
     Project              : LabPlot
     Description          : import file data dialog
     --------------------------------------------------------------------
-    Copyright            : (C) 2008-2019 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2008-2015 by Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2008-2019 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2008-2015 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "ImportFileDialog.h"
 #include "ImportFileWidget.h"
@@ -112,8 +94,8 @@ ImportFileDialog::ImportFileDialog(MainWin* parent, bool liveDataSource, const Q
 	m_importFileWidget->showOptions(m_showOptions);
 	//do the signal-slot connections after all settings were loaded in import file widget and check the OK button after this
 	connect(m_importFileWidget, &ImportFileWidget::checkedFitsTableToMatrix, this, &ImportFileDialog::checkOnFitsTableToMatrix);
-	connect(m_importFileWidget, static_cast<void (ImportFileWidget::*)()>(&ImportFileWidget::fileNameChanged), this, &ImportFileDialog::checkOkButton);
-	connect(m_importFileWidget, static_cast<void (ImportFileWidget::*)()>(&ImportFileWidget::sourceTypeChanged), this, &ImportFileDialog::checkOkButton);
+	connect(m_importFileWidget, QOverload<>::of(&ImportFileWidget::fileNameChanged), this, &ImportFileDialog::checkOkButton);
+	connect(m_importFileWidget, QOverload<>::of(&ImportFileWidget::sourceTypeChanged), this, &ImportFileDialog::checkOkButton);
 	connect(m_importFileWidget, &ImportFileWidget::hostChanged, this, &ImportFileDialog::checkOkButton);
 	connect(m_importFileWidget, &ImportFileWidget::portChanged, this, &ImportFileDialog::checkOkButton);
 	connect(m_importFileWidget, &ImportFileWidget::error, this, &ImportFileDialog::showErrorMessage);
@@ -146,7 +128,7 @@ LiveDataSource::SourceType ImportFileDialog::sourceType() const {
   triggers data import to the live data source \c source
 */
 void ImportFileDialog::importToLiveDataSource(LiveDataSource* source, QStatusBar* statusBar) const {
-	DEBUG("ImportFileDialog::importToLiveDataSource()");
+	DEBUG(Q_FUNC_INFO);
 	m_importFileWidget->saveSettings(source);
 
 	//show a progress bar in the status bar
@@ -183,7 +165,7 @@ void ImportFileDialog::importToMQTT(MQTTClient* client) const{
   triggers data import to the currently selected data container
 */
 void ImportFileDialog::importTo(QStatusBar* statusBar) const {
-	DEBUG("ImportFileDialog::importTo()");
+	DEBUG(Q_FUNC_INFO);
 	QDEBUG("	cbAddTo->currentModelIndex() =" << cbAddTo->currentModelIndex());
 	AbstractAspect* aspect = static_cast<AbstractAspect*>(cbAddTo->currentModelIndex().internalPointer());
 	if (!aspect) {
@@ -217,33 +199,35 @@ void ImportFileDialog::importTo(QStatusBar* statusBar) const {
 	timer.start();
 
 	if (aspect->inherits(AspectType::Matrix)) {
-		DEBUG("ImportFileDialog::importTo(): to Matrix");
+		DEBUG(Q_FUNC_INFO <<", to Matrix");
 		auto* matrix = qobject_cast<Matrix*>(aspect);
 		filter->readDataFromFile(fileName, matrix, mode);
 	} else if (aspect->inherits(AspectType::Spreadsheet)) {
-		DEBUG("ImportFileDialog::importTo(): to Spreadsheet");
+		DEBUG(Q_FUNC_INFO << ", to Spreadsheet");
 		auto* spreadsheet = qobject_cast<Spreadsheet*>(aspect);
-		DEBUG(" Calling filter->readDataFromFile() with spreadsheet " << spreadsheet);
 		filter->readDataFromFile(fileName, spreadsheet, mode);
 	} else if (aspect->inherits(AspectType::Workbook)) {
-		DEBUG("ImportFileDialog::importTo(): to Workbook");
+		DEBUG(Q_FUNC_INFO << ", to Workbook");
 		auto* workbook = static_cast<Workbook*>(aspect);
 		workbook->setUndoAware(false);
 		auto sheets = workbook->children<AbstractAspect>();
 
 		AbstractFileFilter::FileType fileType = m_importFileWidget->currentFileType();
-		// multiple data sets/variables for HDF5, NetCDF and ROOT
+		// multiple data sets/variables for special types
 		if (fileType == AbstractFileFilter::FileType::HDF5 || fileType == AbstractFileFilter::FileType::NETCDF ||
-			fileType == AbstractFileFilter::FileType::ROOT) {
+			fileType == AbstractFileFilter::FileType::ROOT || fileType == AbstractFileFilter::FileType::MATIO) {
 			QStringList names;
 			if (fileType == AbstractFileFilter::FileType::HDF5)
 				names = m_importFileWidget->selectedHDF5Names();
 			else if (fileType == AbstractFileFilter::FileType::NETCDF)
 				names = m_importFileWidget->selectedNetCDFNames();
+			else if (fileType == AbstractFileFilter::FileType::MATIO)
+				names = m_importFileWidget->selectedMatioNames();
 			else
 				names = m_importFileWidget->selectedROOTNames();
 
 			int nrNames = names.size(), offset = sheets.size();
+			//QDEBUG(Q_FUNC_INFO << ", selected names: " << names)
 
 			//TODO: think about importing multiple sets into one sheet
 
@@ -258,7 +242,7 @@ void ImportFileDialog::importTo(QStatusBar* statusBar) const {
 				// delete the unneeded spreadsheets
 				if (offset > nrNames) {
 					for (int i = nrNames; i < offset; i++)
-						sheets[i]->remove();
+						sheets.at(i)->remove();
 					offset = nrNames;
 				}
 
@@ -267,7 +251,7 @@ void ImportFileDialog::importTo(QStatusBar* statusBar) const {
 					//HDF5 variable names contain the whole path, remove it and keep the name only
 					QString sheetName = names.at(i);
 					if (fileType == AbstractFileFilter::FileType::HDF5)
-						sheetName = names[i].mid(names[i].lastIndexOf("/") + 1);
+						sheetName = names.at(i).mid(names.at(i).lastIndexOf("/") + 1);
 
 					auto* sheet = sheets.at(i);
 					sheet->setUndoAware(false);
@@ -281,11 +265,11 @@ void ImportFileDialog::importTo(QStatusBar* statusBar) const {
 				//HDF5 variable names contain the whole path, remove it and keep the name only
 				QString sheetName = names.at(i);
 				if (fileType == AbstractFileFilter::FileType::HDF5)
-					sheetName = names[i].mid(names[i].lastIndexOf("/") + 1);
+					sheetName = names.at(i).mid(names.at(i).lastIndexOf("/") + 1);
 
 				auto* spreadsheet = new Spreadsheet(sheetName);
 				if (mode == AbstractFileFilter::ImportMode::Prepend && !sheets.isEmpty())
-					workbook->insertChildBefore(spreadsheet, sheets[0]);
+					workbook->insertChildBefore(spreadsheet, sheets.at(0));
 				else
 					workbook->addChildFast(spreadsheet);
 			}
@@ -294,18 +278,20 @@ void ImportFileDialog::importTo(QStatusBar* statusBar) const {
 			if (mode != AbstractFileFilter::ImportMode::Append)
 				offset = 0;
 
-			// import all sets to a different sheet
+			// import every set to a different sheet
 			sheets = workbook->children<AbstractAspect>();
 			for (int i = 0; i < nrNames; ++i) {
 				if (fileType == AbstractFileFilter::FileType::HDF5)
-					static_cast<HDF5Filter*>(filter)->setCurrentDataSetName(names[i]);
+					static_cast<HDF5Filter*>(filter)->setCurrentDataSetName(names.at(i));
 				else if (fileType == AbstractFileFilter::FileType::NETCDF)
-					static_cast<NetCDFFilter*>(filter)->setCurrentVarName(names[i]);
-				else
-					static_cast<ROOTFilter*>(filter)->setCurrentObject(names[i]);
+					static_cast<NetCDFFilter*>(filter)->setCurrentVarName(names.at(i));
+				else if (fileType == AbstractFileFilter::FileType::MATIO)
+					static_cast<MatioFilter*>(filter)->setCurrentVarName(names.at(i));
+				else if (fileType == AbstractFileFilter::FileType::ROOT)
+					static_cast<ROOTFilter*>(filter)->setCurrentObject(names.at(i));
 
 				int index = i + offset;
-				filter->readDataFromFile(fileName, qobject_cast<Spreadsheet*>(sheets[index]));
+				filter->readDataFromFile(fileName, qobject_cast<Spreadsheet*>(sheets.at(index)));
 			}
 
 			workbook->setUndoAware(true);
@@ -359,7 +345,7 @@ void ImportFileDialog::checkOnFitsTableToMatrix(const bool enable) {
 }
 
 void ImportFileDialog::checkOkButton() {
-	DEBUG("ImportFileDialog::checkOkButton()");
+	DEBUG(Q_FUNC_INFO);
 	if (cbAddTo) { //only check for the target container when no file data source is being added
 		QDEBUG(" cbAddTo->currentModelIndex() = " << cbAddTo->currentModelIndex());
 		AbstractAspect* aspect = static_cast<AbstractAspect*>(cbAddTo->currentModelIndex().internalPointer());
@@ -381,18 +367,14 @@ void ImportFileDialog::checkOkButton() {
 		}
 	}
 
-	QString fileName = m_importFileWidget->fileName();
-#ifdef HAVE_WINDOWS
-	if (!fileName.isEmpty() && fileName.at(1) != QLatin1String(":"))
-#else
-	if (!fileName.isEmpty() && fileName.at(0) != QLatin1String("/"))
-#endif
-		fileName = QDir::homePath() + QLatin1String("/") + fileName;
+	QString fileName = ImportFileWidget::absolutePath(m_importFileWidget->fileName());
+	if (fileName.isEmpty())
+		return;
 
 	DEBUG("Data Source Type: " << ENUM_TO_STRING(LiveDataSource, SourceType, m_importFileWidget->currentSourceType()));
 	switch (m_importFileWidget->currentSourceType()) {
 	case LiveDataSource::SourceType::FileOrPipe: {
-		DEBUG("	fileName = " << fileName.toUtf8().constData());
+		DEBUG("	fileName = " << qPrintable(fileName));
 		const bool enable = QFile::exists(fileName);
 		okButton->setEnabled(enable);
 		if (enable) {
@@ -403,9 +385,8 @@ void ImportFileDialog::checkOkButton() {
 			okButton->setToolTip(msg);
 
 			//suppress the error widget when the dialog is opened the first time.
-			//show only the error widget if the file was really a non-existing file was provided.
-			if (!fileName.isEmpty())
-				showErrorMessage(msg);
+			//show only the error widget if the file was really a non-existing file.
+			showErrorMessage(msg);
 		}
 
 		break;
@@ -437,8 +418,7 @@ void ImportFileDialog::checkOkButton() {
 			okButton->setEnabled(false);
 			QString msg = i18n("Could not connect to the provided local socket. The socket does not exist.");
 			okButton->setToolTip(msg);
-			if (!fileName.isEmpty())
-				showErrorMessage(msg);
+			showErrorMessage(msg);
 		}
 
 		break;
