@@ -1,30 +1,12 @@
-/***************************************************************************
+/*
     File                 : ImportProjectDialog.cpp
     Project              : LabPlot
     Description          : import project dialog
     --------------------------------------------------------------------
-    Copyright            : (C) 2017-2021 Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2017-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "ImportProjectDialog.h"
 #include "backend/core/AspectTreeModel.h"
@@ -66,7 +48,7 @@ ImportProjectDialog::ImportProjectDialog(MainWin* parent, ProjectType type) : QD
 	auto* vLayout = new QVBoxLayout(this);
 
 	//main widget
-	QWidget* mainWidget = new QWidget(this);
+	auto* mainWidget = new QWidget(this);
 	ui.setupUi(mainWidget);
 	ui.chbUnusedObjects->hide();
 
@@ -112,7 +94,7 @@ ImportProjectDialog::ImportProjectDialog(MainWin* parent, ProjectType type) : QD
 			this, [=](const QUrl &url){fileNameChanged(url.path());});
 	connect(ui.bOpen, &QPushButton::clicked, this, &ImportProjectDialog::selectFile);
 	connect(m_bNewFolder, &QPushButton::clicked, this, &ImportProjectDialog::newFolder);
-	connect(ui.chbUnusedObjects, &QCheckBox::stateChanged, this, &ImportProjectDialog::refreshPreview);
+	connect(ui.chbUnusedObjects, &QCheckBox::toggled, this, &ImportProjectDialog::refreshPreview);
 	connect(m_buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
 	connect(m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
@@ -170,7 +152,7 @@ ImportProjectDialog::ImportProjectDialog(MainWin* parent, ProjectType type) : QD
 	}
 
 	QApplication::processEvents(QEventLoop::AllEvents, 100);
-	m_cbFileName->setUrl(conf.readEntry(file, ""));
+	m_cbFileName->setUrl(QUrl(conf.readEntry(file, "")));
 	QStringList urls = m_cbFileName->urls();
 	urls.append(conf.readXdgListEntry(files));
 	m_cbFileName->setUrls(urls);
@@ -349,9 +331,7 @@ bool ImportProjectDialog::isTopLevel(const AbstractAspect* aspect) const {
 //##############################################################################
 //#################################  SLOTS  ####################################
 //##############################################################################
-void ImportProjectDialog::selectionChanged(const QItemSelection& selected, const QItemSelection& deselected) {
-	Q_UNUSED(deselected);
-
+void ImportProjectDialog::selectionChanged(const QItemSelection& selected, const QItemSelection& /*deselected*/) {
 	//determine the dependent objects and select/deselect them too
 	const QModelIndexList& indexes = selected.indexes();
 	if (indexes.isEmpty())
