@@ -1,31 +1,12 @@
-/***************************************************************************
-File                 : MQTTConnectionManagerWidget.cpp
-Project              : LabPlot
-Description          : widget for managing MQTT connections
---------------------------------------------------------------------
-Copyright            : (C) 2018 Ferencz Kovacs (kferike98@gmail.com)
-Copyright            : (C) 2018-2019 Alexander Semke (alexander.semke@web.de)
-
-***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+/*
+    File                 : MQTTConnectionManagerWidget.cpp
+    Project              : LabPlot
+    Description          : widget for managing MQTT connections
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2018 Ferencz Kovacs <kferike98@gmail.com>
+    SPDX-FileCopyrightText: 2018-2019 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "MQTTConnectionManagerWidget.h"
 
@@ -71,9 +52,9 @@ MQTTConnectionManagerWidget::MQTTConnectionManagerWidget(QWidget* parent, const
 	connect(ui.leUserName, &QLineEdit::textChanged, this, &MQTTConnectionManagerWidget::userNameChanged);
 	connect(ui.lePassword, &QLineEdit::textChanged, this, &MQTTConnectionManagerWidget::passwordChanged);
 	connect(ui.leID, &QLineEdit::textChanged, this, &MQTTConnectionManagerWidget::clientIdChanged);
-	connect(ui.chbAuthentication, &QCheckBox::stateChanged, this, &MQTTConnectionManagerWidget::authenticationChecked);
-	connect(ui.chbID, &QCheckBox::stateChanged, this, &MQTTConnectionManagerWidget::idChecked);
-	connect(ui.chbRetain, &QCheckBox::stateChanged, this, &MQTTConnectionManagerWidget::retainChecked);
+	connect(ui.chbAuthentication, &QCheckBox::toggled, this, &MQTTConnectionManagerWidget::authenticationChecked);
+	connect(ui.chbID, &QCheckBox::toggled, this, &MQTTConnectionManagerWidget::idChecked);
+	connect(ui.chbRetain, &QCheckBox::toggled, this, &MQTTConnectionManagerWidget::retainChecked);
 	connect(ui.bTest, &QPushButton::clicked, this, &MQTTConnectionManagerWidget::testConnection);
 
 	ui.lePassword->hide();
@@ -101,8 +82,8 @@ MQTTConnectionManagerWidget::~MQTTConnectionManagerWidget() {
 QString MQTTConnectionManagerWidget::connection() const {
 	if (ui.lwConnections->currentItem())
 		return ui.lwConnections->currentItem()->text();
-	else
-		return QString();
+
+	return {};
 }
 
 /*!
@@ -150,7 +131,7 @@ void MQTTConnectionManagerWidget::connectionChanged(int index) {
  */
 void MQTTConnectionManagerWidget::nameChanged(const QString &name) {
 	if (name.isEmpty()) {
-		ui.leName->setStyleSheet(QStringLiteral("QLineEdit{background: red;}"));
+		SET_WARNING_STYLE(ui.leName)
 		ui.leHost->setToolTip(i18n("Please set a valid name."));
 	} else {
 		//check uniqueness of the provided name
@@ -172,10 +153,10 @@ void MQTTConnectionManagerWidget::nameChanged(const QString &name) {
 
 			if (!m_initializing) {
 				m_currentConnection->name = name;
-				emit changed();
+				Q_EMIT changed();
 			}
 		} else {
-			ui.leName->setStyleSheet(QStringLiteral("QLineEdit{background: red;}"));
+			SET_WARNING_STYLE(ui.leName)
 			ui.leHost->setToolTip(i18n("Please provide a unique name."));
 		}
 	}
@@ -187,7 +168,7 @@ void MQTTConnectionManagerWidget::nameChanged(const QString &name) {
  */
 void MQTTConnectionManagerWidget::hostChanged(const QString& hostName) {
 	if (hostName.isEmpty()) {
-		ui.leHost->setStyleSheet(QStringLiteral("QLineEdit{background: red;}"));
+		SET_WARNING_STYLE(ui.leHost)
 		ui.leHost->setToolTip(i18n("Please set a valid host name."));
 	} else {
 		m_currentConnection->hostName = hostName;
@@ -204,18 +185,18 @@ void MQTTConnectionManagerWidget::hostChanged(const QString& hostName) {
 		}
 
 		if (!unique) {
-			ui.leHost->setStyleSheet(QStringLiteral("QLineEdit{background: red;}"));
+			SET_WARNING_STYLE(ui.leHost)
+			SET_WARNING_STYLE(ui.lePort)
 			ui.leHost->setToolTip(i18n("Host name and port must be unique."));
-			ui.lePort->setStyleSheet(QStringLiteral("QLineEdit{background: red;}"));
 			ui.lePort->setToolTip(i18n("Host name and port must be unique."));
 		} else {
 			ui.leHost->setStyleSheet(QString());
-			ui.leHost->setToolTip(QString());
 			ui.lePort->setStyleSheet(QString());
+			ui.leHost->setToolTip(QString());
 			ui.lePort->setToolTip(QString());
 
 			if (!m_initializing)
-				emit changed();
+				Q_EMIT changed();
 		}
 	}
 }
@@ -226,7 +207,7 @@ void MQTTConnectionManagerWidget::hostChanged(const QString& hostName) {
  */
 void MQTTConnectionManagerWidget::portChanged(const QString& portString) {
 	if (portString.isEmpty()) {
-		ui.leHost->setStyleSheet(QStringLiteral("QLineEdit{background: red;}"));
+		SET_WARNING_STYLE(ui.leHost)
 		ui.leHost->setToolTip(i18n("Please set a valid port."));
 	} else {
 		m_currentConnection->port = portString.simplified().toInt();
@@ -243,9 +224,9 @@ void MQTTConnectionManagerWidget::portChanged(const QString& portString) {
 		}
 
 		if (!unique) {
-			ui.leHost->setStyleSheet(QStringLiteral("QLineEdit{background: red;}"));
+			SET_WARNING_STYLE(ui.leHost)
+			SET_WARNING_STYLE(ui.lePort)
 			ui.leHost->setToolTip(i18n("Host name and port must be unique."));
-			ui.lePort->setStyleSheet(QStringLiteral("QLineEdit{background: red;}"));
 			ui.lePort->setToolTip(i18n("Host name and port must be unique."));
 		} else {
 			ui.leHost->setStyleSheet(QString());
@@ -254,7 +235,7 @@ void MQTTConnectionManagerWidget::portChanged(const QString& portString) {
 			ui.lePort->setToolTip(QString());
 
 			if (!m_initializing)
-				emit changed();
+				Q_EMIT changed();
 		}
 	}
 
@@ -266,8 +247,8 @@ void MQTTConnectionManagerWidget::portChanged(const QString& portString) {
  *
  * \param state the state of the checkbox
  */
-void MQTTConnectionManagerWidget::authenticationChecked(int state) {
-	if (state == Qt::CheckState::Checked) {
+void MQTTConnectionManagerWidget::authenticationChecked(bool state) {
+	if (state) {
 		ui.lPassword->show();
 		ui.lePassword->show();
 		ui.lUsername->show();
@@ -280,7 +261,7 @@ void MQTTConnectionManagerWidget::authenticationChecked(int state) {
 				m_currentConnection->useAuthentication = true;
 		}
 
-	} else if (state == Qt::CheckState::Unchecked) {
+	} else {
 		ui.lPassword->hide();
 		ui.lePassword->hide();
 		ui.lePassword->clear();
@@ -294,15 +275,15 @@ void MQTTConnectionManagerWidget::authenticationChecked(int state) {
 	}
 
 	if (!m_initializing)
-		emit changed();
+		Q_EMIT changed();
 }
 
 /*!
  *\brief called when ID checkbox's state is changed, if checked a lineEdit is shown so the user can set the ID
  * \param state the state of the checkbox
  */
-void MQTTConnectionManagerWidget::idChecked(int state) {
-	if (state == Qt::CheckState::Checked) {
+void MQTTConnectionManagerWidget::idChecked(bool state) {
+	if (state) {
 		ui.lID->show();
 		ui.leID->show();
 
@@ -312,7 +293,7 @@ void MQTTConnectionManagerWidget::idChecked(int state) {
 				m_currentConnection->useID = true;
 		}
 
-	} else if (state == Qt::CheckState::Unchecked) {
+	} else {
 		ui.lID->hide();
 		ui.leID->hide();
 		ui.leID->clear();
@@ -323,25 +304,24 @@ void MQTTConnectionManagerWidget::idChecked(int state) {
 	}
 
 	if (!m_initializing)
-		emit changed();
+		Q_EMIT changed();
 }
 
 /*!
  * \brief called when retain checkbox's state is changed
  * \param state the state of the checkbox
  */
-void MQTTConnectionManagerWidget::retainChecked(int state) {
+void MQTTConnectionManagerWidget::retainChecked(bool state) {
 	if (m_initializing)
 		return;
 
 	if (m_currentConnection) {
-		if (state == Qt::CheckState::Checked) {
+		if (state)
 			m_currentConnection->retain = true;
-		} else if (state == Qt::CheckState::Unchecked) {
+		else
 			m_currentConnection->retain = false;
-		}
 	}
-	emit changed();
+	Q_EMIT changed();
 }
 
 /*!
@@ -350,7 +330,7 @@ void MQTTConnectionManagerWidget::retainChecked(int state) {
  */
 void MQTTConnectionManagerWidget::userNameChanged(const QString& userName) {
 	if (userName.isEmpty()) {
-		ui.leUserName->setStyleSheet(QStringLiteral("QLineEdit{background: red;}"));
+		SET_WARNING_STYLE(ui.leUserName)
 		ui.leUserName->setToolTip(i18n("Please set a username."));
 	} else {
 		ui.leUserName->setStyleSheet(QString());
@@ -362,7 +342,7 @@ void MQTTConnectionManagerWidget::userNameChanged(const QString& userName) {
 
 	if (m_currentConnection)
 		m_currentConnection->userName = userName;
-	emit changed();
+	Q_EMIT changed();
 }
 
 /*!
@@ -371,7 +351,7 @@ void MQTTConnectionManagerWidget::userNameChanged(const QString& userName) {
  */
 void MQTTConnectionManagerWidget::passwordChanged(const QString& password) {
 	if (password.isEmpty()) {
-		ui.lePassword->setStyleSheet(QStringLiteral("QLineEdit{background: red;}"));
+		SET_WARNING_STYLE(ui.lePassword)
 		ui.lePassword->setToolTip(i18n("Please set a password."));
 	} else {
 		ui.lePassword->setStyleSheet(QString());
@@ -383,7 +363,7 @@ void MQTTConnectionManagerWidget::passwordChanged(const QString& password) {
 
 	if (m_currentConnection)
 		m_currentConnection->password = password;
-	emit changed();
+	Q_EMIT changed();
 }
 
 /*!
@@ -392,7 +372,7 @@ void MQTTConnectionManagerWidget::passwordChanged(const QString& password) {
  */
 void MQTTConnectionManagerWidget::clientIdChanged(const QString& clientID) {
 	if (clientID.isEmpty()) {
-		ui.leID->setStyleSheet(QStringLiteral("QLineEdit{background: red;}"));
+		SET_WARNING_STYLE(ui.leID)
 		ui.leID->setToolTip(i18n("Please set a client ID."));
 	} else {
 		ui.leID->setStyleSheet(QString());
@@ -404,7 +384,7 @@ void MQTTConnectionManagerWidget::clientIdChanged(const QString& clientID) {
 
 	if (m_currentConnection)
 		m_currentConnection->clientID = clientID;
-	emit changed();
+	Q_EMIT changed();
 }
 
 /*!
@@ -415,9 +395,6 @@ void MQTTConnectionManagerWidget::addConnection() {
 	MQTTConnection conn;
 	conn.name = uniqueName();
 	conn.hostName = QStringLiteral("localhost");
-	conn.port = 1883;
-	conn.useAuthentication = false;
-	conn.useID = false;
 
 	m_connections.append(conn);
 	m_currentConnection = &m_connections.back();
@@ -432,7 +409,7 @@ void MQTTConnectionManagerWidget::addConnection() {
 	ui.lePassword->setEnabled(true);
 	ui.leID->setEnabled(true);
 	ui.leName->setEnabled(true);
-	emit changed();
+	Q_EMIT changed();
 }
 
 /*!
@@ -472,7 +449,7 @@ void MQTTConnectionManagerWidget::deleteConnection() {
 		ui.leID->setEnabled(false);
 		m_initializing = false;
 	}
-	emit changed();
+	Q_EMIT changed();
 }
 
 /*!
@@ -591,7 +568,7 @@ bool MQTTConnectionManagerWidget::checkConnections() {
 
 		if (!allOk) {
 			connectionsOk = false;
-			ui.lwConnections->item(i)->setBackground(QBrush(Qt::red));
+			SET_WARNING_BACKGROUND(ui.lwConnections->item(i))
 		} else
 			ui.lwConnections->item(i)->setBackground(QBrush());
 	}
