@@ -1,29 +1,11 @@
-/***************************************************************************
-File                 : MQTTSubscriptionWidget.cpp
-Project              : LabPlot
-Description          : Widget for managing topics and subscribing
---------------------------------------------------------------------
-Copyright            : (C) 2019 by Kovacs Ferencz (kferike98@gmail.com)
-***************************************************************************/
-
-/***************************************************************************
-*                                                                         *
-*  This program is free software; you can redistribute it and/or modify   *
-*  it under the terms of the GNU General Public License as published by   *
-*  the Free Software Foundation; either version 2 of the License, or      *
-*  (at your option) any later version.                                    *
-*                                                                         *
-*  This program is distributed in the hope that it will be useful,        *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
-*  GNU General Public License for more details.                           *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the Free Software           *
-*   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
-*   Boston, MA  02110-1301  USA                                           *
-*                                                                         *
-***************************************************************************/
+/*
+    File                 : MQTTSubscriptionWidget.cpp
+    Project              : LabPlot
+    Description          : Widget for managing topics and subscribing
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2019 Kovacs Ferencz <kferike98@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "MQTTSubscriptionWidget.h"
 
@@ -205,8 +187,13 @@ bool MQTTSubscriptionWidget::checkTopicContains(const QString& superior, const Q
 	if (!superior.contains('/'))
 		return false;
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+	const QStringList& superiorList = superior.split('/', Qt::SkipEmptyParts);
+	const QStringList& inferiorList = inferior.split('/', Qt::SkipEmptyParts);
+#else
 	const QStringList& superiorList = superior.split('/', QString::SkipEmptyParts);
 	const QStringList& inferiorList = inferior.split('/', QString::SkipEmptyParts);
+#endif
 
 	//a longer topic can't contain a shorter one
 	if (superiorList.size() > inferiorList.size())
@@ -246,7 +233,7 @@ void MQTTSubscriptionWidget::unsubscribeFromTopic(const QString& topicName) {
 	findSubscriptionLeafChildren(children, ui.twSubscriptions->topLevelItem(0));
 
 	//signals for ImportFileWidget
-	emit MQTTUnsubscribeFromTopic(topicName, children);
+	Q_EMIT MQTTUnsubscribeFromTopic(topicName, children);
 
 	for (int row = 0; row < ui.twSubscriptions->topLevelItemCount(); row++)  {
 		if (ui.twSubscriptions->topLevelItem(row)->text(0) == topicName) {
@@ -295,7 +282,11 @@ void MQTTSubscriptionWidget::manageCommonLevelSubscriptions() {
 				topics.next();
 
 				int level = commonLevelIndex(topics.value().last(), topics.value().first());
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+				QStringList commonList = topics.value().first().split('/', Qt::SkipEmptyParts);
+#else
 				QStringList commonList = topics.value().first().split('/', QString::SkipEmptyParts);
+#endif
 				QTreeWidgetItem* currentItem = nullptr;
 
 				//search the corresponding item to the common topics first level(root)
@@ -345,7 +336,7 @@ void MQTTSubscriptionWidget::manageCommonLevelSubscriptions() {
 				ui.twSubscriptions->addTopLevelItem(newTopic);
 
 				if (m_parent == MQTTParentWidget::ImportFileWidget)
-					emit makeSubscription(commonTopic, static_cast<quint8> (ui.cbQos->currentText().toUInt()));
+					Q_EMIT makeSubscription(commonTopic, static_cast<quint8> (ui.cbQos->currentText().toUInt()));
 
 				//remove the "merged" topics
 				for (const auto& topic : equalTopics) {
@@ -376,7 +367,7 @@ void MQTTSubscriptionWidget::manageCommonLevelSubscriptions() {
 				}
 
 				if (m_parent == MQTTParentWidget::LiveDataDock)
-					emit makeSubscription(commonTopic, static_cast<quint8> (ui.cbQos->currentText().toUInt()));
+					Q_EMIT makeSubscription(commonTopic, static_cast<quint8> (ui.cbQos->currentText().toUInt()));
 			}
 		}
 	} while (foundEqual);
@@ -406,7 +397,11 @@ void MQTTSubscriptionWidget::updateSubscriptionTree(const QVector<QString>& mqtt
 			auto* newItem = new QTreeWidgetItem(name);
 			ui.twSubscriptions->addTopLevelItem(newItem);
 			name.clear();
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+			name = sub.split('/', Qt::SkipEmptyParts);
+#else
 			name = sub.split('/', QString::SkipEmptyParts);
+#endif
 
 			//find the corresponding "root" item in twTopics
 			QTreeWidgetItem* topic = nullptr;
@@ -596,8 +591,13 @@ int MQTTSubscriptionWidget::checkCommonChildCount(int levelIdx, int level, QStri
  * \return The index of the unequal level, if there is a common topic, otherwise -1
  */
 int MQTTSubscriptionWidget::commonLevelIndex(const QString& first, const QString& second) {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+	QStringList firstList = first.split('/', Qt::SkipEmptyParts);
+	QStringList secondtList = second.split('/', Qt::SkipEmptyParts);
+#else
 	QStringList firstList = first.split('/', QString::SkipEmptyParts);
 	QStringList secondtList = second.split('/', QString::SkipEmptyParts);
+#endif
 	QString commonTopic;
 	int differIndex = -1;
 
@@ -654,11 +654,19 @@ int MQTTSubscriptionWidget::commonLevelIndex(const QString& first, const QString
  * \return The name of the common topic, if it exists, otherwise ""
  */
 QString MQTTSubscriptionWidget::checkCommonLevel(const QString& first, const QString& second) {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+	const QStringList& firstList = first.split('/', Qt::SkipEmptyParts);
+#else
 	const QStringList& firstList = first.split('/', QString::SkipEmptyParts);
+#endif
 	if (firstList.isEmpty())
-		return QString();
+		return {};
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+	const QStringList& secondtList = second.split('/', Qt::SkipEmptyParts);
+#else
 	const QStringList& secondtList = second.split('/', QString::SkipEmptyParts);
+#endif
 	QString commonTopic;
 
 	//the two topics have to be the same size and can't be identic
@@ -709,8 +717,7 @@ QString MQTTSubscriptionWidget::checkCommonLevel(const QString& first, const QSt
 /*!
  *\brief When a leaf topic is double clicked in the topics tree widget we subscribe on that
  */
-void MQTTSubscriptionWidget::mqttAvailableTopicDoubleClicked(QTreeWidgetItem* item, int column) {
-	Q_UNUSED(column)
+void MQTTSubscriptionWidget::mqttAvailableTopicDoubleClicked(QTreeWidgetItem* item, int /*column*/) {
 	// Only for leaf topics
 	if (item->childCount() == 0)
 		mqttSubscribe();
@@ -719,8 +726,7 @@ void MQTTSubscriptionWidget::mqttAvailableTopicDoubleClicked(QTreeWidgetItem* it
 /*!
  *\brief When a leaf subscription is double clicked in the topics tree widget we unsubscribe
  */
-void MQTTSubscriptionWidget::mqttSubscribedTopicDoubleClicked(QTreeWidgetItem* item, int column) {
-	Q_UNUSED(column)
+void MQTTSubscriptionWidget::mqttSubscribedTopicDoubleClicked(QTreeWidgetItem* item, int /*column*/) {
 	// Only for leaf subscriptions
 	if (item->childCount() == 0)
 		mqttUnsubscribe();
@@ -787,13 +793,17 @@ void MQTTSubscriptionWidget::mqttSubscribe() {
 				addSubscriptionChildren(item, newTopLevelItem);
 			}
 
-			emit makeSubscription(name, static_cast<quint8>(ui.cbQos->currentText().toUInt()));
+			Q_EMIT makeSubscription(name, static_cast<quint8>(ui.cbQos->currentText().toUInt()));
 
 			if (name.endsWith('#')) {
 				//if an already existing subscription contains a topic that the new subscription also contains
 				//we decompose the already existing subscription
 				//by unsubscribing from its topics, that are present in the new subscription as well
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+				const QStringList nameList = name.split('/', Qt::SkipEmptyParts);
+#else
 				const QStringList nameList = name.split('/', QString::SkipEmptyParts);
+#endif
 				const QString& root = nameList.first();
 				QVector<QTreeWidgetItem*> children;
 				for (int i = 0; i < ui.twSubscriptions->topLevelItemCount(); ++i) {
@@ -817,21 +827,21 @@ void MQTTSubscriptionWidget::mqttSubscribe() {
 											if (unsubscribeItem->text(0) != childText) {
 												//add topic as subscription
 												quint8 qos = static_cast<quint8>(ui.cbQos->currentText().toUInt());
-												emit addBeforeRemoveSubscription(childText, qos);
+												Q_EMIT addBeforeRemoveSubscription(childText, qos);
 												//also add it to twSubscriptions
 												ui.twSubscriptions->addTopLevelItem(unsubscribeItem->parent()->takeChild(i));
 												--i;
 											} else {
 												//before we remove the topic, we reparent it to the new subscription
 												//so no data is lost
-												emit reparentTopic(unsubscribeItem->text(0), name);
+												Q_EMIT reparentTopic(unsubscribeItem->text(0), name);
 											}
 										}
 										unsubscribeItem = unsubscribeItem->parent();
 									}
 
 									qDebug() << "Remove: " << unsubscribeItem->text(0);
-									emit removeMQTTSubscription(unsubscribeItem->text(0));
+									Q_EMIT removeMQTTSubscription(unsubscribeItem->text(0));
 
 									ui.twSubscriptions->takeTopLevelItem(ui.twSubscriptions->indexOfTopLevelItem(unsubscribeItem));
 								}
@@ -846,7 +856,7 @@ void MQTTSubscriptionWidget::mqttSubscribe() {
 			manageCommonLevelSubscriptions();
 			updateSubscriptionCompleter();
 
-			emit enableWill(true);
+			Q_EMIT enableWill(true);
 		} else
 			QMessageBox::warning(this, i18n("Warning"), i18n("You already subscribed to a topic containing this one"));
 	} else
@@ -887,7 +897,7 @@ void MQTTSubscriptionWidget::mqttUnsubscribe() {
 		if (m_parent == MQTTParentWidget::ImportFileWidget)
 			unsubscribeFromTopic(unsubscribeItem->text(0));
 		else {
-			emit removeMQTTSubscription(unsubscribeItem->text(0));
+			Q_EMIT removeMQTTSubscription(unsubscribeItem->text(0));
 			ui.twSubscriptions->takeTopLevelItem(ui.twSubscriptions->indexOfTopLevelItem(unsubscribeItem));
 		}
 	}
@@ -901,9 +911,9 @@ void MQTTSubscriptionWidget::mqttUnsubscribe() {
 				if (unsubscribeItem->text(0) != childText) {
 					quint8 qos = static_cast<quint8>(ui.cbQos->currentText().toUInt());
 					if (m_parent == MQTTParentWidget::ImportFileWidget)
-						emit makeSubscription(childText, qos);
+						Q_EMIT makeSubscription(childText, qos);
 					else
-						emit addBeforeRemoveSubscription(childText, qos);
+						Q_EMIT addBeforeRemoveSubscription(childText, qos);
 
 					ui.twSubscriptions->addTopLevelItem(unsubscribeItem->parent()->takeChild(i));
 					--i;
@@ -915,7 +925,7 @@ void MQTTSubscriptionWidget::mqttUnsubscribe() {
 		if (m_parent == MQTTParentWidget::ImportFileWidget)
 			unsubscribeFromTopic(unsubscribeItem->text(0));
 		else {
-			emit removeMQTTSubscription(unsubscribeItem->text(0));
+			Q_EMIT removeMQTTSubscription(unsubscribeItem->text(0));
 			ui.twSubscriptions->takeTopLevelItem(ui.twSubscriptions->indexOfTopLevelItem(unsubscribeItem));
 		}
 
@@ -925,7 +935,7 @@ void MQTTSubscriptionWidget::mqttUnsubscribe() {
 	updateSubscriptionCompleter();
 
 	if (ui.twSubscriptions->topLevelItemCount() <= 0)
-		emit enableWill(false);
+		Q_EMIT enableWill(false);
 }
 
 /*!
@@ -935,7 +945,11 @@ void MQTTSubscriptionWidget::mqttUnsubscribe() {
  */
 void MQTTSubscriptionWidget::setTopicCompleter(const QString& topic) {
 	if (!m_searching) {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+		const QStringList& list = topic.split('/', Qt::SkipEmptyParts);
+#else
 		const QStringList& list = topic.split('/', QString::SkipEmptyParts);
+#endif
 		QString tempTopic;
 		if (!list.isEmpty())
 			tempTopic = list.at(0);
