@@ -1,38 +1,18 @@
-/***************************************************************************
+/*
     File                 : AxisDock.h
     Project              : LabPlot
     Description          : axes widget class
     --------------------------------------------------------------------
-    Copyright            : (C) 2011-2018 by Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2013 by Stefan Gerlach (stefan.gerlach@uni-konstanz.de)
+    SPDX-FileCopyrightText: 2011-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2013-2021 Stefan Gerlach <stefan.gerlach@uni-konstanz.de>
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef AXISDOCK_H
 #define AXISDOCK_H
 
 #include "ui_axisdock.h"
-#include "backend/worksheet/plots/cartesian/Axis.h"
 #include "kdefrontend/dockwidgets/BaseDock.h"
-#include <KConfig>
 
 class AbstractAspect;
 class LabelWidget;
@@ -40,6 +20,7 @@ class TreeViewComboBox;
 class AspectTreeModel;
 class AbstractColumn;
 class DateTimeSpinBox;
+class KConfig;
 
 class AxisDock : public BaseDock {
 	Q_OBJECT
@@ -51,6 +32,7 @@ public:
 	void setAxes(QList<Axis*>);
 	void activateTitleTab();
 	void updateLocale() override;
+	void updateAutoScale();
 
 private:
 	Ui::AxisDock ui;
@@ -60,19 +42,23 @@ private:
 	LabelWidget* labelWidget;
 	TreeViewComboBox* cbMajorTicksColumn;
 	TreeViewComboBox* cbMinorTicksColumn;
+	TreeViewComboBox* cbLabelsTextColumn;
 	bool m_dataChanged{false};
 
 	void setModel();
 	void setModelIndexFromColumn(TreeViewComboBox*, const AbstractColumn*);
+	void updatePlotRanges() override;
 
 	void load();
 	void loadConfig(KConfig&);
 
+	void setOffset(double);
+
 	// own created widgets
 	DateTimeSpinBox* dtsbMajorTicksIncrement {nullptr};
 	DateTimeSpinBox* dtsbMinorTicksIncrement {nullptr};
 
-private slots:
+private Q_SLOTS:
 	void init();
 
 	//SLOTs for changes triggered in AxisDock
@@ -80,18 +66,25 @@ private slots:
 	void visibilityChanged(bool);
 	void orientationChanged(int);
 	void positionChanged(int);
-	void positionChanged();
+	void positionChanged(double value);
+	void logicalPositionChanged(double value);
 	void scaleChanged(int);
-	void autoScaleChanged(int);
+	void rangeTypeChanged(int);
 	void startChanged();
 	void endChanged();
 	void startDateTimeChanged(const QDateTime&);
 	void endDateTimeChanged(const QDateTime&);
 	void zeroOffsetChanged();
 	void scalingFactorChanged();
+	void showScaleOffsetChanged(bool);
+	void setLeftOffset();
+	void setCenterOffset();
+	void setRightOffset();
+	void setUnityScale();
+	void setUnityRange();
 
 	//Line-Tab
-  	void lineStyleChanged(int);
+	void lineStyleChanged(int);
 	void lineColorChanged(const QColor&);
 	void lineWidthChanged(double);
 	void lineOpacityChanged(int);
@@ -102,9 +95,12 @@ private slots:
 	//"Major ticks"-tab
 	void majorTicksDirectionChanged(int);
 	void majorTicksTypeChanged(int);
- 	void majorTicksNumberChanged(int);
+	void majorTicksNumberChanged(int);
 	void majorTicksSpacingChanged();
 	void majorTicksColumnChanged(const QModelIndex&);
+	void majorTickStartOffsetChanged();
+	void setTickOffsetData(bool nice = false);	// set first tick on first data point (if nice: nice value)
+	void setTickOffsetAuto() { setTickOffsetData(true); }
 	void majorTicksLineStyleChanged(int);
 	void majorTicksColorChanged(const QColor&);
 	void majorTicksWidthChanged(double);
@@ -114,7 +110,7 @@ private slots:
 	//"Minor ticks"-tab
 	void minorTicksDirectionChanged(int);
 	void minorTicksTypeChanged(int);
- 	void minorTicksNumberChanged(int);
+	void minorTicksNumberChanged(int);
 	void minorTicksSpacingChanged();
 	void minorTicksColumnChanged(const QModelIndex&);
 	void minorTicksLineStyleChanged(int);
@@ -128,11 +124,13 @@ private slots:
 	//"Tick labels"-tab
 	void labelsFormatChanged(int);
 	void labelsPrecisionChanged(int);
-	void labelsAutoPrecisionChanged(int);
-	void labelsDateTimeFormatChanged(int);
+	void labelsAutoPrecisionChanged(bool);
+	void labelsDateTimeFormatChanged();
 	void labelsPositionChanged(int);
 	void labelsOffsetChanged(double);
 	void labelsRotationChanged(int);
+	void labelsTextTypeChanged(int);
+	void labelsTextColumnChanged(const QModelIndex&);
 	void labelsFontChanged(const QFont&);
 	void labelsFontColorChanged(const QColor&);
 	void labelsBackgroundTypeChanged(int);
@@ -142,28 +140,29 @@ private slots:
 	void labelsOpacityChanged(int);
 
 	//"Grid"-tab
-  	void majorGridStyleChanged(int);
+	void majorGridStyleChanged(int);
 	void majorGridColorChanged(const QColor&);
 	void majorGridWidthChanged(double);
 	void majorGridOpacityChanged(int);
 
-  	void minorGridStyleChanged(int);
+	void minorGridStyleChanged(int);
 	void minorGridColorChanged(const QColor&);
 	void minorGridWidthChanged(double);
 	void minorGridOpacityChanged(int);
 
 	//SLOTs for changes triggered in Axis
 	//General-Tab
-	void axisDescriptionChanged(const AbstractAspect*);
 	void axisOrientationChanged(Axis::Orientation);
 	void axisPositionChanged(Axis::Position);
 	void axisPositionChanged(double);
-	void axisScaleChanged(Axis::Scale);
-	void axisAutoScaleChanged(bool);
+	void axisLogicalPositionChanged(double);
+	void axisScaleChanged(RangeT::Scale);
+	void axisRangeTypeChanged(Axis::RangeType);
 	void axisStartChanged(double);
 	void axisEndChanged(double);
-	void axisZeroOffsetChanged(qreal);
 	void axisScalingFactorChanged(qreal);
+	void axisZeroOffsetChanged(qreal);
+	void axisShowScaleOffsetChanged(bool);
 
 	//line
 	void axisLinePenChanged(const QPen&);
@@ -177,6 +176,8 @@ private slots:
 	void axisMajorTicksTypeChanged(Axis::TicksType);
 	void axisMajorTicksNumberChanged(int);
 	void axisMajorTicksSpacingChanged(qreal);
+	void axisMajorTickStartOffsetChanged(qreal);
+	void axisMajorTicksColumnChanged(const AbstractColumn*);
 	void axisMajorTicksPenChanged(const QPen&);
 	void axisMajorTicksLengthChanged(qreal);
 	void axisMajorTicksOpacityChanged(qreal);
@@ -184,6 +185,7 @@ private slots:
 	void axisMinorTicksTypeChanged(Axis::TicksType);
 	void axisMinorTicksNumberChanged(int);
 	void axisMinorTicksSpacingChanged(qreal);
+	void axisMinorTicksColumnChanged(const AbstractColumn*);
 	void axisMinorTicksPenChanged(const QPen&);
 	void axisMinorTicksLengthChanged(qreal);
 	void axisMinorTicksOpacityChanged(qreal);
@@ -196,6 +198,8 @@ private slots:
 	void axisLabelsPositionChanged(Axis::LabelsPosition);
 	void axisLabelsOffsetChanged(double);
 	void axisLabelsRotationAngleChanged(qreal);
+	void axisLabelsTextTypeChanged(Axis::LabelsTextType);
+	void axisLabelsTextColumnChanged(const AbstractColumn*);
 	void axisLabelsFontChanged(const QFont&);
 	void axisLabelsFontColorChanged(const QColor&);
 	void axisLabelsBackgroundTypeChanged(Axis::LabelsBackgroundType);
@@ -216,7 +220,7 @@ private slots:
 	void loadConfigFromTemplate(KConfig&);
 	void saveConfigAsTemplate(KConfig&);
 
-signals:
+Q_SIGNALS:
 	void info(const QString&);
 };
 
