@@ -1,30 +1,12 @@
-/***************************************************************************
+/*
     File                 : CartesianPlotLegendDock.cpp
     Project              : LabPlot
-    --------------------------------------------------------------------
-    Copyright            : (C) 2013-2020 by Alexander Semke (alexander.semke@web.de)
     Description          : widget for cartesian plot legend properties
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2013-2021 Alexander Semke <alexander.semke@web.de>
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "CartesianPlotLegendDock.h"
 #include "backend/worksheet/plots/PlotArea.h"
@@ -36,8 +18,6 @@
 #include <QCompleter>
 #include <QDir>
 #include <QDirModel>
-#include <QFileDialog>
-#include <QImageReader>
 
 #include <KLocalizedString>
 
@@ -50,7 +30,8 @@
 CartesianPlotLegendDock::CartesianPlotLegendDock(QWidget* parent) : BaseDock(parent) {
 	ui.setupUi(this);
 	m_leName = ui.leName;
-	m_leComment = ui.leComment;
+	m_teComment = ui.teComment;
+	m_teComment->setFixedHeight(1.2 * m_leName->height());
 
 	//"Title"-tab
 	auto hboxLayout = new QHBoxLayout(ui.tabTitle);
@@ -82,7 +63,7 @@ CartesianPlotLegendDock::CartesianPlotLegendDock(QWidget* parent) : BaseDock(par
 
 	//General
 	connect(ui.leName, &QLineEdit::textChanged, this, &CartesianPlotLegendDock::nameChanged);
-	connect(ui.leComment, &QLineEdit::textChanged, this, &CartesianPlotLegendDock::commentChanged);
+	connect(ui.teComment, &QTextEdit::textChanged, this, &CartesianPlotLegendDock::commentChanged);
 	connect(ui.chkVisible, &QCheckBox::clicked, this, &CartesianPlotLegendDock::visibilityChanged);
 	connect(ui.kfrLabelFont, &KFontRequester::fontSelected, this, &CartesianPlotLegendDock::labelFontChanged);
 	connect(ui.kcbLabelColor, &KColorButton::changed, this, &CartesianPlotLegendDock::labelColorChanged);
@@ -91,6 +72,7 @@ CartesianPlotLegendDock::CartesianPlotLegendDock(QWidget* parent) : BaseDock(par
 	connect(ui.sbLineSymbolWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
 			this, &CartesianPlotLegendDock::lineSymbolWidthChanged);
 
+	connect(ui.chbBindLogicalPos, &QCheckBox::clicked, this, &CartesianPlotLegendDock::bindingChanged);
 	connect(ui.cbPositionX, QOverload<int>::of(&QComboBox::currentIndexChanged),
 			this, &CartesianPlotLegendDock::positionXChanged);
 	connect(ui.cbPositionY, QOverload<int>::of(&QComboBox::currentIndexChanged),
@@ -100,6 +82,8 @@ CartesianPlotLegendDock::CartesianPlotLegendDock(QWidget* parent) : BaseDock(par
 	connect(ui.sbPositionY, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
 			this, &CartesianPlotLegendDock::customPositionYChanged);
 
+	connect( ui.cbHorizontalAlignment, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &CartesianPlotLegendDock::horizontalAlignmentChanged);
+	connect( ui.cbVerticalAlignment, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &CartesianPlotLegendDock::verticalAlignmentChanged);
 	connect(ui.sbRotation, QOverload<int>::of(&QSpinBox::valueChanged),
 			this, &CartesianPlotLegendDock::rotationChanged);
 
@@ -178,18 +162,18 @@ void CartesianPlotLegendDock::setLegends(QList<CartesianPlotLegend*> list) {
 		ui.lName->setEnabled(true);
 		ui.leName->setEnabled(true);
 		ui.lComment->setEnabled(true);
-		ui.leComment->setEnabled(true);
+		ui.teComment->setEnabled(true);
 
 		ui.leName->setText(m_legend->name());
-		ui.leComment->setText(m_legend->comment());
+		ui.teComment->setText(m_legend->comment());
 	} else {
 		ui.lName->setEnabled(false);
 		ui.leName->setEnabled(false);
 		ui.lComment->setEnabled(false);
-		ui.leComment->setEnabled(false);
+		ui.teComment->setEnabled(false);
 
 		ui.leName->setText(QString());
-		ui.leComment->setText(QString());
+		ui.teComment->setText(QString());
 	}
 	ui.leName->setStyleSheet("");
 	ui.leName->setToolTip("");
@@ -215,15 +199,17 @@ void CartesianPlotLegendDock::setLegends(QList<CartesianPlotLegend*> list) {
 
 	//SIGNALs/SLOTs
 	//General
-	connect(m_legend, &AbstractAspect::aspectDescriptionChanged, this, &CartesianPlotLegendDock::legendDescriptionChanged);
+	connect(m_legend, &AbstractAspect::aspectDescriptionChanged, this, &CartesianPlotLegendDock::aspectDescriptionChanged);
 	connect(m_legend, &CartesianPlotLegend::labelFontChanged, this, &CartesianPlotLegendDock::legendLabelFontChanged);
 	connect(m_legend, &CartesianPlotLegend::labelColorChanged, this, &CartesianPlotLegendDock::legendLabelColorChanged);
 	connect(m_legend, &CartesianPlotLegend::labelColumnMajorChanged, this, &CartesianPlotLegendDock::legendLabelOrderChanged);
-	connect(m_legend, QOverload<const CartesianPlotLegend::PositionWrapper&>::of(&CartesianPlotLegend::positionChanged),
-			this, &CartesianPlotLegendDock::legendPositionChanged);
+	connect(m_legend, &CartesianPlotLegend::positionChanged, this, &CartesianPlotLegendDock::legendPositionChanged);
+	connect(m_legend, &CartesianPlotLegend::positionLogicalChanged, this, &CartesianPlotLegendDock::legendPositionLogicalChanged);
+	connect(m_legend, &CartesianPlotLegend::horizontalAlignmentChanged, this, &CartesianPlotLegendDock::legendHorizontalAlignmentChanged);
+	connect(m_legend, &CartesianPlotLegend::verticalAlignmentChanged, this, &CartesianPlotLegendDock::legendVerticalAlignmentChanged);
 	connect(m_legend, &CartesianPlotLegend::rotationAngleChanged, this, &CartesianPlotLegendDock::legendRotationAngleChanged);
 	connect(m_legend, &CartesianPlotLegend::lineSymbolWidthChanged, this, &CartesianPlotLegendDock::legendLineSymbolWidthChanged);
-	connect(m_legend, &CartesianPlotLegend::visibilityChanged, this, &CartesianPlotLegendDock::legendVisibilityChanged);
+	connect(m_legend, &CartesianPlotLegend::visibleChanged, this, &CartesianPlotLegendDock::legendVisibilityChanged);
 
 	//background
 	connect(m_legend, &CartesianPlotLegend::backgroundTypeChanged, this, &CartesianPlotLegendDock::legendBackgroundTypeChanged);
@@ -260,6 +246,8 @@ void CartesianPlotLegendDock::updateLocale() {
 	ui.sbLineSymbolWidth->setLocale(numberLocale);
 	ui.sbPositionX->setLocale(numberLocale);
 	ui.sbPositionY->setLocale(numberLocale);
+	ui.lePositionXLogical->setLocale(numberLocale);
+	ui.lePositionYLogical->setLocale(numberLocale);
 	ui.sbBorderWidth->setLocale(numberLocale);
 	ui.sbBorderCornerRadius->setLocale(numberLocale);
 	ui.sbLayoutTopMargin->setLocale(numberLocale);
@@ -348,14 +336,22 @@ void CartesianPlotLegendDock::retranslateUi() {
 	ui.cbOrder->addItem(i18n("Column Major"));
 	ui.cbOrder->addItem(i18n("Row Major"));
 
+	//Positioning and alignment
 	ui.cbPositionX->addItem(i18n("Left"));
 	ui.cbPositionX->addItem(i18n("Center"));
 	ui.cbPositionX->addItem(i18n("Right"));
-	ui.cbPositionX->addItem(i18n("Custom"));
+
 	ui.cbPositionY->addItem(i18n("Top"));
 	ui.cbPositionY->addItem(i18n("Center"));
 	ui.cbPositionY->addItem(i18n("Bottom"));
-	ui.cbPositionY->addItem(i18n("Custom"));
+
+	ui.cbHorizontalAlignment->addItem(i18n("Left"));
+	ui.cbHorizontalAlignment->addItem(i18n("Center"));
+	ui.cbHorizontalAlignment->addItem(i18n("Right"));
+
+	ui.cbVerticalAlignment->addItem(i18n("Top"));
+	ui.cbVerticalAlignment->addItem(i18n("Center"));
+	ui.cbVerticalAlignment->addItem(i18n("Bottom"));
 
 	GuiTools::updatePenStyles(ui.cbBorderStyle, Qt::black);
 	GuiTools::updateBrushStyles(ui.cbBackgroundBrushStyle, Qt::SolidPattern);
@@ -424,16 +420,9 @@ void CartesianPlotLegendDock::lineSymbolWidthChanged(double value) {
 }
 
 /*!
-	called when legend's current horizontal position relative to its parent (left, center, right, custom ) is changed.
+	called when legend's current horizontal position relative to its parent (left, center, right ) is changed.
 */
 void CartesianPlotLegendDock::positionXChanged(int index) {
-	//Enable/disable the spinbox for the x- oordinates if the "custom position"-item is selected/deselected
-	if (index == ui.cbPositionX->count()-1 ) {
-		ui.sbPositionX->setEnabled(true);
-	} else {
-		ui.sbPositionX->setEnabled(false);
-	}
-
 	if (m_initializing)
 		return;
 
@@ -443,16 +432,26 @@ void CartesianPlotLegendDock::positionXChanged(int index) {
 		legend->setPosition(position);
 }
 
+void CartesianPlotLegendDock::horizontalAlignmentChanged(int index) {
+	if (m_initializing)
+		return;
+
+	for (auto* legend : m_legendList)
+		legend->setHorizontalAlignment(WorksheetElement::HorizontalAlignment(index));
+}
+
+void CartesianPlotLegendDock::verticalAlignmentChanged(int index) {
+	if (m_initializing)
+		return;
+
+	for (auto* legend : m_legendList)
+		legend->setVerticalAlignment(WorksheetElement::VerticalAlignment(index));
+}
+
 /*!
-	called when legend's current horizontal position relative to its parent (top, center, bottom, custom ) is changed.
+	called when legend's current horizontal position relative to its parent (top, center, bottom ) is changed.
 */
 void CartesianPlotLegendDock::positionYChanged(int index) {
-	//Enable/disable the spinbox for the y- oordinates if the "custom position"-item is selected/deselected
-	if (index == ui.cbPositionY->count()-1 ) {
-		ui.sbPositionY->setEnabled(true);
-	} else {
-		ui.sbPositionY->setEnabled(false);
-	}
 
 	if (m_initializing)
 		return;
@@ -487,15 +486,56 @@ void CartesianPlotLegendDock::rotationChanged(int value) {
 	if (m_initializing)
 		return;
 
-	for (auto* curve : m_legendList)
-		curve->setRotationAngle(value);
+	for (auto* legend : m_legendList)
+		legend->setRotationAngle(value);
+}
+
+/*!
+ * \brief CartesianPlotLegendDock::bindingChanged
+ * Bind CartesianPlotLegend to the cartesian plot coords or not
+ * \param checked
+ */
+void CartesianPlotLegendDock::bindingChanged(bool checked) {
+	//widgets for positioning using absolute plot distances
+	ui.lPositionX->setVisible(!checked);
+	ui.cbPositionX->setVisible(!checked);
+	ui.sbPositionX->setVisible(!checked);
+
+	ui.lPositionY->setVisible(!checked);
+	ui.cbPositionY->setVisible(!checked);
+	ui.sbPositionY->setVisible(!checked);
+
+	//widgets for positioning using logical plot coordinates
+	const auto* plot = static_cast<const CartesianPlot*>(m_legend->parent(AspectType::CartesianPlot));
+	if (plot && plot->xRangeFormat() == RangeT::Format::DateTime) {
+		ui.lPositionXLogicalDateTime->setVisible(checked);
+		ui.dtePositionXLogical->setVisible(checked);
+
+		ui.lPositionXLogical->setVisible(false);
+		ui.lePositionXLogical->setVisible(false);
+	} else {
+		ui.lPositionXLogicalDateTime->setVisible(false);
+		ui.dtePositionXLogical->setVisible(false);
+
+		ui.lPositionXLogical->setVisible(checked);
+		ui.lePositionXLogical->setVisible(checked);
+	}
+
+	ui.lPositionYLogical->setVisible(checked);
+	ui.lePositionYLogical->setVisible(checked);
+
+	if(m_initializing)
+		return;
+
+	for (auto* legend : m_legendList)
+		legend->setCoordinateBindingEnabled(checked);
 }
 
 // "Background"-tab
 void CartesianPlotLegendDock::backgroundTypeChanged(int index) {
-	const auto type = (PlotArea::BackgroundType)index;
+	const auto type = (WorksheetElement::BackgroundType)index;
 
-	if (type == PlotArea::BackgroundType::Color) {
+	if (type == WorksheetElement::BackgroundType::Color) {
 		ui.lBackgroundColorStyle->show();
 		ui.cbBackgroundColorStyle->show();
 		ui.lBackgroundImageStyle->hide();
@@ -510,8 +550,8 @@ void CartesianPlotLegendDock::backgroundTypeChanged(int index) {
 		ui.lBackgroundFirstColor->show();
 		ui.kcbBackgroundFirstColor->show();
 
-		auto style = (PlotArea::BackgroundColorStyle) ui.cbBackgroundColorStyle->currentIndex();
-		if (style == PlotArea::BackgroundColorStyle::SingleColor) {
+		auto style = (WorksheetElement::BackgroundColorStyle) ui.cbBackgroundColorStyle->currentIndex();
+		if (style == WorksheetElement::BackgroundColorStyle::SingleColor) {
 			ui.lBackgroundFirstColor->setText(i18n("Color:"));
 			ui.lBackgroundSecondColor->hide();
 			ui.kcbBackgroundSecondColor->hide();
@@ -520,7 +560,7 @@ void CartesianPlotLegendDock::backgroundTypeChanged(int index) {
 			ui.lBackgroundSecondColor->show();
 			ui.kcbBackgroundSecondColor->show();
 		}
-	} else if (type == PlotArea::BackgroundType::Image) {
+	} else if (type == WorksheetElement::BackgroundType::Image) {
 		ui.lBackgroundColorStyle->hide();
 		ui.cbBackgroundColorStyle->hide();
 		ui.lBackgroundImageStyle->show();
@@ -535,7 +575,7 @@ void CartesianPlotLegendDock::backgroundTypeChanged(int index) {
 		ui.kcbBackgroundFirstColor->hide();
 		ui.lBackgroundSecondColor->hide();
 		ui.kcbBackgroundSecondColor->hide();
-	} else if (type == PlotArea::BackgroundType::Pattern) {
+	} else if (type == WorksheetElement::BackgroundType::Pattern) {
 		ui.lBackgroundFirstColor->setText(i18n("Color:"));
 		ui.lBackgroundColorStyle->hide();
 		ui.cbBackgroundColorStyle->hide();
@@ -561,9 +601,9 @@ void CartesianPlotLegendDock::backgroundTypeChanged(int index) {
 }
 
 void CartesianPlotLegendDock::backgroundColorStyleChanged(int index) {
-	auto style = (PlotArea::BackgroundColorStyle)index;
+	auto style = (WorksheetElement::BackgroundColorStyle)index;
 
-	if (style == PlotArea::BackgroundColorStyle::SingleColor) {
+	if (style == WorksheetElement::BackgroundColorStyle::SingleColor) {
 		ui.lBackgroundFirstColor->setText(i18n("Color:"));
 		ui.lBackgroundSecondColor->hide();
 		ui.kcbBackgroundSecondColor->hide();
@@ -586,7 +626,7 @@ void CartesianPlotLegendDock::backgroundImageStyleChanged(int index) {
 	if (m_initializing)
 		return;
 
-	auto style = (PlotArea::BackgroundImageStyle)index;
+	auto style = (WorksheetElement::BackgroundImageStyle)index;
 	for (auto* legend : m_legendList)
 		legend->setBackgroundImageStyle(style);
 }
@@ -620,32 +660,11 @@ void CartesianPlotLegendDock::backgroundSecondColorChanged(const QColor& c) {
 	opens a file dialog and lets the user select the image file.
 */
 void CartesianPlotLegendDock::selectFile() {
-	KConfigGroup conf(KSharedConfig::openConfig(), "CartesianPlotLegendDock");
-	QString dir = conf.readEntry("LastImageDir", "");
-
-	QString formats;
-	for (const QByteArray& format : QImageReader::supportedImageFormats()) {
-		QString f = "*." + QString(format.constData());
-		if (f == QLatin1String("*.svg"))
-			continue;
-		formats.isEmpty() ? formats += f : formats += ' ' + f;
-	}
-
-	QString path = QFileDialog::getOpenFileName(this, i18n("Select the image file"), dir, i18n("Images (%1)", formats));
+	const QString& path = GuiTools::openImageFile(QLatin1String("CartesianPlotLegendDock"));
 	if (path.isEmpty())
-		return; //cancel was clicked in the file-dialog
+		return;
 
-	int pos = path.lastIndexOf(QLatin1String("/"));
-	if (pos != -1) {
-		QString newDir = path.left(pos);
-		if (newDir != dir)
-			conf.writeEntry("LastImageDir", newDir);
-	}
-
-    ui.leBackgroundFileName->setText( path );
-
-	for (auto* legend : m_legendList)
-		legend->setBackgroundFileName(path);
+	ui.leBackgroundFileName->setText(path);
 }
 
 void CartesianPlotLegendDock::fileNameChanged() {
@@ -694,9 +713,9 @@ void CartesianPlotLegendDock::borderColorChanged(const QColor& color) {
 		legend->setBorderPen(pen);
 	}
 
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	GuiTools::updatePenStyles(ui.cbBorderStyle, color);
-	m_initializing = false;
+
 }
 
 void CartesianPlotLegendDock::borderWidthChanged(double value) {
@@ -792,118 +811,107 @@ void CartesianPlotLegendDock::layoutColumnCountChanged(int count) {
 //**** SLOTs for changes triggered in CartesianPlotLegend *****
 //*************************************************************
 //General
-void CartesianPlotLegendDock::legendDescriptionChanged(const AbstractAspect* aspect) {
-	if (m_legend != aspect)
-		return;
-
-	m_initializing = true;
-	if (aspect->name() != ui.leName->text()) {
-		ui.leName->setText(aspect->name());
-	} else if (aspect->comment() != ui.leComment->text()) {
-		ui.leComment->setText(aspect->comment());
-	}
-	m_initializing = false;
-}
-
 void CartesianPlotLegendDock::legendLabelFontChanged(QFont& font) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	//we need to set the font size in points for KFontRequester
 	QFont f(font);
-	f.setPointSizeF( Worksheet::convertFromSceneUnits(f.pixelSize(), Worksheet::Unit::Point) );
+	f.setPointSizeF( round(Worksheet::convertFromSceneUnits(f.pixelSize(), Worksheet::Unit::Point)) );
 	ui.kfrLabelFont->setFont(f);
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendLabelColorChanged(QColor& color) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.kcbLabelColor->setColor(color);
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendLabelOrderChanged(bool b) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	if (b)
 		ui.cbOrder->setCurrentIndex(0); //column major
 	else
 		ui.cbOrder->setCurrentIndex(1); //row major
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendLineSymbolWidthChanged(float value) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.sbLineSymbolWidth->setValue(Worksheet::convertFromSceneUnits(value, m_worksheetUnit));
-	m_initializing = false;
 }
 
+void CartesianPlotLegendDock::legendHorizontalAlignmentChanged(TextLabel::HorizontalAlignment index) {
+	const Lock lock(m_initializing);
+	ui.cbHorizontalAlignment->setCurrentIndex(static_cast<int>(index));
+}
+
+void CartesianPlotLegendDock::legendVerticalAlignmentChanged(TextLabel::VerticalAlignment index) {
+	const Lock lock(m_initializing);
+	ui.cbVerticalAlignment->setCurrentIndex(static_cast<int>(index));
+}
+
+void CartesianPlotLegendDock::legendPositionLogicalChanged(QPointF pos) {
+	const Lock lock(m_initializing);
+	SET_NUMBER_LOCALE
+	ui.lePositionXLogical->setText(numberLocale.toString(pos.x()));
+	ui.dtePositionXLogical->setDateTime(QDateTime::fromMSecsSinceEpoch(pos.x()));
+	ui.lePositionYLogical->setText(numberLocale.toString(pos.y()));
+}
 
 void CartesianPlotLegendDock::legendPositionChanged(const CartesianPlotLegend::PositionWrapper& position) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.sbPositionX->setValue( Worksheet::convertFromSceneUnits(position.point.x(), m_worksheetUnit) );
 	ui.sbPositionY->setValue( Worksheet::convertFromSceneUnits(position.point.y(), m_worksheetUnit) );
 	ui.cbPositionX->setCurrentIndex( static_cast<int>(position.horizontalPosition) );
 	ui.cbPositionY->setCurrentIndex( static_cast<int>(position.verticalPosition) );
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendRotationAngleChanged(qreal angle) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.sbRotation->setValue(angle);
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendVisibilityChanged(bool on) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.chkVisible->setChecked(on);
-	m_initializing = false;
 }
 
 //Background
-void CartesianPlotLegendDock::legendBackgroundTypeChanged(PlotArea::BackgroundType type) {
-	m_initializing = true;
+void CartesianPlotLegendDock::legendBackgroundTypeChanged(WorksheetElement::BackgroundType type) {
+	const Lock lock(m_initializing);
 	ui.cbBackgroundType->setCurrentIndex(static_cast<int>(type));
-	m_initializing = false;
 }
 
-void CartesianPlotLegendDock::legendBackgroundColorStyleChanged(PlotArea::BackgroundColorStyle style) {
-	m_initializing = true;
+void CartesianPlotLegendDock::legendBackgroundColorStyleChanged(WorksheetElement::BackgroundColorStyle style) {
+	const Lock lock(m_initializing);
 	ui.cbBackgroundColorStyle->setCurrentIndex(static_cast<int>(style));
-	m_initializing = false;
 }
 
-void CartesianPlotLegendDock::legendBackgroundImageStyleChanged(PlotArea::BackgroundImageStyle style) {
-	m_initializing = true;
+void CartesianPlotLegendDock::legendBackgroundImageStyleChanged(WorksheetElement::BackgroundImageStyle style) {
+	const Lock lock(m_initializing);
 	ui.cbBackgroundImageStyle->setCurrentIndex(static_cast<int>(style));
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendBackgroundBrushStyleChanged(Qt::BrushStyle style) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.cbBackgroundBrushStyle->setCurrentIndex(style);
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendBackgroundFirstColorChanged(QColor& color) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.kcbBackgroundFirstColor->setColor(color);
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendBackgroundSecondColorChanged(QColor& color) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.kcbBackgroundSecondColor->setColor(color);
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendBackgroundFileNameChanged(QString& filename) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.leBackgroundFileName->setText(filename);
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendBackgroundOpacityChanged(float opacity) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.sbBackgroundOpacity->setValue( qRound(opacity*100.0) );
-	m_initializing = false;
 }
 
 //Border
@@ -911,69 +919,59 @@ void CartesianPlotLegendDock::legendBorderPenChanged(QPen& pen) {
 	if (m_initializing)
 		return;
 
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	if (ui.cbBorderStyle->currentIndex() != pen.style())
 		ui.cbBorderStyle->setCurrentIndex(pen.style());
 	if (ui.kcbBorderColor->color() != pen.color())
 		ui.kcbBorderColor->setColor(pen.color());
 	if (ui.sbBorderWidth->value() != pen.widthF())
 		ui.sbBorderWidth->setValue(Worksheet::convertFromSceneUnits(pen.widthF(), Worksheet::Unit::Point));
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendBorderCornerRadiusChanged(float value) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.sbBorderCornerRadius->setValue(Worksheet::convertFromSceneUnits(value, m_worksheetUnit));
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendBorderOpacityChanged(float opacity) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.sbBorderOpacity->setValue( qRound(opacity*100.0) );
-	m_initializing = false;
 }
 
 //Layout
 void CartesianPlotLegendDock::legendLayoutTopMarginChanged(float value) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.sbLayoutTopMargin->setValue(Worksheet::convertFromSceneUnits(value, m_worksheetUnit));
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendLayoutBottomMarginChanged(float value) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.sbLayoutBottomMargin->setValue(Worksheet::convertFromSceneUnits(value, m_worksheetUnit));
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendLayoutLeftMarginChanged(float value) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.sbLayoutLeftMargin->setValue(Worksheet::convertFromSceneUnits(value, m_worksheetUnit));
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendLayoutRightMarginChanged(float value) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.sbLayoutRightMargin->setValue(Worksheet::convertFromSceneUnits(value, m_worksheetUnit));
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendLayoutVerticalSpacingChanged(float value) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.sbLayoutVerticalSpacing->setValue(Worksheet::convertFromSceneUnits(value, m_worksheetUnit));
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendLayoutHorizontalSpacingChanged(float value) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.sbLayoutHorizontalSpacing->setValue(Worksheet::convertFromSceneUnits(value, m_worksheetUnit));
-	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::legendLayoutColumnCountChanged(int value) {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	ui.sbLayoutColumnCount->setValue(value);
-	m_initializing = false;
 }
 
 //*************************************************************
@@ -998,10 +996,54 @@ void CartesianPlotLegendDock::load() {
 	ui.sbLineSymbolWidth->setValue( Worksheet::convertFromSceneUnits(m_legend->lineSymbolWidth(), m_worksheetUnit) );
 
 	//Geometry
-	ui.cbPositionX->setCurrentIndex(static_cast<int>(m_legend->position().horizontalPosition));
+
+	//widgets for positioning using absolute plot distances
+	ui.cbPositionX->setCurrentIndex( (int)m_legend->position().horizontalPosition );
+//	positionXChanged(ui.cbPositionX->currentIndex());
 	ui.sbPositionX->setValue( Worksheet::convertFromSceneUnits(m_legend->position().point.x(), m_worksheetUnit) );
-	ui.cbPositionY->setCurrentIndex(static_cast<int>(m_legend->position().verticalPosition));
+	ui.cbPositionY->setCurrentIndex( (int)m_legend->position().verticalPosition );
+//	positionYChanged(ui.cbPositionY->currentIndex());
 	ui.sbPositionY->setValue( Worksheet::convertFromSceneUnits(m_legend->position().point.y(), m_worksheetUnit) );
+
+	ui.cbHorizontalAlignment->setCurrentIndex( (int) m_legend->horizontalAlignment() );
+	ui.cbVerticalAlignment->setCurrentIndex( (int) m_legend->verticalAlignment() );
+
+	//widgets for positioning using logical plot coordinates
+	SET_NUMBER_LOCALE
+	bool allowLogicalCoordinates = (m_legend->plot() != nullptr);
+	ui.lBindLogicalPos->setVisible(allowLogicalCoordinates);
+	ui.chbBindLogicalPos->setVisible(allowLogicalCoordinates);
+
+	if (allowLogicalCoordinates) {
+		const auto* plot = static_cast<const CartesianPlot*>(m_legend->plot());
+		if (plot->xRangeFormat() == RangeT::Format::Numeric) {
+			ui.lPositionXLogical->show();
+			ui.lePositionXLogical->show();
+			ui.lPositionXLogicalDateTime->hide();
+			ui.dtePositionXLogical->hide();
+
+			ui.lePositionXLogical->setText(numberLocale.toString(m_legend->positionLogical().x()));
+			ui.lePositionYLogical->setText(numberLocale.toString(m_legend->positionLogical().y()));
+		} else { //DateTime
+			ui.lPositionXLogical->hide();
+			ui.lePositionXLogical->hide();
+			ui.lPositionXLogicalDateTime->show();
+			ui.dtePositionXLogical->show();
+
+			ui.dtePositionXLogical->setDisplayFormat(plot->xRangeDateTimeFormat());
+			ui.dtePositionXLogical->setDateTime(QDateTime::fromMSecsSinceEpoch(m_legend->positionLogical().x()));
+		}
+
+		ui.chbBindLogicalPos->setChecked(m_legend->coordinateBindingEnabled());
+		bindingChanged(m_legend->coordinateBindingEnabled());
+	} else {
+		ui.lPositionXLogical->hide();
+		ui.lePositionXLogical->hide();
+		ui.lPositionYLogical->hide();
+		ui.lePositionYLogical->hide();
+		ui.lPositionXLogicalDateTime->hide();
+		ui.dtePositionXLogical->hide();
+	}
 	ui.sbRotation->setValue(m_legend->rotationAngle());
 
 	ui.chkVisible->setChecked( m_legend->isVisible() );
@@ -1038,9 +1080,9 @@ void CartesianPlotLegendDock::load() {
 
 	ui.sbLayoutColumnCount->setValue( m_legend->layoutColumnCount() );
 
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	GuiTools::updatePenStyles(ui.cbBorderStyle, ui.kcbBorderColor->color());
-	m_initializing = false;
+
 }
 
 void CartesianPlotLegendDock::loadConfigFromTemplate(KConfig& config) {
@@ -1123,9 +1165,9 @@ void CartesianPlotLegendDock::loadConfig(KConfig& config) {
 	group = config.group("PlotLegend");
 	labelWidget->loadConfig(group);
 
-	m_initializing = true;
+	const Lock lock(m_initializing);
 	GuiTools::updatePenStyles(ui.cbBorderStyle, ui.kcbBorderColor->color());
-	m_initializing = false;
+
 }
 
 void CartesianPlotLegendDock::saveConfigAsTemplate(KConfig& config) {
