@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : ColumnDock.cpp
     Project              : LabPlot
-    --------------------------------------------------------------------
-    Copyright            : (C) 2011-2020 by Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2013-2017 by Stefan Gerlach (stefan.gerlach@uni.kn)
     Description          : widget for column properties
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2011-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2013-2017 Stefan Gerlach <stefan.gerlach@uni.kn>
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "ColumnDock.h"
 
@@ -36,6 +18,8 @@
 #include "backend/core/datatypes/DateTime2StringFilter.h"
 #include "backend/core/datatypes/String2DateTimeFilter.h"
 #include "backend/spreadsheet/Spreadsheet.h"
+#include "kdefrontend/spreadsheet/AddValueLabelDialog.h"
+#include "kdefrontend/spreadsheet/BatchEditValueLabelsDialog.h"
 
 #include <KLocalizedString>
 
@@ -49,7 +33,8 @@
 ColumnDock::ColumnDock(QWidget* parent) : BaseDock(parent) {
 	ui.setupUi(this);
 	m_leName = ui.leName;
-	m_leComment = ui.leComment;
+	m_teComment = ui.teComment;
+	m_teComment->setFixedHeight(m_leName->height());
 
 	//add formats for numeric values
 	ui.cbNumericFormat->addItem(i18n("Decimal"), QVariant('f'));
@@ -64,13 +49,19 @@ ColumnDock::ColumnDock(QWidget* parent) : BaseDock(parent) {
 
 	ui.cbDateTimeFormat->setEditable(true);
 
+	ui.twLabels->horizontalHeader()->setSectionResizeMode(0, QHeaderView::ResizeToContents);
+	ui.twLabels->horizontalHeader()->setSectionResizeMode(1, QHeaderView::Stretch);
+
 	connect(ui.leName, &QLineEdit::textChanged, this, &ColumnDock::nameChanged);
-	connect(ui.leComment, &QLineEdit::textChanged, this, &ColumnDock::commentChanged);
+	connect(ui.teComment, &QTextEdit::textChanged, this, &ColumnDock::commentChanged);
 	connect(ui.cbType, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &ColumnDock::typeChanged);
 	connect(ui.cbNumericFormat, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &ColumnDock::numericFormatChanged);
 	connect(ui.sbPrecision, QOverload<int>::of(&QSpinBox::valueChanged), this, &ColumnDock::precisionChanged);
 	connect(ui.cbDateTimeFormat, &QComboBox::currentTextChanged, this, &ColumnDock::dateTimeFormatChanged);
 	connect(ui.cbPlotDesignation, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &ColumnDock::plotDesignationChanged);
+	connect(ui.bAddLabel, &QPushButton::clicked, this, &ColumnDock::addLabel);
+	connect(ui.bRemoveLabel, &QPushButton::clicked, this, &ColumnDock::removeLabel);
+	connect(ui.bBatchEditLabels, &QPushButton::clicked, this, &ColumnDock::batchEditLabels);
 
 	retranslateUi();
 }
@@ -106,20 +97,20 @@ void ColumnDock::setColumns(QList<Column*> list) {
 		//names and comments of non-editable columns in a file data source can be changed.
 		if (!nonEditable && m_column->parentAspect()->type() == AspectType::LiveDataSource) {
 			ui.leName->setEnabled(false);
-			ui.leComment->setEnabled(false);
+			ui.teComment->setEnabled(false);
 		} else {
 			ui.leName->setEnabled(true);
-			ui.leComment->setEnabled(true);
+			ui.teComment->setEnabled(true);
 		}
 
 		ui.leName->setText(m_column->name());
-		ui.leComment->setText(m_column->comment());
+		ui.teComment->setText(m_column->comment());
 	} else {
 		ui.leName->setEnabled(false);
-		ui.leComment->setEnabled(false);
+		ui.teComment->setEnabled(false);
 
 		ui.leName->setText(QString());
-		ui.leComment->setText(QString());
+		ui.teComment->setText(QString());
 
 		auto mode = m_column->columnMode();
 		for (auto* col : m_columnsList) {
@@ -138,6 +129,9 @@ void ColumnDock::setColumns(QList<Column*> list) {
 	ui.sbPrecision->setEnabled(sameMode);
 	ui.lDateTimeFormat->setEnabled(sameMode);
 	ui.cbDateTimeFormat->setEnabled(sameMode);
+	ui.lLabels->setEnabled(sameMode);
+	ui.twLabels->setEnabled(sameMode);
+	ui.frameLabels->setEnabled(sameMode);
 
 	ui.leName->setStyleSheet("");
 	ui.leName->setToolTip("");
@@ -146,8 +140,16 @@ void ColumnDock::setColumns(QList<Column*> list) {
 	updateTypeWidgets(m_column->columnMode());
 	ui.cbPlotDesignation->setCurrentIndex( int(m_column->plotDesignation()) );
 
+	//show value labels of the first column if all selected columns have the same mode
+	if (sameMode)
+		showValueLabels();
+	else {
+		for (int i = 0; ui.twLabels->rowCount(); ++i)
+			ui.twLabels->removeRow(0);
+	}
+
 	// slots
-	connect(m_column, &AbstractColumn::aspectDescriptionChanged, this, &ColumnDock::columnDescriptionChanged);
+	connect(m_column, &AbstractColumn::aspectDescriptionChanged, this, &ColumnDock::aspectDescriptionChanged);
 	connect(m_column, &AbstractColumn::modeChanged, this, &ColumnDock::columnModeChanged);
 	connect(m_column->outputFilter(), &AbstractSimpleFilter::formatChanged, this, &ColumnDock::columnFormatChanged);
 	connect(m_column->outputFilter(), &AbstractSimpleFilter::digitsChanged, this, &ColumnDock::columnPrecisionChanged);
@@ -167,9 +169,9 @@ void ColumnDock::setColumns(QList<Column*> list) {
 */
 void ColumnDock::updateTypeWidgets(AbstractColumn::ColumnMode mode) {
 	const Lock lock(m_initializing);
-	ui.cbType->setCurrentIndex(ui.cbType->findData((int)mode));
+	ui.cbType->setCurrentIndex(ui.cbType->findData(static_cast<int>(mode)));
 	switch (mode) {
-	case AbstractColumn::ColumnMode::Numeric: {
+	case AbstractColumn::ColumnMode::Double: {
 			auto* filter = static_cast<Double2StringFilter*>(m_column->outputFilter());
 			ui.cbNumericFormat->setCurrentIndex(ui.cbNumericFormat->findData(filter->numericFormat()));
 			ui.sbPrecision->setValue(filter->numDigits());
@@ -198,13 +200,9 @@ void ColumnDock::updateTypeWidgets(AbstractColumn::ColumnMode mode) {
 	ui.lDateTimeFormat->hide();
 	ui.cbDateTimeFormat->hide();
 
-	if (mode == AbstractColumn::ColumnMode::Numeric) {
+	if (mode == AbstractColumn::ColumnMode::Double) {
 		ui.lNumericFormat->show();
 		ui.cbNumericFormat->show();
-	}
-
-	//precision is only available for Numeric
-	if (mode == AbstractColumn::ColumnMode::Numeric) {
 		ui.lPrecision->show();
 		ui.sbPrecision->show();
 	}
@@ -215,50 +213,129 @@ void ColumnDock::updateTypeWidgets(AbstractColumn::ColumnMode mode) {
 	}
 }
 
+void ColumnDock::showValueLabels() {
+	for (int i = 0; ui.twLabels->rowCount(); ++i)
+		ui.twLabels->removeRow(0);
+
+	if (m_column->hasValueLabels()) {
+		auto mode = m_column->columnMode();
+		int i = 0;
+
+		switch (mode) {
+		case AbstractColumn::ColumnMode::Double: {
+			auto labels = m_column->valueLabels();
+			ui.twLabels->setRowCount(labels.size());
+			auto it = labels.constBegin();
+			while (it != labels.constEnd()) {
+				ui.twLabels->setItem(i, 0, new QTableWidgetItem(QString::number(it.key())));
+				ui.twLabels->setItem(i, 1, new QTableWidgetItem(it.value()));
+				++it;
+				++i;
+			}
+			break;
+		}
+		case AbstractColumn::ColumnMode::Integer: {
+			auto labels = m_column->intValueLabels();
+			ui.twLabels->setRowCount(labels.size());
+			auto it = labels.constBegin();
+			while (it != labels.constEnd()) {
+				ui.twLabels->setItem(i, 0, new QTableWidgetItem(QString::number(it.key())));
+				ui.twLabels->setItem(i, 1, new QTableWidgetItem(it.value()));
+				++it;
+				++i;
+			}
+			break;
+		}
+		case AbstractColumn::ColumnMode::BigInt: {
+			auto labels = m_column->bigIntValueLabels();
+			ui.twLabels->setRowCount(labels.size());
+			auto it = labels.constBegin();
+			while (it != labels.constEnd()) {
+				ui.twLabels->setItem(i, 0, new QTableWidgetItem(QString::number(it.key())));
+				ui.twLabels->setItem(i, 1, new QTableWidgetItem(it.value()));
+				++it;
+				++i;
+			}
+			break;
+		}
+		case AbstractColumn::ColumnMode::Text: {
+			auto labels = m_column->textValueLabels();
+			ui.twLabels->setRowCount(labels.size());
+			auto it = labels.constBegin();
+			while (it != labels.constEnd()) {
+				ui.twLabels->setItem(i, 0, new QTableWidgetItem(it.key()));
+				ui.twLabels->setItem(i, 1, new QTableWidgetItem(it.value()));
+				++it;
+				++i;
+			}
+			break;
+		}
+		case AbstractColumn::ColumnMode::Month:
+		case AbstractColumn::ColumnMode::Day:
+		case AbstractColumn::ColumnMode::DateTime: {
+			auto labels = m_column->dateTimeValueLabels();
+			ui.twLabels->setRowCount(labels.size());
+			auto it = labels.constBegin();
+			const QString& format = ui.cbDateTimeFormat->currentText();
+			while (it != labels.constEnd()) {
+				ui.twLabels->setItem(i, 0, new QTableWidgetItem(it.key().toString(format)));
+				ui.twLabels->setItem(i, 1, new QTableWidgetItem(it.value()));
+				++it;
+				++i;
+			}
+			break;
+		}
+		}
+	}
+}
+
 //*************************************************************
 //******** SLOTs for changes triggered in ColumnDock **********
 //*************************************************************
 void ColumnDock::retranslateUi() {
-	m_initializing = true;
+	const Lock lock(m_initializing);
 
 	ui.cbType->clear();
-	ui.cbType->addItem(i18n("Numeric"), QVariant(static_cast<int>(AbstractColumn::ColumnMode::Numeric)));
-	ui.cbType->addItem(i18n("Integer"), QVariant(static_cast<int>(AbstractColumn::ColumnMode::Integer)));
-	ui.cbType->addItem(i18n("Big Integer"), QVariant(static_cast<int>(AbstractColumn::ColumnMode::BigInt)));
-	ui.cbType->addItem(i18n("Text"), QVariant(static_cast<int>(AbstractColumn::ColumnMode::Text)));
-	ui.cbType->addItem(i18n("Month Names"), QVariant(static_cast<int>(AbstractColumn::ColumnMode::Month)));
-	ui.cbType->addItem(i18n("Day Names"), QVariant(static_cast<int>(AbstractColumn::ColumnMode::Day)));
-	ui.cbType->addItem(i18n("Date and Time"), QVariant(static_cast<int>(AbstractColumn::ColumnMode::DateTime)));
+	ui.cbType->addItem(AbstractColumn::columnModeString(AbstractColumn::ColumnMode::Double), QVariant(static_cast<int>(AbstractColumn::ColumnMode::Double)));
+	ui.cbType->addItem(AbstractColumn::columnModeString(AbstractColumn::ColumnMode::Integer), QVariant(static_cast<int>(AbstractColumn::ColumnMode::Integer)));
+	ui.cbType->addItem(AbstractColumn::columnModeString(AbstractColumn::ColumnMode::BigInt), QVariant(static_cast<int>(AbstractColumn::ColumnMode::BigInt)));
+	ui.cbType->addItem(AbstractColumn::columnModeString(AbstractColumn::ColumnMode::Text), QVariant(static_cast<int>(AbstractColumn::ColumnMode::Text)));
+	ui.cbType->addItem(AbstractColumn::columnModeString(AbstractColumn::ColumnMode::Month), QVariant(static_cast<int>(AbstractColumn::ColumnMode::Month)));
+	ui.cbType->addItem(AbstractColumn::columnModeString(AbstractColumn::ColumnMode::Day), QVariant(static_cast<int>(AbstractColumn::ColumnMode::Day)));
+	ui.cbType->addItem(AbstractColumn::columnModeString(AbstractColumn::ColumnMode::DateTime), QVariant(static_cast<int>(AbstractColumn::ColumnMode::DateTime)));
 
 	ui.cbPlotDesignation->clear();
-	ui.cbPlotDesignation->addItem(i18n("None"));
-	ui.cbPlotDesignation->addItem(i18n("X"));
-	ui.cbPlotDesignation->addItem(i18n("Y"));
-	ui.cbPlotDesignation->addItem(i18n("Z"));
-	ui.cbPlotDesignation->addItem(i18n("X-error"));
-	ui.cbPlotDesignation->addItem(i18n("X-error -"));
-	ui.cbPlotDesignation->addItem(i18n("X-error +"));
-	ui.cbPlotDesignation->addItem(i18n("Y-error"));
-	ui.cbPlotDesignation->addItem(i18n("Y-error -"));
-	ui.cbPlotDesignation->addItem(i18n("Y-error +"));
+	ui.cbPlotDesignation->addItem(AbstractColumn::plotDesignationString(AbstractColumn::PlotDesignation::NoDesignation, false));
+	ui.cbPlotDesignation->addItem(AbstractColumn::plotDesignationString(AbstractColumn::PlotDesignation::X, false));
+	ui.cbPlotDesignation->addItem(AbstractColumn::plotDesignationString(AbstractColumn::PlotDesignation::Y, false));
+	ui.cbPlotDesignation->addItem(AbstractColumn::plotDesignationString(AbstractColumn::PlotDesignation::Z, false));
+	ui.cbPlotDesignation->addItem(AbstractColumn::plotDesignationString(AbstractColumn::PlotDesignation::XError, false));
+	ui.cbPlotDesignation->addItem(AbstractColumn::plotDesignationString(AbstractColumn::PlotDesignation::XErrorMinus, false));
+	ui.cbPlotDesignation->addItem(AbstractColumn::plotDesignationString(AbstractColumn::PlotDesignation::XErrorPlus, false));
+	ui.cbPlotDesignation->addItem(AbstractColumn::plotDesignationString(AbstractColumn::PlotDesignation::YError, false));
+	ui.cbPlotDesignation->addItem(AbstractColumn::plotDesignationString(AbstractColumn::PlotDesignation::YErrorMinus, false));
+	ui.cbPlotDesignation->addItem(AbstractColumn::plotDesignationString(AbstractColumn::PlotDesignation::YErrorPlus, false));
 
-	m_initializing = false;
+	ui.bAddLabel->setToolTip(i18n("Add a new value label"));
+	ui.bRemoveLabel->setToolTip(i18n("Remove the selected value label"));
+	ui.bBatchEditLabels->setToolTip(i18n("Modify multiple values labels in a batch mode"));
 }
 
 /*!
   called when the type (column mode - numeric, text etc.) of the column was changed.
 */
 void ColumnDock::typeChanged(int index) {
-	DEBUG("ColumnDock::typeChanged()");
+	DEBUG("ColumnDock::typeChanged()")
 	if (m_initializing)
 		return;
 
-	auto columnMode = (AbstractColumn::ColumnMode)ui.cbType->itemData(index).toInt();
+	auto columnMode = static_cast<AbstractColumn::ColumnMode>(ui.cbType->itemData(index).toInt());
+	const auto& columns = m_columnsList;
 
 	switch (columnMode) {
-	case AbstractColumn::ColumnMode::Numeric: {
+	case AbstractColumn::ColumnMode::Double: {
 		int digits = ui.sbPrecision->value();
-		for (auto* col : m_columnsList) {
+		for (auto* col : columns) {
 			col->beginMacro(i18n("%1: change column type", col->name()));
 			col->setColumnMode(columnMode);
 			auto* filter = static_cast<Double2StringFilter*>(col->outputFilter());
@@ -277,15 +354,15 @@ void ColumnDock::typeChanged(int index) {
 	case AbstractColumn::ColumnMode::Integer:
 	case AbstractColumn::ColumnMode::BigInt:
 	case AbstractColumn::ColumnMode::Text:
-		for (auto* col : m_columnsList)
+		for (auto* col : columns)
 			col->setColumnMode(columnMode);
 		break;
 	case AbstractColumn::ColumnMode::Month:
 	case AbstractColumn::ColumnMode::Day:
-		for (auto* col : m_columnsList) {
+		for (auto* col : columns) {
 			col->beginMacro(i18n("%1: change column type", col->name()));
 			// the format is saved as item data
-			QString format = ui.cbDateTimeFormat->itemData(ui.cbDateTimeFormat->currentIndex()).toString();
+			const QString& format = ui.cbDateTimeFormat->itemData(ui.cbDateTimeFormat->currentIndex()).toString();
 			col->setColumnMode(columnMode);
 			auto* filter = static_cast<DateTime2StringFilter*>(col->outputFilter());
 			filter->setFormat(format);
@@ -293,10 +370,10 @@ void ColumnDock::typeChanged(int index) {
 		}
 		break;
 	case AbstractColumn::ColumnMode::DateTime:
-		for (auto* col : m_columnsList) {
+		for (auto* col : columns) {
 			col->beginMacro(i18n("%1: change column type", col->name()));
 			// the format is the current text
-			QString format = ui.cbDateTimeFormat->currentText();
+			const QString& format = ui.cbDateTimeFormat->currentText();
 			col->setColumnMode(columnMode);
 			auto* filter = static_cast<DateTime2StringFilter*>(col->outputFilter());
 			filter->setFormat(format);
@@ -306,8 +383,6 @@ void ColumnDock::typeChanged(int index) {
 	}
 
 	updateTypeWidgets(columnMode);
-
-	DEBUG("ColumnDock::typeChanged() DONE");
 }
 
 void ColumnDock::numericFormatChanged(int index) {
@@ -315,7 +390,7 @@ void ColumnDock::numericFormatChanged(int index) {
 		return;
 
 	char format = ui.cbNumericFormat->itemData(index).toChar().toLatin1();
-	for (auto* col : m_columnsList) {
+	for (auto* col : qAsConst(m_columnsList)) {
 		auto* filter = static_cast<Double2StringFilter*>(col->outputFilter());
 		filter->setNumericFormat(format);
 	}
@@ -325,7 +400,7 @@ void ColumnDock::precisionChanged(int digits) {
 	if (m_initializing)
 		return;
 
-	for (auto* col : m_columnsList) {
+	for (auto* col : qAsConst(m_columnsList)) {
 		auto* filter = static_cast<Double2StringFilter*>(col->outputFilter());
 		filter->setNumDigits(digits);
 	}
@@ -335,7 +410,7 @@ void ColumnDock::dateTimeFormatChanged(const QString& format) {
 	if (m_initializing)
 		return;
 
-	for (auto* col : m_columnsList) {
+	for (auto* col : qAsConst(m_columnsList)) {
 		auto* filter = static_cast<DateTime2StringFilter*>(col->outputFilter());
 		filter->setFormat(format);
 	}
@@ -346,25 +421,97 @@ void ColumnDock::plotDesignationChanged(int index) {
 		return;
 
 	auto pd = AbstractColumn::PlotDesignation(index);
-	for (auto* col : m_columnsList)
+	for (auto* col :qAsConst(m_columnsList))
 		col->setPlotDesignation(pd);
 }
 
+//value labels
+void ColumnDock::addLabel() {
+	auto mode = m_column->columnMode();
+	auto* dlg = new AddValueLabelDialog(this, mode);
+
+	if (mode == AbstractColumn::ColumnMode::Month
+		|| mode == AbstractColumn::ColumnMode::Day
+		|| mode == AbstractColumn::ColumnMode::DateTime)
+		dlg->setDateTimeFormat(ui.cbDateTimeFormat->currentText());
+
+	if (dlg->exec() == QDialog::Accepted) {
+		const QString& label = dlg->label();
+		const auto& columns = m_columnsList;
+		QString valueStr;
+		switch (mode) {
+		case AbstractColumn::ColumnMode::Double: {
+			double value = dlg->value();
+			valueStr = QString::number(value);
+			for (auto* col : columns)
+				col->addValueLabel(value, label);
+			break;
+		}
+		case AbstractColumn::ColumnMode::Integer: {
+			int value = dlg->valueInt();
+			valueStr = QString::number(value);
+			for (auto* col : columns)
+				col->addValueLabel(value, label);
+			break;
+		}
+		case AbstractColumn::ColumnMode::BigInt: {
+			qint64 value = dlg->valueBigInt();
+			valueStr = QString::number(value);
+			for (auto* col : columns)
+				col->addValueLabel(value, label);
+			break;
+		}
+		case AbstractColumn::ColumnMode::Text: {
+			valueStr = dlg->valueText();
+			for (auto* col : columns)
+				col->addValueLabel(valueStr, label);
+			break;
+		}
+		case AbstractColumn::ColumnMode::Month:
+		case AbstractColumn::ColumnMode::Day:
+		case AbstractColumn::ColumnMode::DateTime: {
+			const QDateTime& value = dlg->valueDateTime();
+			valueStr = value.toString(ui.cbDateTimeFormat->currentText());
+			for (auto* col : columns)
+				col->addValueLabel(value, label);
+			break;
+		}
+		}
+
+		int count = ui.twLabels->rowCount();
+		ui.twLabels->insertRow(count);
+		ui.twLabels->setItem(count, 0, new QTableWidgetItem(valueStr));
+		ui.twLabels->setItem(count, 1, new QTableWidgetItem(label));
+
+	}
+	delete dlg;
+}
+
+void ColumnDock::removeLabel() {
+	auto* item = ui.twLabels->currentItem();
+	if (!item)
+		return;
+
+	int row = ui.twLabels->currentRow();
+	const auto& value = ui.twLabels->itemAt(row, 0)->text();
+	for (auto* col : qAsConst(m_columnsList))
+		col->removeValueLabel(value);
+
+	ui.twLabels->removeRow(ui.twLabels->currentRow());
+}
+
+void ColumnDock::batchEditLabels() {
+	auto* dlg = new BatchEditValueLabelsDialog(this);
+	dlg->setColumns(m_columnsList);
+	if (dlg->exec() == QDialog::Accepted)
+		showValueLabels(); //new value labels were saved in the dialog, show them here
+
+	delete dlg;
+}
+
 //*************************************************************
 //********* SLOTs for changes triggered in Column *************
 //*************************************************************
-void ColumnDock::columnDescriptionChanged(const AbstractAspect* aspect) {
-	if (m_column != aspect)
-		return;
-
-	m_initializing = true;
-	if (aspect->name() != ui.leName->text())
-		ui.leName->setText(aspect->name());
-	else if (aspect->comment() != ui.leComment->text())
-		ui.leComment->setText(aspect->comment());
-	m_initializing = false;
-}
-
 void ColumnDock::columnModeChanged(const AbstractAspect* aspect) {
 	if (m_column != aspect)
 		return;
@@ -373,11 +520,11 @@ void ColumnDock::columnModeChanged(const AbstractAspect* aspect) {
 }
 
 void ColumnDock::columnFormatChanged() {
-	DEBUG("ColumnDock::columnFormatChanged()");
+	DEBUG("ColumnDock::columnFormatChanged()")
 	const Lock lock(m_initializing);
 	auto columnMode = m_column->columnMode();
 	switch (columnMode) {
-	case AbstractColumn::ColumnMode::Numeric: {
+	case AbstractColumn::ColumnMode::Double: {
 		auto* filter = static_cast<Double2StringFilter*>(m_column->outputFilter());
 		ui.cbNumericFormat->setCurrentIndex(ui.cbNumericFormat->findData(filter->numericFormat()));
 		break;
