@@ -1,32 +1,15 @@
-/***************************************************************************
-File                 : LiveDataDock.cpp
-Project              : LabPlot
-Description          : Dock widget for live data properties
---------------------------------------------------------------------
-Copyright            : (C) 2017 by Fabian Kristof (fkristofszabolcs@gmail.com)
-Copyright            : (C) 2018-2019 Kovacs Ferencz (kferike98@gmail.com)
-Copyright            : (C) 2018 by Stefan Gerlach (stefan.gerlach@uni.kn)
-Copyright            : (C) 2017-2020 Alexander Semke (alexander.semke@web.de)
-***************************************************************************/
+/*
+    File                 : LiveDataDock.cpp
+    Project              : LabPlot
+    Description          : Dock widget for live data properties
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2017 Fabian Kristof <fkristofszabolcs@gmail.com>
+    SPDX-FileCopyrightText: 2018-2019 Kovacs Ferencz <kferike98@gmail.com>
+    SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-FileCopyrightText: 2017-2020 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
-/***************************************************************************
-*                                                                         *
-*  This program is free software; you can redistribute it and/or modify   *
-*  it under the terms of the GNU General Public License as published by   *
-*  the Free Software Foundation; either version 2 of the License, or      *
-*  (at your option) any later version.                                    *
-*                                                                         *
-*  This program is distributed in the hope that it will be useful,        *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
-*  GNU General Public License for more details.                           *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the Free Software           *
-*   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
-*   Boston, MA  02110-1301  USA                                           *
-*                                                                         *
-***************************************************************************/
 #include "LiveDataDock.h"
 #include "kdefrontend/GuiTools.h"
 
@@ -61,12 +44,12 @@ LiveDataDock::LiveDataDock(QWidget* parent) : BaseDock(parent)
 	connect(ui.leName, &QLineEdit::textChanged, this, &LiveDataDock::nameChanged);
 	connect(ui.bPausePlayReading, &QPushButton::clicked, this, &LiveDataDock::pauseContinueReading);
 	connect(ui.bUpdateNow, &QPushButton::clicked, this, &LiveDataDock::updateNow);
-	connect(ui.sbUpdateInterval, static_cast<void (QSpinBox::*) (int)>(&QSpinBox::valueChanged), this, &LiveDataDock::updateIntervalChanged);
+	connect(ui.sbUpdateInterval, QOverload<int>::of(&QSpinBox::valueChanged), this, &LiveDataDock::updateIntervalChanged);
 
-	connect(ui.sbKeepNValues, static_cast<void (QSpinBox::*) (int)>(&QSpinBox::valueChanged), this, &LiveDataDock::keepNValuesChanged);
-	connect(ui.sbSampleSize, static_cast<void (QSpinBox::*) (int)>(&QSpinBox::valueChanged), this, &LiveDataDock::sampleSizeChanged);
-	connect(ui.cbUpdateType, static_cast<void (QComboBox::*) (int)>(&QComboBox::currentIndexChanged), this, &LiveDataDock::updateTypeChanged);
-	connect(ui.cbReadingType, static_cast<void (QComboBox::*) (int)>(&QComboBox::currentIndexChanged), this, &LiveDataDock::readingTypeChanged);
+	connect(ui.sbKeepNValues, QOverload<int>::of(&QSpinBox::valueChanged), this, &LiveDataDock::keepNValuesChanged);
+	connect(ui.sbSampleSize, QOverload<int>::of(&QSpinBox::valueChanged), this, &LiveDataDock::sampleSizeChanged);
+	connect(ui.cbUpdateType, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &LiveDataDock::updateTypeChanged);
+	connect(ui.cbReadingType, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &LiveDataDock::readingTypeChanged);
 
 #ifdef HAVE_MQTT
 	connect(ui.bWillUpdateNow, &QPushButton::clicked, this, &LiveDataDock::willUpdateNow);
@@ -193,14 +176,14 @@ void LiveDataDock::setMQTTClient(MQTTClient* const client) {
 
 	if (m_previousMQTTClient == nullptr) {
 		m_updateSubscriptionConn = connect(client, &MQTTClient::MQTTSubscribed, [this]() {
-			emit updateSubscriptionTree(m_mqttClient->MQTTSubscriptions());
+			Q_EMIT updateSubscriptionTree(m_mqttClient->MQTTSubscriptions());
 		});
 
 		//Fill the subscription tree(useful if the MQTTClient was loaded)
 		QVector<QString> topics = client->topicNames();
 		for (const auto& topic : topics)
 			addTopicToTree(topic);
-		emit updateSubscriptionTree(m_mqttClient->MQTTSubscriptions());
+		Q_EMIT updateSubscriptionTree(m_mqttClient->MQTTSubscriptions());
 	}
 
 	//if the previous MQTTClient's host name was different from the current one we have to disconnect some slots
@@ -220,16 +203,16 @@ void LiveDataDock::setMQTTClient(MQTTClient* const client) {
 		m_previousHost->topicList = m_subscriptionWidget->getTopicList();
 		m_subscriptionWidget->setTopicList(m_currentHost->topicList);
 
-		emit MQTTClearTopics();
+		Q_EMIT MQTTClearTopics();
 		//repopulating the tree widget with the already known topics of the client
 		for (const auto& topic : m_currentHost->addedTopics)
 			addTopicToTree(topic);
 
 		//fill subscriptions tree widget
-		emit updateSubscriptionTree(m_mqttClient->MQTTSubscriptions());
+		Q_EMIT updateSubscriptionTree(m_mqttClient->MQTTSubscriptions());
 
 		m_updateSubscriptionConn = connect(client, &MQTTClient::MQTTSubscribed, [this]() {
-			emit updateSubscriptionTree(m_mqttClient->MQTTSubscriptions());
+			Q_EMIT updateSubscriptionTree(m_mqttClient->MQTTSubscriptions());
 		});
 		connect(m_currentHost->client, &QMqttClient::messageReceived, this, &LiveDataDock::mqttMessageReceived);
 
@@ -379,7 +362,7 @@ void LiveDataDock::updateNow() {
 void LiveDataDock::nameChanged(const QString& name) {
 	if (m_liveDataSource) {
 		if (!m_liveDataSource->setName(name, false)) {
-			ui.leName->setStyleSheet("background:red;");
+			SET_WARNING_STYLE(m_leName)
 			ui.leName->setToolTip(i18n("Please choose another name, because this is already in use."));
 			return;
 		}
@@ -387,7 +370,7 @@ void LiveDataDock::nameChanged(const QString& name) {
 #ifdef HAVE_MQTT
 	else if (m_mqttClient) {
 		if (!m_mqttClient->setName(name, false)) {
-			ui.leName->setStyleSheet("background:red;");
+			SET_WARNING_STYLE(m_leName)
 			ui.leName->setToolTip(i18n("Please choose another name, because this is already in use."));
 			return;
 		}
@@ -699,8 +682,7 @@ void LiveDataDock::onMQTTConnect() {
  *\brief called when the client receives a message
  * if the message arrived from a new topic, the topic is put in twTopics
  */
-void LiveDataDock::mqttMessageReceived(const QByteArray& message, const QMqttTopicName& topic) {
-	Q_UNUSED(message)
+void LiveDataDock::mqttMessageReceived(const QByteArray& /*message*/, const QMqttTopicName& topic) {
 	if (!m_currentHost->addedTopics.contains(topic.name())) {
 		m_currentHost->addedTopics.push_back(topic.name());
 		addTopicToTree(topic.name());
@@ -717,7 +699,11 @@ void LiveDataDock::addTopicToTree(const QString &topicName) {
 	QChar sep = '/';
 	QString rootName;
 	if (topicName.contains(sep)) {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+		QStringList list = topicName.split(sep, Qt::SkipEmptyParts);
+#else
 		QStringList list = topicName.split(sep, QString::SkipEmptyParts);
+#endif
 
 		if (!list.isEmpty()) {
 			rootName = list.at(0);
@@ -781,24 +767,27 @@ void LiveDataDock::addTopicToTree(const QString &topicName) {
 
 	//if a subscribed topic contains the new topic, we have to update twSubscriptions
 	for (int i = 0; i < m_subscriptionWidget->subscriptionCount(); ++i) {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+		QStringList subscriptionName = m_subscriptionWidget->topLevelSubscription(i)->text(0).split('/', Qt::SkipEmptyParts);
+#else
 		QStringList subscriptionName = m_subscriptionWidget->topLevelSubscription(i)->text(0).split('/', QString::SkipEmptyParts);
+#endif
 		if (rootName == subscriptionName[0]) {
-			emit updateSubscriptionTree(m_mqttClient->MQTTSubscriptions());
+			Q_EMIT updateSubscriptionTree(m_mqttClient->MQTTSubscriptions());
 			break;
 		}
 	}
 
 	//signals that a newTopic was added, in order to fill the completer of leTopics
 	//we have to pass the whole topic name, not just the root name, for testing purposes
-	emit newTopic(topicName);
+	Q_EMIT newTopic(topicName);
 }
 
 /*!
  *\brief called when a client receives a message, if the clients hostname isn't identic with the host name of MQTTClient
  * if the message arrived from a new topic, the topic is added to the host data
  */
-void LiveDataDock::mqttMessageReceivedInBackground(const QByteArray& message, const QMqttTopicName& topic) {
-	Q_UNUSED(message)
+void LiveDataDock::mqttMessageReceivedInBackground(const QByteArray& /*message*/, const QMqttTopicName& topic) {
 	if (!m_currentHost->addedTopics.contains(topic.name()))
 		m_currentHost->addedTopics.push_back(topic.name());
 }
@@ -830,7 +819,7 @@ void LiveDataDock::removeClient(const QString& hostname, quint16 port) {
 	}
 
 	if (m_mqttClient && m_mqttClient->clientHostName() == hostname) {
-		emit MQTTClearTopics();
+		Q_EMIT MQTTClearTopics();
 		m_mqttClient = nullptr;
 	}
 
@@ -843,7 +832,11 @@ void LiveDataDock::removeClient(const QString& hostname, quint16 port) {
  * \param topic
  */
 bool LiveDataDock::testSubscribe(const QString& topic) {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+	QStringList topicList = topic.split('/', Qt::SkipEmptyParts);
+#else
 	QStringList topicList = topic.split('/', QString::SkipEmptyParts);
+#endif
 	QTreeWidgetItem* currentItem = nullptr;
 	for (int i = 0; i < m_subscriptionWidget->topicCount(); ++i) {
 		if (m_subscriptionWidget->topLevelTopic(i)->text(0) == topicList[0]) {
