@@ -1,30 +1,12 @@
-/***************************************************************************
+/*
     File                 : NotesDock.cpp
     Project              : LabPlot
     Description          : Dock for configuring notes
     --------------------------------------------------------------------
-    Copyright            : (C) 2016 Garvit Khatri (garvitdelhi@gmail.com)
+    SPDX-FileCopyrightText: 2016 Garvit Khatri <garvitdelhi@gmail.com>
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "NoteDock.h"
 #include "kdefrontend/TemplateHandler.h"
@@ -37,10 +19,11 @@
 NoteDock::NoteDock(QWidget *parent) : BaseDock(parent) {
 	ui.setupUi(this);
 	m_leName = ui.leName;
-	m_leComment = ui.leComment;
+	m_teComment = ui.teComment;
+	m_teComment->setFixedHeight(1.2 * m_leName->height());
 
 	connect(ui.leName, &QLineEdit::textChanged, this, &NoteDock::nameChanged);
-	connect(ui.leComment, &QLineEdit::textChanged, this, &NoteDock::commentChanged);
+	connect(ui.teComment, &QTextEdit::textChanged, this, &NoteDock::commentChanged);
 
 	connect(ui.kcbBgColor, &KColorButton::changed, this, &NoteDock::backgroundColorChanged);
 	connect(ui.kcbTextColor, &KColorButton::changed, this, &NoteDock::textColorChanged);
@@ -66,6 +49,8 @@ void NoteDock::setNotesList(QList< Note* > list) {
 	ui.kcbTextColor->setColor(m_notes->textColor());
 	ui.kfrTextFont->setFont(m_notes->textFont());
 	m_initializing = false;
+
+	connect(m_notes, &Note::aspectDescriptionChanged, this, &NoteDock::aspectDescriptionChanged);
 }
 
 //*************************************************************
