@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : SpreadsheetDock.cpp
     Project              : LabPlot
     Description          : widget for spreadsheet properties
 	--------------------------------------------------------------------
-	Copyright            : (C) 2010-2019 by Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2012-2013 by Stefan Gerlach (stefan.gerlach@uni-konstanz.de)
+    SPDX-FileCopyrightText: 2010-2019 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2012-2013 Stefan Gerlach <stefan.gerlach@uni-konstanz.de>
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "SpreadsheetDock.h"
 #include "commonfrontend/spreadsheet/SpreadsheetView.h"
@@ -48,13 +30,14 @@
 SpreadsheetDock::SpreadsheetDock(QWidget* parent) : BaseDock(parent) {
 	ui.setupUi(this);
 	m_leName = ui.leName;
-	//leComment = ui.teComment; // is not a lineedit
+	m_teComment = ui.teComment;
+	ui.teComment->setFixedHeight(1.2 * ui.leName->height());
 
 	connect(ui.leName, &QLineEdit::textChanged, this, &SpreadsheetDock::nameChanged);
 	connect(ui.teComment, &QTextEdit::textChanged, this, &SpreadsheetDock::commentChanged);
-	connect(ui.sbColumnCount, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &SpreadsheetDock::columnCountChanged);
-	connect(ui.sbRowCount, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &SpreadsheetDock::rowCountChanged);
-	connect(ui.cbShowComments, &QCheckBox::stateChanged, this, &SpreadsheetDock::commentsShownChanged);
+	connect(ui.sbColumnCount, QOverload<int>::of(&QSpinBox::valueChanged), this, &SpreadsheetDock::columnCountChanged);
+	connect(ui.sbRowCount, QOverload<int>::of(&QSpinBox::valueChanged), this, &SpreadsheetDock::rowCountChanged);
+	connect(ui.cbShowComments, &QCheckBox::toggled, this, &SpreadsheetDock::commentsShownChanged);
 
 	auto* templateHandler = new TemplateHandler(this, TemplateHandler::ClassName::Spreadsheet);
 	ui.gridLayout->addWidget(templateHandler, 11, 0, 1, 4);
@@ -104,7 +87,7 @@ void SpreadsheetDock::setSpreadsheets(QList<Spreadsheet*> list) {
 	this->load();
 
 	// undo functions
-	connect(m_spreadsheet, &AbstractAspect::aspectDescriptionChanged, this, &SpreadsheetDock::spreadsheetDescriptionChanged);
+	connect(m_spreadsheet, &AbstractAspect::aspectDescriptionChanged, this, &SpreadsheetDock::aspectDescriptionChanged);
 	connect(m_spreadsheet, &Spreadsheet::rowCountChanged, this, &SpreadsheetDock::spreadsheetRowCountChanged);
 	connect(m_spreadsheet, &Spreadsheet::columnCountChanged, this, &SpreadsheetDock::spreadsheetColumnCountChanged);
 	//TODO: show comments
@@ -124,13 +107,6 @@ void SpreadsheetDock::setSpreadsheets(QList<Spreadsheet*> list) {
 //*************************************************************
 //****** SLOTs for changes triggered in SpreadsheetDock *******
 //*************************************************************
-void SpreadsheetDock::commentChanged() {
-	if (m_initializing)
-		return;
-
-	m_spreadsheet->setComment(ui.teComment->document()->toPlainText());
-}
-
 void SpreadsheetDock::rowCountChanged(int rows) {
 	if (m_initializing)
 		return;
@@ -148,9 +124,9 @@ void SpreadsheetDock::columnCountChanged(int columns) {
 }
 
 /*!
-  switches on/off  the comment header in the views of the selected spreadsheets.
+  enable/disable the comment header in the views of the selected spreadsheets.
 */
-void SpreadsheetDock::commentsShownChanged(int state) {
+void SpreadsheetDock::commentsShownChanged(bool state) {
 	if (m_initializing)
 		return;
 
@@ -161,19 +137,6 @@ void SpreadsheetDock::commentsShownChanged(int state) {
 //*************************************************************
 //******** SLOTs for changes triggered in Spreadsheet *********
 //*************************************************************
-void SpreadsheetDock::spreadsheetDescriptionChanged(const AbstractAspect* aspect) {
-	if (m_spreadsheet != aspect)
-		return;
-
-	m_initializing = true;
-	if (aspect->name() != ui.leName->text())
-		ui.leName->setText(aspect->name());
-	else if (aspect->comment() != ui.teComment->toPlainText())
-		ui.teComment->document()->setPlainText(aspect->comment());
-
-	m_initializing = false;
-}
-
 void SpreadsheetDock::spreadsheetRowCountChanged(int count) {
 	m_initializing = true;
   	ui.sbRowCount->setValue(count);
@@ -186,7 +149,7 @@ void SpreadsheetDock::spreadsheetColumnCountChanged(int count) {
 	m_initializing = false;
 }
 
-void SpreadsheetDock::spreadsheetShowCommentsChanged(int checked) {
+void SpreadsheetDock::spreadsheetShowCommentsChanged(bool checked) {
 	m_initializing = true;
 	ui.cbShowComments->setChecked(checked);
 	m_initializing = false;
