@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : WorksheetDock.cpp
     Project              : LabPlot
     Description          : widget for worksheet properties
     --------------------------------------------------------------------
-    Copyright            : (C) 2010-2016 by Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2012-2013 by Stefan Gerlach (stefan.gerlach@uni-konstanz.de)
+    SPDX-FileCopyrightText: 2010-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2012-2013 Stefan Gerlach <stefan.gerlach@uni-konstanz.de>
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "WorksheetDock.h"
 #include "kdefrontend/GuiTools.h"
@@ -34,8 +16,6 @@
 
 #include <QCompleter>
 #include <QDirModel>
-#include <QFileDialog>
-#include <QImageReader>
 #include <QPageSize>
 
 #include <KConfig>
@@ -51,7 +31,8 @@
 WorksheetDock::WorksheetDock(QWidget *parent): BaseDock(parent) {
 	ui.setupUi(this);
 	m_leName = ui.leName;
-	m_leComment = ui.leComment;
+	m_teComment = ui.teComment;
+	m_teComment->setFixedHeight(m_leName->height());
 
 	//Background-tab
 	ui.cbBackgroundColorStyle->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
@@ -63,8 +44,8 @@ WorksheetDock::WorksheetDock(QWidget *parent): BaseDock(parent) {
 	ui.chScaleContent->setToolTip(i18n("If checked, rescale the content of the worksheet on size changes. Otherwise resize the canvas only."));
 
 	ui.cbLayout->addItem(QIcon::fromTheme("labplot-editbreaklayout"), i18n("No Layout"));
-	ui.cbLayout->addItem(QIcon::fromTheme("labplot-editvlayout"), i18n("Vertical Layout"));
-	ui.cbLayout->addItem(QIcon::fromTheme("labplot-edithlayout"), i18n("Horizontal Layout"));
+	ui.cbLayout->addItem(QIcon::fromTheme("labplot-edithlayout"), i18n("Vertical Layout"));
+	ui.cbLayout->addItem(QIcon::fromTheme("labplot-editvlayout"), i18n("Horizontal Layout"));
 	ui.cbLayout->addItem(QIcon::fromTheme("labplot-editgrid"), i18n("Grid Layout"));
 
 	//adjust layouts in the tabs
@@ -83,15 +64,12 @@ WorksheetDock::WorksheetDock(QWidget *parent): BaseDock(parent) {
 	//SLOTs
 	//General
 	connect(ui.leName, &QLineEdit::textChanged, this, &WorksheetDock::nameChanged);
-	connect(ui.leComment, &QLineEdit::textChanged, this, &WorksheetDock::commentChanged);
-	connect(ui.cbSize, QOverload<int>::of(&QComboBox::currentIndexChanged),
-			 this, static_cast<void (WorksheetDock::*)(int)>(&WorksheetDock::sizeChanged));
-	connect(ui.sbWidth, static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged),
-			this, static_cast<void (WorksheetDock::*)()>(&WorksheetDock::sizeChanged));
-	connect(ui.sbHeight, static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged),
-			 this, static_cast<void (WorksheetDock::*)()>(&WorksheetDock::sizeChanged));
-	connect(ui.cbOrientation, QOverload<int>::of(&QComboBox::currentIndexChanged),
-			 this, &WorksheetDock::orientationChanged);
+	connect(ui.teComment, &QTextEdit::textChanged, this, &WorksheetDock::commentChanged);
+	connect(ui.cbSizeType, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &WorksheetDock::sizeTypeChanged);
+	connect(ui.cbPage, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &WorksheetDock::pageChanged);
+	connect(ui.sbWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &WorksheetDock::sizeChanged);
+	connect(ui.sbHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &WorksheetDock::sizeChanged);
+	connect(ui.cbOrientation, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &WorksheetDock::orientationChanged);
 
 	//Background
 	connect(ui.cbBackgroundType, QOverload<int>::of(&QComboBox::currentIndexChanged),
@@ -107,28 +85,28 @@ WorksheetDock::WorksheetDock(QWidget *parent): BaseDock(parent) {
 	connect(ui.leBackgroundFileName, &QLineEdit::textChanged, this, &WorksheetDock::fileNameChanged);
 	connect(ui.kcbBackgroundFirstColor, &KColorButton::changed, this, &WorksheetDock::backgroundFirstColorChanged);
 	connect(ui.kcbBackgroundSecondColor, &KColorButton::changed, this, &WorksheetDock::backgroundSecondColorChanged);
-	connect(ui.sbBackgroundOpacity, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged),
+	connect(ui.sbBackgroundOpacity, QOverload<int>::of(&QSpinBox::valueChanged),
 			this, &WorksheetDock::backgroundOpacityChanged);
 
 	//Layout
 	connect(ui.cbLayout, QOverload<int>::of(&QComboBox::currentIndexChanged),
 			 this, &WorksheetDock::layoutChanged);
 	connect( ui.chScaleContent, &QCheckBox::clicked, this, &WorksheetDock::scaleContentChanged);
-	connect( ui.sbLayoutTopMargin, static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged),
+	connect( ui.sbLayoutTopMargin, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
 			 this, &WorksheetDock::layoutTopMarginChanged);
-	connect( ui.sbLayoutBottomMargin, static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged),
+	connect( ui.sbLayoutBottomMargin, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
 			 this, &WorksheetDock::layoutBottomMarginChanged);
-	connect( ui.sbLayoutLeftMargin, static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged),
+	connect( ui.sbLayoutLeftMargin, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
 			 this, &WorksheetDock::layoutLeftMarginChanged);
-	connect( ui.sbLayoutRightMargin, static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged),
+	connect( ui.sbLayoutRightMargin, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
 			 this, &WorksheetDock::layoutRightMarginChanged);
-	connect( ui.sbLayoutHorizontalSpacing, static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged),
+	connect( ui.sbLayoutHorizontalSpacing, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
 			 this, &WorksheetDock::layoutHorizontalSpacingChanged);
-	connect( ui.sbLayoutVerticalSpacing, static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged),
+	connect( ui.sbLayoutVerticalSpacing, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
 			 this, &WorksheetDock::layoutVerticalSpacingChanged);
-	connect( ui.sbLayoutRowCount, static_cast<void (QSpinBox::*) (int)>(&QSpinBox::valueChanged),
+	connect( ui.sbLayoutRowCount, QOverload<int>::of(&QSpinBox::valueChanged),
 			 this, &WorksheetDock::layoutRowCountChanged);
-	connect( ui.sbLayoutColumnCount, static_cast<void (QSpinBox::*) (int)>(&QSpinBox::valueChanged),
+	connect( ui.sbLayoutColumnCount, QOverload<int>::of(&QSpinBox::valueChanged),
 			 this, &WorksheetDock::layoutColumnCountChanged);
 
 	//theme and template handlers
@@ -163,18 +141,18 @@ void WorksheetDock::setWorksheets(QList<Worksheet*> list) {
 		ui.lName->setEnabled(true);
 		ui.leName->setEnabled(true);
 		ui.lComment->setEnabled(true);
-		ui.leComment->setEnabled(true);
+		ui.teComment->setEnabled(true);
 
 		ui.leName->setText(m_worksheet->name());
-		ui.leComment->setText(m_worksheet->comment());
+		ui.teComment->setText(m_worksheet->comment());
 	} else {
 		ui.lName->setEnabled(false);
 		ui.leName->setEnabled(false);
 		ui.lComment->setEnabled(false);
-		ui.leComment->setEnabled(false);
+		ui.teComment->setEnabled(false);
 
 		ui.leName->setText(QString());
-		ui.leComment->setText(QString());
+		ui.teComment->setText(QString());
 	}
 	ui.leName->setStyleSheet("");
 	ui.leName->setToolTip("");
@@ -188,6 +166,7 @@ void WorksheetDock::setWorksheets(QList<Worksheet*> list) {
 	connect(m_worksheet, &Worksheet::aspectDescriptionChanged, this, &WorksheetDock::worksheetDescriptionChanged);
 	connect(m_worksheet, &Worksheet::pageRectChanged, this, &WorksheetDock::worksheetPageRectChanged);
 	connect(m_worksheet, &Worksheet::scaleContentChanged, this, &WorksheetDock::worksheetScaleContentChanged);
+	connect(m_worksheet, &Worksheet::useViewSizeChanged, this, &WorksheetDock::worksheetUseViewSizeChanged);
 
 	connect(m_worksheet, &Worksheet::backgroundTypeChanged, this, &WorksheetDock::worksheetBackgroundTypeChanged);
 	connect(m_worksheet, &Worksheet::backgroundColorStyleChanged, this, &WorksheetDock::worksheetBackgroundColorStyleChanged);
@@ -276,7 +255,7 @@ void WorksheetDock::updateUnits() {
 */
 void WorksheetDock::updatePaperSize() {
 	if (m_worksheet->useViewSize()) {
-		ui.cbSize->setCurrentIndex(0);
+		ui.cbSizeType->setCurrentIndex(0);
 		return;
 	}
 
@@ -293,8 +272,8 @@ void WorksheetDock::updatePaperSize() {
 
 	//determine the position of the QPageSize::PageSizeId in the combobox
 	bool found = false;
-	for (int i = 0; i < ui.cbSize->count(); ++i) {
-		const QVariant v = ui.cbSize->itemData(i);
+	for (int i = 0; i < ui.cbPage->count(); ++i) {
+		const QVariant v = ui.cbPage->itemData(i);
 		if (!v.isValid())
 			continue;
 
@@ -302,12 +281,12 @@ void WorksheetDock::updatePaperSize() {
 		QPageSize::Unit pageUnit = (m_units == Units::Metric) ? QPageSize::Millimeter : QPageSize::Inch;
 		const QSizeF ps = QPageSize::size(id, pageUnit);
 		if (s == ps) { //check the portrait-orientation first
-			ui.cbSize->setCurrentIndex(i);
+			ui.cbPage->setCurrentIndex(i);
 			ui.cbOrientation->setCurrentIndex(0);  //a QPageSize::PaperSize in portrait-orientation was found
 			found = true;
 			break;
 		} else if (st == ps) { //check for the landscape-orientation
-			ui.cbSize->setCurrentIndex(i);
+			ui.cbPage->setCurrentIndex(i);
 			ui.cbOrientation->setCurrentIndex(1); //a QPageSize::PaperSize in landscape-orientation was found
 			found = true;
 			break;
@@ -315,7 +294,7 @@ void WorksheetDock::updatePaperSize() {
 	}
 
 	if (!found)
-		ui.cbSize->setCurrentIndex(ui.cbSize->count() - 1); //select "Custom" size
+		ui.cbSizeType->setCurrentIndex(2); //select "Custom"
 }
 
 //*************************************************************
@@ -344,6 +323,11 @@ void WorksheetDock::retranslateUi() {
 	ui.sbLayoutHorizontalSpacing->setSuffix(suffix);
 	ui.sbLayoutVerticalSpacing->setSuffix(suffix);
 
+	ui.cbSizeType->clear();
+	ui.cbSizeType->addItem(i18n("View Size"));
+	ui.cbSizeType->addItem(i18n("Standard Page"));
+	ui.cbSizeType->addItem(i18n("Custom"));
+
 	const QVector<QPageSize::PageSizeId> pageSizeIds = {
 		QPageSize::A0,
 		QPageSize::A1,
@@ -374,14 +358,11 @@ void WorksheetDock::retranslateUi() {
 		QPageSize::Legal,
 		QPageSize::Letter,
 		QPageSize::Tabloid,
-		QPageSize::Comm10E,
-		QPageSize::Custom,
+		QPageSize::Comm10E
 	};
-	ui.cbSize->clear();
-	ui.cbSize->addItem(i18n("View Size"));
+	ui.cbPage->clear();
 	for (auto id : pageSizeIds)
-		ui.cbSize->addItem(QPageSize::name(id), id);
-	ui.cbSize->insertSeparator(1);
+		ui.cbPage->addItem(QPageSize::name(id), id);
 
 	//Background
 	ui.cbBackgroundType->clear();
@@ -416,60 +397,74 @@ void WorksheetDock::scaleContentChanged(bool scaled) {
 		worksheet->setScaleContent(scaled);
 }
 
-void WorksheetDock::sizeChanged(int i) {
-	const auto index = ui.cbSize->itemData(i).value<QPageSize::PageSizeId>();
-
-	if (index == QPageSize::Custom) {
-		ui.sbWidth->setEnabled(true);
-		ui.sbHeight->setEnabled(true);
+void WorksheetDock::sizeTypeChanged(int index) {
+	if (index == 0) { //view size
+		ui.lPage->hide();
+		ui.cbPage->hide();
 		ui.lOrientation->hide();
 		ui.cbOrientation->hide();
-	} else {
 		ui.sbWidth->setEnabled(false);
 		ui.sbHeight->setEnabled(false);
-		if (i == 0) { //no orientation available when using the complete view size (first item in the combox is selected)
-			ui.lOrientation->hide();
-			ui.cbOrientation->hide();
-		} else {
-			ui.lOrientation->show();
-			ui.cbOrientation->show();
-		}
+	} else if (index == 1) { //standard page
+		ui.lPage->show();
+		ui.cbPage->show();
+		ui.lOrientation->show();
+		ui.cbOrientation->show();
+		ui.sbWidth->setEnabled(false);
+		ui.sbHeight->setEnabled(false);
+	} else { //custom size
+		ui.lPage->hide();
+		ui.cbPage->hide();
+		ui.lOrientation->hide();
+		ui.cbOrientation->hide();
+		ui.sbWidth->setEnabled(true);
+		ui.sbHeight->setEnabled(true);
 	}
 
 	if (m_initializing)
 		return;
 
-	Lock lock(m_initializing);
-	if (i == 0) {
-		//use the complete view size (first item in the combox is selected)
+	if (index == 0) { //viewSize
+		Lock lock(m_initializing);
 		for (auto* worksheet : m_worksheetList)
 			worksheet->setUseViewSize(true);
-	} else if (index == QPageSize::Custom) {
+	} else if (index == 1) { //standard page
+		pageChanged(ui.cbPage->currentIndex());
+	} else { //custom size
 		if (m_worksheet->useViewSize()) {
 			for (auto* worksheet : m_worksheetList)
 				worksheet->setUseViewSize(false);
 		}
+		sizeChanged();
+	}
+}
+
+void WorksheetDock::pageChanged(int i) {
+	if (m_initializing)
+		return;
+
+	Lock lock(m_initializing);
+
+	//determine the width and the height of the to be used predefined layout
+	const auto index = ui.cbPage->itemData(i).value<QPageSize::PageSizeId>();
+	QSizeF s = QPageSize::size(index, QPageSize::Millimeter);
+	if (ui.cbOrientation->currentIndex() == 1)
+		s.transpose();
+
+	//s is in mm, in UI we show everything in cm/in
+	if (m_units == Units::Metric) {
+		ui.sbWidth->setValue(s.width()/10);
+		ui.sbHeight->setValue(s.height()/10);
 	} else {
-		//determine the width and the height of the to be used predefined layout
-		QSizeF s = QPageSize::size(index, QPageSize::Millimeter);
-		if (ui.cbOrientation->currentIndex() == 1)
-			s.transpose();
+		ui.sbWidth->setValue(s.width()/25.4);
+		ui.sbHeight->setValue(s.height()/25.4);
+	}
 
-		//s is in mm, in UI we show everything in cm/in
-		if (m_units == Units::Metric) {
-			ui.sbWidth->setValue(s.width()/10);
-			ui.sbHeight->setValue(s.height()/10);
-		} else {
-			ui.sbWidth->setValue(s.width()/25.4);
-			ui.sbHeight->setValue(s.height()/25.4);
-		}
-
-		float w = Worksheet::convertToSceneUnits(s.width(), Worksheet::Unit::Millimeter);
-		float h = Worksheet::convertToSceneUnits(s.height(), Worksheet::Unit::Millimeter);
-		for (auto* worksheet : m_worksheetList) {
-			worksheet->setUseViewSize(false);
-			worksheet->setPageRect(QRect(0,0,w,h));
-		}
+	double w = Worksheet::convertToSceneUnits(s.width(), Worksheet::Unit::Millimeter);
+	double h = Worksheet::convertToSceneUnits(s.height(), Worksheet::Unit::Millimeter);
+	for (auto* worksheet : m_worksheetList) {
+		worksheet->setUseViewSize(false);
+		worksheet->setPageRect(QRectF(0,0,w,h));
 	}
 }
 
@@ -477,18 +472,17 @@ void WorksheetDock::sizeChanged() {
 	if (m_initializing)
 		return;
 
-	int w = Worksheet::convertToSceneUnits(ui.sbWidth->value(), m_worksheetUnit);
-	int h = Worksheet::convertToSceneUnits(ui.sbHeight->value(), m_worksheetUnit);
+	double w = Worksheet::convertToSceneUnits(ui.sbWidth->value(), m_worksheetUnit);
+	double h = Worksheet::convertToSceneUnits(ui.sbHeight->value(), m_worksheetUnit);
 	for (auto* worksheet : m_worksheetList)
-		worksheet->setPageRect(QRect(0,0,w,h));
+		worksheet->setPageRect(QRectF(0,0,w,h));
 }
 
-void WorksheetDock::orientationChanged(int index) {
-	Q_UNUSED(index);
+void WorksheetDock::orientationChanged(int /*index*/) {
 	if (m_initializing)
 		return;
 
-	this->sizeChanged(ui.cbSize->currentIndex());
+	this->pageChanged(ui.cbPage->currentIndex());
 }
 
 // "Background"-tab
@@ -496,9 +490,9 @@ void WorksheetDock::backgroundTypeChanged(int index) {
 	if (index == -1)
 		return;
 
-	auto type = (PlotArea::BackgroundType)index;
+	auto type = (WorksheetElement::BackgroundType)index;
 
-	if (type == PlotArea::BackgroundType::Color) {
+	if (type == WorksheetElement::BackgroundType::Color) {
 		ui.lBackgroundColorStyle->show();
 		ui.cbBackgroundColorStyle->show();
 		ui.lBackgroundImageStyle->hide();
@@ -513,8 +507,8 @@ void WorksheetDock::backgroundTypeChanged(int index) {
 		ui.lBackgroundFirstColor->show();
 		ui.kcbBackgroundFirstColor->show();
 
-		auto style = (PlotArea::BackgroundColorStyle)ui.cbBackgroundColorStyle->currentIndex();
-		if (style == PlotArea::BackgroundColorStyle::SingleColor) {
+		auto style = (WorksheetElement::BackgroundColorStyle)ui.cbBackgroundColorStyle->currentIndex();
+		if (style == WorksheetElement::BackgroundColorStyle::SingleColor) {
 			ui.lBackgroundFirstColor->setText(i18n("Color:"));
 			ui.lBackgroundSecondColor->hide();
 			ui.kcbBackgroundSecondColor->hide();
@@ -523,7 +517,7 @@ void WorksheetDock::backgroundTypeChanged(int index) {
 			ui.lBackgroundSecondColor->show();
 			ui.kcbBackgroundSecondColor->show();
 		}
-	} else if (type == PlotArea::BackgroundType::Image) {
+	} else if (type == WorksheetElement::BackgroundType::Image) {
 		ui.lBackgroundFirstColor->hide();
 		ui.kcbBackgroundFirstColor->hide();
 		ui.lBackgroundSecondColor->hide();
@@ -538,7 +532,7 @@ void WorksheetDock::backgroundTypeChanged(int index) {
 		ui.lBackgroundFileName->show();
 		ui.leBackgroundFileName->show();
 		ui.bOpen->show();
-	} else if (type == PlotArea::BackgroundType::Pattern) {
+	} else if (type == WorksheetElement::BackgroundType::Pattern) {
 		ui.lBackgroundFirstColor->setText(i18n("Color:"));
 		ui.lBackgroundFirstColor->show();
 		ui.kcbBackgroundFirstColor->show();
@@ -567,9 +561,9 @@ void WorksheetDock::backgroundColorStyleChanged(int index) {
 	if (index == -1)
 		return;
 
-	auto style = (PlotArea::BackgroundColorStyle)index;
+	auto style = (WorksheetElement::BackgroundColorStyle)index;
 
-	if (style == PlotArea::BackgroundColorStyle::SingleColor) {
+	if (style == WorksheetElement::BackgroundColorStyle::SingleColor) {
 		ui.lBackgroundFirstColor->setText(i18n("Color:"));
 		ui.lBackgroundSecondColor->hide();
 		ui.kcbBackgroundSecondColor->hide();
@@ -596,7 +590,7 @@ void WorksheetDock::backgroundImageStyleChanged(int index) {
 	if (m_initializing)
 		return;
 
-	auto style = (PlotArea::BackgroundImageStyle)index;
+	auto style = (WorksheetElement::BackgroundImageStyle)index;
 	for (auto* worksheet : m_worksheetList)
 		worksheet->setBackgroundImageStyle(style);
 }
@@ -745,32 +739,11 @@ void WorksheetDock::layoutColumnCountChanged(int count) {
 	opens a file dialog and lets the user select the image file.
 */
 void WorksheetDock::selectFile() {
-	KConfigGroup conf(KSharedConfig::openConfig(), "WorksheetDock");
-	QString dir = conf.readEntry("LastImageDir", "");
-
-	QString formats;
-	for (const QByteArray& format : QImageReader::supportedImageFormats()) {
-		QString f = "*." + QString(format.constData());
-		if (f == QLatin1String("*.svg"))
-			continue;
-		formats.isEmpty() ? formats += f : formats += ' ' + f;
-	}
-
-	QString path = QFileDialog::getOpenFileName(this, i18n("Select the image file"), dir, i18n("Images (%1)", formats));
+	const QString& path = GuiTools::openImageFile(QLatin1String("WorksheetDock"));
 	if (path.isEmpty())
-		return; //cancel was clicked in the file-dialog
+		return;
 
-	int pos = path.lastIndexOf(QLatin1String("/"));
-	if (pos != -1) {
-		QString newDir = path.left(pos);
-		if (newDir != dir)
-			conf.writeEntry("LastImageDir", newDir);
-	}
-
-	ui.leBackgroundFileName->setText( path );
-
-	for (auto* worksheet : m_worksheetList)
-		worksheet->setBackgroundFileName(path);
+	ui.leBackgroundFileName->setText(path);
 }
 
 void WorksheetDock::fileNameChanged() {
@@ -795,8 +768,8 @@ void WorksheetDock::worksheetDescriptionChanged(const AbstractAspect* aspect) {
 	m_initializing = true;
 	if (aspect->name() != ui.leName->text())
 		ui.leName->setText(aspect->name());
-	else if (aspect->comment() != ui.leComment->text())
-		ui.leComment->setText(aspect->comment());
+	else if (aspect->comment() != ui.teComment->text())
+		ui.teComment->setText(aspect->comment());
 	m_initializing = false;
 }
 
@@ -805,7 +778,14 @@ void WorksheetDock::worksheetScaleContentChanged(bool scaled) {
 	ui.chScaleContent->setChecked(scaled);
 	m_initializing = false;
 }
-
+void WorksheetDock::worksheetUseViewSizeChanged(bool useViewSize) {
+	m_initializing = true;
+	if (useViewSize)
+		ui.cbSizeType->setCurrentIndex(0);
+	else
+		updatePaperSize();
+	m_initializing = false;
+}
 void WorksheetDock::worksheetPageRectChanged(const QRectF& rect) {
 	m_initializing = true;
 	ui.sbWidth->setValue(Worksheet::convertFromSceneUnits(rect.width(), m_worksheetUnit));
@@ -814,19 +794,19 @@ void WorksheetDock::worksheetPageRectChanged(const QRectF& rect) {
 	m_initializing = false;
 }
 
-void WorksheetDock::worksheetBackgroundTypeChanged(PlotArea::BackgroundType type) {
+void WorksheetDock::worksheetBackgroundTypeChanged(WorksheetElement::BackgroundType type) {
 	m_initializing = true;
 	ui.cbBackgroundType->setCurrentIndex(static_cast<int>(type));
 	m_initializing = false;
 }
 
-void WorksheetDock::worksheetBackgroundColorStyleChanged(PlotArea::BackgroundColorStyle style) {
+void WorksheetDock::worksheetBackgroundColorStyleChanged(WorksheetElement::BackgroundColorStyle style) {
 	m_initializing = true;
 	ui.cbBackgroundColorStyle->setCurrentIndex(static_cast<int>(style));
 	m_initializing = false;
 }
 
-void WorksheetDock::worksheetBackgroundImageStyleChanged(PlotArea::BackgroundImageStyle style) {
+void WorksheetDock::worksheetBackgroundImageStyleChanged(WorksheetElement::BackgroundImageStyle style) {
 	m_initializing = true;
 	ui.cbBackgroundImageStyle->setCurrentIndex(static_cast<int>(style));
 	m_initializing = false;
@@ -981,7 +961,7 @@ void WorksheetDock::loadConfig(KConfig& config) {
 	ui.sbWidth->setValue(Worksheet::convertFromSceneUnits(group.readEntry("Width", m_worksheet->pageRect().width()), m_worksheetUnit));
 	ui.sbHeight->setValue(Worksheet::convertFromSceneUnits(group.readEntry("Height", m_worksheet->pageRect().height()), m_worksheetUnit));
 	if (group.readEntry("UseViewSize", false))
-		ui.cbSize->setCurrentIndex(0);
+		ui.cbSizeType->setCurrentIndex(0);
 	else
 		updatePaperSize();
 
@@ -1013,7 +993,7 @@ void WorksheetDock::saveConfigAsTemplate(KConfig& config) {
 
 	//General
 	group.writeEntry("ScaleContent",ui.chScaleContent->isChecked());
-	group.writeEntry("UseViewSize",ui.cbSize->currentIndex() == 0);
+	group.writeEntry("UseViewSize", ui.cbSizeType->currentIndex() == 0);
 	group.writeEntry("Width",Worksheet::convertToSceneUnits(ui.sbWidth->value(), m_worksheetUnit));
 	group.writeEntry("Height",Worksheet::convertToSceneUnits(ui.sbHeight->value(), m_worksheetUnit));
 
