@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File             : XYDataReductionCurveDock.h
     Project          : LabPlot
-    --------------------------------------------------------------------
-    Copyright        : (C) 2016 Stefan Gerlach (stefan.gerlach@uni.kn)
-    Copyright        : (C) 2017 Alexander Semke (alexander.semke@web.de)
     Description      : widget for editing properties of data reduction curves
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2016-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef XYDATAREDUCTIONCURVEDOCK_H
 #define XYDATAREDUCTIONCURVEDOCK_H
@@ -48,9 +30,10 @@ public:
 
 private:
 	void initGeneralTab() override;
-	void showDataReductionResult();
+	void updatePlotRanges() override;
 	void updateTolerance();
 	void updateTolerance2();
+	void showDataReductionResult();
 
 	Ui::XYDataReductionCurveDockGeneralTab uiGeneralTab;
 	QStatusBar* statusBar;	// main status bar to display progress
@@ -65,7 +48,7 @@ private:
 protected:
 	void setModel() override;
 
-private slots:
+private Q_SLOTS:
 	//SLOTs for changes triggered in XYDataReductionCurveDock
 	//general tab
 	void dataSourceTypeChanged(int);
@@ -73,8 +56,8 @@ private slots:
 	void xDataColumnChanged(const QModelIndex&);
 	void yDataColumnChanged(const QModelIndex&);
 	void autoRangeChanged();
-	void xRangeMinChanged(double);
-	void xRangeMaxChanged(double);
+	void xRangeMinChanged();
+	void xRangeMaxChanged();
 	void xRangeMinDateTimeChanged(const QDateTime&);
 	void xRangeMaxDateTimeChanged(const QDateTime&);
 	void typeChanged(int);
@@ -88,7 +71,6 @@ private slots:
 
 	//SLOTs for changes triggered in XYCurve
 	//General-Tab
-	void curveDescriptionChanged(const AbstractAspect*);
 	void curveDataSourceTypeChanged(XYAnalysisCurve::DataSourceType);
 	void curveDataSourceCurveChanged(const XYCurve*);
 	void curveXDataColumnChanged(const AbstractColumn*);
