@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File             : XYFitCurveDock.cpp
     Project          : LabPlot
-    --------------------------------------------------------------------
-    Copyright        : (C) 2014-2020 Alexander Semke (alexander.semke@web.de)
-    Copyright        : (C) 2016-2020 Stefan Gerlach (stefan.gerlach@uni.kn)
     Description      : widget for editing properties of fit curves
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2014-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2016-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "XYFitCurveDock.h"
 #include "backend/core/AspectTreeModel.h"
@@ -33,12 +15,18 @@
 #include "backend/lib/macros.h"
 #include "backend/gsl/ExpressionParser.h"
 #include "backend/worksheet/plots/cartesian/CartesianPlot.h"
+#include "backend/worksheet/plots/cartesian/Histogram.h"
 #include "commonfrontend/widgets/TreeViewComboBox.h"
+#include "kdefrontend/GuiTools.h"
 #include "kdefrontend/widgets/ConstantsWidget.h"
 #include "kdefrontend/widgets/FunctionsWidget.h"
 #include "kdefrontend/widgets/FitOptionsWidget.h"
 #include "kdefrontend/widgets/FitParametersWidget.h"
 
+extern "C" {
+#include "backend/nsl/nsl_sf_stats.h"
+}
+
 #include <KMessageWidget>
 
 #include <QMenu>
@@ -46,10 +34,11 @@
 #include <QStandardItemModel>
 #include <QStandardPaths>
 #include <QClipboard>
+#include <QDesktopWidget>
 
-extern "C" {
-#include "backend/nsl/nsl_sf_stats.h"
-}
+#ifdef HAVE_POPPLER
+#include <poppler-qt5.h>
+#endif
 
 /*!
   \class XYFitCurveDock
@@ -68,15 +57,19 @@ extern "C" {
 XYFitCurveDock::XYFitCurveDock(QWidget* parent) : XYCurveDock(parent) {
 }
 
+XYFitCurveDock::~XYFitCurveDock() {
+	delete m_dataSourceModel;
+}
+
 /*!
  * 	set up "General" tab
  */
 void XYFitCurveDock::setupGeneral() {
-	DEBUG("XYFitCurveDock::setupGeneral()");
-	QWidget* generalTab = new QWidget(ui.tabGeneral);
+	auto* generalTab = new QWidget(ui.tabGeneral);
 	uiGeneralTab.setupUi(generalTab);
 	m_leName = uiGeneralTab.leName;
-	m_leComment = uiGeneralTab.leComment;
+	m_teComment = uiGeneralTab.teComment;
+	m_teComment->setFixedHeight(1.2 * m_leName->height());
 
 	auto* gridLayout = static_cast<QGridLayout*>(generalTab->layout());
 	gridLayout->setContentsMargins(2, 2, 2, 2);
@@ -85,6 +78,7 @@ void XYFitCurveDock::setupGeneral() {
 
 	uiGeneralTab.cbDataSourceType->addItem(i18n("Spreadsheet"));
 	uiGeneralTab.cbDataSourceType->addItem(i18n("XY-Curve"));
+	uiGeneralTab.cbDataSourceType->addItem(i18n("Histogram"));
 
 	cbDataSourceCurve = new TreeViewComboBox(generalTab);
 	gridLayout->addWidget(cbDataSourceCurve, 5, 3, 1, 4);
@@ -153,7 +147,7 @@ void XYFitCurveDock::setupGeneral() {
 
 	//header labels
 	QStringList headerLabels;
-	headerLabels << QString() << i18n("Value") << i18n("Error") << i18n("Error, %") << i18n("t statistic") << QLatin1String("P > |t|")
+	headerLabels << QString() << i18n("Value") << i18n("Uncertainty") << i18n("Uncertainty, %") << i18n("t statistic") << QLatin1String("P > |t|")
 		<< i18n("Lower") << i18n("Upper");
 	uiGeneralTab.twParameters->setHorizontalHeaderLabels(headerLabels);
 
@@ -196,7 +190,7 @@ void XYFitCurveDock::setupGeneral() {
 
 	//Slots
 	connect(uiGeneralTab.leName, &QLineEdit::textChanged, this, &XYFitCurveDock::nameChanged);
-	connect(uiGeneralTab.leComment, &QLineEdit::textChanged, this, &XYFitCurveDock::commentChanged);
+	connect(uiGeneralTab.teComment, &QTextEdit::textChanged, this, &XYFitCurveDock::commentChanged);
 	connect(uiGeneralTab.chkVisible, &QCheckBox::clicked, this, &XYFitCurveDock::visibilityChanged);
 	connect(uiGeneralTab.cbDataSourceType, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &XYFitCurveDock::dataSourceTypeChanged);
 	connect(uiGeneralTab.lWeights, &QPushButton::clicked, this, &XYFitCurveDock::showWeightsOptions);
@@ -214,6 +208,7 @@ void XYFitCurveDock::setupGeneral() {
 	connect(uiGeneralTab.lFit, &QPushButton::clicked, this, &XYFitCurveDock::showFitOptions);
 	connect(uiGeneralTab.lParameters, &QPushButton::clicked, this, &XYFitCurveDock::showParameters);
 	connect(uiGeneralTab.lResults, &QPushButton::clicked, this, &XYFitCurveDock::showResults);
+	connect(uiGeneralTab.cbPlotRanges, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &XYFitCurveDock::plotRangeChanged );
 
 	connect(cbDataSourceCurve, &TreeViewComboBox::currentModelIndexChanged, this, &XYFitCurveDock::dataSourceCurveChanged);
 	connect(cbXDataColumn, &TreeViewComboBox::currentModelIndexChanged, this, &XYFitCurveDock::xDataColumnChanged);
@@ -231,33 +226,34 @@ void XYFitCurveDock::initGeneralTab() {
 		uiGeneralTab.lName->setEnabled(true);
 		uiGeneralTab.leName->setEnabled(true);
 		uiGeneralTab.lComment->setEnabled(true);
-		uiGeneralTab.leComment->setEnabled(true);
+		uiGeneralTab.teComment->setEnabled(true);
 
 		uiGeneralTab.leName->setText(m_curve->name());
-		uiGeneralTab.leComment->setText(m_curve->comment());
+		uiGeneralTab.teComment->setText(m_curve->comment());
 	} else {
 		uiGeneralTab.lName->setEnabled(false);
 		uiGeneralTab.leName->setEnabled(false);
 		uiGeneralTab.lComment->setEnabled(false);
-		uiGeneralTab.leComment->setEnabled(false);
+		uiGeneralTab.teComment->setEnabled(false);
 
 		uiGeneralTab.leName->setText(QString());
-		uiGeneralTab.leComment->setText(QString());
+		uiGeneralTab.teComment->setText(QString());
 	}
 
-	auto* fitCurve = static_cast<XYFitCurve*>(m_curve);
-	checkColumnAvailability(cbXDataColumn, fitCurve->xDataColumn(), fitCurve->xDataColumnPath());
-	checkColumnAvailability(cbYDataColumn, fitCurve->yDataColumn(), fitCurve->yDataColumnPath());
-	checkColumnAvailability(cbXErrorColumn, fitCurve->xErrorColumn(), fitCurve->xErrorColumnPath());
-	checkColumnAvailability(cbYErrorColumn, fitCurve->yErrorColumn(), fitCurve->yErrorColumnPath());
-
 	uiGeneralTab.cbDataSourceType->setCurrentIndex(static_cast<int>(m_fitCurve->dataSourceType()));
 	this->dataSourceTypeChanged(uiGeneralTab.cbDataSourceType->currentIndex());
-	XYCurveDock::setModelIndexFromAspect(cbDataSourceCurve, m_fitCurve->dataSourceCurve());
-	XYCurveDock::setModelIndexFromAspect(cbXDataColumn, m_fitCurve->xDataColumn());
-	XYCurveDock::setModelIndexFromAspect(cbYDataColumn, m_fitCurve->yDataColumn());
-	XYCurveDock::setModelIndexFromAspect(cbXErrorColumn, m_fitCurve->xErrorColumn());
-	XYCurveDock::setModelIndexFromAspect(cbYErrorColumn, m_fitCurve->yErrorColumn());
+
+	if (m_fitCurve->dataSourceType() == XYAnalysisCurve::DataSourceType::Curve)
+		cbDataSourceCurve->setAspect(m_fitCurve->dataSourceCurve());
+	else if (m_fitCurve->dataSourceType() == XYAnalysisCurve::DataSourceType::Histogram)
+		cbDataSourceCurve->setAspect(m_fitCurve->dataSourceHistogram());
+	else
+		cbDataSourceCurve->setAspect(nullptr);
+
+	cbXDataColumn->setColumn(m_fitCurve->xDataColumn(), m_fitCurve->xDataColumnPath());
+	cbYDataColumn->setColumn(m_fitCurve->yDataColumn(), m_fitCurve->yDataColumnPath());
+	cbXErrorColumn->setColumn(m_fitCurve->xErrorColumn(), m_fitCurve->xErrorColumnPath());
+	cbYErrorColumn->setColumn(m_fitCurve->yErrorColumn(), m_fitCurve->yErrorColumnPath());
 
 	int tmpModelType = m_fitData.modelType;	// save type because it's reset when category changes
 	if (m_fitData.modelCategory == nsl_fit_model_custom)
@@ -282,39 +278,41 @@ void XYFitCurveDock::initGeneralTab() {
 	uiGeneralTab.chkVisible->setChecked(m_curve->isVisible());
 
 	//Slots
-	connect(m_fitCurve, &XYFitCurve::aspectDescriptionChanged, this, &XYFitCurveDock::curveDescriptionChanged);
+	connect(m_fitCurve, &XYFitCurve::aspectDescriptionChanged, this, &XYFitCurveDock::aspectDescriptionChanged);
 	connect(m_fitCurve, &XYFitCurve::dataSourceTypeChanged, this, &XYFitCurveDock::curveDataSourceTypeChanged);
 	connect(m_fitCurve, &XYFitCurve::dataSourceCurveChanged, this, &XYFitCurveDock::curveDataSourceCurveChanged);
+	connect(m_fitCurve, &XYFitCurve::dataSourceHistogramChanged, this, &XYFitCurveDock::curveDataSourceHistogramChanged);
 	connect(m_fitCurve, &XYFitCurve::xDataColumnChanged, this, &XYFitCurveDock::curveXDataColumnChanged);
 	connect(m_fitCurve, &XYFitCurve::yDataColumnChanged, this, &XYFitCurveDock::curveYDataColumnChanged);
 	connect(m_fitCurve, &XYFitCurve::xErrorColumnChanged, this, &XYFitCurveDock::curveXErrorColumnChanged);
 	connect(m_fitCurve, &XYFitCurve::yErrorColumnChanged, this, &XYFitCurveDock::curveYErrorColumnChanged);
 	connect(m_fitCurve, &XYFitCurve::fitDataChanged, this, &XYFitCurveDock::curveFitDataChanged);
 	connect(m_fitCurve, &XYFitCurve::sourceDataChanged, this, &XYFitCurveDock::enableRecalculate);
-	connect(m_fitCurve, QOverload<bool>::of(&XYCurve::visibilityChanged), this, &XYFitCurveDock::curveVisibilityChanged);
+	connect(m_fitCurve, &WorksheetElement::plotRangeListChanged, this, &XYFitCurveDock::updatePlotRanges);
+	connect(m_fitCurve, &WorksheetElement::visibleChanged, this, &XYFitCurveDock::curveVisibilityChanged);
 
 	connect(fitParametersWidget, &FitParametersWidget::parametersChanged, this, &XYFitCurveDock::parametersChanged);
 	connect(fitParametersWidget, &FitParametersWidget::parametersValid, this, &XYFitCurveDock::parametersValid);
 }
 
 void XYFitCurveDock::setModel() {
-	QList<AspectType> list{AspectType::Folder, AspectType::Datapicker, AspectType::Worksheet,
-							AspectType::CartesianPlot, AspectType::XYCurve, AspectType::XYAnalysisCurve};
-	cbDataSourceCurve->setTopLevelClasses(list);
-
 	QList<const AbstractAspect*> hiddenAspects;
 	for (auto* curve : m_curvesList)
 		hiddenAspects << curve;
 	cbDataSourceCurve->setHiddenAspects(hiddenAspects);
 
-	list = {AspectType::Folder, AspectType::Workbook, AspectType::Spreadsheet, AspectType::LiveDataSource,
-	        AspectType::Column, AspectType::CantorWorksheet, AspectType::Datapicker};
+	QList<AspectType> list = {AspectType::Folder, AspectType::Workbook,
+								AspectType::Spreadsheet, AspectType::LiveDataSource,
+								AspectType::CantorWorksheet, AspectType::Datapicker,
+								AspectType::Column};
 	cbXDataColumn->setTopLevelClasses(list);
 	cbYDataColumn->setTopLevelClasses(list);
 	cbXErrorColumn->setTopLevelClasses(list);
 	cbYErrorColumn->setTopLevelClasses(list);
 
-	cbDataSourceCurve->setModel(m_aspectTreeModel);
+	list = {AspectType::Column};
+	m_aspectTreeModel->setSelectableAspects(list);
+
 	cbXDataColumn->setModel(m_aspectTreeModel);
 	cbYDataColumn->setModel(m_aspectTreeModel);
 	cbXErrorColumn->setModel(m_aspectTreeModel);
@@ -331,8 +329,14 @@ void XYFitCurveDock::setCurves(QList<XYCurve*> list) {
 	m_curvesList = list;
 	m_curve = list.first();
 	m_aspect = m_curve;
-	m_fitCurve = dynamic_cast<XYFitCurve*>(m_curve);
+	m_fitCurve = static_cast<XYFitCurve*>(m_curve);
 	m_aspectTreeModel = new AspectTreeModel(m_curve->project());
+
+	//we need a second model for data source comboboxe which will be dynamically
+	//updated in the slot depending on the current type (spreadsheet, curve or histogram)
+	//to allow to select the relevant aspects only
+	m_dataSourceModel = new AspectTreeModel(m_curve->project());
+
 	this->setModel();
 	m_fitData = m_fitCurve->fitData();
 
@@ -348,20 +352,26 @@ void XYFitCurveDock::setCurves(QList<XYCurve*> list) {
 
 	initGeneralTab();
 	initTabs();
+	setSymbols(list);
 
 	if (m_messageWidget && m_messageWidget->isVisible())
 		m_messageWidget->close();
 
 	showFitResult();
 	enableRecalculate();
-
 	m_initializing = false;
 
+	updatePlotRanges();
+
 	//init parameter list when not available
 	if (m_fitData.paramStartValues.size() == 0)
 		updateModelEquation();
 }
 
+void XYFitCurveDock	::updatePlotRanges() {
+	updatePlotRangeList(uiGeneralTab.cbPlotRanges);
+}
+
 bool XYFitCurveDock::eventFilter(QObject* obj, QEvent* event) {
 	if (event->type() == QEvent::KeyPress
 		&& (obj == uiGeneralTab.twParameters || obj == uiGeneralTab.twGoodness || obj == uiGeneralTab.twLog)) {
@@ -380,12 +390,27 @@ bool XYFitCurveDock::eventFilter(QObject* obj, QEvent* event) {
 void XYFitCurveDock::dataSourceTypeChanged(int index) {
 	const auto type = (XYAnalysisCurve::DataSourceType)index;
 	if (type == XYAnalysisCurve::DataSourceType::Spreadsheet) {
+		uiGeneralTab.cbCategory->setEnabled(true);
 		uiGeneralTab.lDataSourceCurve->hide();
 		cbDataSourceCurve->hide();
 		uiGeneralTab.lXColumn->show();
 		cbXDataColumn->show();
 		uiGeneralTab.lYColumn->show();
 		cbYDataColumn->show();
+
+		QList<AspectType> list{AspectType::Folder, AspectType::Workbook,
+							AspectType::Spreadsheet, AspectType::Datapicker};
+		cbDataSourceCurve->setTopLevelClasses(list);
+
+		//when the dock is initialized, this functions is called before setModel(),
+		//we need this nullptr check
+		if (m_dataSourceModel) {
+			list = {AspectType::Column};
+			m_dataSourceModel->setSelectableAspects(list);
+
+			//TODO: why do we need to reset the model here and below again to get the combobox updated?
+			cbDataSourceCurve->setModel(m_dataSourceModel);
+		}
 	} else {
 		uiGeneralTab.lDataSourceCurve->show();
 		cbDataSourceCurve->show();
@@ -393,13 +418,45 @@ void XYFitCurveDock::dataSourceTypeChanged(int index) {
 		cbXDataColumn->hide();
 		uiGeneralTab.lYColumn->hide();
 		cbYDataColumn->hide();
+
+		if (type == XYAnalysisCurve::DataSourceType::Curve) {
+			uiGeneralTab.cbCategory->setEnabled(true);
+			uiGeneralTab.lDataSourceCurve->setText(i18n("Curve:"));
+
+			QList<AspectType> list{AspectType::Folder, AspectType::Datapicker,
+									AspectType::Worksheet, AspectType::CartesianPlot,
+									AspectType::XYCurve, AspectType::XYAnalysisCurve, AspectType::XYEquationCurve};
+			cbDataSourceCurve->setTopLevelClasses(list);
+
+			if (m_dataSourceModel) {
+				list = {AspectType::XYCurve, AspectType::XYAnalysisCurve, AspectType::XYEquationCurve};
+				m_dataSourceModel->setSelectableAspects(list);
+				cbDataSourceCurve->setModel(m_dataSourceModel);
+				cbDataSourceCurve->setAspect(m_fitCurve->dataSourceCurve());
+			}
+		} else {	// histogram
+			uiGeneralTab.cbCategory->setEnabled(false);
+			uiGeneralTab.cbCategory->setCurrentIndex(3); //select "statistics (distributions);
+			uiGeneralTab.lDataSourceCurve->setText(i18n("Histogram:"));
+
+			QList<AspectType> list{AspectType::Folder, AspectType::Worksheet,
+								AspectType::CartesianPlot, AspectType::Histogram};
+			cbDataSourceCurve->setTopLevelClasses(list);
+
+			if (m_dataSourceModel) {
+				list = {AspectType::Histogram};
+				m_dataSourceModel->setSelectableAspects(list);
+				cbDataSourceCurve->setModel(m_dataSourceModel);
+				cbDataSourceCurve->setAspect(m_fitCurve->dataSourceHistogram());
+			}
+		}
 	}
 
 	if (m_initializing)
 		return;
 
 	for (auto* curve : m_curvesList)
-		dynamic_cast<XYFitCurve*>(curve)->setDataSourceType(type);
+		static_cast<XYFitCurve*>(curve)->setDataSourceType(type);
 }
 
 void XYFitCurveDock::dataSourceCurveChanged(const QModelIndex& index) {
@@ -407,10 +464,17 @@ void XYFitCurveDock::dataSourceCurveChanged(const QModelIndex& index) {
 		return;
 
 	auto* aspect = static_cast<AbstractAspect*>(index.internalPointer());
-	auto* dataSourceCurve = dynamic_cast<XYCurve*>(aspect);
 
-	for (auto* curve : m_curvesList)
-		dynamic_cast<XYFitCurve*>(curve)->setDataSourceCurve(dataSourceCurve);
+	const auto type = (XYAnalysisCurve::DataSourceType)uiGeneralTab.cbDataSourceType->currentIndex();
+	if (type == XYAnalysisCurve::DataSourceType::Curve) {
+		auto* dataSourceCurve = static_cast<XYCurve*>(aspect);
+		for (auto* curve : m_curvesList)
+			static_cast<XYFitCurve*>(curve)->setDataSourceCurve(dataSourceCurve);
+	} else {
+		auto* dataSourceHist = static_cast<Histogram*>(aspect);
+		for (auto* curve : m_curvesList)
+			static_cast<XYFitCurve*>(curve)->setDataSourceHistogram(dataSourceHist);
+	}
 }
 
 void XYFitCurveDock::xDataColumnChanged(const QModelIndex& index) {
@@ -421,7 +485,7 @@ void XYFitCurveDock::xDataColumnChanged(const QModelIndex& index) {
 	auto* column = dynamic_cast<AbstractColumn*>(aspect);
 
 	for (auto* curve : m_curvesList)
-		dynamic_cast<XYFitCurve*>(curve)->setXDataColumn(column);
+		static_cast<XYFitCurve*>(curve)->setXDataColumn(column);
 
 	// set model dependent start values from new data
 	XYFitCurve::initStartValues(m_fitData, m_curve);
@@ -441,7 +505,7 @@ void XYFitCurveDock::yDataColumnChanged(const QModelIndex& index) {
 	auto* column = dynamic_cast<AbstractColumn*>(aspect);
 
 	for (auto* curve : m_curvesList)
-		dynamic_cast<XYFitCurve*>(curve)->setYDataColumn(column);
+		static_cast<XYFitCurve*>(curve)->setYDataColumn(column);
 
 	// set model dependent start values from new data
 	XYFitCurve::initStartValues(m_fitData, m_curve);
@@ -458,7 +522,7 @@ void XYFitCurveDock::xErrorColumnChanged(const QModelIndex& index) {
 	auto* column = dynamic_cast<AbstractColumn*>(aspect);
 
 	for (auto* curve : m_curvesList)
-		dynamic_cast<XYFitCurve*>(curve)->setXErrorColumn(column);
+		static_cast<XYFitCurve*>(curve)->setXErrorColumn(column);
 
 	cbXErrorColumn->useCurrentIndexText(true);
 	cbXErrorColumn->setInvalid(false);
@@ -472,7 +536,7 @@ void XYFitCurveDock::yErrorColumnChanged(const QModelIndex& index) {
 	auto* column = dynamic_cast<AbstractColumn*>(aspect);
 
 	for (auto* curve : m_curvesList)
-		dynamic_cast<XYFitCurve*>(curve)->setYErrorColumn(column);
+		static_cast<XYFitCurve*>(curve)->setYErrorColumn(column);
 
 	cbYErrorColumn->useCurrentIndexText(true);
 	cbYErrorColumn->setInvalid(false);
@@ -735,11 +799,11 @@ void XYFitCurveDock::modelTypeChanged(int index) {
 		xColumn = m_fitCurve->xDataColumn();
 	} else {
 		DEBUG("	data source: Curve")
-		if (m_fitCurve->dataSourceCurve() != nullptr)
+		if (m_fitCurve->dataSourceCurve())
 			xColumn = m_fitCurve->dataSourceCurve()->xColumn();
 	}
 	// with no xColumn: show all models (assume 100 data points)
-	const int availableRowCount = (xColumn != nullptr) ? xColumn->availableRowCount() : 100;
+	const int availableRowCount = xColumn ? xColumn->availableRowCount(100) : 100;
 	DEBUG("	available row count = " << availableRowCount)
 
 	bool disableFit = false;
@@ -840,7 +904,7 @@ void XYFitCurveDock::updateModelEquation() {
 		if ((nsl_fit_model_type_basic)m_fitData.modelType == nsl_fit_model_power && degree > 2)
 			numSuffix = '2';
 		file = QStandardPaths::locate(QStandardPaths::AppDataLocation, "pics/fit_models/"
-			+ QString(nsl_fit_model_basic_pic_name[m_fitData.modelType]) + numSuffix + ".png");
+			+ QString(nsl_fit_model_basic_pic_name[m_fitData.modelType]) + numSuffix + ".pdf");
 		break;
 	}
 	case nsl_fit_model_peak: {
@@ -849,16 +913,16 @@ void XYFitCurveDock::updateModelEquation() {
 		if (degree > 4)
 			numSuffix = '4';
 		file = QStandardPaths::locate(QStandardPaths::AppDataLocation, "pics/fit_models/"
-			+ QString(nsl_fit_model_peak_pic_name[m_fitData.modelType]) + numSuffix + ".png");
+			+ QString(nsl_fit_model_peak_pic_name[m_fitData.modelType]) + numSuffix + ".pdf");
 		break;
 	}
 	case nsl_fit_model_growth:
 		file = QStandardPaths::locate(QStandardPaths::AppDataLocation, "pics/fit_models/"
-			+ QString(nsl_fit_model_growth_pic_name[m_fitData.modelType]) + ".png");
+			+ QString(nsl_fit_model_growth_pic_name[m_fitData.modelType]) + ".pdf");
 		break;
 	case nsl_fit_model_distribution:
 		file = QStandardPaths::locate(QStandardPaths::AppDataLocation, "pics/gsl_distributions/"
-			+ QString(nsl_sf_stats_distribution_pic_name[m_fitData.modelType]) + ".png");
+			+ QString(nsl_sf_stats_distribution_pic_name[m_fitData.modelType]) + ".pdf");
 		// change label
 		if (m_fitData.modelType == nsl_sf_stats_poisson)
 			uiGeneralTab.lEquation->setText(QLatin1String("f(k)/A ="));
@@ -872,9 +936,15 @@ void XYFitCurveDock::updateModelEquation() {
 	}
 
 	if (m_fitData.modelCategory != nsl_fit_model_custom) {
-		DEBUG("Model pixmap path = " << STDSTRING(file));
-		uiGeneralTab.lFuncPic->setPixmap(file);
-		uiGeneralTab.lFuncPic->show();
+		QImage image = GuiTools::importPDFFile(file);
+
+		if (image.isNull()) {
+			uiGeneralTab.lEquation->hide();
+			uiGeneralTab.lFuncPic->hide();
+		} else {
+			uiGeneralTab.lFuncPic->setPixmap(QPixmap::fromImage(image));
+			uiGeneralTab.lFuncPic->show();
+		}
 		uiGeneralTab.teEquation->hide();
 	}
 
@@ -1001,33 +1071,30 @@ void XYFitCurveDock::insertConstant(const QString& constantsName) const {
 /*!
  * When a custom evaluate range is specified, set the plot range too.
  */
-void XYFitCurveDock::setPlotXRange() {
-	if (m_fitData.autoEvalRange || m_curve == nullptr)
+/*void XYFitCurveDock::setPlotXRange() {
+	if (m_fitData.autoEvalRange || !m_curve)
 		return;
 
 	auto* plot = dynamic_cast<CartesianPlot*>(m_curve->parentAspect());
-	if (plot != nullptr) {
-		const Range<double> range{ m_fitData.evalRange };
-		const double extend{ range.size() * 0.05 };	// + 5 %
-		if (!range.isZero()) {
-			plot->setXMin(range.min() - extend);
-			plot->setXMax(range.max() + extend);
-		}
+	if (plot) {
+		Range<double> range{ m_fitData.evalRange };
+		if (!range.isZero())
+			plot->setXRange(range);
 	}
-}
+}*/
 
 void XYFitCurveDock::recalculateClicked() {
-	DEBUG("XYFitCurveDock::recalculateClicked()");
+	DEBUG(Q_FUNC_INFO);
 	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 	m_fitData.degree = uiGeneralTab.sbDegree->value();
 	if (m_fitData.modelCategory == nsl_fit_model_custom)
 		updateParameterList();
 
 	for (XYCurve* curve: m_curvesList)
-		dynamic_cast<XYFitCurve*>(curve)->setFitData(m_fitData);
+		static_cast<XYFitCurve*>(curve)->setFitData(m_fitData);
 
 	m_fitCurve->recalculate();
-	setPlotXRange();
+	//setPlotXRange();
 
 	//update fitParametersWidget
 	if (m_fitData.useResults) {
@@ -1050,7 +1117,7 @@ void XYFitCurveDock::recalculateClicked() {
 	const XYFitCurve::FitResult& fitResult = m_fitCurve->fitResult();
 	const QString& status = fitResult.status;
 	if (status != i18n("Success")) {
-		emit info(i18n("Fit status: %1", fitResult.status));
+		Q_EMIT info(i18n("Fit status: %1", fitResult.status));
 		if (!m_messageWidget) {
 			m_messageWidget = new KMessageWidget(this);
 			uiGeneralTab.gridLayout_2->addWidget(m_messageWidget, 25, 3, 1, 4);
@@ -1068,11 +1135,11 @@ void XYFitCurveDock::recalculateClicked() {
 	}
 
 	QApplication::restoreOverrideCursor();
-	DEBUG("XYFitCurveDock::recalculateClicked() DONE");
+	DEBUG(Q_FUNC_INFO << " DONE");
 }
 
 void XYFitCurveDock::expressionChanged() {
-	DEBUG("XYFitCurveDock::expressionChanged()");
+	DEBUG(Q_FUNC_INFO);
 	if (m_initializing)
 		return;
 
@@ -1084,16 +1151,17 @@ void XYFitCurveDock::expressionChanged() {
 }
 
 void XYFitCurveDock::enableRecalculate() {
-	DEBUG("XYFitCurveDock::enableRecalculate()");
-	if (m_initializing || m_fitCurve == nullptr)
+	DEBUG(Q_FUNC_INFO);
+	if (m_initializing || !m_fitCurve)
 		return;
 
 	//no fitting possible without the x- and y-data
 	bool hasSourceData = false;
-	if (m_fitCurve->dataSourceType() == XYAnalysisCurve::DataSourceType::Spreadsheet) {
+	auto type = m_fitCurve->dataSourceType();
+	if (type == XYAnalysisCurve::DataSourceType::Spreadsheet) {
 		auto* aspectX = static_cast<AbstractAspect*>(cbXDataColumn->currentModelIndex().internalPointer());
 		auto* aspectY = static_cast<AbstractAspect*>(cbYDataColumn->currentModelIndex().internalPointer());
-		hasSourceData = (aspectX != nullptr && aspectY != nullptr);
+		hasSourceData = (aspectX && aspectY);
 		if (aspectX) {
 			cbXDataColumn->useCurrentIndexText(true);
 			cbXDataColumn->setInvalid(false);
@@ -1102,9 +1170,10 @@ void XYFitCurveDock::enableRecalculate() {
 			cbYDataColumn->useCurrentIndexText(true);
 			cbYDataColumn->setInvalid(false);
 		}
-	} else {
+	} else if (type == XYAnalysisCurve::DataSourceType::Curve)
 		hasSourceData = (m_fitCurve->dataSourceCurve() != nullptr);
-	}
+	else
+		hasSourceData = (m_fitCurve->dataSourceHistogram() != nullptr);
 
 	uiGeneralTab.pbRecalculate->setEnabled(hasSourceData && m_parametersValid);
 
@@ -1115,12 +1184,12 @@ void XYFitCurveDock::enableRecalculate() {
 		m_fitCurve->setFitData(m_fitData);
 		// calculate fit function
 		m_fitCurve->evaluate(true);
-		setPlotXRange();
+		//setPlotXRange();
 	}
 	else {
 		DEBUG("	PREVIEW DISABLED");
 	}
-	DEBUG("XYFitCurveDock::enableRecalculate() DONE");
+	DEBUG(Q_FUNC_INFO << " DONE");
 }
 
 void XYFitCurveDock::resultCopy(bool copyAll) {
@@ -1364,18 +1433,6 @@ void XYFitCurveDock::showFitResult() {
 //*********** SLOTs for changes triggered in XYCurve **********
 //*************************************************************
 //General-Tab
-void XYFitCurveDock::curveDescriptionChanged(const AbstractAspect* aspect) {
-	if (m_curve != aspect)
-		return;
-
-	m_initializing = true;
-	if (aspect->name() != uiGeneralTab.leName->text())
-		uiGeneralTab.leName->setText(aspect->name());
-	else if (aspect->comment() != uiGeneralTab.leComment->text())
-		uiGeneralTab.leComment->setText(aspect->comment());
-	m_initializing = false;
-}
-
 void XYFitCurveDock::curveDataSourceTypeChanged(XYAnalysisCurve::DataSourceType type) {
 	m_initializing = true;
 	uiGeneralTab.cbDataSourceType->setCurrentIndex(static_cast<int>(type));
@@ -1384,31 +1441,37 @@ void XYFitCurveDock::curveDataSourceTypeChanged(XYAnalysisCurve::DataSourceType
 
 void XYFitCurveDock::curveDataSourceCurveChanged(const XYCurve* curve) {
 	m_initializing = true;
-	XYCurveDock::setModelIndexFromAspect(cbDataSourceCurve, curve);
+	cbDataSourceCurve->setAspect(curve);
+	m_initializing = false;
+}
+
+void XYFitCurveDock::curveDataSourceHistogramChanged(const Histogram* hist) {
+	m_initializing = true;
+	cbDataSourceCurve->setAspect(hist);
 	m_initializing = false;
 }
 
 void XYFitCurveDock::curveXDataColumnChanged(const AbstractColumn* column) {
 	m_initializing = true;
-	XYCurveDock::setModelIndexFromAspect(cbXDataColumn, column);
+	cbXDataColumn->setColumn(column, m_fitCurve->xDataColumnPath());
 	m_initializing = false;
 }
 
 void XYFitCurveDock::curveYDataColumnChanged(const AbstractColumn* column) {
 	m_initializing = true;
-	XYCurveDock::setModelIndexFromAspect(cbYDataColumn, column);
+	cbYDataColumn->setColumn(column, m_fitCurve->yDataColumnPath());
 	m_initializing = false;
 }
 
 void XYFitCurveDock::curveXErrorColumnChanged(const AbstractColumn* column) {
 	m_initializing = true;
-	XYCurveDock::setModelIndexFromAspect(cbXErrorColumn, column);
+	cbXErrorColumn->setColumn(column, m_fitCurve->xErrorColumnPath());
 	m_initializing = false;
 }
 
 void XYFitCurveDock::curveYErrorColumnChanged(const AbstractColumn* column) {
 	m_initializing = true;
-	XYCurveDock::setModelIndexFromAspect(cbYErrorColumn, column);
+	cbYErrorColumn->setColumn(column, m_fitCurve->yErrorColumnPath());
 	m_initializing = false;
 }
 
