@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File             : XYFitCurveDock.h
     Project          : LabPlot
-    --------------------------------------------------------------------
-    Copyright        : (C) 2014 Alexander Semke (alexander.semke@web.de)
-    Copyright        : (C) 2017-2018 Stefan Gerlach (stefan.gerlach@uni.kn)
     Description      : widget for editing properties of equation curves
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2014-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2017-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef XYFITCURVEDOCK_H
 #define XYFITCURVEDOCK_H
@@ -34,6 +16,7 @@
 #include "backend/worksheet/plots/cartesian/XYFitCurve.h"
 #include "ui_xyfitcurvedockgeneraltab.h"
 
+class AspectTreeModel;
 class TreeViewComboBox;
 class FitParametersWidget;
 class KMessageWidget;
@@ -43,13 +26,16 @@ class XYFitCurveDock: public XYCurveDock {
 
 public:
 	explicit XYFitCurveDock(QWidget* parent);
+	~XYFitCurveDock() override;
+
 	void setCurves(QList<XYCurve*>);
 	void setupGeneral() override;
 
 private:
 	void initGeneralTab() override;
-	void showFitResult();
+	void updatePlotRanges() override;
 	void updateSettings(const AbstractColumn*);
+	void showFitResult();
 	bool eventFilter(QObject*, QEvent*) override;
 
 	Ui::XYFitCurveDockGeneralTab uiGeneralTab;
@@ -66,11 +52,12 @@ private:
 	QList<double> parameterValues;
 	bool m_parametersValid{true};
 	KMessageWidget* m_messageWidget{nullptr};
+	AspectTreeModel* m_dataSourceModel{nullptr};
 
 protected:
 	void setModel() override;
 
-private slots:
+private Q_SLOTS:
 	//SLOTs for changes triggered in XYFitCurveDock
 	//general tab
 	void dataSourceTypeChanged(int);
@@ -98,7 +85,7 @@ private slots:
 	void showOptions();
 	void insertFunction(const QString&) const;
 	void insertConstant(const QString&) const;
-	void setPlotXRange();
+//	void setPlotXRange();
 	void recalculateClicked();
 	void updateModelEquation();
 	void expressionChanged();
@@ -111,9 +98,9 @@ private slots:
 
 	//SLOTs for changes triggered in XYCurve
 	//General-Tab
-	void curveDescriptionChanged(const AbstractAspect*);
 	void curveDataSourceTypeChanged(XYAnalysisCurve::DataSourceType);
 	void curveDataSourceCurveChanged(const XYCurve*);
+	void curveDataSourceHistogramChanged(const Histogram*);
 	void curveXDataColumnChanged(const AbstractColumn*);
 	void curveYDataColumnChanged(const AbstractColumn*);
 	void curveXErrorColumnChanged(const AbstractColumn*);
