@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : MatrixFunctionDialog.cpp
     Project              : LabPlot
     Description          : Dialog for generating matrix values from a mathematical function
     ------------------------------------------------------------------------
-    Copyright            : (C) 2015-2019 by Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2016 by Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2015-2019 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2016 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 #include "MatrixFunctionDialog.h"
 #include "backend/lib/macros.h"
 #include "backend/gsl/ExpressionParser.h"
@@ -261,7 +243,9 @@ void MatrixFunctionDialog::generate() {
 	}
 
 	// Timing
+#ifndef NDEBUG
 	DEBUG("elapsed time =" << timer.elapsed() << "ms");
+#endif
 
 	m_matrix->setFormula(ui.teEquation->toPlainText());
 	m_matrix->setData(new_data);
