@@ -1,30 +1,12 @@
-/***************************************************************************
+/*
     File                 : DropValuesDialog.cpp
     Project              : LabPlot
     Description          : Dialog for droping and masking values in columns
     --------------------------------------------------------------------
-	Copyright            : (C) 2015-2020 by Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2015-2020 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 #include "DropValuesDialog.h"
 #include "backend/core/column/Column.h"
 #include "backend/lib/macros.h"
@@ -84,7 +66,7 @@ DropValuesDialog::DropValuesDialog(Spreadsheet* s, bool mask, QWidget* parent) :
 		m_okButton->setToolTip(i18n("Drop values in the specified region"));
 	}
 
-	connect(ui.cbOperator, static_cast<void (QComboBox::*) (int)>(&QComboBox::currentIndexChanged), this, &DropValuesDialog::operatorChanged );
+	connect(ui.cbOperator, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &DropValuesDialog::operatorChanged );
 	connect(m_okButton, &QPushButton::clicked, this, &DropValuesDialog::okClicked);
 	connect(btnBox, &QDialogButtonBox::accepted, this, &DropValuesDialog::accept);
 	connect(btnBox, &QDialogButtonBox::rejected, this, &DropValuesDialog::reject);
@@ -150,7 +132,7 @@ class MaskValuesTask : public QRunnable {
 			auto mode = m_column->columnMode();
 			switch (m_operator) {
 			case Operator::EqualTo:
-				if (mode == AbstractColumn::ColumnMode::Numeric) {
+				if (mode == AbstractColumn::ColumnMode::Double) {
 					for (int i = 0; i < rows; ++i) {
 						if (data->at(i) == m_value1) {
 							m_column->setMasked(i, true);
@@ -174,7 +156,7 @@ class MaskValuesTask : public QRunnable {
 				}
 				break;
 			case Operator::BetweenIncl:
-				if (mode == AbstractColumn::ColumnMode::Numeric) {
+				if (mode == AbstractColumn::ColumnMode::Double) {
 					for (int i = 0; i < rows; ++i) {
 						if (data->at(i) >= m_value1 && data->at(i) <= m_value2) {
 							m_column->setMasked(i, true);
@@ -198,7 +180,7 @@ class MaskValuesTask : public QRunnable {
 				}
 				break;
 			case Operator::BetweenExcl:
-				if (mode == AbstractColumn::ColumnMode::Numeric) {
+				if (mode == AbstractColumn::ColumnMode::Double) {
 					for (int i = 0; i < rows; ++i) {
 						if (data->at(i) > m_value1 && data->at(i) < m_value2) {
 							m_column->setMasked(i, true);
@@ -222,7 +204,7 @@ class MaskValuesTask : public QRunnable {
 				}
 				break;
 			case Operator::GreaterThan:
-				if (mode == AbstractColumn::ColumnMode::Numeric) {
+				if (mode == AbstractColumn::ColumnMode::Double) {
 					for (int i = 0; i < rows; ++i) {
 						if (data->at(i) > m_value1) {
 							m_column->setMasked(i, true);
@@ -246,7 +228,7 @@ class MaskValuesTask : public QRunnable {
 				}
 				break;
 			case Operator::GreaterThanEqualTo:
-				if (mode == AbstractColumn::ColumnMode::Numeric) {
+				if (mode == AbstractColumn::ColumnMode::Double) {
 					for (int i = 0; i < rows; ++i) {
 						if (data->at(i) >= m_value1) {
 							m_column->setMasked(i, true);
@@ -270,7 +252,7 @@ class MaskValuesTask : public QRunnable {
 				}
 				break;
 			case Operator::LessThan:
-				if (mode == AbstractColumn::ColumnMode::Numeric) {
+				if (mode == AbstractColumn::ColumnMode::Double) {
 					for (int i = 0; i < rows; ++i) {
 						if (data->at(i) < m_value1) {
 							m_column->setMasked(i, true);
@@ -294,7 +276,7 @@ class MaskValuesTask : public QRunnable {
 				}
 				break;
 			case Operator::LessThanEqualTo:
-				if (mode == AbstractColumn::ColumnMode::Numeric) {
+				if (mode == AbstractColumn::ColumnMode::Double) {
 					for (int i = 0; i < rows; ++i) {
 						if (data->at(i) <= m_value1) {
 							m_column->setMasked(i, true);
@@ -344,7 +326,7 @@ class DropValuesTask : public QRunnable {
 			bool changed = false;
 
 			auto mode = m_column->columnMode();
-			if (mode == AbstractColumn::ColumnMode::Numeric) {
+			if (mode == AbstractColumn::ColumnMode::Double) {
 				auto* data = static_cast<QVector<double>* >(m_column->data());
 				QVector<double> new_data(*data);
 
@@ -552,7 +534,7 @@ void DropValuesDialog::maskValues() const {
 	WAIT_CURSOR;
 	m_spreadsheet->beginMacro(i18n("%1: mask values", m_spreadsheet->name()));
 
-	const Operator op = static_cast<Operator>(ui.cbOperator->currentIndex());
+	const auto op = static_cast<Operator>(ui.cbOperator->currentIndex());
 	SET_NUMBER_LOCALE
 	bool ok;
 	const double value1 = numberLocale.toDouble(ui.leValue1->text(), &ok);
@@ -589,7 +571,7 @@ void DropValuesDialog::dropValues() const {
 	WAIT_CURSOR;
 	m_spreadsheet->beginMacro(i18n("%1: drop values", m_spreadsheet->name()));
 
-	const Operator op = static_cast<Operator>(ui.cbOperator->currentIndex());
+	const auto op = static_cast<Operator>(ui.cbOperator->currentIndex());
 	SET_NUMBER_LOCALE
 	bool ok;
 	const double value1 = numberLocale.toDouble(ui.leValue1->text(), &ok);
