@@ -1,30 +1,12 @@
-/***************************************************************************
+/*
     File                 : EquidistantValuesDialog.cpp
     Project              : LabPlot
     Description          : Dialog for generating equidistant numbers
     --------------------------------------------------------------------
-    Copyright            : (C) 2014-2019 by Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2014-2022 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 #include "EquidistantValuesDialog.h"
 #include "backend/core/column/Column.h"
 #include "backend/lib/macros.h"
@@ -47,7 +29,7 @@
 EquidistantValuesDialog::EquidistantValuesDialog(Spreadsheet* s, QWidget* parent) : QDialog(parent), m_spreadsheet(s) {
 	setWindowTitle(i18nc("@title:window", "Equidistant Values"));
 
-	QWidget* mainWidget = new QWidget(this);
+	auto* mainWidget = new QWidget(this);
 	ui.setupUi(mainWidget);
 	auto* layout = new QVBoxLayout(this);
 
@@ -79,11 +61,7 @@ EquidistantValuesDialog::EquidistantValuesDialog(Spreadsheet* s, QWidget* parent
 	ui.leIncrement->setValidator( new QDoubleValidator(ui.leIncrement) );
 	ui.leNumber->setValidator( new QIntValidator(ui.leNumber) );
 
-	ui.leFrom->setText("1");
-	ui.leTo->setText("100");
-	ui.leIncrement->setText("1");
-
-	connect( ui.cbType, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &EquidistantValuesDialog::typeChanged);
+	connect( ui.cbType, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &EquidistantValuesDialog::typeChanged);
 	connect( ui.leFrom, &QLineEdit::textChanged, this, &EquidistantValuesDialog::checkValues);
 	connect( ui.leTo, &QLineEdit::textChanged, this, &EquidistantValuesDialog::checkValues);
 	connect( ui.leNumber, &QLineEdit::textChanged, this, &EquidistantValuesDialog::checkValues);
@@ -101,12 +79,24 @@ EquidistantValuesDialog::EquidistantValuesDialog(Spreadsheet* s, QWidget* parent
 		resize(windowHandle()->size()); // workaround for QTBUG-40584
 	} else
 		resize(QSize(300, 0).expandedTo(minimumSize()));
+
+	ui.cbType->setCurrentIndex(conf.readEntry("Type", 0));
+	ui.leFrom->setText(QString::number(conf.readEntry("From", 1)));
+	ui.leTo->setText(QString::number(conf.readEntry("To", 100)));
+	SET_NUMBER_LOCALE
+	ui.leIncrement->setText(numberLocale.toString(conf.readEntry("Increment", 1.)));
 }
 
 EquidistantValuesDialog::~EquidistantValuesDialog() {
 	//save current settings
 	KConfigGroup conf(KSharedConfig::openConfig(), "EquidistantValuesDialog");
 	KWindowConfig::saveWindowSize(windowHandle(), conf);
+
+	conf.writeEntry("Type", ui.cbType->currentIndex());
+	SET_NUMBER_LOCALE
+	conf.writeEntry("From", numberLocale.toInt(ui.leFrom->text()));
+	conf.writeEntry("To", numberLocale.toInt(ui.leTo->text()));
+	conf.writeEntry("Increment", numberLocale.toDouble(ui.leIncrement->text()));
 }
 
 void EquidistantValuesDialog::setColumns(const QVector<Column*>& columns) {
@@ -191,19 +181,12 @@ void EquidistantValuesDialog::generate() {
 	if (m_spreadsheet->rowCount() < number)
 		m_spreadsheet->setRowCount(number);
 
-	for (auto* col : m_columns) {
-		col->setSuppressDataChangedSignal(true);
+	QVector<double> newData;
+	for (int i = 0; i < number; ++i)
+		newData.push_back(start + dist*i);
 
-		if (m_spreadsheet->rowCount()>number)
-			col->clear();
-
-		for (int i = 0; i < number; ++i) {
-			col->setValueAt(i, start + dist*i);
-		}
-
-		col->setSuppressDataChangedSignal(false);
-		col->setChanged();
-	}
+	for (auto* col : m_columns)
+		col->replaceValues(0, newData);
 
 	m_spreadsheet->endMacro();
 	RESET_CURSOR;
