@@ -1,30 +1,12 @@
-/***************************************************************************
+/*
     File                 : ExportSpreadsheetDialog.cpp
     Project              : LabPlot
     Description          : export spreadsheet dialog
     --------------------------------------------------------------------
-    Copyright            : (C) 2014-2019 by Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2014-2019 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "ExportSpreadsheetDialog.h"
 #include "ui_exportspreadsheetwidget.h"
@@ -71,9 +53,10 @@ ExportSpreadsheetDialog::ExportSpreadsheetDialog(QWidget* parent) : QDialog(pare
 	ui->leFileName->setCompleter(new QCompleter(new QDirModel, this));
 
 	ui->cbFormat->addItem("ASCII", static_cast<int>(Format::ASCII));
-	ui->cbFormat->addItem("Binary", static_cast<int>(Format::Binary));
 	ui->cbFormat->addItem("LaTeX", static_cast<int>(Format::LaTeX));
+#ifdef HAVE_FITS
 	ui->cbFormat->addItem("FITS", static_cast<int>(Format::FITS));
+#endif
 
 	const QStringList& drivers = QSqlDatabase::drivers();
 	if (drivers.contains(QLatin1String("QSQLITE")) || drivers.contains(QLatin1String("QSQLITE3")))
@@ -101,8 +84,8 @@ ExportSpreadsheetDialog::ExportSpreadsheetDialog(QWidget* parent) : QDialog(pare
 	connect(ui->bOpen, &QPushButton::clicked, this, &ExportSpreadsheetDialog::selectFile);
 	connect(ui->leFileName, &QLineEdit::textChanged, this, &ExportSpreadsheetDialog::fileNameChanged );
 	connect(m_showOptionsButton, &QPushButton::clicked, this, &ExportSpreadsheetDialog::toggleOptions);
-	connect(ui->cbFormat, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &ExportSpreadsheetDialog::formatChanged);
-	connect(ui->cbExportToFITS, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &ExportSpreadsheetDialog::fitsExportToChanged);
+	connect(ui->cbFormat, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &ExportSpreadsheetDialog::formatChanged);
+	connect(ui->cbExportToFITS, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &ExportSpreadsheetDialog::fitsExportToChanged);
 
 	setWindowTitle(i18nc("@title:window", "Export Spreadsheet"));
 	setWindowIcon(QIcon::fromTheme("document-export-database"));
@@ -321,10 +304,11 @@ void ExportSpreadsheetDialog::toggleOptions() {
 	m_showOptions = !m_showOptions;
 	ui->gbOptions->setVisible(m_showOptions);
 	m_showOptions ? m_showOptionsButton->setText(i18n("Hide Options")) :
-			m_showOptionsButton->setText(i18n("Show Options"));	//resize the dialog
-	resize(layout()->minimumSize());
+			m_showOptionsButton->setText(i18n("Show Options"));
+
+	//resize the dialog
 	layout()->activate();
-	resize( QSize(this->width(),0).expandedTo(minimumSize()) );
+	resize( QSize(this->width(), 0).expandedTo(minimumSize()) );
 }
 
 /*!
@@ -340,9 +324,11 @@ void ExportSpreadsheetDialog::selectFile() {
 	case Format::ASCII:
 		extensions = i18n("Text files (*.txt *.dat *.csv)");
 		break;
+	/*
 	case Format::Binary:
 		extensions = i18n("Binary files (*.*)");
 		break;
+	*/
 	case Format::LaTeX:
 		extensions = i18n("LaTeX files (*.tex)");
 		break;
@@ -354,7 +340,7 @@ void ExportSpreadsheetDialog::selectFile() {
 		break;
 	}
 
-	const QString path = QFileDialog::getSaveFileName(this, i18n("Export to file"), dir, extensions);
+	const QString path = QFileDialog::getSaveFileName(this, i18nc("@title:window", "Export to File"), dir, extensions);
 	if (!path.isEmpty()) {
 		ui->leFileName->setText(path);
 
@@ -372,7 +358,11 @@ void ExportSpreadsheetDialog::selectFile() {
  */
 void ExportSpreadsheetDialog::formatChanged(int index) {
 	QStringList extensions;
-	extensions << ".txt" << ".bin" << ".tex" << ".fits" << ".db";
+    extensions << ".txt" << ".tex";
+#ifdef HAVE_FITS
+    extensions<< ".fits";
+#endif
+    extensions << ".db";
 	QString path = ui->leFileName->text();
 	int i = path.indexOf(".");
 	if (index != -1) {
@@ -383,7 +373,8 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 	}
 
 	const Format format = Format(ui->cbFormat->itemData(ui->cbFormat->currentIndex()).toInt());
-	if (format == Format::LaTeX) {
+	switch (format) {
+	case Format::LaTeX: {
 		ui->cbSeparator->hide();
 		ui->lSeparator->hide();
 		ui->lDecimalSeparator->hide();
@@ -415,7 +406,10 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 		ui->lExportToFITS->hide();
 		ui->lColumnAsUnits->hide();
 		ui->chkColumnsAsUnits->hide();
-	} else if (format == Format::FITS) {
+
+		break;
+	}
+	case Format::FITS: {
 		ui->lCaptions->hide();
 		ui->lEmptyRows->hide();
 		ui->lExportArea->hide();
@@ -445,7 +439,10 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 				ui->chkColumnsAsUnits->show();
 			}
 		}
-	} else if (format == Format::SQLite) {
+
+		break;
+	}
+	case Format::SQLite: {
 		ui->cbSeparator->hide();
 		ui->lSeparator->hide();
 		ui->lDecimalSeparator->hide();
@@ -474,7 +471,10 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 		ui->lExportToFITS->hide();
 		ui->lColumnAsUnits->hide();
 		ui->chkColumnsAsUnits->hide();
-	} else {
+
+		break;
+	}
+	case Format::ASCII: {
 		ui->cbSeparator->show();
 		ui->lSeparator->show();
 		ui->lDecimalSeparator->show();
@@ -501,6 +501,7 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 		ui->lColumnAsUnits->hide();
 		ui->chkColumnsAsUnits->hide();
 	}
+	}
 
 	if (!m_matrixMode && !(format == Format::FITS || format == Format::SQLite)) {
 		ui->chkExportHeader->show();
