@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : FunctionValuesDialog.cpp
     Project              : LabPlot
     Description          : Dialog for generating values from a mathematical function
     --------------------------------------------------------------------
-    Copyright            : (C) 2014-2018 by Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2020 by Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2014-2018 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2020 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 #include "FunctionValuesDialog.h"
 #include "backend/core/AspectTreeModel.h"
 #include "backend/core/column/Column.h"
@@ -125,23 +107,21 @@ void FunctionValuesDialog::setColumns(const QVector<Column*>& columns) {
 	ui.teEquation->setPlainText(firstColumn->formula());
 
 	//variables
-	const QStringList& variableNames = firstColumn->formulaVariableNames();
-	if (variableNames.isEmpty()) {	//no formula was used for this column -> add the first variable "x"
+	const auto& formulaData = firstColumn->formulaData();
+	if (formulaData.isEmpty()) {	//no formula was used for this column -> add the first variable "x"
 		addVariable();
 		m_variableLineEdits[0]->setText("x");
 	} else {	//formula and variables are available
-		const QVector<Column*>& variableColumns = firstColumn->formulaVariableColumns();
-		const QStringList& columnPaths = firstColumn->formulaVariableColumnPaths();
 
 		//add all available variables and select the corresponding columns
-		const QVector<AbstractAspect*> cols = m_spreadsheet->project()->children(AspectType::Column, AbstractAspect::ChildIndexFlag::Recursive);
-		for (int i = 0; i < variableNames.size(); ++i) {
+		const auto& cols = m_spreadsheet->project()->children<Column>(AbstractAspect::ChildIndexFlag::Recursive);
+		for (int i = 0; i < formulaData.size(); ++i) {
 			addVariable();
-			m_variableLineEdits[i]->setText(variableNames.at(i));
+			m_variableLineEdits[i]->setText(formulaData.at(i).variableName());
 
 			bool found = false;
 			for (const auto* col : cols) {
-				if (col != variableColumns.at(i))
+				if (col != formulaData.at(i).column())
 					continue;
 
 				const auto* column = dynamic_cast<const AbstractColumn*>(col);
@@ -162,8 +142,8 @@ void FunctionValuesDialog::setColumns(const QVector<Column*>& columns) {
 			if (!found) {
 				m_variableDataColumns[i]->setCurrentModelIndex(QModelIndex());
 				m_variableDataColumns[i]->useCurrentIndexText(false);
-				m_variableDataColumns[i]->setInvalid(true, i18n("The column \"%1\"\nis not available anymore. It will be automatically used once it is created again.", columnPaths[i]));
-				m_variableDataColumns[i]->setText(columnPaths[i].split('/').last());
+				m_variableDataColumns[i]->setInvalid(true, i18n("The column \"%1\"\nis not available anymore. It will be automatically used once it is created again.", formulaData.at(i).columnName()));
+				m_variableDataColumns[i]->setText(formulaData.at(i).columnName().split('/').last());
 			}
 		}
 	}
@@ -175,12 +155,12 @@ void FunctionValuesDialog::setColumns(const QVector<Column*>& columns) {
 }
 
 bool FunctionValuesDialog::validVariableName(QLineEdit* le) {
-	bool isValid{false};
+	bool isValid = false;
 	if (ExpressionParser::getInstance()->constants().indexOf(le->text()) != -1) {
-		le->setStyleSheet("QLineEdit{background: red;}");
+		SET_WARNING_STYLE(le)
 		le->setToolTip(i18n("Provided variable name is already reserved for a name of a constant. Please use another name."));
 	} else if (ExpressionParser::getInstance()->functions().indexOf(le->text()) != -1) {
-		le->setStyleSheet("QLineEdit{background: red;}");
+		SET_WARNING_STYLE(le)
 		le->setToolTip(i18n("Provided variable name is already reserved for a name of a function. Please use another name."));
 	} else {
 		le->setStyleSheet(QString());
@@ -402,7 +382,7 @@ void FunctionValuesDialog::generate() {
 	const QString& expression{ ui.teEquation->toPlainText() };
 	bool autoUpdate{ (ui.chkAutoUpdate->checkState() == Qt::Checked) };
 	for (auto* col : m_columns) {
-		col->setColumnMode(AbstractColumn::ColumnMode::Numeric);
+		col->setColumnMode(AbstractColumn::ColumnMode::Double);
 		col->setFormula(expression, variableNames, variableColumns, autoUpdate);
 		col->updateFormula();
 	}
