@@ -1,31 +1,14 @@
-/***************************************************************************
+/*
     File                 : RandomValuesDialog.cpp
     Project              : LabPlot
     Description          : Dialog for generating non-uniformly distributed random numbers
     --------------------------------------------------------------------
-    Copyright            : (C) 2014-2019 by Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2016-2020 by Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2014-2019 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2016-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+#include "kdefrontend/GuiTools.h"
 #include "RandomValuesDialog.h"
 #include "backend/core/column/Column.h"
 #include "backend/lib/macros.h"
@@ -56,7 +39,7 @@ extern "C" {
 RandomValuesDialog::RandomValuesDialog(Spreadsheet* s, QWidget* parent) : QDialog(parent), m_spreadsheet(s) {
 	setWindowTitle(i18nc("@title:window", "Random Values"));
 
-	QWidget* mainWidget = new QWidget(this);
+	auto* mainWidget = new QWidget(this);
 	ui.setupUi(mainWidget);
 	auto* layout = new QVBoxLayout(this);
 
@@ -74,14 +57,20 @@ RandomValuesDialog::RandomValuesDialog(Spreadsheet* s, QWidget* parent) : QDialo
 	layout->addWidget(buttonBox);
 	setLayout(layout);
 	setAttribute(Qt::WA_DeleteOnClose);
+	QVector<QPair<QString, int>> distros;
 	for (int i = 0; i < NSL_SF_STATS_DISTRIBUTION_RNG_COUNT; i++)
-		ui.cbDistribution->addItem(i18n(nsl_sf_stats_distribution_name[i]), i);
+		distros << QPair<QString, int>(i18n(nsl_sf_stats_distribution_name[i]), i);
+	std::sort(std::begin(distros), std::end(distros));
+	for (const auto& d : distros)
+		ui.cbDistribution->addItem(d.first, d.second);
+	const int defaultDist = (int)nsl_sf_stats_gaussian;	// default dist
 
 	//use white background in the preview label
 	QPalette p;
 	p.setColor(QPalette::Window, Qt::white);
 	ui.lFuncPic->setAutoFillBackground(true);
 	ui.lFuncPic->setPalette(p);
+	ui.lFuncPic->setScaledContents(false);
 
 	ui.leParameter1->setClearButtonEnabled(true);
 	ui.leParameter2->setClearButtonEnabled(true);
@@ -91,7 +80,7 @@ RandomValuesDialog::RandomValuesDialog(Spreadsheet* s, QWidget* parent) : QDialo
 	ui.leParameter2->setValidator( new QDoubleValidator(ui.leParameter2) );
 	ui.leParameter3->setValidator( new QDoubleValidator(ui.leParameter3) );
 
-	connect(ui.cbDistribution, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &RandomValuesDialog::distributionChanged);
+	connect(ui.cbDistribution, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &RandomValuesDialog::distributionChanged);
 	connect(ui.leParameter1, &QLineEdit::textChanged, this, &RandomValuesDialog::checkValues);
 	connect(ui.leParameter2, &QLineEdit::textChanged, this, &RandomValuesDialog::checkValues);
 	connect(ui.leParameter3, &QLineEdit::textChanged, this, &RandomValuesDialog::checkValues);
@@ -101,18 +90,20 @@ RandomValuesDialog::RandomValuesDialog(Spreadsheet* s, QWidget* parent) : QDialo
 	create(); // ensure there's a window created
 	const KConfigGroup conf(KSharedConfig::openConfig(), "RandomValuesDialog");
 	if (conf.exists()) {
-		ui.cbDistribution->setCurrentIndex(conf.readEntry("Distribution", 0));
-		this->distributionChanged(ui.cbDistribution->currentIndex()); //if index=0 no signal is emitted above, call this slot directly here
+		const int dist = conf.readEntry("Distribution", defaultDist);
+		ui.cbDistribution->setCurrentIndex(ui.cbDistribution->findData(dist));
+		if (ui.cbDistribution->currentIndex() == 0)	// if index=0 no signal is emitted above, call this slot directly
+			this->distributionChanged();
 		SET_NUMBER_LOCALE
-		ui.leParameter1->setText(numberLocale.toString(conf.readEntry("Parameter1", 1.0)));
+		// read parameter or set values for default dist
+		ui.leParameter1->setText(numberLocale.toString(conf.readEntry("Parameter1", 0.0)));
 		ui.leParameter2->setText(numberLocale.toString(conf.readEntry("Parameter2", 1.0)));
 		ui.leParameter3->setText(numberLocale.toString(conf.readEntry("Parameter3", 1.0)));
 
 		KWindowConfig::restoreWindowSize(windowHandle(), conf);
 		resize(windowHandle()->size()); // workaround for QTBUG-40584
 	} else {
-		//Gaussian distribution as default
-		this->distributionChanged(0);
+		ui.cbDistribution->setCurrentIndex(ui.cbDistribution->findData(defaultDist));
 
 		resize( QSize(400, 0).expandedTo(minimumSize()) );
 	}
@@ -121,7 +112,8 @@ RandomValuesDialog::RandomValuesDialog(Spreadsheet* s, QWidget* parent) : QDialo
 RandomValuesDialog::~RandomValuesDialog() {
 	//save current settings
 	KConfigGroup conf(KSharedConfig::openConfig(), "RandomValuesDialog");
-	conf.writeEntry("Distribution", ui.cbDistribution->currentIndex());
+	// saving enum value to be consistent
+	conf.writeEntry("Distribution", ui.cbDistribution->itemData(ui.cbDistribution->currentIndex()).toInt());
 	SET_NUMBER_LOCALE
 	conf.writeEntry("Parameter1", numberLocale.toDouble(ui.leParameter1->text()));
 	conf.writeEntry("Parameter2", numberLocale.toDouble(ui.leParameter2->text()));
@@ -135,7 +127,9 @@ void RandomValuesDialog::setColumns(const QVector<Column*>& columns) {
 }
 
 void RandomValuesDialog::distributionChanged(int index) {
-	nsl_sf_stats_distribution dist = (nsl_sf_stats_distribution)ui.cbDistribution->itemData(index).toInt();
+	DEBUG(Q_FUNC_INFO << ", index = " << index)
+	const nsl_sf_stats_distribution dist = (nsl_sf_stats_distribution)ui.cbDistribution->itemData(index).toInt();
+	DEBUG(Q_FUNC_INFO << ", dist = " << nsl_sf_stats_distribution_name[(int)dist])
 
 	//  default settings (used by most distributions)
 	ui.lParameter1->show();
@@ -281,8 +275,8 @@ void RandomValuesDialog::distributionChanged(int index) {
 		ui.leParameter2->setText(numberLocale.toString(0.0));
 		break;
 	case nsl_sf_stats_lognormal:
-		ui.lParameter1->setText(UTF8_QSTRING("σ ="));
-		ui.lParameter2->setText(UTF8_QSTRING("μ ="));
+		ui.lParameter1->setText(UTF8_QSTRING("μ ="));
+		ui.lParameter2->setText(UTF8_QSTRING("σ ="));
 		ui.leParameter1->setText(numberLocale.toString(1.0));
 		ui.leParameter2->setText(numberLocale.toString(1.0));
 		break;
@@ -358,9 +352,17 @@ void RandomValuesDialog::distributionChanged(int index) {
 		break;
 	}
 
-	QString file = QStandardPaths::locate(QStandardPaths::AppDataLocation, "pics/gsl_distributions/" + QString(nsl_sf_stats_distribution_pic_name[dist]) + ".png");
-	DEBUG("Distribution pixmap path = " << STDSTRING(file));
-	ui.lFuncPic->setPixmap(QPixmap(file));
+	QString file = QStandardPaths::locate( QStandardPaths::AppDataLocation,
+			"pics/gsl_distributions/" + QString(nsl_sf_stats_distribution_pic_name[dist]) + QLatin1String(".pdf") );
+	QImage image = GuiTools::importPDFFile(file);
+
+	if (image.isNull()) {
+		ui.lFunc->hide();
+		ui.lFuncPic->hide();
+	} else {
+		ui.lFuncPic->setPixmap(QPixmap::fromImage(image));
+		ui.lFuncPic->show();
+	}
 }
 
 void RandomValuesDialog::checkValues() {
@@ -417,7 +419,7 @@ void RandomValuesDialog::generate() {
 		DEBUG(Q_FUNC_INFO << ", mu = " << mu << ", sigma = " << sigma);
 		for (auto* col : m_columns) {
 			auto mode = col->columnMode();
-			if (mode == AbstractColumn::ColumnMode::Numeric) {
+			if (mode == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_gaussian(r, sigma) + mu;
 				col->replaceValues(0, data);
@@ -439,7 +441,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(sigma, ui.leParameter2)
 		SET_DOUBLE_FROM_LE(a, ui.leParameter3)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_gaussian_tail(r, a, sigma) + mu;
 				col->replaceValues(0, data);
@@ -460,7 +462,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(l, ui.leParameter1)
 		SET_DOUBLE_FROM_LE(mu, ui.leParameter2)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				//GSL uses the inverse for exp. distrib.
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_exponential(r, 1./l) + mu;
@@ -482,7 +484,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(mu, ui.leParameter1)
 		SET_DOUBLE_FROM_LE(s, ui.leParameter2)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_laplace(r, s) + mu;
 				col->replaceValues(0, data);
@@ -504,7 +506,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(a, ui.leParameter2)
 		SET_DOUBLE_FROM_LE(b, ui.leParameter3)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_exppow(r, a, b) + mu;
 				col->replaceValues(0, data);
@@ -525,7 +527,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(gamma, ui.leParameter1)
 		SET_DOUBLE_FROM_LE(mu, ui.leParameter2)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_cauchy(r, gamma) + mu;
 				col->replaceValues(0, data);
@@ -545,7 +547,7 @@ void RandomValuesDialog::generate() {
 		double s{1.0};
 		SET_DOUBLE_FROM_LE(s, ui.leParameter1)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_rayleigh(r, s);
 				col->replaceValues(0, data);
@@ -566,7 +568,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(mu, ui.leParameter1)
 		SET_DOUBLE_FROM_LE(sigma, ui.leParameter2)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_rayleigh_tail(r, mu, sigma);
 				col->replaceValues(0, data);
@@ -584,7 +586,7 @@ void RandomValuesDialog::generate() {
 	}
 	case nsl_sf_stats_landau:
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_landau(r);
 				col->replaceValues(0, data);
@@ -604,7 +606,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(c, ui.leParameter1)
 		SET_DOUBLE_FROM_LE(alpha, ui.leParameter2)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_levy(r, c, alpha);
 				col->replaceValues(0, data);
@@ -626,7 +628,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(alpha, ui.leParameter2)
 		SET_DOUBLE_FROM_LE(beta, ui.leParameter3)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_levy_skew(r, c, alpha, beta);
 				col->replaceValues(0, data);
@@ -647,7 +649,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(a, ui.leParameter1)
 		SET_DOUBLE_FROM_LE(b, ui.leParameter2)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_flat(r, a, b);
 				col->replaceValues(0, data);
@@ -668,7 +670,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(a, ui.leParameter1)
 		SET_DOUBLE_FROM_LE(b, ui.leParameter2)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_gamma(r, a, b);
 				col->replaceValues(0, data);
@@ -686,10 +688,10 @@ void RandomValuesDialog::generate() {
 	}
 	case nsl_sf_stats_lognormal: {
 		double s{1.0}, mu{1.0};
-		SET_DOUBLE_FROM_LE(s, ui.leParameter1)
-		SET_DOUBLE_FROM_LE(mu, ui.leParameter2)
+		SET_DOUBLE_FROM_LE(mu, ui.leParameter1)
+		SET_DOUBLE_FROM_LE(s, ui.leParameter2)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_lognormal(r, mu, s);
 				col->replaceValues(0, data);
@@ -709,7 +711,7 @@ void RandomValuesDialog::generate() {
 		double n{1.0};
 		SET_DOUBLE_FROM_LE(n, ui.leParameter1)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_chisq(r, n);
 				col->replaceValues(0, data);
@@ -730,7 +732,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(nu1, ui.leParameter1)
 		SET_DOUBLE_FROM_LE(nu2, ui.leParameter2)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_fdist(r, nu1, nu2);
 				col->replaceValues(0, data);
@@ -750,7 +752,7 @@ void RandomValuesDialog::generate() {
 		double nu{1.0};
 		SET_DOUBLE_FROM_LE(nu, ui.leParameter1)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_tdist(r, nu);
 				col->replaceValues(0, data);
@@ -771,7 +773,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(a, ui.leParameter1)
 		SET_DOUBLE_FROM_LE(b, ui.leParameter2)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_beta(r, a, b);
 				col->replaceValues(0, data);
@@ -792,7 +794,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(s, ui.leParameter1)
 		SET_DOUBLE_FROM_LE(mu, ui.leParameter2)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_logistic(r, s) + mu;
 				col->replaceValues(0, data);
@@ -813,7 +815,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(a, ui.leParameter1)
 		SET_DOUBLE_FROM_LE(b, ui.leParameter2)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_pareto(r, a, b);
 				col->replaceValues(0, data);
@@ -835,7 +837,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(l, ui.leParameter2)
 		SET_DOUBLE_FROM_LE(mu, ui.leParameter3)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_weibull(r, l, k) + mu;
 				col->replaceValues(0, data);
@@ -857,7 +859,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(b, ui.leParameter2)
 		SET_DOUBLE_FROM_LE(mu, ui.leParameter3)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_gumbel1(r, 1./s, b) + mu;
 				col->replaceValues(0, data);
@@ -879,7 +881,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(b, ui.leParameter2)
 		SET_DOUBLE_FROM_LE(mu, ui.leParameter3)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_gumbel2(r, a, b) + mu;
 				col->replaceValues(0, data);
@@ -899,7 +901,7 @@ void RandomValuesDialog::generate() {
 		double l{1.0};
 		SET_DOUBLE_FROM_LE(l, ui.leParameter1)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_poisson(r, l);
 				col->replaceValues(0, data);
@@ -919,7 +921,7 @@ void RandomValuesDialog::generate() {
 		double p{1.0};
 		SET_DOUBLE_FROM_LE(p, ui.leParameter1)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_bernoulli(r, p);
 				col->replaceValues(0, data);
@@ -940,7 +942,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(p, ui.leParameter1)
 		SET_DOUBLE_FROM_LE(n, ui.leParameter2)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_binomial(r, p, n);
 				col->replaceValues(0, data);
@@ -961,7 +963,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(p, ui.leParameter1)
 		SET_DOUBLE_FROM_LE(n, ui.leParameter2)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_negative_binomial(r, p, n);
 				col->replaceValues(0, data);
@@ -982,7 +984,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(p, ui.leParameter1)
 		SET_DOUBLE_FROM_LE(n, ui.leParameter2)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_pascal(r, p, n);
 				col->replaceValues(0, data);
@@ -1002,7 +1004,7 @@ void RandomValuesDialog::generate() {
 		double p{0.5};
 		SET_DOUBLE_FROM_LE(p, ui.leParameter1)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_geometric(r, p);
 				col->replaceValues(0, data);
@@ -1024,7 +1026,7 @@ void RandomValuesDialog::generate() {
 		SET_DOUBLE_FROM_LE(n2, ui.leParameter2)
 		SET_DOUBLE_FROM_LE(t, ui.leParameter3)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_hypergeometric(r, n1, n2, t);
 				col->replaceValues(0, data);
@@ -1044,7 +1046,7 @@ void RandomValuesDialog::generate() {
 		double p{0.5};
 		SET_DOUBLE_FROM_LE(p, ui.leParameter1)
 		for (auto* col : m_columns) {
-			if (col->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			if (col->columnMode() == AbstractColumn::ColumnMode::Double) {
 				for (int i = 0; i < rows; ++i)
 					data[i] = gsl_ran_logarithmic(r, p);
 				col->replaceValues(0, data);
