@@ -1,29 +1,11 @@
-/***************************************************************************
-File                 : FITSHeaderEditAddUnitDialog.cpp
-Project              : LabPlot
-Description          : Widget for adding or modifying FITS header keyword units
---------------------------------------------------------------------
-Copyright            : (C) 2016-2017 by Fabian Kristof (fkristofszabolcs@gmail.com)
-***************************************************************************/
-
-/***************************************************************************
-*                                                                         *
-*  This program is free software; you can redistribute it and/or modify   *
-*  it under the terms of the GNU General Public License as published by   *
-*  the Free Software Foundation; either version 2 of the License, or      *
-*  (at your option) any later version.                                    *
-*                                                                         *
-*  This program is distributed in the hope that it will be useful,        *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
-*  GNU General Public License for more details.                           *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the Free Software           *
-*   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
-*   Boston, MA  02110-1301  USA                                           *
-*                                                                         *
-***************************************************************************/
+/*
+    File                 : FITSHeaderEditAddUnitDialog.cpp
+    Project              : LabPlot
+    Description          : Widget for adding or modifying FITS header keyword units
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2016-2017 Fabian Kristof <fkristofszabolcs@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "FITSHeaderEditAddUnitDialog.h"
 #include "backend/datasources/filters/FITSFilter.h"
 
@@ -48,7 +30,7 @@ FITSHeaderEditAddUnitDialog::FITSHeaderEditAddUnitDialog(const QString& unit, QW
 	setWindowIcon(QIcon::fromTheme("document-new"));
 	m_okButton->setEnabled(false);
 
-	QCompleter* keyCompleter = new QCompleter(FITSFilter::units(), this);
+	auto* keyCompleter = new QCompleter(FITSFilter::units(), this);
 	ui.leUnit->setCompleter(keyCompleter);
 	ui.leUnit->setPlaceholderText(i18n("Enter unit name here"));
 
