@@ -1,29 +1,11 @@
-/***************************************************************************
-File                 : FITSHeaderEditWidget.cpp
-Project              : LabPlot
-Description          : Widget for listing/editing FITS header keywords
---------------------------------------------------------------------
-Copyright            : (C) 2016-2017 by Fabian Kristof (fkristofszabolcs@gmail.com)
-***************************************************************************/
-
-/***************************************************************************
-*                                                                         *
-*  This program is free software; you can redistribute it and/or modify   *
-*  it under the terms of the GNU General Public License as published by   *
-*  the Free Software Foundation; either version 2 of the License, or      *
-*  (at your option) any later version.                                    *
-*                                                                         *
-*  This program is distributed in the hope that it will be useful,        *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
-*  GNU General Public License for more details.                           *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the Free Software           *
-*   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
-*   Boston, MA  02110-1301  USA                                           *
-*                                                                         *
-***************************************************************************/
+/*
+    File                 : FITSHeaderEditWidget.cpp
+    Project              : LabPlot
+    Description          : Widget for listing/editing FITS header keywords
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2016-2017 Fabian Kristof <fkristofszabolcs@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "FITSHeaderEditWidget.h"
 #include "ui_fitsheadereditwidget.h"
@@ -187,7 +169,7 @@ void FITSHeaderEditWidget::fillTableSlot(QTreeWidgetItem *item, int col) {
 void FITSHeaderEditWidget::openFile() {
 	KConfigGroup conf(KSharedConfig::openConfig(), "FITSHeaderEditWidget");
 	QString dir = conf.readEntry("LastDir", "");
-	QString fileName = QFileDialog::getOpenFileName(this, i18n("Open FITS file"), dir,
+	QString fileName = QFileDialog::getOpenFileName(this, i18nc("@title:window", "Open FITS File"), dir,
 	                   i18n("FITS files (*.fits *.fit *.fts)"));
 	if (fileName.isEmpty())
 		return;
@@ -276,7 +258,7 @@ bool FITSHeaderEditWidget::save() {
 	}
 	if (saved) {
 		//to reset the window title
-		emit changed(false);
+		Q_EMIT changed(false);
 	}
 
 	return saved;
@@ -371,7 +353,7 @@ void FITSHeaderEditWidget::addKeyword() {
 		newKeyWordItem = new QTableWidgetItem(newKeyWord.comment);
 		newKeyWordItem->setFlags(Qt::ItemIsEditable | Qt::ItemIsSelectable | Qt::ItemIsEnabled);
 		ui->twKeywordsTable->setItem(lastRow, 2, newKeyWordItem);
-		emit changed(true);
+		Q_EMIT changed(true);
 	}
 	m_initializingTable = false;
 	delete newKeywordDialog;
@@ -406,7 +388,7 @@ void FITSHeaderEditWidget::removeKeyword() {
 
 			m_extensionData[m_seletedExtension].keywords.removeAt(row);
 			m_extensionData[m_seletedExtension].updates.removedKeywords.append(toRemove);
-			emit changed(true);
+			Q_EMIT changed(true);
 		} else
 			KMessageBox::information(this, i18n("Cannot remove mandatory keyword."), i18n("Removing Keyword"));
 	}
@@ -458,7 +440,7 @@ void FITSHeaderEditWidget::updateKeyword(QTableWidgetItem *item) {
 				m_extensionData[m_seletedExtension].updates.newKeywords.operator [](idx).updates.commentUpdated = true;
 			}
 		}
-		emit changed(true);
+		Q_EMIT changed(true);
 	}
 }
 
@@ -501,7 +483,7 @@ void FITSHeaderEditWidget::addModifyKeywordUnit() {
 			if (!m_extensionData[m_seletedExtension].keywords.at(idx).unit.isEmpty())
 				m_extensionData[m_seletedExtension].keywords.operator [](idx).updates.unitUpdated = true;
 		}
-		emit changed(true);
+		Q_EMIT changed(true);
 		fillTable();
 	}
 
@@ -533,7 +515,7 @@ void FITSHeaderEditWidget::removeExtension() {
 		fillTable();
 	}
 	ui->twExtensions->setCurrentItem(newCurrent);
-	emit changed(true);
+	Q_EMIT changed(true);
 }
 
 /*!
@@ -623,7 +605,7 @@ void FITSHeaderEditWidget::closeFile() {
 		delete current;
 
 		enableButtonAddUnit();
-		emit changed(false);
+		Q_EMIT changed(false);
 	}
 }
 void FITSHeaderEditWidget::enableButtonAddUnit() {
@@ -633,7 +615,6 @@ void FITSHeaderEditWidget::enableButtonAddUnit() {
 		ui->bAddUnit->setEnabled(false);
 }
 
-void FITSHeaderEditWidget::enableButtonCloseFile(QTreeWidgetItem* item,int col) {
-	Q_UNUSED(col)
+void FITSHeaderEditWidget::enableButtonCloseFile(QTreeWidgetItem* item,int /*col*/) {
 	ui->bClose->setEnabled(item->parent() ? false : true);
 }
