@@ -1,33 +1,17 @@
-/***************************************************************************
+/*
     File                 : FitOptionsWidget.cc
     Project              : LabPlot
     Description          : widget for editing advanced fit options
     --------------------------------------------------------------------
-    Copyright            : (C) 2014-2020 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2017-2018 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2014-2020 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2017-2018 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 #include "FitOptionsWidget.h"
+#include "backend/core/AbstractColumn.h"
 #include "backend/worksheet/plots/cartesian/CartesianPlot.h"
+#include "backend/worksheet/plots/cartesian/CartesianCoordinateSystem.h"
 
 /*!
 	\class FitOptionsWidget
@@ -59,17 +43,18 @@ FitOptionsWidget::FitOptionsWidget(QWidget* parent, XYFitCurve::FitData* fitData
 
 	//range widgets
 	const auto* plot = static_cast<const CartesianPlot*>(fitCurve->parentAspect());
-	m_dateTimeRange = (plot->xRangeFormat() != CartesianPlot::RangeFormat::Numeric);
+	const int xIndex = plot->coordinateSystem(m_fitCurve->coordinateSystemIndex())->xIndex();
+	m_dateTimeRange = (plot->xRangeFormat(xIndex) != RangeT::Format::Numeric);
 	if (!m_dateTimeRange) {
-		ui.leMin->setText(numberLocale.toString(m_fitData->fitRange.min()));
-		ui.leMax->setText(numberLocale.toString(m_fitData->fitRange.max()));
-		ui.leEvalMin->setText(numberLocale.toString(m_fitData->evalRange.min()));
-		ui.leEvalMax->setText(numberLocale.toString(m_fitData->evalRange.max()));
+		ui.leMin->setText(numberLocale.toString(m_fitData->fitRange.start()));
+		ui.leMax->setText(numberLocale.toString(m_fitData->fitRange.end()));
+		ui.leEvalMin->setText(numberLocale.toString(m_fitData->evalRange.start()));
+		ui.leEvalMax->setText(numberLocale.toString(m_fitData->evalRange.end()));
 	} else {
-		ui.dateTimeEditMin->setDateTime( QDateTime::fromMSecsSinceEpoch(m_fitData->fitRange.min()) );
-		ui.dateTimeEditMax->setDateTime( QDateTime::fromMSecsSinceEpoch(m_fitData->fitRange.max()) );
-		ui.dateTimeEditEvalMin->setDateTime( QDateTime::fromMSecsSinceEpoch(m_fitData->evalRange.min()) );
-		ui.dateTimeEditEvalMax->setDateTime( QDateTime::fromMSecsSinceEpoch(m_fitData->evalRange.max()) );
+		ui.dateTimeEditMin->setDateTime( QDateTime::fromMSecsSinceEpoch(m_fitData->fitRange.start()) );
+		ui.dateTimeEditMax->setDateTime( QDateTime::fromMSecsSinceEpoch(m_fitData->fitRange.end()) );
+		ui.dateTimeEditEvalMin->setDateTime( QDateTime::fromMSecsSinceEpoch(m_fitData->evalRange.start()) );
+		ui.dateTimeEditEvalMax->setDateTime( QDateTime::fromMSecsSinceEpoch(m_fitData->evalRange.end()) );
 	}
 
 	ui.leMin->setVisible(!m_dateTimeRange);
@@ -193,40 +178,40 @@ void FitOptionsWidget::autoEvalRangeChanged() {
 }
 
 void FitOptionsWidget::fitRangeMinChanged() {
-	SET_DOUBLE_FROM_LE(m_fitData->fitRange.min(), ui.leMin);
+	SET_DOUBLE_FROM_LE(m_fitData->fitRange.start(), ui.leMin);
 	changed();
 }
 void FitOptionsWidget::fitRangeMaxChanged() {
-	SET_DOUBLE_FROM_LE(m_fitData->fitRange.max(), ui.leMax);
+	SET_DOUBLE_FROM_LE(m_fitData->fitRange.end(), ui.leMax);
 	changed();
 }
 
 void FitOptionsWidget::fitRangeMinDateTimeChanged(const QDateTime& dateTime) {
-	m_fitData->fitRange.setMin(dateTime.toMSecsSinceEpoch());
+	m_fitData->fitRange.setStart(dateTime.toMSecsSinceEpoch());
 	changed();
 }
 
 void FitOptionsWidget::fitRangeMaxDateTimeChanged(const QDateTime& dateTime) {
-	m_fitData->fitRange.setMax(dateTime.toMSecsSinceEpoch());
+	m_fitData->fitRange.setEnd(dateTime.toMSecsSinceEpoch());
 	changed();
 }
 
 void FitOptionsWidget::evalRangeMinChanged() {
-	SET_DOUBLE_FROM_LE(m_fitData->evalRange.min(), ui.leEvalMin);
+	SET_DOUBLE_FROM_LE(m_fitData->evalRange.start(), ui.leEvalMin);
 	changed();
 }
 void FitOptionsWidget::evalRangeMaxChanged() {
-	SET_DOUBLE_FROM_LE(m_fitData->evalRange.max(), ui.leEvalMax);
+	SET_DOUBLE_FROM_LE(m_fitData->evalRange.end(), ui.leEvalMax);
 	changed();
 }
 
 void FitOptionsWidget::evalRangeMinDateTimeChanged(const QDateTime& dateTime) {
-	m_fitData->evalRange.setMin(dateTime.toMSecsSinceEpoch());
+	m_fitData->evalRange.setStart(dateTime.toMSecsSinceEpoch());
 	changed();
 }
 
 void FitOptionsWidget::evalRangeMaxDateTimeChanged(const QDateTime& dateTime) {
-	m_fitData->evalRange.setMax(dateTime.toMSecsSinceEpoch());
+	m_fitData->evalRange.setEnd(dateTime.toMSecsSinceEpoch());
 	changed();
 }
 
@@ -241,9 +226,9 @@ void FitOptionsWidget::applyClicked() {
 	m_fitData->confidenceInterval = ui.sbConfidenceInterval->value();
 
 	if (m_changed)
-		emit optionsChanged();
+		Q_EMIT optionsChanged();
 
-	emit finished();
+	Q_EMIT finished();
 }
 
 void FitOptionsWidget::changed() {
