@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : FitParametersWidget.cc
     Project              : LabPlot
     Description          : widget for editing fit parameters
     --------------------------------------------------------------------
-    Copyright            : (C) 2014-2016 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2016-2018 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2014-2016 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2016-2018 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 #include "FitParametersWidget.h"
 
 #include <KLocalizedString>
@@ -78,7 +60,7 @@ FitParametersWidget::FitParametersWidget(QWidget* parent) : QWidget(parent) {
 }
 
 void FitParametersWidget::setFitData(XYFitCurve::FitData* data) {
-	DEBUG("FitParametersWidget::setFitData()");
+	DEBUG(Q_FUNC_INFO);
 	m_initializing = true;
 	m_fitData = data;
 
@@ -105,7 +87,7 @@ void FitParametersWidget::setFitData(XYFitCurve::FitData* data) {
 			connect(le, SIGNAL(textChanged(QString)), this, SLOT(startValueChanged()) );
 
 			// fixed
-			QWidget* widget = new QWidget();
+			auto* widget = new QWidget();
 			auto* cb = new QCheckBox();
 			cb->setChecked(m_fitData->paramFixed.at(i));
 			auto* cbl = new QHBoxLayout(widget);
@@ -153,7 +135,7 @@ void FitParametersWidget::setFitData(XYFitCurve::FitData* data) {
 				connect(le, SIGNAL(textChanged(QString)), this, SLOT(startValueChanged()) );
 
 				// fixed
-				QWidget* widget = new QWidget();
+				auto* widget = new QWidget();
 				auto* cb = new QCheckBox();
 				cb->setChecked(m_fitData->paramFixed.at(i));
 				auto* cbl = new QHBoxLayout(widget);
@@ -196,7 +178,7 @@ void FitParametersWidget::setFitData(XYFitCurve::FitData* data) {
 			connect(le, SIGNAL(textChanged(QString)), this, SLOT(startValueChanged()) );
 
 			// fixed
-			QWidget* widget = new QWidget();
+			auto* widget = new QWidget();
 			auto* cb = new QCheckBox();
 			auto* cbl = new QHBoxLayout(widget);
 			cbl->addWidget(cb);
@@ -282,7 +264,7 @@ void FitParametersWidget::changed() {
 	DEBUG("FitParametersWidget::changed()");
 	if (!m_initializing) {
 		apply();
-		emit parametersChanged(false);
+		Q_EMIT parametersChanged(false);
 	}
 }
 
@@ -440,12 +422,12 @@ void FitParametersWidget::upperLimitChanged() {
 void FitParametersWidget::highlightInvalid(int row, int col, bool invalid) {
 	QLineEdit* le = ((QLineEdit*)ui.tableWidget->cellWidget(row, col));
 	if (invalid)
-		le->setStyleSheet("QLineEdit{background: red;}");
+		SET_WARNING_STYLE(le)
 	else
 		le->setStyleSheet(QString());
 
 	if (m_invalidRanges)
-		emit parametersValid(false);
+		Q_EMIT parametersValid(false);
 	else
-		emit parametersValid(true);
+		Q_EMIT parametersValid(true);
 }
