@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : LabelWidget.h
     Project              : LabPlot
-    --------------------------------------------------------------------
-    Copyright            : (C) 2008-2020 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2012-2014 Stefan Gerlach (stefan.gerlach@uni-konstanz.de)
     Description          : label settings widget
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2008-2020 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2012-2014 Stefan Gerlach <stefan.gerlach@uni-konstanz.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 #ifndef LABELWIDGET_H
 #define LABELWIDGET_H
 
@@ -35,7 +17,7 @@
 #include <KConfigGroup>
 
 #ifdef HAVE_KF5_SYNTAX_HIGHLIGHTING
-#include <repository.h>
+#include <KSyntaxHighlighting/repository.h>
 namespace KSyntaxHighlighting {
 	class SyntaxHighlighter;
 }
@@ -69,8 +51,8 @@ private:
 	TextLabel* m_label{nullptr};
 	QList<TextLabel*> m_labelsList;
 	QList<Axis*> m_axesList;
-	bool m_initializing{false};
 	QMenu* m_dateTimeMenu;
+	bool m_initializing{false};
 	bool m_teXEnabled{false};
 	BaseDock::Units m_units{BaseDock::Units::Metric};
 	Worksheet::Unit m_worksheetUnit{Worksheet::Unit::Centimeter};
@@ -81,14 +63,15 @@ private:
 
 	void initConnections() const;
 
-signals:
+Q_SIGNALS:
 	void dataChanged(bool);
 
-private slots:
+private Q_SLOTS:
 	//SLOTs for changes triggered in LabelWidget
 	void textChanged();
 	void charFormatChanged(const QTextCharFormat&);
-	void teXUsedChanged(bool);
+	void modeChanged(int);
+	void updateMode(TextLabel::Mode mode);
 	void fontColorChanged(const QColor&);
 	void updateBackground() const;
 	void backgroundColorChanged(const QColor&);
@@ -112,6 +95,11 @@ private slots:
 	void customPositionYChanged(double);
 	void horizontalAlignmentChanged(int);
 	void verticalAlignmentChanged(int);
+
+	void positionXLogicalChanged(const QString&);
+	void positionXLogicalDateTimeChanged(const QDateTime&);
+	void positionYLogicalChanged(const QString&);
+
 	void rotationChanged(int);
 	void offsetXChanged(double);
 	void offsetYChanged(double);
@@ -123,18 +111,22 @@ private slots:
 	void borderOpacityChanged(int);
 
 	void visibilityChanged(bool);
+	void bindingChanged(bool checked);
+	void showPlaceholderTextChanged(bool checked);
 
 	//SLOTs for changes triggered in TextLabel
 	void labelTextWrapperChanged(const TextLabel::TextWrapper&);
 	void labelTeXImageUpdated(bool);
 	void labelTeXFontChanged(const QFont&);
-	void labelFontColorChanged(const QColor);
-	void labelBackgroundColorChanged(const QColor);
+	void labelFontColorChanged(const QColor&);
+	void labelBackgroundColorChanged(const QColor&);
 	void labelPositionChanged(const TextLabel::PositionWrapper&);
 	void labelHorizontalAlignmentChanged(TextLabel::HorizontalAlignment);
 	void labelVerticalAlignmentChanged(TextLabel::VerticalAlignment);
-	void labelOffsetxChanged(qreal);
-	void labelOffsetyChanged(qreal);
+	void labelPositionLogicalChanged(QPointF);
+	void labelCoordinateBindingEnabledChanged(bool);
+	void labelOffsetXChanged(qreal);
+	void labelOffsetYChanged(qreal);
 	void labelRotationAngleChanged(qreal);
 
 	void labelBorderShapeChanged(TextLabel::BorderShape);
@@ -142,6 +134,8 @@ private slots:
 	void labelBorderOpacityChanged(float);
 
 	void labelVisibleChanged(bool);
+	void labelCartesianPlotParent(bool on);
+	void labelModeChanged(TextLabel::Mode);
 };
 
 #endif //LABELWIDGET_H
