@@ -1,30 +1,12 @@
-/***************************************************************************
-File                 : DynamicPresenterWidget.cpp
-Project              : LabPlot
-Description          : Widget for dynamic presenting of worksheets
---------------------------------------------------------------------
-Copyright            : (C) 2016 by Fabian Kristof (fkristofszabolcs@gmail.com)
-Copyright            : (C) 2018-2020 Alexander Semke (alexander.semke@web.de)
-***************************************************************************/
-
-/***************************************************************************
-*                                                                         *
-*  This program is free software; you can redistribute it and/or modify   *
-*  it under the terms of the GNU General Public License as published by   *
-*  the Free Software Foundation; either version 2 of the License, or      *
-*  (at your option) any later version.                                    *
-*                                                                         *
-*  This program is distributed in the hope that it will be useful,        *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
-*  GNU General Public License for more details.                           *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the Free Software           *
-*   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
-*   Boston, MA  02110-1301  USA                                           *
-*                                                                         *
-***************************************************************************/
+/*
+    File                 : DynamicPresenterWidget.cpp
+    Project              : LabPlot
+    Description          : Widget for dynamic presenting of worksheets
+    --------------------------------------------------------------------
+    SPDX-FileCopyrightText: 2016 Fabian Kristof <fkristofszabolcs@gmail.com>
+    SPDX-FileCopyrightText: 2018-2020 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "DynamicPresenterWidget.h"
 #include "commonfrontend/worksheet/WorksheetView.h"
 #include "SlidingPanel.h"
@@ -65,8 +47,7 @@ DynamicPresenterWidget::~DynamicPresenterWidget() {
 	delete m_view;
 }
 
-bool DynamicPresenterWidget::eventFilter(QObject* watched, QEvent* event) {
-	Q_UNUSED(watched);
+bool DynamicPresenterWidget::eventFilter(QObject* /*watched*/, QEvent* event) {
 	if (event->type() == QEvent::MouseMove) {
 		if (m_panel->y() != 0 && m_panel->rect().contains(QCursor::pos()))
 			slideDown();
