@@ -1,31 +1,13 @@
-/***************************************************************************
+/*
     File                 : ExportWorksheetDialog.cpp
     Project              : LabPlot
     Description          : export worksheet dialog
     --------------------------------------------------------------------
-    Copyright            : (C) 2011-2019 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2021 Stefan Gerlach (stefan.gerlach@uni.kn)
+    SPDX-FileCopyrightText: 2011-2019 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 
 #include "ExportWorksheetDialog.h"
 #include "ui_exportworksheetwidget.h"
@@ -85,9 +67,9 @@ ExportWorksheetDialog::ExportWorksheetDialog(QWidget* parent) : QDialog(parent),
 	ui->cbExportTo->addItem(i18n("File"));
 	ui->cbExportTo->addItem(i18n("Clipboard"));
 
-	ui->cbExportArea->addItem(i18n("Object's bounding box"));
-	ui->cbExportArea->addItem(i18n("Current selection"));
-	ui->cbExportArea->addItem(i18n("Complete worksheet"));
+	ui->cbExportArea->addItem(i18n("Object's Bounding Box"));
+	ui->cbExportArea->addItem(i18n("Current Selection"));
+	ui->cbExportArea->addItem(i18n("Complete Worksheet"));
 
 	ui->cbResolution->addItem(i18nc("%1 is the value of DPI of the current screen", "%1 (desktop)", QString::number(QApplication::desktop()->physicalDpiX())));
 	ui->cbResolution->addItem(QLatin1String("100"));
@@ -97,9 +79,9 @@ ExportWorksheetDialog::ExportWorksheetDialog(QWidget* parent) : QDialog(parent),
 	ui->cbResolution->addItem(QLatin1String("600"));
 	ui->cbResolution->setValidator(new QIntValidator(ui->cbResolution));
 
-	connect(ui->cbFormat, static_cast<void (QComboBox::*)(int)>(&KComboBox::currentIndexChanged),
+	connect(ui->cbFormat, QOverload<int>::of(&KComboBox::currentIndexChanged),
 			this, &ExportWorksheetDialog::formatChanged);
-	connect(ui->cbExportTo, static_cast<void (QComboBox::*)(int)>(&KComboBox::currentIndexChanged),
+	connect(ui->cbExportTo, QOverload<int>::of(&KComboBox::currentIndexChanged),
 			this, &ExportWorksheetDialog::exportToChanged);
 	connect(ui->bOpen, &QPushButton::clicked, this, &ExportWorksheetDialog::selectFile);
 	connect(ui->leFileName, &QLineEdit::textChanged, this, &ExportWorksheetDialog::fileNameChanged);
@@ -155,8 +137,7 @@ void ExportWorksheetDialog::setFileName(const QString& name) {
 QString ExportWorksheetDialog::path() const {
 	if (ui->cbExportTo->currentIndex() == 0)
 		return ui->leFileName->text();
-	else
-		return QString();
+	return {};
 }
 
 WorksheetView::ExportFormat ExportWorksheetDialog::exportFormat() const {
@@ -193,14 +174,15 @@ void ExportWorksheetDialog::slotButtonClicked(QAbstractButton* button) {
 
 //SLOTS
 void ExportWorksheetDialog::okClicked() {
-	if ( QFile::exists(ui->leFileName->text()) ) {
+	if (ui->cbExportTo->currentIndex() == 0 /*export to file*/
+		&& m_askOverwrite && QFile::exists(ui->leFileName->text())) {
 		int r = KMessageBox::questionYesNo(this, i18n("The file already exists. Do you really want to overwrite it?"), i18n("Export"));
 		if (r == KMessageBox::No)
 			return;
 	}
 
 	KConfigGroup conf(KSharedConfig::openConfig(), "ExportWorksheetDialog");
-	QString path = ui->leFileName->text();
+	const auto& path = ui->leFileName->text();
 	if (!path.isEmpty()) {
 		QString dir = conf.readEntry("LastDir", "");
 		int pos = path.lastIndexOf(QLatin1String("/"));
@@ -268,9 +250,16 @@ void ExportWorksheetDialog::selectFile() {
 		break;
 	}
 
-	const QString path = QFileDialog::getSaveFileName(this, i18n("Export to file"), dir, format);
+	const QString path = QFileDialog::getSaveFileName(this, i18nc("@title:window", "Export to File"), dir, format);
 	if (!path.isEmpty()) {
+		//if the file is already existing, the user was already asked
+		//in QFileDialog whether to overwrite or not.
+		//Don't ask again when the user click on Ok-button.
+		m_askOverwrite = false;
+
+		m_initializing = true;
 		ui->leFileName->setText(path);
+		m_initializing = false;
 
 		int pos = path.lastIndexOf(QLatin1String("/"));
 		if (pos != -1) {
@@ -317,13 +306,19 @@ void ExportWorksheetDialog::exportToChanged(int index) {
 	ui->leFileName->setVisible(toFile);
 	ui->bOpen->setVisible(toFile);
 
-	if (toFile)
+	if (toFile) {
 		m_okButton->setToolTip(i18n("Export to file and close the dialog."));
-	else
+		fileNameChanged(ui->leFileName->text()); //call this to check whether a valid file name was provided
+	} else {
 		m_okButton->setToolTip(i18n("Export to clipboard and close the dialog."));
+		m_okButton->setEnabled(true);
+	}
 }
 
 void ExportWorksheetDialog::fileNameChanged(const QString& name) {
+	if (m_initializing)
+		return;
+
 	if (name.simplified().isEmpty()) {
 		m_okButton->setEnabled(false);
 		return;
@@ -340,5 +335,6 @@ void ExportWorksheetDialog::fileNameChanged(const QString& name) {
 		}
 	}
 
+	m_askOverwrite = true;
 	m_okButton->setEnabled(true);
 }
