@@ -1,33 +1,16 @@
-/***************************************************************************
+/*
     File                 : TeXRenderer.cc
     Project              : LabPlot
     Description          : TeX renderer class
     --------------------------------------------------------------------
-    Copyright            : (C) 2008-2016 by Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2012 by Stefan Gerlach (stefan.gerlach@uni-konstanz.de)
+    SPDX-FileCopyrightText: 2008-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2012-2021 Stefan Gerlach <stefan.gerlach@uni-konstanz.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
 #include "TeXRenderer.h"
 #include "backend/lib/macros.h"
+#include "kdefrontend/GuiTools.h"
 
 #include <KConfigGroup>
 #include <KSharedConfig>
@@ -40,6 +23,10 @@
 #include <QTemporaryFile>
 #include <QTextStream>
 
+#ifdef HAVE_POPPLER
+#include <poppler-qt5.h>
+#endif
+
 /*!
 	\class TeXRenderer
 	\brief Implements rendering of latex code to a PNG image.
@@ -48,7 +35,7 @@
 
 	\ingroup tools
 */
-QImage TeXRenderer::renderImageLaTeX(const QString& teXString, bool* success, const TeXRenderer::Formatting& format) {
+QByteArray TeXRenderer::renderImageLaTeX(const QString& teXString, bool* success, const TeXRenderer::Formatting& format) {
 	const QColor& fontColor = format.fontColor;
 	const QColor& backgroundColor = format.backgroundColor;
 	const int fontSize = format.fontSize;
@@ -74,7 +61,7 @@ QImage TeXRenderer::renderImageLaTeX(const QString& teXString, bool* success, co
 		if (file.isEmpty()) {
 			WARN("Couldn't find preview.sty.");
 			*success = false;
-			return QImage();
+			return {};
 		}
 		else
 			QFile::copy(file, tempPath + QLatin1String("/") + QLatin1String("preview.sty"));
@@ -89,12 +76,12 @@ QImage TeXRenderer::renderImageLaTeX(const QString& teXString, bool* success, co
 	} else {
 		WARN("Couldn't open the file " << STDSTRING(file.fileName()));
 		*success = false;
-		return QImage();
+		return {};
 	}
 
 	//determine latex engine to be used
-	KConfigGroup group = KSharedConfig::openConfig()->group("Settings_Worksheet");
-	QString engine = group.readEntry("LaTeXEngine", "pdflatex");
+	const auto& group = KSharedConfig::openConfig()->group("Settings_Worksheet");
+	const auto& engine = group.readEntry("LaTeXEngine", "pdflatex");
 
 	// create latex code
 	QTextStream out(&file);
@@ -127,10 +114,12 @@ QImage TeXRenderer::renderImageLaTeX(const QString& teXString, bool* success, co
 
 	out << "\\usepackage{color}";
 	out << "\\usepackage[active,displaymath,textmath,tightpage]{preview}";
+	out << "\\setlength\\PreviewBorder{0pt}";
 	// TODO: this fails with pdflatex
 	//out << "\\usepackage{mathtools}";
 	out << "\\begin{document}";
 	out << "\\begin{preview}";
+	out << "\\setlength{\\fboxsep}{0.2pt}";
 	out << "\\colorbox[rgb]{" << backgroundColor.redF() << ',' << backgroundColor.greenF() << ',' << backgroundColor.blueF() << "}{";
 	out << "\\fontsize{" << QString::number(fontSize) << "}{" << QString::number(fontSize) << "}\\selectfont";
 	out << "\\color[rgb]{" << fontColor.redF() << ',' << fontColor.greenF() << ',' << fontColor.blueF() << "}";
@@ -139,94 +128,96 @@ QImage TeXRenderer::renderImageLaTeX(const QString& teXString, bool* success, co
 	out << "\\end{preview}";
 	out << "\\end{document}";
 	out.flush();
+
 	if (engine == "latex")
 		return imageFromDVI(file, dpi, success);
 	else
 		return imageFromPDF(file, dpi, engine, success);
 }
 
-// TEX -> PDF -> PNG
-QImage TeXRenderer::imageFromPDF(const QTemporaryFile& file, const int dpi, const QString& engine, bool* success) {
+// TEX -> PDF -> QImage
+QByteArray TeXRenderer::imageFromPDF(const QTemporaryFile& file, const int dpi, const QString& engine, bool* success) {
+	Q_UNUSED(dpi)
+	//DEBUG(Q_FUNC_INFO << ", tmp file = " << STDSTRING(file.fileName()) << ", engine = " << STDSTRING(engine) << ", dpi = " << dpi)
 	QFileInfo fi(file.fileName());
 	const QString& baseName = fi.completeBaseName();
 
-	// pdflatex: produce the PDF file
+	// produce the PDF file with 'engine'
+	const QString engineFullPath = QStandardPaths::findExecutable(engine);
+	if (engineFullPath.isEmpty()) {
+		WARN("engine " << STDSTRING(engine) << " not found");
+		return {};
+	}
+
 	QProcess latexProcess;
 #if defined(HAVE_WINDOWS)
 	latexProcess.setNativeArguments("-interaction=batchmode " + file.fileName());
-	latexProcess.start(engine, QStringList() << QString());
+	latexProcess.start(engineFullPath, QStringList() << QString());
 #else
-	latexProcess.start(engine, QStringList() << "-interaction=batchmode" << file.fileName());
+	latexProcess.start(engineFullPath, QStringList() << "-interaction=batchmode" << file.fileName());
 #endif
 
 	if (!latexProcess.waitForFinished() || latexProcess.exitCode() != 0) {
-		WARN("pdflatex process failed, exit code = " << latexProcess.exitCode());
+		WARN("LaTeX process failed, exit code = " << latexProcess.exitCode());
 		*success = false;
 		QFile::remove(baseName + ".aux");
 		QFile::remove(baseName + ".log");
-		return QImage();
+		return {};
 	}
 
-	// convert: PDF -> PNG
-	QProcess convertProcess;
-#if defined(HAVE_WINDOWS)
-	// need to set path to magick coder modules (which are in the labplot2 directory)
-	QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
-	env.insert("MAGICK_CODER_MODULE_PATH", qPrintable(qgetenv("PROGRAMFILES") + QString("\\labplot2")));
-	convertProcess.setProcessEnvironment(env);
-#endif
-
-	const QStringList params{"-density", QString::number(dpi), baseName + ".pdf", baseName + ".png"};
-	convertProcess.start("convert", params);
-
-	if (!convertProcess.waitForFinished() || convertProcess.exitCode() != 0) {
-		WARN("convert process failed, exit code = " << convertProcess.exitCode());
-		*success = false;
-		QFile::remove(baseName + ".aux");
-		QFile::remove(baseName + ".log");
-		QFile::remove(baseName + ".pdf");
-		return QImage();
-	}
-
-	// read png file
-	QImage image(baseName + ".png", "png");
-
-	// final clean up
 	QFile::remove(baseName + ".aux");
 	QFile::remove(baseName + ".log");
-	QFile::remove(baseName + ".pdf");
-	QFile::remove(baseName + ".png");
 
+	//read PDF file
+	QFile pdfFile(baseName + QLatin1String(".pdf"));
+	if (!pdfFile.open(QIODevice::ReadOnly)) {
+		QFile::remove(baseName + ".pdf");
+		return {};
+	}
+
+	QByteArray ba = pdfFile.readAll();
+ 	QFile::remove(baseName + ".pdf");
 	*success = true;
-	return image;
+
+	return ba;
 }
 
 // TEX -> DVI -> PS -> PNG
-QImage TeXRenderer::imageFromDVI(const QTemporaryFile& file, const int dpi, bool* success) {
+QByteArray TeXRenderer::imageFromDVI(const QTemporaryFile& file, const int dpi, bool* success) {
 	QFileInfo fi(file.fileName());
 	const QString& baseName = fi.completeBaseName();
 
 	//latex: produce the DVI file
+	const QString latexFullPath = QStandardPaths::findExecutable(QLatin1String("latex"));
+	if (latexFullPath.isEmpty()) {
+		WARN("latex not found");
+		return {};
+	}
 	QProcess latexProcess;
-	latexProcess.start("latex", QStringList() << "-interaction=batchmode" << file.fileName());
+	latexProcess.start(latexFullPath, QStringList() << "-interaction=batchmode" << file.fileName());
 	if (!latexProcess.waitForFinished() || latexProcess.exitCode() != 0) {
 		WARN("latex process failed, exit code = " << latexProcess.exitCode());
 		*success = false;
 		QFile::remove(baseName + ".aux");
 		QFile::remove(baseName + ".log");
-		return QImage();
+		return {};
 	}
 
 	// dvips: DVI -> PS
+	const QString dvipsFullPath = QStandardPaths::findExecutable(QLatin1String("dvips"));
+	if (dvipsFullPath.isEmpty()) {
+		WARN("dvips not found");
+		return {};
+	}
 	QProcess dvipsProcess;
-	dvipsProcess.start("dvips", QStringList() << "-E" << baseName);
+	dvipsProcess.start(dvipsFullPath, QStringList() << "-E" << baseName);
 	if (!dvipsProcess.waitForFinished() || dvipsProcess.exitCode() != 0) {
 		WARN("dvips process failed, exit code = " << dvipsProcess.exitCode());
 		*success = false;
 		QFile::remove(baseName + ".aux");
 		QFile::remove(baseName + ".log");
 		QFile::remove(baseName + ".dvi");
-		return QImage();
+		return {};
 	}
 
 	// convert: PS -> PNG
@@ -237,9 +228,14 @@ QImage TeXRenderer::imageFromDVI(const QTemporaryFile& file, const int dpi, bool
 	env.insert("MAGICK_CODER_MODULE_PATH", qPrintable(qgetenv("PROGRAMFILES") + QString("\\labplot2")));
 	convertProcess.setProcessEnvironment(env);
 #endif
+	const QString convertFullPath = QStandardPaths::findExecutable(QLatin1String("convert"));
+	if (convertFullPath.isEmpty()) {
+		WARN("convert not found");
+		return {};
+	}
 
-	const QStringList params{"-density", QString::number(dpi), baseName + ".ps", baseName + ".png"};
-	convertProcess.start("convert", params);
+	const QStringList params{"-density", QString::number(dpi), baseName + ".ps", baseName + ".pdf"};
+	convertProcess.start(convertFullPath, params);
 
 	if (!convertProcess.waitForFinished() || convertProcess.exitCode() != 0) {
 		WARN("convert process failed, exit code = " << convertProcess.exitCode());
@@ -248,21 +244,27 @@ QImage TeXRenderer::imageFromDVI(const QTemporaryFile& file, const int dpi, bool
 		QFile::remove(baseName + ".log");
 		QFile::remove(baseName + ".dvi");
 		QFile::remove(baseName + ".ps");
-		return QImage();
+		return {};
 	}
 
-	// read png file
-	QImage image(baseName + ".png", "png");
-
 	// final clean up
 	QFile::remove(baseName + ".aux");
 	QFile::remove(baseName + ".log");
 	QFile::remove(baseName + ".dvi");
 	QFile::remove(baseName + ".ps");
-	QFile::remove(baseName + ".png");
 
+	//read PDF file
+	QFile pdfFile(baseName + QLatin1String(".pdf"));
+	if (!pdfFile.open(QIODevice::ReadOnly)) {
+		QFile::remove(baseName + ".pdf");
+		return {};
+	}
+
+	QByteArray ba = pdfFile.readAll();
+ 	QFile::remove(baseName + ".pdf");
 	*success = true;
-	return image;
+
+	return ba;
 }
 
 bool TeXRenderer::enabled() {
@@ -291,33 +293,31 @@ bool TeXRenderer::enabled() {
 		return false;
 	}
 
-	//engine found, check the presence of other required tools (s.a. TeXRenderer.cpp):
-	//to convert the generated PDF/PS files to PNG we need 'convert' from the ImageMagic package
-	if (!executableExists(QLatin1String("convert"))) {
-		WARN("program \"convert\" does not exist");
-		return false;
-	}
 
-	//to convert the generated PS files to DVI we need 'dvips'
+	//Tools needed to convert generated  DVI files to PS and PDF
 	if (engine == "latex") {
+		if (!executableExists(QLatin1String("convert"))) {
+			WARN("program \"convert\" does not exist");
+			return false;
+		}
 		if (!executableExists(QLatin1String("dvips"))) {
 			WARN("program \"dvips\" does not exist");
 			return false;
 		}
-	}
 
 #if defined(_WIN64)
-	if (!executableExists(QLatin1String("gswin64c")) && !QDir(qgetenv("PROGRAMFILES") + QString("/gs")).exists()
-		&& !QDir(qgetenv("PROGRAMFILES(X86)") + QString("/gs")).exists()) {
-		WARN("ghostscript (64bit) does not exist");
-		return false;
-	}
+		if (!executableExists(QLatin1String("gswin64c")) && !QDir(qgetenv("PROGRAMFILES") + QString("/gs")).exists()
+			&& !QDir(qgetenv("PROGRAMFILES(X86)") + QString("/gs")).exists()) {
+			WARN("ghostscript (64bit) does not exist");
+			return false;
+		}
 #elif defined(HAVE_WINDOWS)
-	if (!executableExists(QLatin1String("gswin32c")) && !QDir(qgetenv("PROGRAMFILES") + QString("/gs")).exists()) {
-		WARN("ghostscript (32bit) does not exist");
-		return false;
-	}
+		if (!executableExists(QLatin1String("gswin32c")) && !QDir(qgetenv("PROGRAMFILES") + QString("/gs")).exists()) {
+			WARN("ghostscript (32bit) does not exist");
+			return false;
+		}
 #endif
+	}
 
 	return true;
 }
