@@ -1,29 +1,12 @@
-/***************************************************************************
+/*
     File                 : CorrelationTest.cpp
     Project              : LabPlot
     Description          : Tests for data correlation
     --------------------------------------------------------------------
-    Copyright            : (C) 2018 Stefan Gerlach (stefan.gerlach@uni.kn)
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "CorrelationTest.h"
 #include "backend/core/column/Column.h"
@@ -41,10 +24,10 @@ void CorrelationTest::testLinear() {
 	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -94,10 +77,10 @@ void CorrelationTest::testLinear2() {
 	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -140,10 +123,10 @@ void CorrelationTest::testLinear_noX() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -192,10 +175,10 @@ void CorrelationTest::testLinear_swapped() {
 	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -247,10 +230,10 @@ void CorrelationTest::testCircular() {
 	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -300,10 +283,10 @@ void CorrelationTest::testCircular2() {
 	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -349,10 +332,10 @@ void CorrelationTest::testLinear_biased() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -400,10 +383,10 @@ void CorrelationTest::testLinear2_biased() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -447,10 +430,10 @@ void CorrelationTest::testLinear_unbiased() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -498,10 +481,10 @@ void CorrelationTest::testLinear2_unbiased() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -545,10 +528,10 @@ void CorrelationTest::testLinear_coeff() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -597,10 +580,10 @@ void CorrelationTest::testLinear2_coeff() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -645,10 +628,10 @@ void CorrelationTest::testCircular_coeff() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -694,10 +677,10 @@ void CorrelationTest::testCircular2_coeff() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -743,10 +726,10 @@ void CorrelationTest::testLinear_samplingInterval() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -794,10 +777,10 @@ void CorrelationTest::testLinear2_samplingInterval() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -842,10 +825,10 @@ void CorrelationTest::testCircular_samplingInterval() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -889,10 +872,10 @@ void CorrelationTest::testCircular2_samplingInterval() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -943,10 +926,10 @@ void CorrelationTest::testPerformance() {
 	}
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
