@@ -1,29 +1,12 @@
-/***************************************************************************
+/*
     File                 : DifferentiationTest.cpp
     Project              : LabPlot
     Description          : Tests for numerical differentiation
     --------------------------------------------------------------------
-    Copyright            : (C) 2018 Stefan Gerlach (stefan.gerlach@uni.kn)
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2018-2022 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "DifferentiationTest.h"
 #include "backend/core/column/Column.h"
@@ -40,7 +23,7 @@ void DifferentiationTest::testLinear() {
 	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
 	XYDifferentiationCurve differentiationCurve("differentiation");
@@ -80,10 +63,10 @@ void DifferentiationTest::testLinearNonEquidistant() {
 	QVector<double> yData = {1.,1.5,3.,5.};
 
 	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Numeric);
+	Column xDataColumn("x", AbstractColumn::ColumnMode::Double);
 	xDataColumn.replaceValues(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
 	XYDifferentiationCurve differentiationCurve("differentiation");
@@ -123,10 +106,10 @@ void DifferentiationTest::testQuadratic() {
 	QVector<double> yData = {1.,4.,9.,16.};
 
 	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Numeric);
+	Column xDataColumn("x", AbstractColumn::ColumnMode::Double);
 	xDataColumn.replaceValues(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
 	XYDifferentiationCurve differentiationCurve("differentiation");
@@ -166,10 +149,10 @@ void DifferentiationTest::testQuadraticNonEquidistant() {
 	QVector<double> yData = {1.,2.25,9.,25.};
 
 	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Numeric);
+	Column xDataColumn("x", AbstractColumn::ColumnMode::Double);
 	xDataColumn.replaceValues(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
 	XYDifferentiationCurve differentiationCurve("differentiation");
@@ -209,10 +192,10 @@ void DifferentiationTest::testQuadraticSecondOrder() {
 	QVector<double> yData = {1.,4.,9.,16.};
 
 	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Numeric);
+	Column xDataColumn("x", AbstractColumn::ColumnMode::Double);
 	xDataColumn.replaceValues(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
 	XYDifferentiationCurve differentiationCurve("differentiation");
@@ -253,10 +236,10 @@ void DifferentiationTest::testCubicSecondOrder() {
 	QVector<double> yData = {1.,8.,27.,64.};
 
 	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Numeric);
+	Column xDataColumn("x", AbstractColumn::ColumnMode::Double);
 	xDataColumn.replaceValues(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
 	XYDifferentiationCurve differentiationCurve("differentiation");
@@ -297,10 +280,10 @@ void DifferentiationTest::testCubicThirdOrder() {
 	QVector<double> yData = {1.,8.,27.,64.,125.};
 
 	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Numeric);
+	Column xDataColumn("x", AbstractColumn::ColumnMode::Double);
 	xDataColumn.replaceValues(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
 	XYDifferentiationCurve differentiationCurve("differentiation");
@@ -336,4 +319,58 @@ void DifferentiationTest::testCubicThirdOrder() {
 	QCOMPARE(resultYDataColumn->valueAt(4), 6.);
 }
 
+void DifferentiationTest::testLinearDuplicateX() {
+	// data
+	QVector<int> xData = {1,1,2,2,3,4,4,4,5,5};
+	QVector<double> yData = {1.,2.,3.,4.,5.,6.,7.,8.,9.,10.};
+
+	//data source columns
+	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
+	xDataColumn.replaceInteger(0, xData);
+
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	yDataColumn.replaceValues(0, yData);
+
+	XYDifferentiationCurve differentiationCurve("differentiation");
+	differentiationCurve.setXDataColumn(&xDataColumn);
+	differentiationCurve.setYDataColumn(&yDataColumn);
+
+	//prepare the differentiation
+	XYDifferentiationCurve::DifferentiationData differentiationData = differentiationCurve.differentiationData();
+	differentiationCurve.setDifferentiationData(differentiationData);
+
+	//perform the differentiation
+	differentiationCurve.recalculate();
+	const XYDifferentiationCurve::DifferentiationResult& differentiationResult = differentiationCurve.differentiationResult();
+
+	/*for (int i = 0; i < 5; i++)
+		QCOMPARE(xDataColumn.valueAt(i), (double)i + 1);
+
+	QCOMPARE(yDataColumn.valueAt(0), 1.5);
+	QCOMPARE(yDataColumn.valueAt(1), 3.5);
+	QCOMPARE(yDataColumn.valueAt(2), 5.);
+	QCOMPARE(yDataColumn.valueAt(3), 7.);
+	QCOMPARE(yDataColumn.valueAt(4), 9.5);
+	*/
+
+	//check the results
+	QCOMPARE(differentiationResult.available, true);
+	QCOMPARE(differentiationResult.valid, true);
+
+	const AbstractColumn* resultXDataColumn = differentiationCurve.xColumn();
+	const AbstractColumn* resultYDataColumn = differentiationCurve.yColumn();
+
+	const int np = resultXDataColumn->rowCount();
+	QCOMPARE(np, 5);
+
+	for (int i = 0; i < np; i++)
+		QCOMPARE(resultXDataColumn->valueAt(i), (double)i + 1);
+
+	QCOMPARE(resultYDataColumn->valueAt(0), 2.25);
+	QCOMPARE(resultYDataColumn->valueAt(1), 1.75);
+	QCOMPARE(resultYDataColumn->valueAt(2), 3.);
+	QCOMPARE(resultYDataColumn->valueAt(3), 2.5);
+	QCOMPARE(resultYDataColumn->valueAt(4), -1.5);
+}
+
 QTEST_MAIN(DifferentiationTest)
