@@ -1,41 +1,18 @@
-/***************************************************************************
+/*
     File                 : AsciiFilterTest.cpp
     Project              : LabPlot
     Description          : Tests for the ascii filter
     --------------------------------------------------------------------
-    Copyright            : (C) 2017 Alexander Semke (alexander.semke@web.de)
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2022 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "AsciiFilterTest.h"
 #include "backend/datasources/filters/AsciiFilter.h"
 #include "backend/spreadsheet/Spreadsheet.h"
 
-void AsciiFilterTest::initTestCase() {
-	// needed in order to have the signals triggered by SignallingUndoCommand, see LabPlot.cpp
-	//TODO: redesign/remove this
-	qRegisterMetaType<const AbstractAspect*>("const AbstractAspect*");
-	qRegisterMetaType<const AbstractColumn*>("const AbstractColumn*");
-}
-
 //##############################################################################
 //#################  handling of empty and sparse files ########################
 //##############################################################################
@@ -46,9 +23,8 @@ void AsciiFilterTest::testEmptyFileAppend() {
 	const int rowCount = spreadsheet.rowCount();
 	const int colCount = spreadsheet.columnCount();
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/empty_file.txt"));
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Append;
 
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Append);
 
 	QCOMPARE(spreadsheet.rowCount(), rowCount);
 	QCOMPARE(spreadsheet.columnCount(), colCount);
@@ -61,9 +37,8 @@ void AsciiFilterTest::testEmptyFilePrepend() {
 	const int rowCount = spreadsheet.rowCount();
 	const int colCount = spreadsheet.columnCount();
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/empty_file.txt"));
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Prepend;
 
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Prepend);
 
 	QCOMPARE(spreadsheet.rowCount(), rowCount);
 	QCOMPARE(spreadsheet.columnCount(), colCount);
@@ -76,8 +51,7 @@ void AsciiFilterTest::testEmptyFileReplace() {
 	const int rowCount = spreadsheet.rowCount();
 	const int colCount = spreadsheet.columnCount();
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/empty_file.txt"));
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	QCOMPARE(spreadsheet.rowCount(), rowCount);
 	QCOMPARE(spreadsheet.columnCount(), colCount);
@@ -88,10 +62,9 @@ void AsciiFilterTest::testEmptyLines01() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/empty_lines_01.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
-	filter.setHeaderEnabled(true);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	//filter.setHeaderEnabled(true);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	QCOMPARE(spreadsheet.rowCount(), 3);
 	QCOMPARE(spreadsheet.columnCount(), 3);
@@ -120,11 +93,10 @@ void AsciiFilterTest::testSparseFile01() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/sparse_file_01.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
-	filter.setHeaderEnabled(true);
+	//filter.setHeaderEnabled(true);
 	filter.setSimplifyWhitespacesEnabled(true);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	QCOMPARE(spreadsheet.rowCount(), 3);
 	QCOMPARE(spreadsheet.columnCount(), 3);
@@ -155,13 +127,12 @@ void AsciiFilterTest::testSparseFile02() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/sparse_file_02.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
 	filter.setNaNValueToZero(false);
 	filter.setSimplifyWhitespacesEnabled(true);
 	filter.setSkipEmptyParts(false);
-	filter.setHeaderEnabled(true);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	//filter.setHeaderEnabled(true);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	QCOMPARE(spreadsheet.rowCount(), 3);
 	QCOMPARE(spreadsheet.columnCount(), 3);
@@ -171,8 +142,8 @@ void AsciiFilterTest::testSparseFile02() {
 	QCOMPARE(spreadsheet.column(2)->name(), QLatin1String("Col2"));
 
 	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
 	QCOMPARE(spreadsheet.column(0)->integerAt(1), 2);
@@ -192,13 +163,12 @@ void AsciiFilterTest::testSparseFile03() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/sparse_file_03.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
 	filter.setNaNValueToZero(true);
 	filter.setSimplifyWhitespacesEnabled(true);
 	filter.setSkipEmptyParts(false);
-	filter.setHeaderEnabled(true);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	//filter.setHeaderEnabled(true);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	QCOMPARE(spreadsheet.rowCount(), 4);
 	QCOMPARE(spreadsheet.columnCount(), 3);
@@ -208,8 +178,8 @@ void AsciiFilterTest::testSparseFile03() {
 	QCOMPARE(spreadsheet.column(2)->name(), QLatin1String("Col2"));
 
 	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
 	QCOMPARE(spreadsheet.column(0)->integerAt(1), 2);
@@ -235,11 +205,10 @@ void AsciiFilterTest::testHeader01() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/separator_semicolon.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(";");
 	filter.setHeaderEnabled(false);
 	filter.setVectorNames(QString());
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	QCOMPARE(spreadsheet.rowCount(), 3);
 	QCOMPARE(spreadsheet.columnCount(), 2);
@@ -250,11 +219,10 @@ void AsciiFilterTest::testHeader02() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/separator_semicolon.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(";");
-	filter.setHeaderEnabled(true);
+	//filter.setHeaderEnabled(true);
 	filter.setVectorNames(QString());
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	QCOMPARE(spreadsheet.rowCount(), 2);//out of 3 rows one row is used for the column names (header)
 	QCOMPARE(spreadsheet.columnCount(), 2);
@@ -270,11 +238,10 @@ void AsciiFilterTest::testHeader03() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/separator_semicolon.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(";");
 	filter.setHeaderEnabled(false);
 	filter.setVectorNames("x");
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	QCOMPARE(spreadsheet.rowCount(), 3);
 	QCOMPARE(spreadsheet.columnCount(), 1); //one column name was specified, we import only one column
@@ -286,11 +253,10 @@ void AsciiFilterTest::testHeader04() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/separator_semicolon.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(";");
 	filter.setHeaderEnabled(false);
 	filter.setVectorNames("x");
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	QCOMPARE(spreadsheet.rowCount(), 3);
 	QCOMPARE(spreadsheet.columnCount(), 1); //one column name was specified -> we import only one column
@@ -302,11 +268,10 @@ void AsciiFilterTest::testHeader05() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/separator_semicolon.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(";");
 	filter.setHeaderEnabled(false);
 	filter.setVectorNames("x y");
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	QCOMPARE(spreadsheet.rowCount(), 3);
 	QCOMPARE(spreadsheet.columnCount(), 2); //two names were specified -> we import two columns
@@ -319,11 +284,10 @@ void AsciiFilterTest::testHeader06() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/separator_semicolon.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(";");
 	filter.setHeaderEnabled(false);
 	filter.setVectorNames("x y z");
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	QCOMPARE(spreadsheet.rowCount(), 3);
 	QCOMPARE(spreadsheet.columnCount(), 2); //three names were specified, but there're only two columns in the file -> we import only two columns
@@ -341,12 +305,11 @@ void AsciiFilterTest::testHeader07() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/comment_header_comment.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("TAB");
-	filter.setStartRow(2);
-	filter.setHeaderEnabled(true);
+	filter.setHeaderLine(2);
+	//filter.setHeaderEnabled(true);
 	filter.setDateTimeFormat(QLatin1String("yyyy-MM-dd hh:mm:ss.zzz"));
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//spreadsheet size
 	QCOMPARE(spreadsheet.columnCount(), 3);
@@ -359,8 +322,8 @@ void AsciiFilterTest::testHeader07() {
 
 	//data types
 	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//values
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 0);
@@ -380,6 +343,50 @@ void AsciiFilterTest::testHeader07() {
 	QCOMPARE(spreadsheet.column(2)->valueAt(3), 0.3433);
 }
 
+/*!
+ * test with a file containing the header in the second line
+ * with a subsequent comment line ignored by using startRow.
+ */
+void AsciiFilterTest::testHeader07a() {
+	Spreadsheet spreadsheet("test", false);
+	AsciiFilter filter;
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/comment_header_comment.txt"));
+
+	filter.setSeparatingCharacter("TAB");
+	filter.setHeaderLine(2);
+	//filter.setHeaderEnabled(true);
+	filter.setStartRow(4);
+	filter.setDateTimeFormat(QLatin1String("yyyy-MM-dd hh:mm:ss.zzz"));
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
+
+	//spreadsheet size
+	QCOMPARE(spreadsheet.columnCount(), 3);
+	QCOMPARE(spreadsheet.rowCount(), 3);
+
+	//column names
+	QCOMPARE(spreadsheet.column(0)->name(), QLatin1String("counter"));
+	QCOMPARE(spreadsheet.column(1)->name(), QLatin1String("t[min]"));
+	QCOMPARE(spreadsheet.column(2)->name(), QLatin1String("#1ch1"));
+
+	//data types
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Double);
+
+	//values
+	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
+	QCOMPARE(spreadsheet.column(1)->valueAt(0), 0.0513);
+	QCOMPARE(spreadsheet.column(2)->valueAt(0), 0.3448);
+
+	QCOMPARE(spreadsheet.column(0)->integerAt(1), 2);
+	QCOMPARE(spreadsheet.column(1)->valueAt(1), 0.1005);
+	QCOMPARE(spreadsheet.column(2)->valueAt(1), 0.3418);
+
+	QCOMPARE(spreadsheet.column(0)->integerAt(2), 3);
+	QCOMPARE(spreadsheet.column(1)->valueAt(2), 0.1516);
+	QCOMPARE(spreadsheet.column(2)->valueAt(2), 0.3433);
+}
+
 /*!
  * the header contains spaces in the column names, values are tab separated.
  * when using "auto" for the separator characters, the tab character has to
@@ -390,10 +397,8 @@ void AsciiFilterTest::testHeader08() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/separator_tab_with_header_with_spaces.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
-	filter.setSeparatingCharacter("auto");
-	filter.setHeaderEnabled(true);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	//filter.setHeaderEnabled(true);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//spreadsheet size
 	QCOMPARE(spreadsheet.columnCount(), 2);
@@ -423,18 +428,17 @@ void AsciiFilterTest::testColumnRange00() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//no ranges specified, all rows and columns have to be read
 	QCOMPARE(spreadsheet.rowCount(), 5);
 	QCOMPARE(spreadsheet.columnCount(), 3);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//check the values for the first line
 	QCOMPARE(spreadsheet.column(0)->valueAt(0), 1.716299);
@@ -447,20 +451,19 @@ void AsciiFilterTest::testColumnRange01() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setCreateIndexEnabled(true);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//no ranges specified, all rows and columns have to be read plus the additional column for the index
 	QCOMPARE(spreadsheet.rowCount(), 5);
 	QCOMPARE(spreadsheet.columnCount(), 4);
 
 	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//check the values for the first line
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
@@ -474,19 +477,18 @@ void AsciiFilterTest::testColumnRange02() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setStartColumn(2);
 	filter.setEndColumn(3);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//read all rows and the last two columns only
 	QCOMPARE(spreadsheet.rowCount(), 5);
 	QCOMPARE(spreadsheet.columnCount(), 2);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//check the values for the first line
 	QCOMPARE(spreadsheet.column(0)->valueAt(0), -0.485527);
@@ -498,21 +500,20 @@ void AsciiFilterTest::testColumnRange03() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setCreateIndexEnabled(true);
 	filter.setStartColumn(2);
 	filter.setEndColumn(3);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//read all rows and the last two columns only plus the additional column for the index
 	QCOMPARE(spreadsheet.rowCount(), 5);
 	QCOMPARE(spreadsheet.columnCount(), 3);
 
 	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//check the values for the first line
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
@@ -525,18 +526,17 @@ void AsciiFilterTest::testColumnRange04() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setStartColumn(3);
 	filter.setEndColumn(3);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//read all rows and the last column only
 	QCOMPARE(spreadsheet.rowCount(), 5);
 	QCOMPARE(spreadsheet.columnCount(), 1);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//check the values for the first line
 	QCOMPARE(spreadsheet.column(0)->valueAt(0), -0.288690);
@@ -547,12 +547,11 @@ void AsciiFilterTest::testColumnRange05() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setStartColumn(3);
 	filter.setEndColumn(2);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//wrong column range specified (start>end), nothing to read,
 	//empty spreadsheet because of the replace mode
@@ -565,13 +564,12 @@ void AsciiFilterTest::testColumnRange06() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setCreateIndexEnabled(true);
 	filter.setStartColumn(3);
 	filter.setEndColumn(2);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//wrong column range specified (start>end), only the index column is created
 	QCOMPARE(spreadsheet.rowCount(), 5);
@@ -586,20 +584,19 @@ void AsciiFilterTest::testRowRange00() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setStartRow(3);
 	filter.setEndRow(5);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//three rows to read
 	QCOMPARE(spreadsheet.rowCount(), 3);
 	QCOMPARE(spreadsheet.columnCount(), 3);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//check the values for the first and for the last lines
 	QCOMPARE(spreadsheet.column(0)->valueAt(0), 1.711721);
@@ -616,20 +613,19 @@ void AsciiFilterTest::testRowRange01() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setStartRow(3);
 	filter.setEndRow(10);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//end row larger than the number of available rows, three rows to read
 	QCOMPARE(spreadsheet.rowCount(), 3);
 	QCOMPARE(spreadsheet.columnCount(), 3);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//check the values for the first and for the last lines
 	QCOMPARE(spreadsheet.column(0)->valueAt(0), 1.711721);
@@ -646,12 +642,11 @@ void AsciiFilterTest::testRowRange02() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setStartRow(3);
 	filter.setEndRow(1);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//start bigger than end, no rows to read
 	//wrong row range specified (start>end), nothing to read,
@@ -666,21 +661,20 @@ void AsciiFilterTest::testRowColumnRange00() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setStartRow(3);
 	filter.setEndRow(5);
 	filter.setStartColumn(2);
 	filter.setEndColumn(3);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//three rows and two columns to read
 	QCOMPARE(spreadsheet.rowCount(), 3);
 	QCOMPARE(spreadsheet.columnCount(), 2);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//check the values for the first and for the last lines
 	QCOMPARE(spreadsheet.column(0)->valueAt(0), -0.485527);
@@ -703,11 +697,10 @@ void AsciiFilterTest::testQuotedStrings00() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/quoted_strings.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
 	filter.setHeaderEnabled(false);
 	filter.setRemoveQuotesEnabled(true);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//three rows and two columns to read
 	QCOMPARE(spreadsheet.rowCount(), 3);
@@ -716,7 +709,7 @@ void AsciiFilterTest::testQuotedStrings00() {
 	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Text);
 	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Integer);
 	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Integer);
-	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	QCOMPARE(spreadsheet.column(0)->textAt(0), QLatin1String("a"));
 	QCOMPARE(spreadsheet.column(1)->integerAt(0), 1000);
@@ -739,12 +732,11 @@ void AsciiFilterTest::testQuotedStrings01() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/quoted_strings_with_header.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
-	filter.setHeaderEnabled(true);
+	//filter.setHeaderEnabled(true);
 	filter.setSimplifyWhitespacesEnabled(true);
 	filter.setRemoveQuotesEnabled(true);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//three rows and two columns to read
 	QCOMPARE(spreadsheet.rowCount(), 3);
@@ -760,7 +752,7 @@ void AsciiFilterTest::testQuotedStrings01() {
 	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Text);
 	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Integer);
 	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Integer);
-	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//values
 	QCOMPARE(spreadsheet.column(0)->textAt(0), QLatin1String("a"));
@@ -786,11 +778,10 @@ void AsciiFilterTest::testQuotedStrings02() {
 
 	QCOMPARE(QFile::exists(fileName), true);
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
 	filter.setHeaderEnabled(false);
 	filter.setRemoveQuotesEnabled(true);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//three rows and two columns to read
 // 	QCOMPARE(spreadsheet.rowCount(), 1);
@@ -799,7 +790,7 @@ void AsciiFilterTest::testQuotedStrings02() {
 	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Text);
 	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Integer);
 	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Integer);
-	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	QCOMPARE(spreadsheet.column(0)->textAt(0), QLatin1String("a"));
 	QCOMPARE(spreadsheet.column(1)->integerAt(0), 1000);
@@ -812,12 +803,11 @@ void AsciiFilterTest::testQuotedStrings03() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/quoted_strings_one_line_with_header.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
-	filter.setHeaderEnabled(true);
+	//filter.setHeaderEnabled(true);
 	filter.setSimplifyWhitespacesEnabled(true);
 	filter.setRemoveQuotesEnabled(true);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//three rows and two columns to read
 // 	QCOMPARE(spreadsheet.rowCount(), 1);
@@ -833,7 +823,7 @@ void AsciiFilterTest::testQuotedStrings03() {
 	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Text);
 	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Integer);
 	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Integer);
-	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//values
 	QCOMPARE(spreadsheet.column(0)->textAt(0), QLatin1String("a"));
@@ -851,15 +841,14 @@ void AsciiFilterTest::testComments00() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/multi_line_comment.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	QCOMPARE(spreadsheet.columnCount(), 2);
 
 	//data types
 	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//values
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
@@ -874,15 +863,14 @@ void AsciiFilterTest::testComments01() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/multi_line_comment_with_empty_lines.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	QCOMPARE(spreadsheet.columnCount(), 2);
 
 	//data types
 	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//values
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
@@ -900,11 +888,10 @@ void AsciiFilterTest::testComments02() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/separator_semicolon_with_header.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setCommentCharacter("");
 	filter.setSeparatingCharacter(";");
-	filter.setHeaderEnabled(true);
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	//filter.setHeaderEnabled(true);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//spreadsheet size
 	QCOMPARE(spreadsheet.columnCount(), 2);
@@ -943,11 +930,10 @@ void AsciiFilterTest::testDateTime00() {
 	AsciiFilter filter;
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/datetime_01.csv"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
-	filter.setHeaderEnabled(true);
+	//filter.setHeaderEnabled(true);
 	filter.setDateTimeFormat(QLatin1String("dd/MM/yy hh:mm:ss"));
-	filter.readDataFromFile(fileName, &spreadsheet, mode);
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	//spreadsheet size
 	QCOMPARE(spreadsheet.columnCount(), 2);
@@ -959,10 +945,10 @@ void AsciiFilterTest::testDateTime00() {
 
 	//data types
 	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::DateTime);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//values
-	QDateTime value = QDateTime::fromString(QLatin1String("01/01/2019 00:00:00"), QLatin1String("dd/MM/yyyy hh:mm:ss"));
+	auto value = QDateTime::fromString(QLatin1String("01/01/2019 00:00:00"), QLatin1String("dd/MM/yyyy hh:mm:ss"));
 	QCOMPARE(spreadsheet.column(0)->dateTimeAt(0), value);
 	QCOMPARE(spreadsheet.column(1)->valueAt(0), 14.7982);
 
@@ -971,4 +957,60 @@ void AsciiFilterTest::testDateTime00() {
 	QCOMPARE(spreadsheet.column(1)->valueAt(1), 14.8026);
 }
 
+/* read datetime data before big int
+ *  TODO: handle hex value
+ */
+void AsciiFilterTest::testDateTimeHex() {
+	Spreadsheet spreadsheet("test", false);
+	AsciiFilter filter;
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/datetime-hex.dat"));
+
+	filter.setHeaderEnabled(false);
+	filter.setSeparatingCharacter("|");
+	filter.setDateTimeFormat(QLatin1String("yyyyMMddhhmmss"));
+	filter.readDataFromFile(fileName, &spreadsheet, AbstractFileFilter::ImportMode::Replace);
+
+	//spreadsheet size
+	QCOMPARE(spreadsheet.columnCount(), 17);
+	QCOMPARE(spreadsheet.rowCount(), 1);
+
+	//data types
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::DateTime);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Text);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(4)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(5)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(6)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(7)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(8)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(9)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(10)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(11)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(12)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(13)->columnMode(), AbstractColumn::ColumnMode::Text);
+	QCOMPARE(spreadsheet.column(14)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(spreadsheet.column(15)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(16)->columnMode(), AbstractColumn::ColumnMode::Text);
+
+	auto value = QDateTime::fromString(QLatin1String("18/12/2019 02:36:08"), QLatin1String("dd/MM/yyyy hh:mm:ss"));
+	QCOMPARE(spreadsheet.column(0)->dateTimeAt(0), value);
+	QCOMPARE(spreadsheet.column(1)->textAt(0), QLatin1String("F"));
+	QCOMPARE(spreadsheet.column(2)->integerAt(0), 1000);
+	QCOMPARE(spreadsheet.column(3)->integerAt(0), 0);
+	QCOMPARE(spreadsheet.column(4)->integerAt(0), 0);
+	QCOMPARE(spreadsheet.column(5)->integerAt(0), 3190);
+	QCOMPARE(spreadsheet.column(6)->integerAt(0), 528);
+	QCOMPARE(spreadsheet.column(7)->integerAt(0), 3269);
+	QCOMPARE(spreadsheet.column(8)->integerAt(0), 15);
+	QCOMPARE(spreadsheet.column(9)->integerAt(0), 9);
+	QCOMPARE(spreadsheet.column(10)->valueAt(0), 1.29);
+	QCOMPARE(spreadsheet.column(11)->integerAt(0), 934);
+	QCOMPARE(spreadsheet.column(12)->integerAt(0), -105);
+	QCOMPARE(spreadsheet.column(13)->textAt(0), QLatin1String("G 03935"));
+	QCOMPARE(spreadsheet.column(14)->valueAt(0), 94.09);
+	QCOMPARE(spreadsheet.column(15)->integerAt(0), 9680);
+	QCOMPARE(spreadsheet.column(16)->textAt(0), QLatin1String("5AD17"));
+}
+
 QTEST_MAIN(AsciiFilterTest)
