@@ -1,29 +1,12 @@
-/***************************************************************************
+/*
     File                 : SpreadsheetTest.cpp
     Project              : LabPlot
     Description          : Tests for the Spreadsheet
     --------------------------------------------------------------------
-    Copyright            : (C) 2020 Alexander Semke (alexander.semke@web.de)
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2020 Alexander Semke <alexander.semke@web.de>
 
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "SpreadsheetTest.h"
 #include "backend/spreadsheet/Spreadsheet.h"
@@ -74,8 +57,8 @@ void SpreadsheetTest::testCopyPasteColumnMode00() {
 	QCOMPARE(sheet.rowCount(), 100);
 
 	//column modes
-	QCOMPARE(sheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(sheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(sheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(sheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//values
 	QCOMPARE(sheet.column(0)->valueAt(0), 10.0);
@@ -85,8 +68,8 @@ void SpreadsheetTest::testCopyPasteColumnMode00() {
 }
 
 /*!
-   insert one column with integer values and one column with float numbers into an empty spreadsheet.
-   the first column has to be converted to integer column.
+   insert one column with integer and one column with big integer values into an empty spreadsheet.
+   the first column has to be converted to integer column, the second to big integer.
 */
 void SpreadsheetTest::testCopyPasteColumnMode01() {
 	Spreadsheet sheet("test", false);
@@ -116,8 +99,8 @@ void SpreadsheetTest::testCopyPasteColumnMode01() {
 }
 
 /*!
-   insert one column with integer and one column with big integer values into an empty spreadsheet.
-   the first column has to be converted to integer column, the second to big integer.
+   insert one column with integer values and one column with float numbers into an empty spreadsheet.
+   the first column has to be converted to integer column, the second to float.
 */
 void SpreadsheetTest::testCopyPasteColumnMode02() {
 	Spreadsheet sheet("test", false);
@@ -136,7 +119,7 @@ void SpreadsheetTest::testCopyPasteColumnMode02() {
 
 	//column modes
 	QCOMPARE(sheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
-	QCOMPARE(sheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(sheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//values
 	QCOMPARE(sheet.column(0)->integerAt(0), 10);
@@ -171,9 +154,9 @@ void SpreadsheetTest::testCopyPasteColumnMode03() {
 
 	//column modes
 	QCOMPARE(sheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
-	QCOMPARE(sheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(sheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
 	QCOMPARE(sheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Integer);
-	QCOMPARE(sheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(sheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Double);
 	QCOMPARE(sheet.column(4)->columnMode(), AbstractColumn::ColumnMode::Integer);
 
 	//values
@@ -230,7 +213,7 @@ void SpreadsheetTest::testCopyPasteColumnMode04() {
 
 	//column modes
 	QCOMPARE(sheet.column(0)->columnMode(), AbstractColumn::ColumnMode::DateTime);
-	QCOMPARE(sheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(sheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//values
 	auto* filter = static_cast<DateTime2StringFilter*>(sheet.column(0)->outputFilter());
@@ -265,7 +248,7 @@ void SpreadsheetTest::testCopyPasteColumnMode05() {
 
 	//column modes
 	QCOMPARE(sheet.column(0)->columnMode(), AbstractColumn::ColumnMode::DateTime);
-	QCOMPARE(sheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(sheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//values
 	auto* filter = static_cast<DateTime2StringFilter*>(sheet.column(0)->outputFilter());
@@ -353,8 +336,8 @@ void SpreadsheetTest::testCopyPasteSizeChange00() {
 	QCOMPARE(sheet->rowCount(), 100);
 
 	//column modes
-	QCOMPARE(sheet->column(0)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(sheet->column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(sheet->column(0)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(sheet->column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//values
 	QCOMPARE((bool)std::isnan(sheet->column(0)->valueAt(0)), true);
@@ -398,9 +381,9 @@ void SpreadsheetTest::testCopyPasteSizeChange01() {
 	QCOMPARE(sheet.rowCount(), 100);
 
 	//column modes
-	QCOMPARE(sheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(sheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
-	QCOMPARE(sheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(sheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(sheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Double);
+	QCOMPARE(sheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Double);
 
 	//values
 	QCOMPARE((bool)std::isnan(sheet.column(0)->valueAt(0)), true);
@@ -1087,6 +1070,7 @@ void SpreadsheetTest::testSortPerformanceNumeric1() {
 	sheet.setRowCount(10000);
 
 	QVector<double> xData;
+	WARN("CREATE DATA")
 	for (int i = 0; i < sheet.rowCount(); i++)
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
 		xData << QRandomGenerator::global()->generateDouble();
@@ -1113,6 +1097,7 @@ void SpreadsheetTest::testSortPerformanceNumeric2() {
 
 	QVector<double> xData;
 	QVector<int> yData;
+	WARN("CREATE DATA")
 	for (int i = 0; i < sheet.rowCount(); i++) {
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
 		xData << QRandomGenerator::global()->generateDouble();
